/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/projects/b1198/epifluidlab/yoshii/software/conda/envs/revealer/lib/python3.9/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/projects/b1198/epifluidlab/yoshii/software/conda/envs/revealer/lib/python3.9/site-packages/numpy/core/include/numpy/arrayscalars.h",
            "/projects/b1198/epifluidlab/yoshii/software/conda/envs/revealer/lib/python3.9/site-packages/numpy/core/include/numpy/ndarrayobject.h",
            "/projects/b1198/epifluidlab/yoshii/software/conda/envs/revealer/lib/python3.9/site-packages/numpy/core/include/numpy/ndarraytypes.h",
            "/projects/b1198/epifluidlab/yoshii/software/conda/envs/revealer/lib/python3.9/site-packages/numpy/core/include/numpy/ufuncobject.h"
        ],
        "include_dirs": [
            "/projects/b1198/epifluidlab/yoshii/software/conda/envs/revealer/lib/python3.9/site-packages/numpy/core/include"
        ],
        "name": "revealer.REVEALER_runbenchmark",
        "sources": [
            "src/revealer/REVEALER_runbenchmark.pyx"
        ]
    },
    "module_name": "revealer.REVEALER_runbenchmark"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__revealer__REVEALER_runbenchmark
#define __PYX_HAVE_API__revealer__REVEALER_runbenchmark
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"

    /* NumPy API declarations from "numpy/__init__.pxd" */
    
#include <float.h>
#include <limits.h>
#include <math.h>
#include <stdlib.h>
#include "limits.h"
#include "pythread.h"
#include "pystate.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "src/revealer/REVEALER_runbenchmark.pyx",
  "__init__.pxd",
  "stringsource",
  "type.pxd",
};
/* MemviewSliceStruct.proto */
struct __pyx_memoryview_obj;
typedef struct {
  struct __pyx_memoryview_obj *memview;
  char *data;
  Py_ssize_t shape[8];
  Py_ssize_t strides[8];
  Py_ssize_t suboffsets[8];
} __Pyx_memviewslice;
#define __Pyx_MemoryView_Len(m)  (m.shape[0])

/* Atomics.proto */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __pyx_atomic_int_type int
#if CYTHON_ATOMICS && __GNUC__ >= 4 && (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL >= 2)) &&\
                    !defined(__i386__)
    #define __pyx_atomic_incr_aligned(value, lock) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_aligned(value, lock) __sync_fetch_and_sub(value, 1)
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER) && 0
    #include <Windows.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type LONG
    #define __pyx_atomic_incr_aligned(value, lock) InterlockedIncrement(value)
    #define __pyx_atomic_decr_aligned(value, lock) InterlockedDecrement(value)
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#elif CYTHON_ATOMICS && (defined(__ICC) || defined(__INTEL_COMPILER)) && 0
    #define __pyx_atomic_incr_aligned(value, lock) _InterlockedIncrement(value)
    #define __pyx_atomic_decr_aligned(value, lock) _InterlockedDecrement(value)
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using Intel atomics"
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif
typedef volatile __pyx_atomic_int_type __pyx_atomic_int;
#if CYTHON_ATOMICS
    #define __pyx_add_acquisition_count(memview)\
             __pyx_atomic_incr_aligned(__pyx_get_slice_count_pointer(memview), memview->lock)
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_atomic_decr_aligned(__pyx_get_slice_count_pointer(memview), memview->lock)
#else
    #define __pyx_add_acquisition_count(memview)\
            __pyx_add_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_sub_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
#endif

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* BufferFormatStructs.proto */
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":690
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":691
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":692
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":693
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":697
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":698
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":699
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":700
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":704
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":705
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":714
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":715
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":716
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":718
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":719
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":720
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":722
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":723
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":725
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":726
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":727
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);


/*--- Type declarations ---*/
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig;
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr;
struct __pyx_array_obj;
struct __pyx_MemviewEnum_obj;
struct __pyx_memoryview_obj;
struct __pyx_memoryviewslice_obj;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":729
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":730
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":731
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":733
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_t_8revealer_21REVEALER_runbenchmark_density;
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_calc_bandwidth;
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_py_bcv;
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython;
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython;
struct __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc;
typedef struct __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc;
struct __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t;
typedef struct __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t;
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_runBenchmark;

/* "revealer/REVEALER_runbenchmark.pyx":30
 * cdef int RANDOM_SEED = 20121020
 * 
 * cdef struct density:             # <<<<<<<<<<<<<<
 *     np.double_t d
 *     np.uint32_t* cnt
 */
struct __pyx_t_8revealer_21REVEALER_runbenchmark_density {
  __pyx_t_5numpy_double_t d;
  __pyx_t_5numpy_uint32_t *cnt;
};

/* "revealer/REVEALER_runbenchmark.pyx":254
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cpdef np.double_t calc_bandwidth(             # <<<<<<<<<<<<<<
 *     np.double_t[:] x_view,  #List of double
 *     int n,                  #Size of list
 */
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_calc_bandwidth {
  int __pyx_n;
  int nb;
};

/* "revealer/REVEALER_runbenchmark.pyx":277
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t py_bcv(             # <<<<<<<<<<<<<<
 *     np.double_t* x,     #Pointer to list x
 *     int n,              #Size of sample
 */
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_py_bcv {
  int __pyx_n;
  int nb;
};

/* "revealer/REVEALER_runbenchmark.pyx":429
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t binaryInformationCoefficient_cython(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y,           #Target
 *     np.int_t[:] x,              #Features to calculate correlation
 */
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython {
  int __pyx_n;
  __pyx_t_5numpy_double_t jitter;
};

/* "revealer/REVEALER_runbenchmark.pyx":554
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t ConditionalInformationCoefficient_cython(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y,           #Target
 *     np.int_t[:] x,              #Feature that correlation is calculated
 */
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython {
  int __pyx_n;
  __pyx_t_5numpy_double_t jitter;
};

/* "revealer/REVEALER_runbenchmark.pyx":811
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef (np.int_t,np.double_t,np.double_t) findBestCIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:] z_in,           #Feature that CIC depend on
 */
struct __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc {
  __pyx_t_5numpy_int_t f0;
  __pyx_t_5numpy_double_t f1;
  __pyx_t_5numpy_double_t f2;
};

/* "revealer/REVEALER_runbenchmark.pyx":905
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cpdef (np.int_t,np.double_t) findBestIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:,:] xs_in,        #List of features
 */
struct __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t {
  __pyx_t_5numpy_int_t f0;
  __pyx_t_5numpy_double_t f1;
};

/* "revealer/REVEALER_runbenchmark.pyx":1229
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef runBenchmark(target_file='no', # gct file for target(continuous or binary             # <<<<<<<<<<<<<<
 *                   feature_file='no', # gct file for features(binary)
 *                   seed_file='no', # file for seed, if not provided, feature file is used directly
 */
struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_runBenchmark {
  int __pyx_n;
  PyObject *target_file;
  PyObject *feature_file;
  PyObject *seed_file;
  PyObject *target_df;
  PyObject *feature_df;
  PyObject *seed_df;
  PyObject *prefix;
  PyObject *seed_name;
  PyObject *grid;
  PyObject *target_name;
  PyObject *k;
  PyObject *bandwidth_mult;
  PyObject *bandwidth_adj;
  PyObject *direction;
  PyObject *mode;
  PyObject *num_top;
  PyObject *low_threshold;
  PyObject *high_threshold;
  PyObject *collapse;
  PyObject *normalize;
  PyObject *gene_locus;
  PyObject *verbose;
  PyObject *max_iteration;
  PyObject *thread_number;
  PyObject *figure_format;
  PyObject *subset;
  PyObject *if_pval;
  PyObject *if_bootstrap;
  PyObject *if_cluster;
  PyObject *if_intermediate;
  PyObject *out_folder;
  PyObject *gene_set;
  PyObject *gene_separator;
  PyObject *gmt_file;
  PyObject *alpha;
  PyObject *neighborhood;
  PyObject *tissue_file;
  PyObject *gzip;
};

/* "revealer/REVEALER_runbenchmark.pyx":2255
 * 
 * 
 * def plotCluster(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster {
  PyObject_HEAD
  PyObject *__pyx_v_gmt;
  PyObject *__pyx_v_plotsubdf;
};


/* "revealer/REVEALER_runbenchmark.pyx":2455
 *     plt.close()
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotsubdf.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotsubdf.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *__pyx_outer_scope;
  PyObject *__pyx_v_elem;
};


/* "revealer/REVEALER_runbenchmark.pyx":2514
 * 
 * 
 * def savetopfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig {
  PyObject_HEAD
  PyObject *__pyx_v_gmt;
  PyObject *__pyx_v_plotcomb;
};


/* "revealer/REVEALER_runbenchmark.pyx":2680
 *         plotcomb['pVals'] = pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotcomb.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotcomb.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr {
  PyObject_HEAD
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *__pyx_outer_scope;
  PyObject *__pyx_v_elem;
};


/* "revealer/REVEALER_runbenchmark.pyx":2687
 * 
 * 
 * def saveresfigWithPval(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval {
  PyObject_HEAD
  PyObject *__pyx_v_gmt;
  PyObject *__pyx_v_seedids;
};


/* "revealer/REVEALER_runbenchmark.pyx":2915
 *     reportdf['pVals'] = [''] + pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr {
  PyObject_HEAD
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *__pyx_outer_scope;
  PyObject *__pyx_v_elem;
};


/* "revealer/REVEALER_runbenchmark.pyx":2921
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def saveresfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig {
  PyObject_HEAD
  PyObject *__pyx_v_gmt;
  PyObject *__pyx_v_seedids;
};


/* "revealer/REVEALER_runbenchmark.pyx":3100
 *         reportdf['bootstrap'] = [''] + bootstraps
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */
struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr {
  PyObject_HEAD
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *__pyx_outer_scope;
  PyObject *__pyx_v_elem;
};


/* "View.MemoryView":105
 * 
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
struct __pyx_array_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_array *__pyx_vtab;
  char *data;
  Py_ssize_t len;
  char *format;
  int ndim;
  Py_ssize_t *_shape;
  Py_ssize_t *_strides;
  Py_ssize_t itemsize;
  PyObject *mode;
  PyObject *_format;
  void (*callback_free_data)(void *);
  int free_data;
  int dtype_is_object;
};


/* "View.MemoryView":279
 * 
 * @cname('__pyx_MemviewEnum')
 * cdef class Enum(object):             # <<<<<<<<<<<<<<
 *     cdef object name
 *     def __init__(self, name):
 */
struct __pyx_MemviewEnum_obj {
  PyObject_HEAD
  PyObject *name;
};


/* "View.MemoryView":330
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */
struct __pyx_memoryview_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_memoryview *__pyx_vtab;
  PyObject *obj;
  PyObject *_size;
  PyObject *_array_interface;
  PyThread_type_lock lock;
  __pyx_atomic_int acquisition_count[2];
  __pyx_atomic_int *acquisition_count_aligned_p;
  Py_buffer view;
  int flags;
  int dtype_is_object;
  __Pyx_TypeInfo *typeinfo;
};


/* "View.MemoryView":965
 * 
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */
struct __pyx_memoryviewslice_obj {
  struct __pyx_memoryview_obj __pyx_base;
  __Pyx_memviewslice from_slice;
  PyObject *from_object;
  PyObject *(*to_object_func)(char *);
  int (*to_dtype_func)(char *, PyObject *);
};



/* "View.MemoryView":105
 * 
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */

struct __pyx_vtabstruct_array {
  PyObject *(*get_memview)(struct __pyx_array_obj *);
};
static struct __pyx_vtabstruct_array *__pyx_vtabptr_array;


/* "View.MemoryView":330
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */

struct __pyx_vtabstruct_memoryview {
  char *(*get_item_pointer)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*is_slice)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_slice_assignment)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*setitem_slice_assign_scalar)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_indexed)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*convert_item_to_object)(struct __pyx_memoryview_obj *, char *);
  PyObject *(*assign_item_from_object)(struct __pyx_memoryview_obj *, char *, PyObject *);
};
static struct __pyx_vtabstruct_memoryview *__pyx_vtabptr_memoryview;


/* "View.MemoryView":965
 * 
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */

struct __pyx_vtabstruct__memoryviewslice {
  struct __pyx_vtabstruct_memoryview __pyx_base;
};
static struct __pyx_vtabstruct__memoryviewslice *__pyx_vtabptr__memoryviewslice;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* MemviewSliceInit.proto */
#define __Pyx_BUF_MAX_NDIMS %(BUF_MAX_NDIMS)d
#define __Pyx_MEMVIEW_DIRECT   1
#define __Pyx_MEMVIEW_PTR      2
#define __Pyx_MEMVIEW_FULL     4
#define __Pyx_MEMVIEW_CONTIG   8
#define __Pyx_MEMVIEW_STRIDED  16
#define __Pyx_MEMVIEW_FOLLOW   32
#define __Pyx_IS_C_CONTIG 1
#define __Pyx_IS_F_CONTIG 2
static int __Pyx_init_memviewslice(
                struct __pyx_memoryview_obj *memview,
                int ndim,
                __Pyx_memviewslice *memviewslice,
                int memview_is_new_reference);
static CYTHON_INLINE int __pyx_add_acquisition_count_locked(
    __pyx_atomic_int *acquisition_count, PyThread_type_lock lock);
static CYTHON_INLINE int __pyx_sub_acquisition_count_locked(
    __pyx_atomic_int *acquisition_count, PyThread_type_lock lock);
#define __pyx_get_slice_count_pointer(memview) (memview->acquisition_count_aligned_p)
#define __pyx_get_slice_count(memview) (*__pyx_get_slice_count_pointer(memview))
#define __PYX_INC_MEMVIEW(slice, have_gil) __Pyx_INC_MEMVIEW(slice, have_gil, __LINE__)
#define __PYX_XDEC_MEMVIEW(slice, have_gil) __Pyx_XDEC_MEMVIEW(slice, have_gil, __LINE__)
static CYTHON_INLINE void __Pyx_INC_MEMVIEW(__Pyx_memviewslice *, int, int);
static CYTHON_INLINE void __Pyx_XDEC_MEMVIEW(__Pyx_memviewslice *, int, int);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* py_abs.proto */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *num);
#define __Pyx_PyNumber_Absolute(x)\
    ((likely(PyLong_CheckExact(x))) ?\
         (likely(Py_SIZE(x) >= 0) ? (Py_INCREF(x), (x)) : __Pyx_PyLong_AbsNeg(x)) :\
         PyNumber_Absolute(x))
#else
#define __Pyx_PyNumber_Absolute(x)  PyNumber_Absolute(x)
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return __Pyx_PyObject_GetAttrStr(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#else
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntFromDouble.proto */
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE PyObject* __Pyx_PyInt_FromDouble(double value);
#else
#define __Pyx_PyInt_FromDouble(value) PyLong_FromDouble(value)
#endif

/* pyobject_as_double.proto */
static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyInt_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?\
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_TrueDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_TrueDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_TrueDivideObjC(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* PyObjectFormat.proto */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* s, PyObject* f);
#else
#define __Pyx_PyObject_Format(s, f) PyObject_Format(s, f)
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* None.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t, Py_ssize_t);

/* UnaryNegOverflows.proto */
#define UNARY_NEG_WOULD_OVERFLOW(x)\
        (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

static CYTHON_UNUSED int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *); /*proto*/
/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* decode_c_string_utf16.proto */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

static CYTHON_UNUSED int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* None.proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

/* MemviewSliceIsContig.proto */
static int __pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim);

/* OverlappingSlices.proto */
static int __pyx_slices_overlap(__Pyx_memviewslice *slice1,
                                __Pyx_memviewslice *slice2,
                                int ndim, size_t itemsize);

/* Capsule.proto */
static CYTHON_INLINE PyObject *__pyx_capsule_create(void *p, const char *sig);

/* IsLittleEndian.proto */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void);

/* BufferFormatCheck.proto */
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type);

/* TypeInfoCompare.proto */
static int __pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b);

/* MemviewSliceValidateAndInit.proto */
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(PyObject *, int writable_flag);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_double_t(const char *itemp);
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_double_t(const char *itemp, PyObject *obj);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_long(npy_long value);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int_t(const char *itemp);
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_int_t(const char *itemp, PyObject *obj);

/* ToPyCTupleUtility.proto */
static PyObject* __pyx_convert__to_py___pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc(__pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc);

/* ToPyCTupleUtility.proto */
static PyObject* __pyx_convert__to_py___pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t(__pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* MemviewSliceCopyTemplate.proto */
static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_long __Pyx_PyInt_As_npy_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CStringEquals.proto */
static CYTHON_INLINE int __Pyx_StrEq(const char *, const char *);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self); /* proto*/
static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto*/
static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/

/* Module declarations from 'cython.view' */

/* Module declarations from 'cython' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_generic = 0;
static PyTypeObject *__pyx_ptype_5numpy_number = 0;
static PyTypeObject *__pyx_ptype_5numpy_integer = 0;
static PyTypeObject *__pyx_ptype_5numpy_signedinteger = 0;
static PyTypeObject *__pyx_ptype_5numpy_unsignedinteger = 0;
static PyTypeObject *__pyx_ptype_5numpy_inexact = 0;
static PyTypeObject *__pyx_ptype_5numpy_floating = 0;
static PyTypeObject *__pyx_ptype_5numpy_complexfloating = 0;
static PyTypeObject *__pyx_ptype_5numpy_flexible = 0;
static PyTypeObject *__pyx_ptype_5numpy_character = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;

/* Module declarations from 'libc.float' */

/* Module declarations from 'libc.limits' */

/* Module declarations from 'libc.math' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'revealer.REVEALER_runbenchmark' */
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig = 0;
static PyTypeObject *__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr = 0;
static PyTypeObject *__pyx_array_type = 0;
static PyTypeObject *__pyx_MemviewEnum_type = 0;
static PyTypeObject *__pyx_memoryview_type = 0;
static PyTypeObject *__pyx_memoryviewslice_type = 0;
static __pyx_t_5numpy_double_t __pyx_v_8revealer_21REVEALER_runbenchmark_EPS;
static int __pyx_v_8revealer_21REVEALER_runbenchmark_RANDOM_SEED;
static __pyx_t_5numpy_double_t __pyx_v_8revealer_21REVEALER_runbenchmark_DELMAX;
static PyObject *generic = 0;
static PyObject *strided = 0;
static PyObject *indirect = 0;
static PyObject *contiguous = 0;
static PyObject *indirect_contiguous = 0;
static int __pyx_memoryview_thread_locks_used;
static PyThread_type_lock __pyx_memoryview_thread_locks[8];
static CYTHON_INLINE struct __pyx_t_8revealer_21REVEALER_runbenchmark_density __pyx_f_8revealer_21REVEALER_runbenchmark_VR_den_bin(int, int, __pyx_t_5numpy_double_t *, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_VR_bcv_bin(int, int, struct __pyx_t_8revealer_21REVEALER_runbenchmark_density, __pyx_t_5numpy_double_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_r_var(__pyx_t_5numpy_double_t *, int); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_sign(__pyx_t_5numpy_double_t); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__Pyx_memviewslice, int); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__Pyx_memviewslice, int); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_calc_bandwidth(__Pyx_memviewslice, int, int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_calc_bandwidth *__pyx_optional_args); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_py_bcv(__pyx_t_5numpy_double_t *, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_py_bcv *__pyx_optional_args); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_local_pearsonr(__Pyx_memviewslice, __Pyx_memviewslice, int); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__Pyx_memviewslice, __Pyx_memviewslice, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython *__pyx_optional_args); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython(__Pyx_memviewslice, __Pyx_memviewslice, __Pyx_memviewslice, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython *__pyx_optional_args); /*proto*/
static __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc __pyx_f_8revealer_21REVEALER_runbenchmark_findBestCIC(__Pyx_memviewslice, __Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, PyObject *, int, int, int, int __pyx_skip_dispatch); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_rankCIC(__Pyx_memviewslice, __Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, int, int, int __pyx_skip_dispatch); /*proto*/
static __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_findBestIC(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, PyObject *, int, int, int, int __pyx_skip_dispatch); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_rankIC(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, int, int, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_topmatch(PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_runBenchmark(int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_runBenchmark *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_REVEALERInner(PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_updatePval(PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalICInd(PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalCIC(PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalCIC(PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalIC(PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalIC(PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_runIndividualPvalIC(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, int, int, int __pyx_skip_dispatch); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrap(__Pyx_memviewslice, __Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, int, int, int __pyx_skip_dispatch); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrapIC(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, __pyx_t_5numpy_double_t, int, int, int, int __pyx_skip_dispatch); /*proto*/
static struct __pyx_array_obj *__pyx_array_new(PyObject *, Py_ssize_t, char *, char *, char *); /*proto*/
static void *__pyx_align_pointer(void *, size_t); /*proto*/
static PyObject *__pyx_memoryview_new(PyObject *, int, int, __Pyx_TypeInfo *); /*proto*/
static CYTHON_INLINE int __pyx_memoryview_check(PyObject *); /*proto*/
static PyObject *_unellipsify(PyObject *, int); /*proto*/
static PyObject *assert_direct_dimensions(Py_ssize_t *, int); /*proto*/
static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *, PyObject *); /*proto*/
static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int, int); /*proto*/
static char *__pyx_pybuffer_index(Py_buffer *, char *, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memslice_transpose(__Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice, int, PyObject *(*)(char *), int (*)(char *, PyObject *), int); /*proto*/
static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *); /*proto*/
static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static Py_ssize_t abs_py_ssize_t(Py_ssize_t); /*proto*/
static char __pyx_get_best_slice_order(__Pyx_memviewslice *, int); /*proto*/
static void _copy_strided_to_strided(char *, Py_ssize_t *, char *, Py_ssize_t *, Py_ssize_t *, Py_ssize_t *, int, size_t); /*proto*/
static void copy_strided_to_strided(__Pyx_memviewslice *, __Pyx_memviewslice *, int, size_t); /*proto*/
static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *, int); /*proto*/
static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *, Py_ssize_t *, Py_ssize_t, int, char); /*proto*/
static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *, __Pyx_memviewslice *, char, int); /*proto*/
static int __pyx_memoryview_err_extents(int, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memoryview_err_dim(PyObject *, char *, int); /*proto*/
static int __pyx_memoryview_err(PyObject *, char *); /*proto*/
static int __pyx_memoryview_copy_contents(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int); /*proto*/
static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *, int, int); /*proto*/
static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *, int, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *, int, size_t, void *, int); /*proto*/
static void __pyx_memoryview__slice_assign_scalar(char *, Py_ssize_t *, Py_ssize_t *, int, size_t, void *); /*proto*/
static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *, PyObject *); /*proto*/
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_double_t = { "double_t", NULL, sizeof(__pyx_t_5numpy_double_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int_t = { "int_t", NULL, sizeof(__pyx_t_5numpy_int_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int_t), 0 };
#define __Pyx_MODULE_NAME "revealer.REVEALER_runbenchmark"
extern int __pyx_module_is_main_revealer__REVEALER_runbenchmark;
int __pyx_module_is_main_revealer__REVEALER_runbenchmark = 0;

/* Implementation of 'revealer.REVEALER_runbenchmark' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_sum;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_ImportError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_Ellipsis;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_IndexError;
static const char __pyx_k_N[] = "N";
static const char __pyx_k_O[] = "O";
static const char __pyx_k_T[] = "T";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_e[] = "%e";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_g[] = "g";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "j";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_w[] = "w";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_y[] = "y";
static const char __pyx_k_z[] = "z";
static const char __pyx_k_1f[] = ".1f";
static const char __pyx_k_3f[] = ".3f";
static const char __pyx_k_IC[] = "IC";
static const char __pyx_k__2[] = "";
static const char __pyx_k__7[] = ".";
static const char __pyx_k__8[] = "_";
static const char __pyx_k__9[] = "\n";
static const char __pyx_k_ax[] = "ax";
static const char __pyx_k_by[] = "by";
static const char __pyx_k_df[] = "df";
static const char __pyx_k_ha[] = "ha";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_ks[] = "ks";
static const char __pyx_k_ls[] = "ls";
static const char __pyx_k_mp[] = "mp";
static const char __pyx_k_nb[] = "nb";
static const char __pyx_k_no[] = "no";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_pd[] = "pd";
static const char __pyx_k_va[] = "va";
static const char __pyx_k_CIC[] = "CIC(\316\224)";
static const char __pyx_k_ICs[] = "ICs";
static const char __pyx_k_NMF[] = "_NMF/";
static const char __pyx_k_Top[] = "_Top";
static const char __pyx_k__10[] = "/";
static const char __pyx_k__14[] = "\t";
static const char __pyx_k__15[] = "-";
static const char __pyx_k__23[] = ":";
static const char __pyx_k__27[] = "(";
static const char __pyx_k__28[] = ")";
static const char __pyx_k__29[] = ",";
static const char __pyx_k__40[] = ",...";
static const char __pyx_k__44[] = " ";
static const char __pyx_k__45[] = "<";
static const char __pyx_k__46[] = "}}$";
static const char __pyx_k__84[] = "*";
static const char __pyx_k_agg[] = "agg";
static const char __pyx_k_all[] = "all";
static const char __pyx_k_bwr[] = "bwr";
static const char __pyx_k_clr[] = "clr";
static const char __pyx_k_e_2[] = "e";
static const char __pyx_k_eps[] = "eps";
static const char __pyx_k_fig[] = "fig";
static const char __pyx_k_gmt[] = "gmt";
static const char __pyx_k_how[] = "how";
static const char __pyx_k_itr[] = "itr";
static const char __pyx_k_loc[] = "loc";
static const char __pyx_k_neg[] = "neg";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_old[] = "old";
static const char __pyx_k_pdf[] = "pdf";
static const char __pyx_k_plt[] = "plt";
static const char __pyx_k_pos[] = "pos";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_sep[] = "sep";
static const char __pyx_k_sns[] = "sns";
static const char __pyx_k_std[] = "std";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sub[] = "sub";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_top[] = "_top";
static const char __pyx_k_txt[] = ".txt";
static const char __pyx_k_3f_2[] = "%.3f";
static const char __pyx_k_CICs[] = "CICs";
static const char __pyx_k_IC_2[] = "IC(\316\224)";
static const char __pyx_k_Name[] = "Name";
static const char __pyx_k_None[] = "None";
static const char __pyx_k_Seed[] = "Seed:";
static const char __pyx_k_Used[] = ") Used";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_axis[] = "axis";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_blue[] = "blue";
static const char __pyx_k_cbar[] = "cbar";
static const char __pyx_k_ccal[] = "ccal";
static const char __pyx_k_cmap[] = "cmap";
static const char __pyx_k_comb[] = "comb";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_corr[] = "corr";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_diff[] = "diff";
static const char __pyx_k_drop[] = "drop";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_gene[] = "gene";
static const char __pyx_k_grid[] = "grid";
static const char __pyx_k_gzip[] = "gzip";
static const char __pyx_k_iloc[] = "iloc";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_math[] = "math";
static const char __pyx_k_mean[] = "mean";
static const char __pyx_k_miny[] = "miny";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_ndim[] = "ndim";
static const char __pyx_k_nitr[] = "nitr";
static const char __pyx_k_norm[] = "norm";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_pack[] = "pack";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_pile[] = "pile";
static const char __pyx_k_plot[] = "plot";
static const char __pyx_k_pval[] = "pval";
static const char __pyx_k_rank[] = "rank";
static const char __pyx_k_seed[] = "seed";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_sign[] = "sign";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_test[] = "test";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_tqdm[] = "tqdm";
static const char __pyx_k_x_10[] = "x${10^{";
static const char __pyx_k_x_in[] = "x_in";
static const char __pyx_k_y_in[] = "y_in";
static const char __pyx_k_z_in[] = "z_in";
static const char __pyx_k_ASCII[] = "ASCII";
static const char __pyx_k_CIC_2[] = "CIC";
static const char __pyx_k_Group[] = "Group";
static const char __pyx_k_Round[] = "Round ";
static const char __pyx_k_alpha[] = "alpha";
static const char __pyx_k_annot[] = "annot";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_color[] = "color";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_finfo[] = "finfo";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_floor[] = "floor";
static const char __pyx_k_gmt_2[] = ".gmt";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_inner[] = "inner";
static const char __pyx_k_itr_2[] = "_itr";
static const char __pyx_k_locus[] = "locus";
static const char __pyx_k_multi[] = "multi";
static const char __pyx_k_new_2[] = "new";
static const char __pyx_k_notna[] = "notna";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_pVals[] = "pVals";
static const char __pyx_k_piled[] = "piled";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_right[] = "right";
static const char __pyx_k_rmrow[] = "rmrow";
static const char __pyx_k_scipy[] = "scipy";
static const char __pyx_k_shape[] = "shape";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = " start!";
static const char __pyx_k_stats[] = "stats";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_total[] = "total";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_xs_in[] = "xs_in";
static const char __pyx_k_ys_in[] = "ys_in";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_Result[] = "_Result.";
static const char __pyx_k_Seed_2[] = "Seed";
static const char __pyx_k_Target[] = "Target:";
static const char __pyx_k_astype[] = "astype";
static const char __pyx_k_center[] = "center";
static const char __pyx_k_concat[] = "concat";
static const char __pyx_k_cython[] = "cython";
static const char __pyx_k_deltay[] = "deltay";
static const char __pyx_k_dropna[] = "dropna";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_exists[] = "exists";
static const char __pyx_k_exit_2[] = "exit";
static const char __pyx_k_figure[] = "figure";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_gsubdf[] = "gsubdf";
static const char __pyx_k_header[] = "header";
static const char __pyx_k_ifSeed[] = "ifSeed";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_jitter[] = "jitter";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_ninety[] = "ninety";
static const char __pyx_k_pandas[] = "pandas";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_prefix[] = "prefix";
static const char __pyx_k_random[] = "random";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_rename[] = "rename";
static const char __pyx_k_report[] = "report";
static const char __pyx_k_sample[] = "sample";
static const char __pyx_k_seedID[] = "seedID";
static const char __pyx_k_single[] = "single";
static const char __pyx_k_struct[] = "struct";
static const char __pyx_k_subset[] = "subset";
static const char __pyx_k_target[] = "target";
static const char __pyx_k_test_2[] = "__test__";
static const char __pyx_k_to_csv[] = "to_csv";
static const char __pyx_k_tolist[] = "tolist";
static const char __pyx_k_unique[] = "unique";
static const char __pyx_k_unpack[] = "unpack";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_x_view[] = "x_view";
static const char __pyx_k_asarray[] = "asarray";
static const char __pyx_k_colspan[] = "colspan";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_comball[] = "comball";
static const char __pyx_k_feature[] = "feature";
static const char __pyx_k_figsize[] = "figsize";
static const char __pyx_k_fortran[] = "fortran";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_heatmap[] = "heatmap";
static const char __pyx_k_if_pval[] = "if_pval";
static const char __pyx_k_inplace[] = "inplace";
static const char __pyx_k_memview[] = "memview";
static const char __pyx_k_newseed[] = "newseed";
static const char __pyx_k_num_top[] = "num_top";
static const char __pyx_k_p_value[] = "p-value";
static const char __pyx_k_patient[] = "patient";
static const char __pyx_k_pileres[] = "pileres";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_results[] = "results";
static const char __pyx_k_rowspan[] = "rowspan";
static const char __pyx_k_savefig[] = "savefig";
static const char __pyx_k_seaborn[] = "seaborn";
static const char __pyx_k_seed_df[] = "seed_df";
static const char __pyx_k_seedids[] = "seedids";
static const char __pyx_k_start_2[] = "start";
static const char __pyx_k_subcomb[] = "subcomb";
static const char __pyx_k_subseed[] = "subseed";
static const char __pyx_k_tarfile[] = "tarfile";
static const char __pyx_k_targets[] = "targets";
static const char __pyx_k_verbose[] = "verbose";
static const char __pyx_k_All_core[] = "All core(";
static const char __pyx_k_Ellipsis[] = "Ellipsis";
static const char __pyx_k_Location[] = "Location";
static const char __pyx_k_New_Seed[] = "New Seed";
static const char __pyx_k_Run_name[] = "Run name: ";
static const char __pyx_k_Target_2[] = "Target";
static const char __pyx_k_collapse[] = "collapse";
static const char __pyx_k_drawSeed[] = "drawSeed";
static const char __pyx_k_features[] = "features";
static const char __pyx_k_gene_set[] = "gene_set";
static const char __pyx_k_genename[] = "genename";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_gmt_file[] = "gmt_file";
static const char __pyx_k_itemsize[] = "itemsize";
static const char __pyx_k_locusdic[] = "locusdic";
static const char __pyx_k_makedirs[] = "makedirs";
static const char __pyx_k_numgroup[] = "numgroup";
static const char __pyx_k_pearsonr[] = "pearsonr";
static const char __pyx_k_pileRank[] = "pileRank";
static const char __pyx_k_pilesize[] = "pilesize";
static const char __pyx_k_plotcomb[] = "plotcomb";
static const char __pyx_k_plotpval[] = "plotpval";
static const char __pyx_k_pvallist[] = "pvallist";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_read_csv[] = "read_csv";
static const char __pyx_k_reportdf[] = "reportdf";
static const char __pyx_k_seedcmap[] = "seedcmap";
static const char __pyx_k_seedcomb[] = "seedcomb";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_skiprows[] = "skiprows";
static const char __pyx_k_subplots[] = "subplots";
static const char __pyx_k_to_numpy[] = "to_numpy";
static const char __pyx_k_warnings[] = "warnings";
static const char __pyx_k_zerobase[] = "zerobase";
static const char __pyx_k_DataFrame[] = "DataFrame";
static const char __pyx_k_Iteration[] = "Iteration";
static const char __pyx_k_Null_Seed[] = "Null Seed";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_algorithm[] = "algorithm";
static const char __pyx_k_ascending[] = "ascending";
static const char __pyx_k_bandwidth[] = "bandwidth";
static const char __pyx_k_bootstrap[] = "bootstrap";
static const char __pyx_k_commoncol[] = "commoncol";
static const char __pyx_k_countless[] = "countless";
static const char __pyx_k_cpu_count[] = "cpu_count";
static const char __pyx_k_diffindex[] = "diffindex";
static const char __pyx_k_direction[] = "direction";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_firstseed[] = "firstseed";
static const char __pyx_k_from_list[] = "from_list";
static const char __pyx_k_grid_size[] = "grid size: ";
static const char __pyx_k_index_col[] = "index_col";
static const char __pyx_k_normalize[] = "normalize";
static const char __pyx_k_plotcomb2[] = "plotcomb2";
static const char __pyx_k_plotsubdf[] = "plotsubdf";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_readInput[] = "readInput";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_seedIndex[] = "seedIndex";
static const char __pyx_k_seed_file[] = "seed_file";
static const char __pyx_k_seed_name[] = "seed_name";
static const char __pyx_k_seedlists[] = "seedlists";
static const char __pyx_k_target_df[] = "target_df";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_Result_gmt[] = "_Result.gmt";
static const char __pyx_k_Result_txt[] = "_Result.txt";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_bootstraps[] = "bootstraps";
static const char __pyx_k_cythonseed[] = "cythonseed";
static const char __pyx_k_drawTarget[] = "drawTarget";
static const char __pyx_k_feature_df[] = "feature_df";
static const char __pyx_k_gene_locus[] = "gene_locus";
static const char __pyx_k_groupindex[] = "groupindex";
static const char __pyx_k_if_cluster[] = "if_cluster";
static const char __pyx_k_inset_list[] = "inset_list";
static const char __pyx_k_origtarget[] = "origtarget";
static const char __pyx_k_out_folder[] = "out_folder";
static const char __pyx_k_patientfig[] = "patientfig";
static const char __pyx_k_percentile[] = "percentile";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_report_txt[] = "report.txt";
static const char __pyx_k_saveresfig[] = "saveresfig";
static const char __pyx_k_savetopfig[] = "savetopfig";
static const char __pyx_k_subsubcomb[] = "subsubcomb";
static const char __pyx_k_tissueType[] = "_tissueType.";
static const char __pyx_k_topMatches[] = "topMatches";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_bandwidth_2[] = "bandwidth: ";
static const char __pyx_k_check_inset[] = "check_inset";
static const char __pyx_k_currentseed[] = "currentseed";
static const char __pyx_k_drawFeature[] = "drawFeature";
static const char __pyx_k_featurecmap[] = "featurecmap";
static const char __pyx_k_nmf_results[] = "nmf_results";
static const char __pyx_k_origfeature[] = "origfeature";
static const char __pyx_k_plotCluster[] = "plotCluster";
static const char __pyx_k_random_seed[] = "random_seed";
static const char __pyx_k_scipy_stats[] = "scipy.stats";
static const char __pyx_k_seedCombine[] = "seedCombine";
static const char __pyx_k_seed_Search[] = "seed Search...";
static const char __pyx_k_seedcomball[] = "seedcomball";
static const char __pyx_k_sort_values[] = "sort_values";
static const char __pyx_k_target_file[] = "target_file";
static const char __pyx_k_target_name[] = "target_name";
static const char __pyx_k_tissue_file[] = "tissue_file";
static const char __pyx_k_xticklabels[] = "xticklabels";
static const char __pyx_k_yticklabels[] = "yticklabels";
static const char __pyx_k_Grid_size_is[] = "Grid size is: ";
static const char __pyx_k_custom_greys[] = "custom greys";
static const char __pyx_k_feature_file[] = "feature_file";
static const char __pyx_k_feature_name[] = "feature_name";
static const char __pyx_k_if_bootstrap[] = "if_bootstrap";
static const char __pyx_k_n_clustering[] = "n_clustering";
static const char __pyx_k_neighborhood[] = "neighborhood";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_seed_file_is[] = "seed_file is";
static const char __pyx_k_set_axis_off[] = "set_axis_off";
static const char __pyx_k_set_figwidth[] = "set_figwidth";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_subplot2grid[] = "subplot2grid";
static const char __pyx_k_CIC_GeneNames[] = "CIC\tGeneNames\n";
static const char __pyx_k_bandwidth_adj[] = "bandwidth_adj";
static const char __pyx_k_calcBootstrap[] = "calcBootstrap";
static const char __pyx_k_figure_format[] = "figure_format";
static const char __pyx_k_low_threshold[] = "low_threshold";
static const char __pyx_k_max_iteration[] = "max_iteration";
static const char __pyx_k_newseed_names[] = "newseed_names";
static const char __pyx_k_pyx_getbuffer[] = "__pyx_getbuffer";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_revealer_ccal[] = "revealer.ccal";
static const char __pyx_k_set_figheight[] = "set_figheight";
static const char __pyx_k_thread_number[] = "thread_number";
static const char __pyx_k_tqdm_notebook[] = "tqdm.notebook";
static const char __pyx_k_Picked_seed_is[] = "Picked seed is: ";
static const char __pyx_k_bandwidth_mult[] = "bandwidth_mult";
static const char __pyx_k_directory_path[] = "directory_path";
static const char __pyx_k_filterwarnings[] = "filterwarnings";
static const char __pyx_k_gene_separator[] = "gene_separator";
static const char __pyx_k_high_threshold[] = "high_threshold";
static const char __pyx_k_switch_backend[] = "switch_backend";
static const char __pyx_k_ResultClustered[] = "ResultClustered.";
static const char __pyx_k_View_MemoryView[] = "View.MemoryView";
static const char __pyx_k_allocate_buffer[] = "allocate_buffer";
static const char __pyx_k_calcBootstrapIC[] = "calcBootstrapIC";
static const char __pyx_k_dtype_is_object[] = "dtype_is_object";
static const char __pyx_k_if_intermediate[] = "if_intermediate";
static const char __pyx_k_multiprocessing[] = "multiprocessing";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_Please_put_input[] = "Please put input!";
static const char __pyx_k_IC_of_new_seed_is[] = "IC of new seed is: ";
static const char __pyx_k_ascontiguousarray[] = "ascontiguousarray";
static const char __pyx_k_matplotlib_colors[] = "matplotlib.colors";
static const char __pyx_k_matplotlib_pyplot[] = "matplotlib.pyplot";
static const char __pyx_k_pyx_unpickle_Enum[] = "__pyx_unpickle_Enum";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_explore_components[] = "explore_components";
static const char __pyx_k_saveresfigWithPval[] = "saveresfigWithPval";
static const char __pyx_k_strided_and_direct[] = "<strided and direct>";
static const char __pyx_k_ResultClustered_txt[] = "ResultClustered.txt";
static const char __pyx_k_calcIndivisualPvalIC[] = "calcIndivisualPvalIC";
static const char __pyx_k_strided_and_indirect[] = "<strided and indirect>";
static const char __pyx_k_Number_of_thread_used[] = "Number of thread used: ";
static const char __pyx_k_PhenotypeDistribution[] = "_PhenotypeDistribution.";
static const char __pyx_k_contiguous_and_direct[] = "<contiguous and direct>";
static const char __pyx_k_MemoryView_of_r_object[] = "<MemoryView of %r object>";
static const char __pyx_k_Universal_bandwidth_is[] = "Universal bandwidth is: ";
static const char __pyx_k_LinearSegmentedColormap[] = "LinearSegmentedColormap";
static const char __pyx_k_MemoryView_of_r_at_0x_x[] = "<MemoryView of %r at 0x%x>";
static const char __pyx_k_contiguous_and_indirect[] = "<contiguous and indirect>";
static const char __pyx_k_Cannot_index_with_type_s[] = "Cannot index with type '%s'";
static const char __pyx_k_Done_reading_input_files[] = "Done reading input files";
static const char __pyx_k_Invalid_shape_in_axis_d_d[] = "Invalid shape in axis %d: %d.";
static const char __pyx_k_Start_reading_input_files[] = "Start reading input files...";
static const char __pyx_k_saveresfig_locals_genexpr[] = "saveresfig.<locals>.genexpr";
static const char __pyx_k_savetopfig_locals_genexpr[] = "savetopfig.<locals>.genexpr";
static const char __pyx_k_plotCluster_locals_genexpr[] = "plotCluster.<locals>.genexpr";
static const char __pyx_k_itemsize_0_for_cython_array[] = "itemsize <= 0 for cython.array";
static const char __pyx_k_unable_to_allocate_array_data[] = "unable to allocate array data.";
static const char __pyx_k_revealer_REVEALER_runbenchmark[] = "revealer.REVEALER_runbenchmark";
static const char __pyx_k_strided_and_direct_or_indirect[] = "<strided and direct or indirect>";
static const char __pyx_k_CIC_calculated_in_this_round_is[] = "CIC calculated in this round is: ";
static const char __pyx_k_Time_used_to_run_loops_s_second[] = "Time used to run loops: %s second(s)";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_Best_feature_choosen_in_this_rou[] = "Best feature choosen in this round is: ";
static const char __pyx_k_Buffer_view_does_not_expose_stri[] = "Buffer view does not expose strides";
static const char __pyx_k_Can_only_create_a_buffer_that_is[] = "Can only create a buffer that is contiguous in memory.";
static const char __pyx_k_Cannot_assign_to_read_only_memor[] = "Cannot assign to read-only memoryview";
static const char __pyx_k_Cannot_create_writable_memory_vi[] = "Cannot create writable memory view from read-only memoryview";
static const char __pyx_k_Empty_shape_tuple_for_cython_arr[] = "Empty shape tuple for cython.array";
static const char __pyx_k_Incompatible_checksums_s_vs_0xb0[] = "Incompatible checksums (%s vs 0xb068931 = (name))";
static const char __pyx_k_Indicated_Core_Number_exceed_max[] = "Indicated Core Number exceed maximum available core. All core is used";
static const char __pyx_k_Indirect_dimensions_not_supporte[] = "Indirect dimensions not supported";
static const char __pyx_k_Invalid_mode_expected_c_or_fortr[] = "Invalid mode, expected 'c' or 'fortran', got %s";
static const char __pyx_k_Names_in_gmt_file_is_not_matchin[] = "Names in gmt file is not matching with input file. Setting gmt to None.";
static const char __pyx_k_Number_of_features_passing_thres[] = "Number of features passing threshold is: ";
static const char __pyx_k_Number_of_features_that_pass_the[] = "Number of features that pass the threshold is: ";
static const char __pyx_k_Out_of_bounds_on_buffer_access_a[] = "Out of bounds on buffer access (axis %d)";
static const char __pyx_k_Time_used_to_read_input_s_second[] = "Time used to read input: %s second(s)";
static const char __pyx_k_Time_used_to_run_one_loop_s_seco[] = "Time used to run one loop: %s second(s)";
static const char __pyx_k_Unable_to_convert_item_to_object[] = "Unable to convert item to object";
static const char __pyx_k_cophenetic_correlation_coefficie[] = "cophenetic_correlation_coefficients";
static const char __pyx_k_got_differing_extents_in_dimensi[] = "got differing extents in dimension %d (got %d and %d)";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_saveresfigWithPval_locals_genexp[] = "saveresfigWithPval.<locals>.genexpr";
static const char __pyx_k_src_revealer_REVEALER_runbenchma[] = "src/revealer/REVEALER_runbenchmark.pyx";
static const char __pyx_k_subset_not_exist_Please_check_yo[] = "subset not exist! Please check your subset list.";
static const char __pyx_k_unable_to_allocate_shape_and_str[] = "unable to allocate shape and strides.";
static PyObject *__pyx_kp_u_1f;
static PyObject *__pyx_kp_u_3f;
static PyObject *__pyx_kp_u_3f_2;
static PyObject *__pyx_n_s_ASCII;
static PyObject *__pyx_kp_u_All_core;
static PyObject *__pyx_kp_u_Best_feature_choosen_in_this_rou;
static PyObject *__pyx_kp_s_Buffer_view_does_not_expose_stri;
static PyObject *__pyx_kp_u_CIC;
static PyObject *__pyx_n_u_CIC_2;
static PyObject *__pyx_kp_u_CIC_GeneNames;
static PyObject *__pyx_kp_u_CIC_calculated_in_this_round_is;
static PyObject *__pyx_n_s_CICs;
static PyObject *__pyx_n_u_CICs;
static PyObject *__pyx_kp_s_Can_only_create_a_buffer_that_is;
static PyObject *__pyx_kp_s_Cannot_assign_to_read_only_memor;
static PyObject *__pyx_kp_s_Cannot_create_writable_memory_vi;
static PyObject *__pyx_kp_s_Cannot_index_with_type_s;
static PyObject *__pyx_n_s_DataFrame;
static PyObject *__pyx_kp_u_Done_reading_input_files;
static PyObject *__pyx_n_s_Ellipsis;
static PyObject *__pyx_kp_s_Empty_shape_tuple_for_cython_arr;
static PyObject *__pyx_kp_u_Grid_size_is;
static PyObject *__pyx_n_u_Group;
static PyObject *__pyx_n_s_IC;
static PyObject *__pyx_n_u_IC;
static PyObject *__pyx_kp_u_IC_2;
static PyObject *__pyx_kp_u_IC_of_new_seed_is;
static PyObject *__pyx_n_s_ICs;
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xb0;
static PyObject *__pyx_n_s_IndexError;
static PyObject *__pyx_kp_u_Indicated_Core_Number_exceed_max;
static PyObject *__pyx_kp_s_Indirect_dimensions_not_supporte;
static PyObject *__pyx_kp_s_Invalid_mode_expected_c_or_fortr;
static PyObject *__pyx_kp_s_Invalid_shape_in_axis_d_d;
static PyObject *__pyx_n_u_Iteration;
static PyObject *__pyx_n_s_LinearSegmentedColormap;
static PyObject *__pyx_n_u_Location;
static PyObject *__pyx_n_s_MemoryError;
static PyObject *__pyx_kp_s_MemoryView_of_r_at_0x_x;
static PyObject *__pyx_kp_s_MemoryView_of_r_object;
static PyObject *__pyx_n_s_N;
static PyObject *__pyx_kp_u_NMF;
static PyObject *__pyx_n_u_Name;
static PyObject *__pyx_kp_u_Names_in_gmt_file_is_not_matchin;
static PyObject *__pyx_kp_u_New_Seed;
static PyObject *__pyx_n_u_None;
static PyObject *__pyx_kp_u_Null_Seed;
static PyObject *__pyx_kp_u_Number_of_features_passing_thres;
static PyObject *__pyx_kp_u_Number_of_features_that_pass_the;
static PyObject *__pyx_kp_u_Number_of_thread_used;
static PyObject *__pyx_n_b_O;
static PyObject *__pyx_kp_s_Out_of_bounds_on_buffer_access_a;
static PyObject *__pyx_kp_u_PhenotypeDistribution;
static PyObject *__pyx_kp_u_Picked_seed_is;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_kp_u_Please_put_input;
static PyObject *__pyx_kp_u_Result;
static PyObject *__pyx_kp_u_ResultClustered;
static PyObject *__pyx_kp_u_ResultClustered_txt;
static PyObject *__pyx_kp_u_Result_gmt;
static PyObject *__pyx_kp_u_Result_txt;
static PyObject *__pyx_kp_u_Round;
static PyObject *__pyx_kp_u_Run_name;
static PyObject *__pyx_kp_u_Seed;
static PyObject *__pyx_n_u_Seed_2;
static PyObject *__pyx_kp_u_Start_reading_input_files;
static PyObject *__pyx_n_s_T;
static PyObject *__pyx_kp_u_Target;
static PyObject *__pyx_n_u_Target_2;
static PyObject *__pyx_kp_u_Time_used_to_read_input_s_second;
static PyObject *__pyx_kp_u_Time_used_to_run_loops_s_second;
static PyObject *__pyx_kp_u_Time_used_to_run_one_loop_s_seco;
static PyObject *__pyx_n_u_Top;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_kp_s_Unable_to_convert_item_to_object;
static PyObject *__pyx_kp_u_Universal_bandwidth_is;
static PyObject *__pyx_kp_u_Used;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_View_MemoryView;
static PyObject *__pyx_kp_u__10;
static PyObject *__pyx_kp_u__14;
static PyObject *__pyx_kp_u__15;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_kp_u__23;
static PyObject *__pyx_kp_u__27;
static PyObject *__pyx_kp_u__28;
static PyObject *__pyx_kp_u__29;
static PyObject *__pyx_kp_u__40;
static PyObject *__pyx_kp_u__44;
static PyObject *__pyx_kp_u__45;
static PyObject *__pyx_kp_u__46;
static PyObject *__pyx_kp_u__7;
static PyObject *__pyx_n_u__8;
static PyObject *__pyx_n_s__84;
static PyObject *__pyx_kp_u__9;
static PyObject *__pyx_n_u_agg;
static PyObject *__pyx_n_s_algorithm;
static PyObject *__pyx_n_u_all;
static PyObject *__pyx_n_s_allocate_buffer;
static PyObject *__pyx_n_s_alpha;
static PyObject *__pyx_n_s_annot;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_array;
static PyObject *__pyx_n_s_asarray;
static PyObject *__pyx_n_s_ascending;
static PyObject *__pyx_n_s_ascontiguousarray;
static PyObject *__pyx_n_s_astype;
static PyObject *__pyx_n_s_ax;
static PyObject *__pyx_n_s_axis;
static PyObject *__pyx_n_s_bandwidth;
static PyObject *__pyx_kp_u_bandwidth_2;
static PyObject *__pyx_n_s_bandwidth_adj;
static PyObject *__pyx_n_s_bandwidth_mult;
static PyObject *__pyx_n_s_base;
static PyObject *__pyx_n_u_blue;
static PyObject *__pyx_n_u_bootstrap;
static PyObject *__pyx_n_s_bootstraps;
static PyObject *__pyx_n_u_bootstraps;
static PyObject *__pyx_n_u_bwr;
static PyObject *__pyx_n_s_by;
static PyObject *__pyx_n_s_c;
static PyObject *__pyx_n_u_c;
static PyObject *__pyx_n_s_calcBootstrap;
static PyObject *__pyx_n_s_calcBootstrapIC;
static PyObject *__pyx_n_s_calcIndivisualPvalIC;
static PyObject *__pyx_n_s_cbar;
static PyObject *__pyx_n_s_ccal;
static PyObject *__pyx_n_s_center;
static PyObject *__pyx_n_u_center;
static PyObject *__pyx_n_s_check_inset;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_clr;
static PyObject *__pyx_n_s_cmap;
static PyObject *__pyx_n_s_collapse;
static PyObject *__pyx_n_s_color;
static PyObject *__pyx_n_s_colspan;
static PyObject *__pyx_n_s_columns;
static PyObject *__pyx_n_u_columns;
static PyObject *__pyx_n_s_comb;
static PyObject *__pyx_n_s_comball;
static PyObject *__pyx_n_s_commoncol;
static PyObject *__pyx_n_s_concat;
static PyObject *__pyx_kp_s_contiguous_and_direct;
static PyObject *__pyx_kp_s_contiguous_and_indirect;
static PyObject *__pyx_n_s_cophenetic_correlation_coefficie;
static PyObject *__pyx_n_s_copy;
static PyObject *__pyx_n_u_corr;
static PyObject *__pyx_n_s_count;
static PyObject *__pyx_n_s_countless;
static PyObject *__pyx_n_s_cpu_count;
static PyObject *__pyx_n_s_currentseed;
static PyObject *__pyx_kp_u_custom_greys;
static PyObject *__pyx_n_s_cython;
static PyObject *__pyx_n_s_cythonseed;
static PyObject *__pyx_n_s_deltay;
static PyObject *__pyx_n_s_df;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_diff;
static PyObject *__pyx_n_s_diffindex;
static PyObject *__pyx_n_s_direction;
static PyObject *__pyx_n_s_directory_path;
static PyObject *__pyx_n_s_drawFeature;
static PyObject *__pyx_n_s_drawSeed;
static PyObject *__pyx_n_s_drawTarget;
static PyObject *__pyx_n_s_drop;
static PyObject *__pyx_n_s_dropna;
static PyObject *__pyx_n_s_dtype_is_object;
static PyObject *__pyx_kp_u_e;
static PyObject *__pyx_n_u_e_2;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_s_enter;
static PyObject *__pyx_n_s_enumerate;
static PyObject *__pyx_n_s_eps;
static PyObject *__pyx_n_s_error;
static PyObject *__pyx_n_s_exists;
static PyObject *__pyx_n_s_exit;
static PyObject *__pyx_n_s_exit_2;
static PyObject *__pyx_n_s_explore_components;
static PyObject *__pyx_n_s_f;
static PyObject *__pyx_n_s_feature;
static PyObject *__pyx_n_s_feature_df;
static PyObject *__pyx_n_s_feature_file;
static PyObject *__pyx_n_s_feature_name;
static PyObject *__pyx_n_s_featurecmap;
static PyObject *__pyx_n_s_features;
static PyObject *__pyx_n_s_fig;
static PyObject *__pyx_n_s_figsize;
static PyObject *__pyx_n_s_figure;
static PyObject *__pyx_n_s_figure_format;
static PyObject *__pyx_n_s_filterwarnings;
static PyObject *__pyx_n_s_finfo;
static PyObject *__pyx_n_u_firstseed;
static PyObject *__pyx_n_s_flags;
static PyObject *__pyx_n_s_floor;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_fortran;
static PyObject *__pyx_n_u_fortran;
static PyObject *__pyx_n_s_from_list;
static PyObject *__pyx_n_s_g;
static PyObject *__pyx_n_s_gene;
static PyObject *__pyx_n_s_gene_locus;
static PyObject *__pyx_n_s_gene_separator;
static PyObject *__pyx_n_s_gene_set;
static PyObject *__pyx_n_s_genename;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_gmt;
static PyObject *__pyx_kp_u_gmt_2;
static PyObject *__pyx_n_s_gmt_file;
static PyObject *__pyx_kp_s_got_differing_extents_in_dimensi;
static PyObject *__pyx_n_s_grid;
static PyObject *__pyx_kp_u_grid_size;
static PyObject *__pyx_n_s_group;
static PyObject *__pyx_n_u_group;
static PyObject *__pyx_n_s_groupindex;
static PyObject *__pyx_n_s_gsubdf;
static PyObject *__pyx_n_s_gzip;
static PyObject *__pyx_n_s_ha;
static PyObject *__pyx_n_s_header;
static PyObject *__pyx_n_s_heatmap;
static PyObject *__pyx_n_s_high_threshold;
static PyObject *__pyx_n_s_how;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_ifSeed;
static PyObject *__pyx_n_s_if_bootstrap;
static PyObject *__pyx_n_s_if_cluster;
static PyObject *__pyx_n_s_if_intermediate;
static PyObject *__pyx_n_s_if_pval;
static PyObject *__pyx_n_u_ignore;
static PyObject *__pyx_n_s_iloc;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_index_col;
static PyObject *__pyx_n_u_inner;
static PyObject *__pyx_n_s_inplace;
static PyObject *__pyx_n_s_inset_list;
static PyObject *__pyx_n_s_itemsize;
static PyObject *__pyx_kp_s_itemsize_0_for_cython_array;
static PyObject *__pyx_n_u_itr;
static PyObject *__pyx_n_u_itr_2;
static PyObject *__pyx_n_s_j;
static PyObject *__pyx_n_s_jitter;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_k;
static PyObject *__pyx_n_s_ks;
static PyObject *__pyx_n_s_loc;
static PyObject *__pyx_n_s_locus;
static PyObject *__pyx_n_s_locusdic;
static PyObject *__pyx_n_s_low_threshold;
static PyObject *__pyx_n_u_ls;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_makedirs;
static PyObject *__pyx_n_s_math;
static PyObject *__pyx_n_s_matplotlib_colors;
static PyObject *__pyx_n_s_matplotlib_pyplot;
static PyObject *__pyx_n_s_max_iteration;
static PyObject *__pyx_n_s_mean;
static PyObject *__pyx_n_s_memview;
static PyObject *__pyx_n_s_miny;
static PyObject *__pyx_n_s_mode;
static PyObject *__pyx_n_s_mp;
static PyObject *__pyx_n_u_multi;
static PyObject *__pyx_n_s_multiprocessing;
static PyObject *__pyx_n_s_n;
static PyObject *__pyx_n_s_n_clustering;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_nb;
static PyObject *__pyx_n_s_ndim;
static PyObject *__pyx_n_u_neg;
static PyObject *__pyx_n_s_neighborhood;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_new_2;
static PyObject *__pyx_n_s_newseed;
static PyObject *__pyx_n_s_newseed_names;
static PyObject *__pyx_n_s_ninety;
static PyObject *__pyx_n_s_nitr;
static PyObject *__pyx_n_s_nmf_results;
static PyObject *__pyx_n_u_no;
static PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
static PyObject *__pyx_n_s_norm;
static PyObject *__pyx_n_s_normalize;
static PyObject *__pyx_n_s_notna;
static PyObject *__pyx_n_s_np;
static PyObject *__pyx_n_s_num_top;
static PyObject *__pyx_n_s_numgroup;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
static PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
static PyObject *__pyx_n_s_obj;
static PyObject *__pyx_n_s_old;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_s_origfeature;
static PyObject *__pyx_n_s_origtarget;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_out_folder;
static PyObject *__pyx_n_s_pVals;
static PyObject *__pyx_n_u_pVals;
static PyObject *__pyx_kp_u_p_value;
static PyObject *__pyx_n_s_pack;
static PyObject *__pyx_n_s_pandas;
static PyObject *__pyx_n_s_path;
static PyObject *__pyx_n_s_patient;
static PyObject *__pyx_n_s_patientfig;
static PyObject *__pyx_n_s_pd;
static PyObject *__pyx_n_u_pdf;
static PyObject *__pyx_n_s_pearsonr;
static PyObject *__pyx_n_s_percentile;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pile;
static PyObject *__pyx_n_s_pileRank;
static PyObject *__pyx_n_s_piled;
static PyObject *__pyx_n_s_pileres;
static PyObject *__pyx_n_s_pilesize;
static PyObject *__pyx_n_s_plot;
static PyObject *__pyx_n_s_plotCluster;
static PyObject *__pyx_n_s_plotCluster_locals_genexpr;
static PyObject *__pyx_n_s_plotcomb;
static PyObject *__pyx_n_s_plotcomb2;
static PyObject *__pyx_n_s_plotpval;
static PyObject *__pyx_n_s_plotsubdf;
static PyObject *__pyx_n_s_plt;
static PyObject *__pyx_n_s_pos;
static PyObject *__pyx_n_u_pos;
static PyObject *__pyx_n_s_prefix;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_pval;
static PyObject *__pyx_n_s_pvallist;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_getbuffer;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_Enum;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_r;
static PyObject *__pyx_n_s_random;
static PyObject *__pyx_n_s_random_seed;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_rank;
static PyObject *__pyx_n_s_readInput;
static PyObject *__pyx_n_s_read_csv;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_rename;
static PyObject *__pyx_n_s_replace;
static PyObject *__pyx_n_s_report;
static PyObject *__pyx_kp_u_report_txt;
static PyObject *__pyx_n_s_reportdf;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_n_s_results;
static PyObject *__pyx_n_s_revealer_REVEALER_runbenchmark;
static PyObject *__pyx_n_s_revealer_ccal;
static PyObject *__pyx_n_u_right;
static PyObject *__pyx_n_s_rmrow;
static PyObject *__pyx_n_s_rowspan;
static PyObject *__pyx_n_s_sample;
static PyObject *__pyx_n_s_savefig;
static PyObject *__pyx_n_s_saveresfig;
static PyObject *__pyx_n_s_saveresfigWithPval;
static PyObject *__pyx_n_s_saveresfigWithPval_locals_genexp;
static PyObject *__pyx_n_s_saveresfig_locals_genexpr;
static PyObject *__pyx_n_s_savetopfig;
static PyObject *__pyx_n_s_savetopfig_locals_genexpr;
static PyObject *__pyx_n_s_scipy;
static PyObject *__pyx_n_s_scipy_stats;
static PyObject *__pyx_n_s_seaborn;
static PyObject *__pyx_n_s_seed;
static PyObject *__pyx_n_s_seedCombine;
static PyObject *__pyx_n_s_seedID;
static PyObject *__pyx_n_s_seedIndex;
static PyObject *__pyx_kp_u_seed_Search;
static PyObject *__pyx_n_s_seed_df;
static PyObject *__pyx_n_s_seed_file;
static PyObject *__pyx_kp_u_seed_file_is;
static PyObject *__pyx_n_s_seed_name;
static PyObject *__pyx_n_s_seedcmap;
static PyObject *__pyx_n_s_seedcomb;
static PyObject *__pyx_n_s_seedcomball;
static PyObject *__pyx_n_s_seedids;
static PyObject *__pyx_n_s_seedlists;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_sep;
static PyObject *__pyx_n_s_set_axis_off;
static PyObject *__pyx_n_s_set_figheight;
static PyObject *__pyx_n_s_set_figwidth;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_shape;
static PyObject *__pyx_n_s_sign;
static PyObject *__pyx_n_u_single;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_n_s_skiprows;
static PyObject *__pyx_n_s_sns;
static PyObject *__pyx_n_s_sort_values;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_kp_s_src_revealer_REVEALER_runbenchma;
static PyObject *__pyx_kp_u_start;
static PyObject *__pyx_n_s_start_2;
static PyObject *__pyx_n_s_stats;
static PyObject *__pyx_n_s_std;
static PyObject *__pyx_n_s_step;
static PyObject *__pyx_n_s_stop;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_kp_s_strided_and_direct;
static PyObject *__pyx_kp_s_strided_and_direct_or_indirect;
static PyObject *__pyx_kp_s_strided_and_indirect;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_struct;
static PyObject *__pyx_n_s_sub;
static PyObject *__pyx_n_s_subcomb;
static PyObject *__pyx_n_s_subplot2grid;
static PyObject *__pyx_n_s_subplots;
static PyObject *__pyx_n_s_subseed;
static PyObject *__pyx_n_s_subset;
static PyObject *__pyx_kp_u_subset_not_exist_Please_check_yo;
static PyObject *__pyx_n_s_subsubcomb;
static PyObject *__pyx_n_s_sum;
static PyObject *__pyx_n_s_switch_backend;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_tarfile;
static PyObject *__pyx_n_s_target;
static PyObject *__pyx_n_s_target_df;
static PyObject *__pyx_n_s_target_file;
static PyObject *__pyx_n_s_target_name;
static PyObject *__pyx_n_s_targets;
static PyObject *__pyx_n_u_test;
static PyObject *__pyx_n_s_test_2;
static PyObject *__pyx_n_s_text;
static PyObject *__pyx_n_s_thread_number;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_time;
static PyObject *__pyx_kp_u_tissueType;
static PyObject *__pyx_n_s_tissue_file;
static PyObject *__pyx_n_s_to_csv;
static PyObject *__pyx_n_s_to_numpy;
static PyObject *__pyx_n_s_tolist;
static PyObject *__pyx_n_u_top;
static PyObject *__pyx_n_s_topMatches;
static PyObject *__pyx_n_s_total;
static PyObject *__pyx_n_s_tqdm;
static PyObject *__pyx_n_s_tqdm_notebook;
static PyObject *__pyx_kp_u_txt;
static PyObject *__pyx_kp_s_unable_to_allocate_array_data;
static PyObject *__pyx_kp_s_unable_to_allocate_shape_and_str;
static PyObject *__pyx_n_s_unique;
static PyObject *__pyx_n_s_unpack;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_va;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_n_s_verbose;
static PyObject *__pyx_n_u_w;
static PyObject *__pyx_n_s_warnings;
static PyObject *__pyx_n_s_write;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_kp_u_x_10;
static PyObject *__pyx_n_s_x_in;
static PyObject *__pyx_n_s_x_view;
static PyObject *__pyx_n_s_xs_in;
static PyObject *__pyx_n_s_xticklabels;
static PyObject *__pyx_n_s_y;
static PyObject *__pyx_n_s_y_in;
static PyObject *__pyx_n_s_ys_in;
static PyObject *__pyx_n_s_yticklabels;
static PyObject *__pyx_n_s_z;
static PyObject *__pyx_n_s_z_in;
static PyObject *__pyx_n_u_zerobase;
static PyObject *__pyx_n_s_zeros;
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_calc_bandwidth(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_x_view, int __pyx_v_n, int __pyx_v_nb); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_2binaryInformationCoefficient_cython(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y, __Pyx_memviewslice __pyx_v_x, int __pyx_v_k, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_neighborhood, __pyx_t_5numpy_double_t __pyx_v_deltay, __pyx_t_5numpy_double_t __pyx_v_miny, __pyx_t_5numpy_double_t __pyx_v_jitter); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_4ConditionalInformationCoefficient_cython(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y, __Pyx_memviewslice __pyx_v_x, __Pyx_memviewslice __pyx_v_z, int __pyx_v_k, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_neighborhood, __pyx_t_5numpy_double_t __pyx_v_deltay, __pyx_t_5numpy_double_t __pyx_v_miny, __pyx_t_5numpy_double_t __pyx_v_jitter); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_6findBestCIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_8rankCIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_10findBestIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_12rankIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_14drawTarget(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_16drawFeature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_seedID); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_18drawSeed(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_seed, PyObject *__pyx_v_seedcmap); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_20seedCombine(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_currentseed, PyObject *__pyx_v_newseed); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_22topmatch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_currentseed, PyObject *__pyx_v_y, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_direction, PyObject *__pyx_v_num_top, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_ifSeed, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_collapse, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_target_name, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_24runBenchmark(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_target_file, PyObject *__pyx_v_feature_file, PyObject *__pyx_v_seed_file, PyObject *__pyx_v_target_df, PyObject *__pyx_v_feature_df, PyObject *__pyx_v_seed_df, PyObject *__pyx_v_prefix, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_grid, PyObject *__pyx_v_target_name, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, PyObject *__pyx_v_mode, PyObject *__pyx_v_num_top, PyObject *__pyx_v_low_threshold, PyObject *__pyx_v_high_threshold, PyObject *__pyx_v_collapse, PyObject *__pyx_v_normalize, PyObject *__pyx_v_gene_locus, PyObject *__pyx_v_verbose, PyObject *__pyx_v_max_iteration, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_subset, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_if_intermediate, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_gene_set, PyObject *__pyx_v_gene_separator, PyObject *__pyx_v_gmt_file, PyObject *__pyx_v_alpha, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_tissue_file, PyObject *__pyx_v_gzip); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_26REVEALERInner(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_prefix, PyObject *__pyx_v_comb, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, PyObject *__pyx_v_num_top, PyObject *__pyx_v_verbose, PyObject *__pyx_v_max_iteration, PyObject *__pyx_v_collapse, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_if_intermediate, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_normalize, PyObject *__pyx_v_target_name, PyObject *__pyx_v_report, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_alpha, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_tissue_file, PyObject *__pyx_v_gzip); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_28updatePval(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_pVals, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_target, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_direction, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_30patientfig(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, CYTHON_UNUSED PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_32prepPvalICInd(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_seedcomb, PyObject *__pyx_v_target, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_34calcPvalCIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_results, PyObject *__pyx_v_IC, PyObject *__pyx_v_direction); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_36prepPvalCIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_38calcPvalIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_results, PyObject *__pyx_v_IC, PyObject *__pyx_v_direction); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_40prepPvalIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_42calcIndivisualPvalIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_subcomb, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, CYTHON_UNUSED PyObject *__pyx_v_IC, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_44runIndividualPvalIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_x_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_46calcBootstrap(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_subcomb, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_k, CYTHON_UNUSED PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_IC, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_48runBootstrap(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_50calcBootstrapIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_subcomb, PyObject *__pyx_v_k, CYTHON_UNUSED PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_IC, PyObject *__pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_52runBootstrapIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_11plotCluster_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_54plotCluster(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_CICs, PyObject *__pyx_v_size, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_pVals, PyObject *__pyx_v_num_top, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_gmt); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_56pileRank(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_rank, PyObject *__pyx_v_num_top, PyObject *__pyx_v_prefix, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_nitr); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_10savetopfig_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_58savetopfig(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_CICs, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_pVals, PyObject *__pyx_v_num_top, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_pilesize, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_18saveresfigWithPval_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_60saveresfigWithPval(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_seedids, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_pVals, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_gmt); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_10saveresfig_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_62saveresfig(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_seedids, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_gmt); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_64topMatches(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_y, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_seed); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_66seedcomball(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_seed_name); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_68readInput(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_target_file, PyObject *__pyx_v_feature_file, PyObject *__pyx_v_seed_file, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_target_name, PyObject *__pyx_v_direction, PyObject *__pyx_v_gene_locus, PyObject *__pyx_v_low_threshold, PyObject *__pyx_v_high_threshold, PyObject *__pyx_v_subset, PyObject *__pyx_v_gene_set, PyObject *__pyx_v_gene_separator, CYTHON_UNUSED PyObject *__pyx_v_thread_number, PyObject *__pyx_v_tissue_file); /* proto */
static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_70check_inset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_gene_set, PyObject *__pyx_v_feature_name, PyObject *__pyx_v_gene_separator); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object); /* proto */
static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_16_memoryviewslice_4base___get__(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_copy = {0, &__pyx_n_s_copy, 0, 0, 0};
static PyObject *__pyx_float__9;
static PyObject *__pyx_float_0_5;
static PyObject *__pyx_float_0_9;
static PyObject *__pyx_float_2_0;
static PyObject *__pyx_float_0_65;
static PyObject *__pyx_float_13_4;
static PyObject *__pyx_float_14_2;
static PyObject *__pyx_float_15_4;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_11;
static PyObject *__pyx_int_12;
static PyObject *__pyx_int_20;
static PyObject *__pyx_int_30;
static PyObject *__pyx_int_34;
static PyObject *__pyx_int_90;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_100;
static PyObject *__pyx_int_110;
static PyObject *__pyx_int_120;
static PyObject *__pyx_int_122;
static PyObject *__pyx_int_132;
static PyObject *__pyx_int_134;
static PyObject *__pyx_int_142;
static PyObject *__pyx_int_144;
static PyObject *__pyx_int_154;
static PyObject *__pyx_int_256;
static PyObject *__pyx_int_1000;
static PyObject *__pyx_int_10000;
static PyObject *__pyx_int_19981218;
static PyObject *__pyx_int_184977713;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_int_neg_100;
static PyObject *__pyx_k__6;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_slice__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_slice__13;
static PyObject *__pyx_slice__20;
static PyObject *__pyx_slice__33;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__88;
static PyObject *__pyx_tuple__90;
static PyObject *__pyx_tuple__92;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_tuple__96;
static PyObject *__pyx_tuple__98;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__102;
static PyObject *__pyx_tuple__104;
static PyObject *__pyx_tuple__106;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__110;
static PyObject *__pyx_tuple__112;
static PyObject *__pyx_tuple__114;
static PyObject *__pyx_tuple__116;
static PyObject *__pyx_tuple__118;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__121;
static PyObject *__pyx_tuple__122;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__124;
static PyObject *__pyx_tuple__125;
static PyObject *__pyx_codeobj__87;
static PyObject *__pyx_codeobj__89;
static PyObject *__pyx_codeobj__91;
static PyObject *__pyx_codeobj__93;
static PyObject *__pyx_codeobj__95;
static PyObject *__pyx_codeobj__97;
static PyObject *__pyx_codeobj__99;
static PyObject *__pyx_codeobj__101;
static PyObject *__pyx_codeobj__103;
static PyObject *__pyx_codeobj__105;
static PyObject *__pyx_codeobj__107;
static PyObject *__pyx_codeobj__109;
static PyObject *__pyx_codeobj__111;
static PyObject *__pyx_codeobj__113;
static PyObject *__pyx_codeobj__115;
static PyObject *__pyx_codeobj__117;
static PyObject *__pyx_codeobj__119;
static PyObject *__pyx_codeobj__126;
/* Late includes */

/* "revealer/REVEALER_runbenchmark.pyx":55
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline density VR_den_bin(             # <<<<<<<<<<<<<<
 *     int n,              #Size of example
 *     int nb,             #nb to calculate bcv
 */

static CYTHON_INLINE struct __pyx_t_8revealer_21REVEALER_runbenchmark_density __pyx_f_8revealer_21REVEALER_runbenchmark_VR_den_bin(int __pyx_v_n, int __pyx_v_nb, __pyx_t_5numpy_double_t *__pyx_v_x, __pyx_t_5numpy_double_t __pyx_v_x_min, __pyx_t_5numpy_double_t __pyx_v_x_max) {
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_ii;
  int __pyx_v_jj;
  int __pyx_v_iij;
  struct __pyx_t_8revealer_21REVEALER_runbenchmark_density __pyx_v_ret;
  __pyx_t_5numpy_double_t __pyx_v_rang;
  struct __pyx_t_8revealer_21REVEALER_runbenchmark_density __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;

  /* "revealer/REVEALER_runbenchmark.pyx":69
 *     cdef int i, j, ii, jj, iij
 *     cdef density ret
 *     ret.cnt = <np.uint32_t*> malloc(nb * sizeof(np.uint32_t))             # <<<<<<<<<<<<<<
 *     for i in range(nb):
 *         ret.cnt[i] = 0
 */
  __pyx_v_ret.cnt = ((__pyx_t_5numpy_uint32_t *)malloc((__pyx_v_nb * (sizeof(__pyx_t_5numpy_uint32_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":70
 *     cdef density ret
 *     ret.cnt = <np.uint32_t*> malloc(nb * sizeof(np.uint32_t))
 *     for i in range(nb):             # <<<<<<<<<<<<<<
 *         ret.cnt[i] = 0
 * 
 */
  __pyx_t_1 = __pyx_v_nb;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":71
 *     ret.cnt = <np.uint32_t*> malloc(nb * sizeof(np.uint32_t))
 *     for i in range(nb):
 *         ret.cnt[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t rang = (x_max - x_min) * 1.01
 */
    (__pyx_v_ret.cnt[__pyx_v_i]) = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":73
 *         ret.cnt[i] = 0
 * 
 *     cdef np.double_t rang = (x_max - x_min) * 1.01             # <<<<<<<<<<<<<<
 *     ret.d = rang / <np.double_t>nb
 * 
 */
  __pyx_v_rang = ((__pyx_v_x_max - __pyx_v_x_min) * 1.01);

  /* "revealer/REVEALER_runbenchmark.pyx":74
 * 
 *     cdef np.double_t rang = (x_max - x_min) * 1.01
 *     ret.d = rang / <np.double_t>nb             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t x_i, x_j
 */
  __pyx_v_ret.d = (__pyx_v_rang / ((__pyx_t_5numpy_double_t)__pyx_v_nb));

  /* "revealer/REVEALER_runbenchmark.pyx":77
 * 
 *     cdef np.double_t x_i, x_j
 *     for i in range(1,n):             # <<<<<<<<<<<<<<
 *         ii = (int)(x[i] / ret.d)
 *         for j in range(i):
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 1; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":78
 *     cdef np.double_t x_i, x_j
 *     for i in range(1,n):
 *         ii = (int)(x[i] / ret.d)             # <<<<<<<<<<<<<<
 *         for j in range(i):
 *             jj = (int)(x[j] / ret.d)
 */
    __pyx_v_ii = ((int)((__pyx_v_x[__pyx_v_i]) / __pyx_v_ret.d));

    /* "revealer/REVEALER_runbenchmark.pyx":79
 *     for i in range(1,n):
 *         ii = (int)(x[i] / ret.d)
 *         for j in range(i):             # <<<<<<<<<<<<<<
 *             jj = (int)(x[j] / ret.d)
 *             iij = (ii - jj)
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = __pyx_t_4;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_j = __pyx_t_6;

      /* "revealer/REVEALER_runbenchmark.pyx":80
 *         ii = (int)(x[i] / ret.d)
 *         for j in range(i):
 *             jj = (int)(x[j] / ret.d)             # <<<<<<<<<<<<<<
 *             iij = (ii - jj)
 *             iij = iij if iij >= 0 else -iij
 */
      __pyx_v_jj = ((int)((__pyx_v_x[__pyx_v_j]) / __pyx_v_ret.d));

      /* "revealer/REVEALER_runbenchmark.pyx":81
 *         for j in range(i):
 *             jj = (int)(x[j] / ret.d)
 *             iij = (ii - jj)             # <<<<<<<<<<<<<<
 *             iij = iij if iij >= 0 else -iij
 *             if(ret.cnt[iij] == INT_MAX):
 */
      __pyx_v_iij = (__pyx_v_ii - __pyx_v_jj);

      /* "revealer/REVEALER_runbenchmark.pyx":82
 *             jj = (int)(x[j] / ret.d)
 *             iij = (ii - jj)
 *             iij = iij if iij >= 0 else -iij             # <<<<<<<<<<<<<<
 *             if(ret.cnt[iij] == INT_MAX):
 *                 printf("maximum count exceeded in pairwise distance binning\n")
 */
      if (((__pyx_v_iij >= 0) != 0)) {
        __pyx_t_7 = __pyx_v_iij;
      } else {
        __pyx_t_7 = (-__pyx_v_iij);
      }
      __pyx_v_iij = __pyx_t_7;

      /* "revealer/REVEALER_runbenchmark.pyx":83
 *             iij = (ii - jj)
 *             iij = iij if iij >= 0 else -iij
 *             if(ret.cnt[iij] == INT_MAX):             # <<<<<<<<<<<<<<
 *                 printf("maximum count exceeded in pairwise distance binning\n")
 *             ret.cnt[iij] += 1
 */
      __pyx_t_8 = (((__pyx_v_ret.cnt[__pyx_v_iij]) == INT_MAX) != 0);
      if (__pyx_t_8) {

        /* "revealer/REVEALER_runbenchmark.pyx":84
 *             iij = iij if iij >= 0 else -iij
 *             if(ret.cnt[iij] == INT_MAX):
 *                 printf("maximum count exceeded in pairwise distance binning\n")             # <<<<<<<<<<<<<<
 *             ret.cnt[iij] += 1
 *     return ret
 */
        (void)(printf(((char const *)"maximum count exceeded in pairwise distance binning\n")));

        /* "revealer/REVEALER_runbenchmark.pyx":83
 *             iij = (ii - jj)
 *             iij = iij if iij >= 0 else -iij
 *             if(ret.cnt[iij] == INT_MAX):             # <<<<<<<<<<<<<<
 *                 printf("maximum count exceeded in pairwise distance binning\n")
 *             ret.cnt[iij] += 1
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":85
 *             if(ret.cnt[iij] == INT_MAX):
 *                 printf("maximum count exceeded in pairwise distance binning\n")
 *             ret.cnt[iij] += 1             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
      __pyx_t_7 = __pyx_v_iij;
      (__pyx_v_ret.cnt[__pyx_t_7]) = ((__pyx_v_ret.cnt[__pyx_t_7]) + 1);
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":86
 *                 printf("maximum count exceeded in pairwise distance binning\n")
 *             ret.cnt[iij] += 1
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":55
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline density VR_den_bin(             # <<<<<<<<<<<<<<
 *     int n,              #Size of example
 *     int nb,             #nb to calculate bcv
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":92
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t VR_bcv_bin(             # <<<<<<<<<<<<<<
 *     int n,          #N value
 *     int nb,         #nb value to calculate bcv
 */

static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_VR_bcv_bin(int __pyx_v_n, int __pyx_v_nb, struct __pyx_t_8revealer_21REVEALER_runbenchmark_density __pyx_v_den, __pyx_t_5numpy_double_t __pyx_v_h) {
  __pyx_t_5numpy_double_t __pyx_v_total_sum;
  __pyx_t_5numpy_double_t __pyx_v_delta;
  __pyx_t_5numpy_double_t __pyx_v_term;
  __pyx_t_5numpy_double_t __pyx_v_hh;
  int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "revealer/REVEALER_runbenchmark.pyx":103
 *     '''
 * 
 *     cdef np.double_t total_sum = 0.0             # <<<<<<<<<<<<<<
 *     cdef np.double_t delta, term
 *     cdef np.double_t hh = h / 4.0
 */
  __pyx_v_total_sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":105
 *     cdef np.double_t total_sum = 0.0
 *     cdef np.double_t delta, term
 *     cdef np.double_t hh = h / 4.0             # <<<<<<<<<<<<<<
 *     cdef int i
 *     for i in range(nb):
 */
  __pyx_v_hh = (__pyx_v_h / ((__pyx_t_5numpy_double_t)4.0));

  /* "revealer/REVEALER_runbenchmark.pyx":107
 *     cdef np.double_t hh = h / 4.0
 *     cdef int i
 *     for i in range(nb):             # <<<<<<<<<<<<<<
 *         delta = (i * den.d / hh)
 *         delta *= delta
 */
  __pyx_t_1 = __pyx_v_nb;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":108
 *     cdef int i
 *     for i in range(nb):
 *         delta = (i * den.d / hh)             # <<<<<<<<<<<<<<
 *         delta *= delta
 *         if delta >= DELMAX:
 */
    __pyx_v_delta = ((__pyx_v_i * __pyx_v_den.d) / __pyx_v_hh);

    /* "revealer/REVEALER_runbenchmark.pyx":109
 *     for i in range(nb):
 *         delta = (i * den.d / hh)
 *         delta *= delta             # <<<<<<<<<<<<<<
 *         if delta >= DELMAX:
 *             break
 */
    __pyx_v_delta = (__pyx_v_delta * __pyx_v_delta);

    /* "revealer/REVEALER_runbenchmark.pyx":110
 *         delta = (i * den.d / hh)
 *         delta *= delta
 *         if delta >= DELMAX:             # <<<<<<<<<<<<<<
 *             break
 *         term = exp(-1.0 * delta / 4.0) * (delta * delta - 12.0 * delta + 12.0)
 */
    __pyx_t_4 = ((__pyx_v_delta >= __pyx_v_8revealer_21REVEALER_runbenchmark_DELMAX) != 0);
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":111
 *         delta *= delta
 *         if delta >= DELMAX:
 *             break             # <<<<<<<<<<<<<<
 *         term = exp(-1.0 * delta / 4.0) * (delta * delta - 12.0 * delta + 12.0)
 *         total_sum += term * den.cnt[i]
 */
      goto __pyx_L4_break;

      /* "revealer/REVEALER_runbenchmark.pyx":110
 *         delta = (i * den.d / hh)
 *         delta *= delta
 *         if delta >= DELMAX:             # <<<<<<<<<<<<<<
 *             break
 *         term = exp(-1.0 * delta / 4.0) * (delta * delta - 12.0 * delta + 12.0)
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":112
 *         if delta >= DELMAX:
 *             break
 *         term = exp(-1.0 * delta / 4.0) * (delta * delta - 12.0 * delta + 12.0)             # <<<<<<<<<<<<<<
 *         total_sum += term * den.cnt[i]
 *     return 1.0 / (2.0 * n * hh * sqrt(M_PI)) + total_sum / (64.0 * n * n * hh * sqrt(M_PI))
 */
    __pyx_v_term = (exp(((-1.0 * __pyx_v_delta) / ((__pyx_t_5numpy_double_t)4.0))) * (((__pyx_v_delta * __pyx_v_delta) - (12.0 * __pyx_v_delta)) + 12.0));

    /* "revealer/REVEALER_runbenchmark.pyx":113
 *             break
 *         term = exp(-1.0 * delta / 4.0) * (delta * delta - 12.0 * delta + 12.0)
 *         total_sum += term * den.cnt[i]             # <<<<<<<<<<<<<<
 *     return 1.0 / (2.0 * n * hh * sqrt(M_PI)) + total_sum / (64.0 * n * n * hh * sqrt(M_PI))
 * 
 */
    __pyx_v_total_sum = (__pyx_v_total_sum + (__pyx_v_term * (__pyx_v_den.cnt[__pyx_v_i])));
  }
  __pyx_L4_break:;

  /* "revealer/REVEALER_runbenchmark.pyx":114
 *         term = exp(-1.0 * delta / 4.0) * (delta * delta - 12.0 * delta + 12.0)
 *         total_sum += term * den.cnt[i]
 *     return 1.0 / (2.0 * n * hh * sqrt(M_PI)) + total_sum / (64.0 * n * n * hh * sqrt(M_PI))             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = ((((__pyx_t_5numpy_double_t)1.0) / (((2.0 * __pyx_v_n) * __pyx_v_hh) * sqrt(M_PI))) + (__pyx_v_total_sum / ((((64.0 * __pyx_v_n) * __pyx_v_n) * __pyx_v_hh) * sqrt(M_PI))));
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":92
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t VR_bcv_bin(             # <<<<<<<<<<<<<<
 *     int n,          #N value
 *     int nb,         #nb value to calculate bcv
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":120
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t r_var(             # <<<<<<<<<<<<<<
 *     np.double_t* x,     #Pointer to list
 *     int n               #N value
 */

static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_r_var(__pyx_t_5numpy_double_t *__pyx_v_x, int __pyx_v_n) {
  __pyx_t_5numpy_double_t __pyx_v_mean;
  int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_v_out;
  __pyx_t_5numpy_double_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "revealer/REVEALER_runbenchmark.pyx":129
 *     '''
 * 
 *     cdef np.double_t mean = 0.0             # <<<<<<<<<<<<<<
 *     cdef int i
 *     for i in range(n):
 */
  __pyx_v_mean = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":131
 *     cdef np.double_t mean = 0.0
 *     cdef int i
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         mean += x[i]
 *     mean = mean / n
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":132
 *     cdef int i
 *     for i in range(n):
 *         mean += x[i]             # <<<<<<<<<<<<<<
 *     mean = mean / n
 * 
 */
    __pyx_v_mean = (__pyx_v_mean + (__pyx_v_x[__pyx_v_i]));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":133
 *     for i in range(n):
 *         mean += x[i]
 *     mean = mean / n             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t out = 0.0
 */
  __pyx_v_mean = (__pyx_v_mean / ((__pyx_t_5numpy_double_t)__pyx_v_n));

  /* "revealer/REVEALER_runbenchmark.pyx":135
 *     mean = mean / n
 * 
 *     cdef np.double_t out = 0.0             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  __pyx_v_out = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":137
 *     cdef np.double_t out = 0.0
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         out += (x[i] - mean) ** 2
 *     return out / (n - 1.0)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":138
 * 
 *     for i in range(n):
 *         out += (x[i] - mean) ** 2             # <<<<<<<<<<<<<<
 *     return out / (n - 1.0)
 * 
 */
    __pyx_v_out = (__pyx_v_out + pow(((__pyx_v_x[__pyx_v_i]) - __pyx_v_mean), 2.0));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":139
 *     for i in range(n):
 *         out += (x[i] - mean) ** 2
 *     return out / (n - 1.0)             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = (__pyx_v_out / ((__pyx_t_5numpy_double_t)(__pyx_v_n - 1.0)));
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":120
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t r_var(             # <<<<<<<<<<<<<<
 *     np.double_t* x,     #Pointer to list
 *     int n               #N value
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":145
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t sign(             # <<<<<<<<<<<<<<
 *     np.double_t x   #Value to be get sign
 *     ) nogil:
 */

static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_sign(__pyx_t_5numpy_double_t __pyx_v_x) {
  __pyx_t_5numpy_double_t __pyx_r;
  int __pyx_t_1;

  /* "revealer/REVEALER_runbenchmark.pyx":153
 *     '''
 * 
 *     if x < 0:             # <<<<<<<<<<<<<<
 *         return -1.0
 *     elif x == 0.0:
 */
  __pyx_t_1 = ((__pyx_v_x < 0.0) != 0);
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":154
 * 
 *     if x < 0:
 *         return -1.0             # <<<<<<<<<<<<<<
 *     elif x == 0.0:
 *         return 0.0
 */
    __pyx_r = -1.0;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":153
 *     '''
 * 
 *     if x < 0:             # <<<<<<<<<<<<<<
 *         return -1.0
 *     elif x == 0.0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":155
 *     if x < 0:
 *         return -1.0
 *     elif x == 0.0:             # <<<<<<<<<<<<<<
 *         return 0.0
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_x == 0.0) != 0);
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":156
 *         return -1.0
 *     elif x == 0.0:
 *         return 0.0             # <<<<<<<<<<<<<<
 *     else:
 *         return 1.0
 */
    __pyx_r = 0.0;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":155
 *     if x < 0:
 *         return -1.0
 *     elif x == 0.0:             # <<<<<<<<<<<<<<
 *         return 0.0
 *     else:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":158
 *         return 0.0
 *     else:
 *         return 1.0             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  /*else*/ {
    __pyx_r = 1.0;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":145
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t sign(             # <<<<<<<<<<<<<<
 *     np.double_t x   #Value to be get sign
 *     ) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":164
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cdef inline int imin(             # <<<<<<<<<<<<<<
 *     int x,  #X value
 *     int y   #Y value
 */

static CYTHON_INLINE int __pyx_f_8revealer_21REVEALER_runbenchmark_imin(int __pyx_v_x, int __pyx_v_y) {
  int __pyx_r;
  int __pyx_t_1;

  /* "revealer/REVEALER_runbenchmark.pyx":173
 *     '''
 * 
 *     if x < y:             # <<<<<<<<<<<<<<
 *         return x
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_x < __pyx_v_y) != 0);
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":174
 * 
 *     if x < y:
 *         return x             # <<<<<<<<<<<<<<
 *     else:
 *         return y
 */
    __pyx_r = __pyx_v_x;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":173
 *     '''
 * 
 *     if x < y:             # <<<<<<<<<<<<<<
 *         return x
 *     else:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":176
 *         return x
 *     else:
 *         return y             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  /*else*/ {
    __pyx_r = __pyx_v_y;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":164
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cdef inline int imin(             # <<<<<<<<<<<<<<
 *     int x,  #X value
 *     int y   #Y value
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":182
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline int imax(             # <<<<<<<<<<<<<<
 *     int x,  #X value
 *     int y   #Y value
 */

static CYTHON_INLINE int __pyx_f_8revealer_21REVEALER_runbenchmark_imax(int __pyx_v_x, int __pyx_v_y) {
  int __pyx_r;
  int __pyx_t_1;

  /* "revealer/REVEALER_runbenchmark.pyx":191
 *     '''
 * 
 *     if x > y:             # <<<<<<<<<<<<<<
 *         return x
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_x > __pyx_v_y) != 0);
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":192
 * 
 *     if x > y:
 *         return x             # <<<<<<<<<<<<<<
 *     else:
 *         return y
 */
    __pyx_r = __pyx_v_x;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":191
 *     '''
 * 
 *     if x > y:             # <<<<<<<<<<<<<<
 *         return x
 *     else:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":194
 *         return x
 *     else:
 *         return y             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  /*else*/ {
    __pyx_r = __pyx_v_y;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":182
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline int imax(             # <<<<<<<<<<<<<<
 *     int x,  #X value
 *     int y   #Y value
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":200
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cdef inline int rint(             # <<<<<<<<<<<<<<
 *     np.double_t x   #Value to be converted to int
 *     ) nogil:
 */

static CYTHON_INLINE int __pyx_f_8revealer_21REVEALER_runbenchmark_rint(__pyx_t_5numpy_double_t __pyx_v_x) {
  int __pyx_r;

  /* "revealer/REVEALER_runbenchmark.pyx":208
 *     '''
 * 
 *     return <int> round(x)             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = ((int)round(__pyx_v_x));
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":200
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cdef inline int rint(             # <<<<<<<<<<<<<<
 *     np.double_t x   #Value to be converted to int
 *     ) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":214
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cdef np.double_t findmin(             # <<<<<<<<<<<<<<
 *     np.double_t[:] arr,     #List to find minimum value
 *     int size                #Size of list
 */

static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__Pyx_memviewslice __pyx_v_arr, int __pyx_v_size) {
  __pyx_t_5numpy_double_t __pyx_v_minVal;
  int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;

  /* "revealer/REVEALER_runbenchmark.pyx":223
 *     '''
 * 
 *     cdef np.double_t minVal = arr[0]             # <<<<<<<<<<<<<<
 *     cdef int i = 0
 *     for i in range(size):
 */
  __pyx_t_1 = 0;
  __pyx_v_minVal = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_1 * __pyx_v_arr.strides[0]) )));

  /* "revealer/REVEALER_runbenchmark.pyx":224
 * 
 *     cdef np.double_t minVal = arr[0]
 *     cdef int i = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         if arr[i] < minVal:
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":225
 *     cdef np.double_t minVal = arr[0]
 *     cdef int i = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         if arr[i] < minVal:
 *             minVal = arr[i]
 */
  __pyx_t_2 = __pyx_v_size;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "revealer/REVEALER_runbenchmark.pyx":226
 *     cdef int i = 0
 *     for i in range(size):
 *         if arr[i] < minVal:             # <<<<<<<<<<<<<<
 *             minVal = arr[i]
 *     return minVal
 */
    __pyx_t_1 = __pyx_v_i;
    __pyx_t_5 = (((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_1 * __pyx_v_arr.strides[0]) ))) < __pyx_v_minVal) != 0);
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":227
 *     for i in range(size):
 *         if arr[i] < minVal:
 *             minVal = arr[i]             # <<<<<<<<<<<<<<
 *     return minVal
 * 
 */
      __pyx_t_1 = __pyx_v_i;
      __pyx_v_minVal = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_1 * __pyx_v_arr.strides[0]) )));

      /* "revealer/REVEALER_runbenchmark.pyx":226
 *     cdef int i = 0
 *     for i in range(size):
 *         if arr[i] < minVal:             # <<<<<<<<<<<<<<
 *             minVal = arr[i]
 *     return minVal
 */
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":228
 *         if arr[i] < minVal:
 *             minVal = arr[i]
 *     return minVal             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_minVal;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":214
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cdef np.double_t findmin(             # <<<<<<<<<<<<<<
 *     np.double_t[:] arr,     #List to find minimum value
 *     int size                #Size of list
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":234
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cdef np.double_t findmax(             # <<<<<<<<<<<<<<
 *     np.double_t[:] arr,     #List to find minimum value
 *     int size                #Size of list
 */

static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__Pyx_memviewslice __pyx_v_arr, int __pyx_v_size) {
  __pyx_t_5numpy_double_t __pyx_v_minVal;
  int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;

  /* "revealer/REVEALER_runbenchmark.pyx":243
 *     '''
 * 
 *     cdef np.double_t minVal = arr[0]             # <<<<<<<<<<<<<<
 *     cdef int i = 0
 *     for i in range(size):
 */
  __pyx_t_1 = 0;
  __pyx_v_minVal = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_1 * __pyx_v_arr.strides[0]) )));

  /* "revealer/REVEALER_runbenchmark.pyx":244
 * 
 *     cdef np.double_t minVal = arr[0]
 *     cdef int i = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         if arr[i] > minVal:
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":245
 *     cdef np.double_t minVal = arr[0]
 *     cdef int i = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         if arr[i] > minVal:
 *             minVal = arr[i]
 */
  __pyx_t_2 = __pyx_v_size;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "revealer/REVEALER_runbenchmark.pyx":246
 *     cdef int i = 0
 *     for i in range(size):
 *         if arr[i] > minVal:             # <<<<<<<<<<<<<<
 *             minVal = arr[i]
 *     return minVal
 */
    __pyx_t_1 = __pyx_v_i;
    __pyx_t_5 = (((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_1 * __pyx_v_arr.strides[0]) ))) > __pyx_v_minVal) != 0);
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":247
 *     for i in range(size):
 *         if arr[i] > minVal:
 *             minVal = arr[i]             # <<<<<<<<<<<<<<
 *     return minVal
 * 
 */
      __pyx_t_1 = __pyx_v_i;
      __pyx_v_minVal = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_1 * __pyx_v_arr.strides[0]) )));

      /* "revealer/REVEALER_runbenchmark.pyx":246
 *     cdef int i = 0
 *     for i in range(size):
 *         if arr[i] > minVal:             # <<<<<<<<<<<<<<
 *             minVal = arr[i]
 *     return minVal
 */
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":248
 *         if arr[i] > minVal:
 *             minVal = arr[i]
 *     return minVal             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_minVal;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":234
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cdef np.double_t findmax(             # <<<<<<<<<<<<<<
 *     np.double_t[:] arr,     #List to find minimum value
 *     int size                #Size of list
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":254
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cpdef np.double_t calc_bandwidth(             # <<<<<<<<<<<<<<
 *     np.double_t[:] x_view,  #List of double
 *     int n,                  #Size of list
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_1calc_bandwidth(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_calc_bandwidth(__Pyx_memviewslice __pyx_v_x_view, int __pyx_v_n, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_calc_bandwidth *__pyx_optional_args) {
  int __pyx_v_nb = ((int)0x3E8);
  CYTHON_UNUSED int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_v_x_min;
  __pyx_t_5numpy_double_t __pyx_v_x_max;
  __pyx_t_5numpy_double_t *__pyx_v_x_ptr;
  __pyx_t_5numpy_double_t __pyx_v_ret;
  __pyx_t_5numpy_double_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_double_t __pyx_t_2;
  struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_py_bcv __pyx_t_3;
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_nb = __pyx_optional_args->nb;
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":264
 *     '''
 * 
 *     cdef int i = 0             # <<<<<<<<<<<<<<
 *     cdef np.double_t x_min = findmin(x_view,n)
 *     cdef np.double_t x_max = findmax(x_view,n)
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":265
 * 
 *     cdef int i = 0
 *     cdef np.double_t x_min = findmin(x_view,n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t x_max = findmax(x_view,n)
 *     cdef np.double_t* x_ptr = &x_view[0]
 */
  __pyx_v_x_min = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_x_view, __pyx_v_n);

  /* "revealer/REVEALER_runbenchmark.pyx":266
 *     cdef int i = 0
 *     cdef np.double_t x_min = findmin(x_view,n)
 *     cdef np.double_t x_max = findmax(x_view,n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t* x_ptr = &x_view[0]
 *     cdef np.double_t ret = 0.0
 */
  __pyx_v_x_max = __pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_v_x_view, __pyx_v_n);

  /* "revealer/REVEALER_runbenchmark.pyx":267
 *     cdef np.double_t x_min = findmin(x_view,n)
 *     cdef np.double_t x_max = findmax(x_view,n)
 *     cdef np.double_t* x_ptr = &x_view[0]             # <<<<<<<<<<<<<<
 *     cdef np.double_t ret = 0.0
 * 
 */
  __pyx_t_1 = 0;
  __pyx_v_x_ptr = (&(*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_x_view.data + __pyx_t_1 * __pyx_v_x_view.strides[0]) ))));

  /* "revealer/REVEALER_runbenchmark.pyx":268
 *     cdef np.double_t x_max = findmax(x_view,n)
 *     cdef np.double_t* x_ptr = &x_view[0]
 *     cdef np.double_t ret = 0.0             # <<<<<<<<<<<<<<
 * 
 *     ret = py_bcv(x_ptr, n, x_min, x_max, nb)
 */
  __pyx_v_ret = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":270
 *     cdef np.double_t ret = 0.0
 * 
 *     ret = py_bcv(x_ptr, n, x_min, x_max, nb)             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.nb = __pyx_v_nb;
  __pyx_t_2 = __pyx_f_8revealer_21REVEALER_runbenchmark_py_bcv(__pyx_v_x_ptr, __pyx_v_n, __pyx_v_x_min, __pyx_v_x_max, &__pyx_t_3); 
  __pyx_v_ret = __pyx_t_2;

  /* "revealer/REVEALER_runbenchmark.pyx":271
 * 
 *     ret = py_bcv(x_ptr, n, x_min, x_max, nb)
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":254
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cpdef np.double_t calc_bandwidth(             # <<<<<<<<<<<<<<
 *     np.double_t[:] x_view,  #List of double
 *     int n,                  #Size of list
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_1calc_bandwidth(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_calc_bandwidth[] = "\n    Function to calculate bandwidth\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_1calc_bandwidth(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_x_view = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_n;
  int __pyx_v_nb;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calc_bandwidth (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x_view,&__pyx_n_s_n,&__pyx_n_s_nb,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_x_view)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calc_bandwidth", 0, 2, 3, 1); __PYX_ERR(0, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nb);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "calc_bandwidth") < 0)) __PYX_ERR(0, 254, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_x_view = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_x_view.memview)) __PYX_ERR(0, 255, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 256, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_nb = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_nb == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
    } else {
      __pyx_v_nb = ((int)0x3E8);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calc_bandwidth", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 254, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calc_bandwidth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_calc_bandwidth(__pyx_self, __pyx_v_x_view, __pyx_v_n, __pyx_v_nb);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_calc_bandwidth(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_x_view, int __pyx_v_n, int __pyx_v_nb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_double_t __pyx_t_1;
  struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_calc_bandwidth __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calc_bandwidth", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.nb = __pyx_v_nb;
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_calc_bandwidth(__pyx_v_x_view, __pyx_v_n, 0, &__pyx_t_2); 
  __pyx_t_3 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calc_bandwidth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_x_view, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":277
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t py_bcv(             # <<<<<<<<<<<<<<
 *     np.double_t* x,     #Pointer to list x
 *     int n,              #Size of sample
 */

static CYTHON_INLINE __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_py_bcv(__pyx_t_5numpy_double_t *__pyx_v_x, int __pyx_v_n, __pyx_t_5numpy_double_t __pyx_v_x_min, __pyx_t_5numpy_double_t __pyx_v_x_max, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_py_bcv *__pyx_optional_args) {
  int __pyx_v_nb = ((int)0x3E8);
  __pyx_t_5numpy_double_t __pyx_v_h;
  __pyx_t_5numpy_double_t __pyx_v_lower;
  __pyx_t_5numpy_double_t __pyx_v_upper;
  struct __pyx_t_8revealer_21REVEALER_runbenchmark_density __pyx_v_den;
  double __pyx_v_hmax;
  __pyx_t_5numpy_double_t __pyx_v_x1;
  __pyx_t_5numpy_double_t __pyx_v_x2;
  __pyx_t_5numpy_double_t __pyx_v_xatol;
  int __pyx_v_maxfun;
  int __pyx_v_num;
  __pyx_t_5numpy_double_t __pyx_v_sqrt_eps;
  __pyx_t_5numpy_double_t __pyx_v_golden_mean;
  __pyx_t_5numpy_double_t __pyx_v_a;
  __pyx_t_5numpy_double_t __pyx_v_b;
  __pyx_t_5numpy_double_t __pyx_v_nfc;
  __pyx_t_5numpy_double_t __pyx_v_xf;
  __pyx_t_5numpy_double_t __pyx_v_fulc;
  __pyx_t_5numpy_double_t __pyx_v_rat;
  __pyx_t_5numpy_double_t __pyx_v_e;
  __pyx_t_5numpy_double_t __pyx_v_fx;
  __pyx_t_5numpy_double_t __pyx_v_ffulc;
  __pyx_t_5numpy_double_t __pyx_v_fnfc;
  __pyx_t_5numpy_double_t __pyx_v_xm;
  __pyx_t_5numpy_double_t __pyx_v_tol1;
  __pyx_t_5numpy_double_t __pyx_v_tol2;
  __pyx_t_5numpy_double_t __pyx_v_r;
  __pyx_t_5numpy_double_t __pyx_v_p;
  __pyx_t_5numpy_double_t __pyx_v_q;
  __pyx_t_5numpy_double_t __pyx_v_golden;
  __pyx_t_5numpy_double_t __pyx_v_si;
  __pyx_t_5numpy_double_t __pyx_v_fu;
  __pyx_t_5numpy_double_t __pyx_r;
  int __pyx_t_1;
  __pyx_t_5numpy_double_t __pyx_t_2;
  __pyx_t_5numpy_double_t __pyx_t_3;
  int __pyx_t_4;
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_nb = __pyx_optional_args->nb;
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":291
 *     cdef np.double_t h, lower, upper
 *     cdef density den
 *     if(n == 0):             # <<<<<<<<<<<<<<
 *         printf("'x' has length zero\n")
 *         return -1
 */
  __pyx_t_1 = ((__pyx_v_n == 0) != 0);
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":292
 *     cdef density den
 *     if(n == 0):
 *         printf("'x' has length zero\n")             # <<<<<<<<<<<<<<
 *         return -1
 *     hmax = 1.144 * sqrt(r_var(x, n)) * (n**(-1.0/5.0)) * 4 #Why *4?
 */
    (void)(printf(((char const *)"'x' has length zero\n")));

    /* "revealer/REVEALER_runbenchmark.pyx":293
 *     if(n == 0):
 *         printf("'x' has length zero\n")
 *         return -1             # <<<<<<<<<<<<<<
 *     hmax = 1.144 * sqrt(r_var(x, n)) * (n**(-1.0/5.0)) * 4 #Why *4?
 *     lower = 0.1 * hmax
 */
    __pyx_r = -1.0;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":291
 *     cdef np.double_t h, lower, upper
 *     cdef density den
 *     if(n == 0):             # <<<<<<<<<<<<<<
 *         printf("'x' has length zero\n")
 *         return -1
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":294
 *         printf("'x' has length zero\n")
 *         return -1
 *     hmax = 1.144 * sqrt(r_var(x, n)) * (n**(-1.0/5.0)) * 4 #Why *4?             # <<<<<<<<<<<<<<
 *     lower = 0.1 * hmax
 *     upper = hmax
 */
  __pyx_v_hmax = (((1.144 * sqrt(__pyx_f_8revealer_21REVEALER_runbenchmark_r_var(__pyx_v_x, __pyx_v_n))) * pow(((double)__pyx_v_n), (-1.0 / 5.0))) * 4.0);

  /* "revealer/REVEALER_runbenchmark.pyx":295
 *         return -1
 *     hmax = 1.144 * sqrt(r_var(x, n)) * (n**(-1.0/5.0)) * 4 #Why *4?
 *     lower = 0.1 * hmax             # <<<<<<<<<<<<<<
 *     upper = hmax
 *     den = VR_den_bin(n, nb, x, x_min, x_max)
 */
  __pyx_v_lower = (0.1 * __pyx_v_hmax);

  /* "revealer/REVEALER_runbenchmark.pyx":296
 *     hmax = 1.144 * sqrt(r_var(x, n)) * (n**(-1.0/5.0)) * 4 #Why *4?
 *     lower = 0.1 * hmax
 *     upper = hmax             # <<<<<<<<<<<<<<
 *     den = VR_den_bin(n, nb, x, x_min, x_max)
 * 
 */
  __pyx_v_upper = __pyx_v_hmax;

  /* "revealer/REVEALER_runbenchmark.pyx":297
 *     lower = 0.1 * hmax
 *     upper = hmax
 *     den = VR_den_bin(n, nb, x, x_min, x_max)             # <<<<<<<<<<<<<<
 * 
 *     # Optimize
 */
  __pyx_v_den = __pyx_f_8revealer_21REVEALER_runbenchmark_VR_den_bin(__pyx_v_n, __pyx_v_nb, __pyx_v_x, __pyx_v_x_min, __pyx_v_x_max);

  /* "revealer/REVEALER_runbenchmark.pyx":300
 * 
 *     # Optimize
 *     cdef np.double_t x1 = lower, x2 = upper, xatol = 0.1*lower             # <<<<<<<<<<<<<<
 *     cdef int maxfun = 500, num
 *     cdef np.double_t sqrt_eps = sqrt(2.2e-16), golden_mean = 0.5 * (3.0 - sqrt(5.0))
 */
  __pyx_v_x1 = __pyx_v_lower;
  __pyx_v_x2 = __pyx_v_upper;
  __pyx_v_xatol = (0.1 * __pyx_v_lower);

  /* "revealer/REVEALER_runbenchmark.pyx":301
 *     # Optimize
 *     cdef np.double_t x1 = lower, x2 = upper, xatol = 0.1*lower
 *     cdef int maxfun = 500, num             # <<<<<<<<<<<<<<
 *     cdef np.double_t sqrt_eps = sqrt(2.2e-16), golden_mean = 0.5 * (3.0 - sqrt(5.0))
 *     cdef np.double_t a, b, nfc, xf, fulc,
 */
  __pyx_v_maxfun = 0x1F4;

  /* "revealer/REVEALER_runbenchmark.pyx":302
 *     cdef np.double_t x1 = lower, x2 = upper, xatol = 0.1*lower
 *     cdef int maxfun = 500, num
 *     cdef np.double_t sqrt_eps = sqrt(2.2e-16), golden_mean = 0.5 * (3.0 - sqrt(5.0))             # <<<<<<<<<<<<<<
 *     cdef np.double_t a, b, nfc, xf, fulc,
 *     cdef np.double_t rat, e, fx, ffulc, fnfc, xm, tol1, tol2, r, p, q, golden, si, fu
 */
  __pyx_v_sqrt_eps = sqrt(2.2e-16);
  __pyx_v_golden_mean = (0.5 * (3.0 - sqrt(5.0)));

  /* "revealer/REVEALER_runbenchmark.pyx":306
 *     cdef np.double_t rat, e, fx, ffulc, fnfc, xm, tol1, tol2, r, p, q, golden, si, fu
 * 
 *     a = x1; b = x2             # <<<<<<<<<<<<<<
 *     fulc = a + golden_mean * (b - a)
 *     nfc, xf = fulc, fulc
 */
  __pyx_v_a = __pyx_v_x1;
  __pyx_v_b = __pyx_v_x2;

  /* "revealer/REVEALER_runbenchmark.pyx":307
 * 
 *     a = x1; b = x2
 *     fulc = a + golden_mean * (b - a)             # <<<<<<<<<<<<<<
 *     nfc, xf = fulc, fulc
 *     rat = e = 0.0
 */
  __pyx_v_fulc = (__pyx_v_a + (__pyx_v_golden_mean * (__pyx_v_b - __pyx_v_a)));

  /* "revealer/REVEALER_runbenchmark.pyx":308
 *     a = x1; b = x2
 *     fulc = a + golden_mean * (b - a)
 *     nfc, xf = fulc, fulc             # <<<<<<<<<<<<<<
 *     rat = e = 0.0
 *     h = xf
 */
  __pyx_t_2 = __pyx_v_fulc;
  __pyx_t_3 = __pyx_v_fulc;
  __pyx_v_nfc = __pyx_t_2;
  __pyx_v_xf = __pyx_t_3;

  /* "revealer/REVEALER_runbenchmark.pyx":309
 *     fulc = a + golden_mean * (b - a)
 *     nfc, xf = fulc, fulc
 *     rat = e = 0.0             # <<<<<<<<<<<<<<
 *     h = xf
 * 
 */
  __pyx_v_rat = 0.0;
  __pyx_v_e = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":310
 *     nfc, xf = fulc, fulc
 *     rat = e = 0.0
 *     h = xf             # <<<<<<<<<<<<<<
 * 
 *     fx = VR_bcv_bin(n, nb, den, h)
 */
  __pyx_v_h = __pyx_v_xf;

  /* "revealer/REVEALER_runbenchmark.pyx":312
 *     h = xf
 * 
 *     fx = VR_bcv_bin(n, nb, den, h)             # <<<<<<<<<<<<<<
 *     num = 1
 * 
 */
  __pyx_v_fx = __pyx_f_8revealer_21REVEALER_runbenchmark_VR_bcv_bin(__pyx_v_n, __pyx_v_nb, __pyx_v_den, __pyx_v_h);

  /* "revealer/REVEALER_runbenchmark.pyx":313
 * 
 *     fx = VR_bcv_bin(n, nb, den, h)
 *     num = 1             # <<<<<<<<<<<<<<
 * 
 *     ffulc = fnfc = fx
 */
  __pyx_v_num = 1;

  /* "revealer/REVEALER_runbenchmark.pyx":315
 *     num = 1
 * 
 *     ffulc = fnfc = fx             # <<<<<<<<<<<<<<
 *     xm = 0.5 * (a + b)
 *     tol1 = sqrt_eps * fabs(xf) + xatol / 3.0
 */
  __pyx_v_ffulc = __pyx_v_fx;
  __pyx_v_fnfc = __pyx_v_fx;

  /* "revealer/REVEALER_runbenchmark.pyx":316
 * 
 *     ffulc = fnfc = fx
 *     xm = 0.5 * (a + b)             # <<<<<<<<<<<<<<
 *     tol1 = sqrt_eps * fabs(xf) + xatol / 3.0
 *     tol2 = 2.0 * tol1
 */
  __pyx_v_xm = (0.5 * (__pyx_v_a + __pyx_v_b));

  /* "revealer/REVEALER_runbenchmark.pyx":317
 *     ffulc = fnfc = fx
 *     xm = 0.5 * (a + b)
 *     tol1 = sqrt_eps * fabs(xf) + xatol / 3.0             # <<<<<<<<<<<<<<
 *     tol2 = 2.0 * tol1
 * 
 */
  __pyx_v_tol1 = ((__pyx_v_sqrt_eps * fabs(__pyx_v_xf)) + (__pyx_v_xatol / ((__pyx_t_5numpy_double_t)3.0)));

  /* "revealer/REVEALER_runbenchmark.pyx":318
 *     xm = 0.5 * (a + b)
 *     tol1 = sqrt_eps * fabs(xf) + xatol / 3.0
 *     tol2 = 2.0 * tol1             # <<<<<<<<<<<<<<
 * 
 *     while (fabs(xf - xm) > (tol2 - 0.5 * (b - a))):
 */
  __pyx_v_tol2 = (2.0 * __pyx_v_tol1);

  /* "revealer/REVEALER_runbenchmark.pyx":320
 *     tol2 = 2.0 * tol1
 * 
 *     while (fabs(xf - xm) > (tol2 - 0.5 * (b - a))):             # <<<<<<<<<<<<<<
 *         golden = 1.0
 *         # Check for parabolic fit
 */
  while (1) {
    __pyx_t_1 = ((fabs((__pyx_v_xf - __pyx_v_xm)) > (__pyx_v_tol2 - (0.5 * (__pyx_v_b - __pyx_v_a)))) != 0);
    if (!__pyx_t_1) break;

    /* "revealer/REVEALER_runbenchmark.pyx":321
 * 
 *     while (fabs(xf - xm) > (tol2 - 0.5 * (b - a))):
 *         golden = 1.0             # <<<<<<<<<<<<<<
 *         # Check for parabolic fit
 *         if fabs(e) > tol1:
 */
    __pyx_v_golden = 1.0;

    /* "revealer/REVEALER_runbenchmark.pyx":323
 *         golden = 1.0
 *         # Check for parabolic fit
 *         if fabs(e) > tol1:             # <<<<<<<<<<<<<<
 *             golden = 0.0
 *             r = (xf - nfc) * (fx - ffulc)
 */
    __pyx_t_1 = ((fabs(__pyx_v_e) > __pyx_v_tol1) != 0);
    if (__pyx_t_1) {

      /* "revealer/REVEALER_runbenchmark.pyx":324
 *         # Check for parabolic fit
 *         if fabs(e) > tol1:
 *             golden = 0.0             # <<<<<<<<<<<<<<
 *             r = (xf - nfc) * (fx - ffulc)
 *             q = (xf - fulc) * (fx - fnfc)
 */
      __pyx_v_golden = 0.0;

      /* "revealer/REVEALER_runbenchmark.pyx":325
 *         if fabs(e) > tol1:
 *             golden = 0.0
 *             r = (xf - nfc) * (fx - ffulc)             # <<<<<<<<<<<<<<
 *             q = (xf - fulc) * (fx - fnfc)
 *             p = (xf - fulc) * q - (xf - nfc) * r
 */
      __pyx_v_r = ((__pyx_v_xf - __pyx_v_nfc) * (__pyx_v_fx - __pyx_v_ffulc));

      /* "revealer/REVEALER_runbenchmark.pyx":326
 *             golden = 0.0
 *             r = (xf - nfc) * (fx - ffulc)
 *             q = (xf - fulc) * (fx - fnfc)             # <<<<<<<<<<<<<<
 *             p = (xf - fulc) * q - (xf - nfc) * r
 *             q = 2.0 * (q - r)
 */
      __pyx_v_q = ((__pyx_v_xf - __pyx_v_fulc) * (__pyx_v_fx - __pyx_v_fnfc));

      /* "revealer/REVEALER_runbenchmark.pyx":327
 *             r = (xf - nfc) * (fx - ffulc)
 *             q = (xf - fulc) * (fx - fnfc)
 *             p = (xf - fulc) * q - (xf - nfc) * r             # <<<<<<<<<<<<<<
 *             q = 2.0 * (q - r)
 *             if q > 0.0:
 */
      __pyx_v_p = (((__pyx_v_xf - __pyx_v_fulc) * __pyx_v_q) - ((__pyx_v_xf - __pyx_v_nfc) * __pyx_v_r));

      /* "revealer/REVEALER_runbenchmark.pyx":328
 *             q = (xf - fulc) * (fx - fnfc)
 *             p = (xf - fulc) * q - (xf - nfc) * r
 *             q = 2.0 * (q - r)             # <<<<<<<<<<<<<<
 *             if q > 0.0:
 *                 p = -p
 */
      __pyx_v_q = (2.0 * (__pyx_v_q - __pyx_v_r));

      /* "revealer/REVEALER_runbenchmark.pyx":329
 *             p = (xf - fulc) * q - (xf - nfc) * r
 *             q = 2.0 * (q - r)
 *             if q > 0.0:             # <<<<<<<<<<<<<<
 *                 p = -p
 *             q = fabs(q)
 */
      __pyx_t_1 = ((__pyx_v_q > 0.0) != 0);
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":330
 *             q = 2.0 * (q - r)
 *             if q > 0.0:
 *                 p = -p             # <<<<<<<<<<<<<<
 *             q = fabs(q)
 *             r = e
 */
        __pyx_v_p = (-__pyx_v_p);

        /* "revealer/REVEALER_runbenchmark.pyx":329
 *             p = (xf - fulc) * q - (xf - nfc) * r
 *             q = 2.0 * (q - r)
 *             if q > 0.0:             # <<<<<<<<<<<<<<
 *                 p = -p
 *             q = fabs(q)
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":331
 *             if q > 0.0:
 *                 p = -p
 *             q = fabs(q)             # <<<<<<<<<<<<<<
 *             r = e
 *             e = rat
 */
      __pyx_v_q = fabs(__pyx_v_q);

      /* "revealer/REVEALER_runbenchmark.pyx":332
 *                 p = -p
 *             q = fabs(q)
 *             r = e             # <<<<<<<<<<<<<<
 *             e = rat
 * 
 */
      __pyx_v_r = __pyx_v_e;

      /* "revealer/REVEALER_runbenchmark.pyx":333
 *             q = fabs(q)
 *             r = e
 *             e = rat             # <<<<<<<<<<<<<<
 * 
 *             # Check for acceptability of parabola
 */
      __pyx_v_e = __pyx_v_rat;

      /* "revealer/REVEALER_runbenchmark.pyx":336
 * 
 *             # Check for acceptability of parabola
 *             if ((fabs(p) < fabs(0.5*q*r)) and (p > q*(a - xf)) and             # <<<<<<<<<<<<<<
 *                     (p < q * (b - xf))):
 *                 rat = (p + 0.0) / q
 */
      __pyx_t_4 = ((fabs(__pyx_v_p) < fabs(((0.5 * __pyx_v_q) * __pyx_v_r))) != 0);
      if (__pyx_t_4) {
      } else {
        __pyx_t_1 = __pyx_t_4;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_4 = ((__pyx_v_p > (__pyx_v_q * (__pyx_v_a - __pyx_v_xf))) != 0);
      if (__pyx_t_4) {
      } else {
        __pyx_t_1 = __pyx_t_4;
        goto __pyx_L9_bool_binop_done;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":337
 *             # Check for acceptability of parabola
 *             if ((fabs(p) < fabs(0.5*q*r)) and (p > q*(a - xf)) and
 *                     (p < q * (b - xf))):             # <<<<<<<<<<<<<<
 *                 rat = (p + 0.0) / q
 *                 h = xf + rat
 */
      __pyx_t_4 = ((__pyx_v_p < (__pyx_v_q * (__pyx_v_b - __pyx_v_xf))) != 0);
      __pyx_t_1 = __pyx_t_4;
      __pyx_L9_bool_binop_done:;

      /* "revealer/REVEALER_runbenchmark.pyx":336
 * 
 *             # Check for acceptability of parabola
 *             if ((fabs(p) < fabs(0.5*q*r)) and (p > q*(a - xf)) and             # <<<<<<<<<<<<<<
 *                     (p < q * (b - xf))):
 *                 rat = (p + 0.0) / q
 */
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":338
 *             if ((fabs(p) < fabs(0.5*q*r)) and (p > q*(a - xf)) and
 *                     (p < q * (b - xf))):
 *                 rat = (p + 0.0) / q             # <<<<<<<<<<<<<<
 *                 h = xf + rat
 * 
 */
        __pyx_v_rat = ((__pyx_v_p + 0.0) / __pyx_v_q);

        /* "revealer/REVEALER_runbenchmark.pyx":339
 *                     (p < q * (b - xf))):
 *                 rat = (p + 0.0) / q
 *                 h = xf + rat             # <<<<<<<<<<<<<<
 * 
 *                 if ((h - a) < tol2) or ((b - h) < tol2):
 */
        __pyx_v_h = (__pyx_v_xf + __pyx_v_rat);

        /* "revealer/REVEALER_runbenchmark.pyx":341
 *                 h = xf + rat
 * 
 *                 if ((h - a) < tol2) or ((b - h) < tol2):             # <<<<<<<<<<<<<<
 *                     si = sign(xm - xf) + ((xm - xf) == 0.0)
 *                     rat = tol1 * si
 */
        __pyx_t_4 = (((__pyx_v_h - __pyx_v_a) < __pyx_v_tol2) != 0);
        if (!__pyx_t_4) {
        } else {
          __pyx_t_1 = __pyx_t_4;
          goto __pyx_L13_bool_binop_done;
        }
        __pyx_t_4 = (((__pyx_v_b - __pyx_v_h) < __pyx_v_tol2) != 0);
        __pyx_t_1 = __pyx_t_4;
        __pyx_L13_bool_binop_done:;
        if (__pyx_t_1) {

          /* "revealer/REVEALER_runbenchmark.pyx":342
 * 
 *                 if ((h - a) < tol2) or ((b - h) < tol2):
 *                     si = sign(xm - xf) + ((xm - xf) == 0.0)             # <<<<<<<<<<<<<<
 *                     rat = tol1 * si
 *             else:      # do a golden section step
 */
          __pyx_v_si = (__pyx_f_8revealer_21REVEALER_runbenchmark_sign((__pyx_v_xm - __pyx_v_xf)) + ((__pyx_v_xm - __pyx_v_xf) == 0.0));

          /* "revealer/REVEALER_runbenchmark.pyx":343
 *                 if ((h - a) < tol2) or ((b - h) < tol2):
 *                     si = sign(xm - xf) + ((xm - xf) == 0.0)
 *                     rat = tol1 * si             # <<<<<<<<<<<<<<
 *             else:      # do a golden section step
 *                 golden = 1.0
 */
          __pyx_v_rat = (__pyx_v_tol1 * __pyx_v_si);

          /* "revealer/REVEALER_runbenchmark.pyx":341
 *                 h = xf + rat
 * 
 *                 if ((h - a) < tol2) or ((b - h) < tol2):             # <<<<<<<<<<<<<<
 *                     si = sign(xm - xf) + ((xm - xf) == 0.0)
 *                     rat = tol1 * si
 */
        }

        /* "revealer/REVEALER_runbenchmark.pyx":336
 * 
 *             # Check for acceptability of parabola
 *             if ((fabs(p) < fabs(0.5*q*r)) and (p > q*(a - xf)) and             # <<<<<<<<<<<<<<
 *                     (p < q * (b - xf))):
 *                 rat = (p + 0.0) / q
 */
        goto __pyx_L8;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":345
 *                     rat = tol1 * si
 *             else:      # do a golden section step
 *                 golden = 1.0             # <<<<<<<<<<<<<<
 * 
 *         if golden:  # Do a golden-section step
 */
      /*else*/ {
        __pyx_v_golden = 1.0;
      }
      __pyx_L8:;

      /* "revealer/REVEALER_runbenchmark.pyx":323
 *         golden = 1.0
 *         # Check for parabolic fit
 *         if fabs(e) > tol1:             # <<<<<<<<<<<<<<
 *             golden = 0.0
 *             r = (xf - nfc) * (fx - ffulc)
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":347
 *                 golden = 1.0
 * 
 *         if golden:  # Do a golden-section step             # <<<<<<<<<<<<<<
 *             if xf >= xm:
 *                 e = a - xf
 */
    __pyx_t_1 = (__pyx_v_golden != 0);
    if (__pyx_t_1) {

      /* "revealer/REVEALER_runbenchmark.pyx":348
 * 
 *         if golden:  # Do a golden-section step
 *             if xf >= xm:             # <<<<<<<<<<<<<<
 *                 e = a - xf
 *             else:
 */
      __pyx_t_1 = ((__pyx_v_xf >= __pyx_v_xm) != 0);
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":349
 *         if golden:  # Do a golden-section step
 *             if xf >= xm:
 *                 e = a - xf             # <<<<<<<<<<<<<<
 *             else:
 *                 e = b - xf
 */
        __pyx_v_e = (__pyx_v_a - __pyx_v_xf);

        /* "revealer/REVEALER_runbenchmark.pyx":348
 * 
 *         if golden:  # Do a golden-section step
 *             if xf >= xm:             # <<<<<<<<<<<<<<
 *                 e = a - xf
 *             else:
 */
        goto __pyx_L16;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":351
 *                 e = a - xf
 *             else:
 *                 e = b - xf             # <<<<<<<<<<<<<<
 *             rat = golden_mean*e
 * 
 */
      /*else*/ {
        __pyx_v_e = (__pyx_v_b - __pyx_v_xf);
      }
      __pyx_L16:;

      /* "revealer/REVEALER_runbenchmark.pyx":352
 *             else:
 *                 e = b - xf
 *             rat = golden_mean*e             # <<<<<<<<<<<<<<
 * 
 *         si = sign(rat) + (rat == 0.0)
 */
      __pyx_v_rat = (__pyx_v_golden_mean * __pyx_v_e);

      /* "revealer/REVEALER_runbenchmark.pyx":347
 *                 golden = 1.0
 * 
 *         if golden:  # Do a golden-section step             # <<<<<<<<<<<<<<
 *             if xf >= xm:
 *                 e = a - xf
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":354
 *             rat = golden_mean*e
 * 
 *         si = sign(rat) + (rat == 0.0)             # <<<<<<<<<<<<<<
 *         h = xf + si * fmax(fabs(rat), tol1)
 *         fu = VR_bcv_bin(n, nb, den, h)
 */
    __pyx_v_si = (__pyx_f_8revealer_21REVEALER_runbenchmark_sign(__pyx_v_rat) + (__pyx_v_rat == 0.0));

    /* "revealer/REVEALER_runbenchmark.pyx":355
 * 
 *         si = sign(rat) + (rat == 0.0)
 *         h = xf + si * fmax(fabs(rat), tol1)             # <<<<<<<<<<<<<<
 *         fu = VR_bcv_bin(n, nb, den, h)
 *         num += 1
 */
    __pyx_v_h = (__pyx_v_xf + (__pyx_v_si * fmax(fabs(__pyx_v_rat), __pyx_v_tol1)));

    /* "revealer/REVEALER_runbenchmark.pyx":356
 *         si = sign(rat) + (rat == 0.0)
 *         h = xf + si * fmax(fabs(rat), tol1)
 *         fu = VR_bcv_bin(n, nb, den, h)             # <<<<<<<<<<<<<<
 *         num += 1
 * 
 */
    __pyx_v_fu = __pyx_f_8revealer_21REVEALER_runbenchmark_VR_bcv_bin(__pyx_v_n, __pyx_v_nb, __pyx_v_den, __pyx_v_h);

    /* "revealer/REVEALER_runbenchmark.pyx":357
 *         h = xf + si * fmax(fabs(rat), tol1)
 *         fu = VR_bcv_bin(n, nb, den, h)
 *         num += 1             # <<<<<<<<<<<<<<
 * 
 *         if fu <= fx:
 */
    __pyx_v_num = (__pyx_v_num + 1);

    /* "revealer/REVEALER_runbenchmark.pyx":359
 *         num += 1
 * 
 *         if fu <= fx:             # <<<<<<<<<<<<<<
 *             if h >= xf:
 *                 a = xf
 */
    __pyx_t_1 = ((__pyx_v_fu <= __pyx_v_fx) != 0);
    if (__pyx_t_1) {

      /* "revealer/REVEALER_runbenchmark.pyx":360
 * 
 *         if fu <= fx:
 *             if h >= xf:             # <<<<<<<<<<<<<<
 *                 a = xf
 *             else:
 */
      __pyx_t_1 = ((__pyx_v_h >= __pyx_v_xf) != 0);
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":361
 *         if fu <= fx:
 *             if h >= xf:
 *                 a = xf             # <<<<<<<<<<<<<<
 *             else:
 *                 b = xf
 */
        __pyx_v_a = __pyx_v_xf;

        /* "revealer/REVEALER_runbenchmark.pyx":360
 * 
 *         if fu <= fx:
 *             if h >= xf:             # <<<<<<<<<<<<<<
 *                 a = xf
 *             else:
 */
        goto __pyx_L18;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":363
 *                 a = xf
 *             else:
 *                 b = xf             # <<<<<<<<<<<<<<
 *             fulc, ffulc = nfc, fnfc
 *             nfc, fnfc = xf, fx
 */
      /*else*/ {
        __pyx_v_b = __pyx_v_xf;
      }
      __pyx_L18:;

      /* "revealer/REVEALER_runbenchmark.pyx":364
 *             else:
 *                 b = xf
 *             fulc, ffulc = nfc, fnfc             # <<<<<<<<<<<<<<
 *             nfc, fnfc = xf, fx
 *             xf, fx = h, fu
 */
      __pyx_t_3 = __pyx_v_nfc;
      __pyx_t_2 = __pyx_v_fnfc;
      __pyx_v_fulc = __pyx_t_3;
      __pyx_v_ffulc = __pyx_t_2;

      /* "revealer/REVEALER_runbenchmark.pyx":365
 *                 b = xf
 *             fulc, ffulc = nfc, fnfc
 *             nfc, fnfc = xf, fx             # <<<<<<<<<<<<<<
 *             xf, fx = h, fu
 *         else:
 */
      __pyx_t_2 = __pyx_v_xf;
      __pyx_t_3 = __pyx_v_fx;
      __pyx_v_nfc = __pyx_t_2;
      __pyx_v_fnfc = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":366
 *             fulc, ffulc = nfc, fnfc
 *             nfc, fnfc = xf, fx
 *             xf, fx = h, fu             # <<<<<<<<<<<<<<
 *         else:
 *             if h < xf:
 */
      __pyx_t_3 = __pyx_v_h;
      __pyx_t_2 = __pyx_v_fu;
      __pyx_v_xf = __pyx_t_3;
      __pyx_v_fx = __pyx_t_2;

      /* "revealer/REVEALER_runbenchmark.pyx":359
 *         num += 1
 * 
 *         if fu <= fx:             # <<<<<<<<<<<<<<
 *             if h >= xf:
 *                 a = xf
 */
      goto __pyx_L17;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":368
 *             xf, fx = h, fu
 *         else:
 *             if h < xf:             # <<<<<<<<<<<<<<
 *                 a = h
 *             else:
 */
    /*else*/ {
      __pyx_t_1 = ((__pyx_v_h < __pyx_v_xf) != 0);
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":369
 *         else:
 *             if h < xf:
 *                 a = h             # <<<<<<<<<<<<<<
 *             else:
 *                 b = h
 */
        __pyx_v_a = __pyx_v_h;

        /* "revealer/REVEALER_runbenchmark.pyx":368
 *             xf, fx = h, fu
 *         else:
 *             if h < xf:             # <<<<<<<<<<<<<<
 *                 a = h
 *             else:
 */
        goto __pyx_L19;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":371
 *                 a = h
 *             else:
 *                 b = h             # <<<<<<<<<<<<<<
 *             if (fu <= fnfc) or (nfc == xf):
 *                 fulc, ffulc = nfc, fnfc
 */
      /*else*/ {
        __pyx_v_b = __pyx_v_h;
      }
      __pyx_L19:;

      /* "revealer/REVEALER_runbenchmark.pyx":372
 *             else:
 *                 b = h
 *             if (fu <= fnfc) or (nfc == xf):             # <<<<<<<<<<<<<<
 *                 fulc, ffulc = nfc, fnfc
 *                 nfc, fnfc = h, fu
 */
      __pyx_t_4 = ((__pyx_v_fu <= __pyx_v_fnfc) != 0);
      if (!__pyx_t_4) {
      } else {
        __pyx_t_1 = __pyx_t_4;
        goto __pyx_L21_bool_binop_done;
      }
      __pyx_t_4 = ((__pyx_v_nfc == __pyx_v_xf) != 0);
      __pyx_t_1 = __pyx_t_4;
      __pyx_L21_bool_binop_done:;
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":373
 *                 b = h
 *             if (fu <= fnfc) or (nfc == xf):
 *                 fulc, ffulc = nfc, fnfc             # <<<<<<<<<<<<<<
 *                 nfc, fnfc = h, fu
 *             elif (fu <= ffulc) or (fulc == xf) or (fulc == nfc):
 */
        __pyx_t_2 = __pyx_v_nfc;
        __pyx_t_3 = __pyx_v_fnfc;
        __pyx_v_fulc = __pyx_t_2;
        __pyx_v_ffulc = __pyx_t_3;

        /* "revealer/REVEALER_runbenchmark.pyx":374
 *             if (fu <= fnfc) or (nfc == xf):
 *                 fulc, ffulc = nfc, fnfc
 *                 nfc, fnfc = h, fu             # <<<<<<<<<<<<<<
 *             elif (fu <= ffulc) or (fulc == xf) or (fulc == nfc):
 *                 fulc, ffulc = h, fu
 */
        __pyx_t_3 = __pyx_v_h;
        __pyx_t_2 = __pyx_v_fu;
        __pyx_v_nfc = __pyx_t_3;
        __pyx_v_fnfc = __pyx_t_2;

        /* "revealer/REVEALER_runbenchmark.pyx":372
 *             else:
 *                 b = h
 *             if (fu <= fnfc) or (nfc == xf):             # <<<<<<<<<<<<<<
 *                 fulc, ffulc = nfc, fnfc
 *                 nfc, fnfc = h, fu
 */
        goto __pyx_L20;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":375
 *                 fulc, ffulc = nfc, fnfc
 *                 nfc, fnfc = h, fu
 *             elif (fu <= ffulc) or (fulc == xf) or (fulc == nfc):             # <<<<<<<<<<<<<<
 *                 fulc, ffulc = h, fu
 * 
 */
      __pyx_t_4 = ((__pyx_v_fu <= __pyx_v_ffulc) != 0);
      if (!__pyx_t_4) {
      } else {
        __pyx_t_1 = __pyx_t_4;
        goto __pyx_L23_bool_binop_done;
      }
      __pyx_t_4 = ((__pyx_v_fulc == __pyx_v_xf) != 0);
      if (!__pyx_t_4) {
      } else {
        __pyx_t_1 = __pyx_t_4;
        goto __pyx_L23_bool_binop_done;
      }
      __pyx_t_4 = ((__pyx_v_fulc == __pyx_v_nfc) != 0);
      __pyx_t_1 = __pyx_t_4;
      __pyx_L23_bool_binop_done:;
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":376
 *                 nfc, fnfc = h, fu
 *             elif (fu <= ffulc) or (fulc == xf) or (fulc == nfc):
 *                 fulc, ffulc = h, fu             # <<<<<<<<<<<<<<
 * 
 *         xm = 0.5 * (a + b)
 */
        __pyx_t_2 = __pyx_v_h;
        __pyx_t_3 = __pyx_v_fu;
        __pyx_v_fulc = __pyx_t_2;
        __pyx_v_ffulc = __pyx_t_3;

        /* "revealer/REVEALER_runbenchmark.pyx":375
 *                 fulc, ffulc = nfc, fnfc
 *                 nfc, fnfc = h, fu
 *             elif (fu <= ffulc) or (fulc == xf) or (fulc == nfc):             # <<<<<<<<<<<<<<
 *                 fulc, ffulc = h, fu
 * 
 */
      }
      __pyx_L20:;
    }
    __pyx_L17:;

    /* "revealer/REVEALER_runbenchmark.pyx":378
 *                 fulc, ffulc = h, fu
 * 
 *         xm = 0.5 * (a + b)             # <<<<<<<<<<<<<<
 *         tol1 = sqrt_eps * fabs(xf) + xatol / 3.0
 *         tol2 = 2.0 * tol1
 */
    __pyx_v_xm = (0.5 * (__pyx_v_a + __pyx_v_b));

    /* "revealer/REVEALER_runbenchmark.pyx":379
 * 
 *         xm = 0.5 * (a + b)
 *         tol1 = sqrt_eps * fabs(xf) + xatol / 3.0             # <<<<<<<<<<<<<<
 *         tol2 = 2.0 * tol1
 * 
 */
    __pyx_v_tol1 = ((__pyx_v_sqrt_eps * fabs(__pyx_v_xf)) + (__pyx_v_xatol / ((__pyx_t_5numpy_double_t)3.0)));

    /* "revealer/REVEALER_runbenchmark.pyx":380
 *         xm = 0.5 * (a + b)
 *         tol1 = sqrt_eps * fabs(xf) + xatol / 3.0
 *         tol2 = 2.0 * tol1             # <<<<<<<<<<<<<<
 * 
 *         if num >= maxfun:
 */
    __pyx_v_tol2 = (2.0 * __pyx_v_tol1);

    /* "revealer/REVEALER_runbenchmark.pyx":382
 *         tol2 = 2.0 * tol1
 * 
 *         if num >= maxfun:             # <<<<<<<<<<<<<<
 *             break
 *     h = xf
 */
    __pyx_t_1 = ((__pyx_v_num >= __pyx_v_maxfun) != 0);
    if (__pyx_t_1) {

      /* "revealer/REVEALER_runbenchmark.pyx":383
 * 
 *         if num >= maxfun:
 *             break             # <<<<<<<<<<<<<<
 *     h = xf
 *     free(den.cnt)
 */
      goto __pyx_L5_break;

      /* "revealer/REVEALER_runbenchmark.pyx":382
 *         tol2 = 2.0 * tol1
 * 
 *         if num >= maxfun:             # <<<<<<<<<<<<<<
 *             break
 *     h = xf
 */
    }
  }
  __pyx_L5_break:;

  /* "revealer/REVEALER_runbenchmark.pyx":384
 *         if num >= maxfun:
 *             break
 *     h = xf             # <<<<<<<<<<<<<<
 *     free(den.cnt)
 * 
 */
  __pyx_v_h = __pyx_v_xf;

  /* "revealer/REVEALER_runbenchmark.pyx":385
 *             break
 *     h = xf
 *     free(den.cnt)             # <<<<<<<<<<<<<<
 * 
 *     return h
 */
  free(__pyx_v_den.cnt);

  /* "revealer/REVEALER_runbenchmark.pyx":387
 *     free(den.cnt)
 * 
 *     return h             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_h;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":277
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cdef inline np.double_t py_bcv(             # <<<<<<<<<<<<<<
 *     np.double_t* x,     #Pointer to list x
 *     int n,              #Size of sample
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":393
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cdef np.double_t local_pearsonr(             # <<<<<<<<<<<<<<
 *     np.double_t[:] x,   #list x
 *     np.int_t[:] y,      #list y
 */

static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_local_pearsonr(__Pyx_memviewslice __pyx_v_x, __Pyx_memviewslice __pyx_v_y, int __pyx_v_n) {
  __pyx_t_5numpy_double_t __pyx_v_mx;
  __pyx_t_5numpy_double_t __pyx_v_my;
  __pyx_t_5numpy_double_t __pyx_v_r_num;
  __pyx_t_5numpy_double_t __pyx_v_r_den;
  __pyx_t_5numpy_double_t __pyx_v_r;
  __pyx_t_5numpy_double_t __pyx_v_sum_x;
  __pyx_t_5numpy_double_t __pyx_v_sum_y;
  __pyx_t_5numpy_double_t __pyx_v_xm;
  __pyx_t_5numpy_double_t __pyx_v_ym;
  int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "revealer/REVEALER_runbenchmark.pyx":403
 *     '''
 * 
 *     cdef np.double_t mx, my, r_num = 0, r_den, r             # <<<<<<<<<<<<<<
 *     cdef np.double_t sum_x = 0, sum_y = 0
 *     cdef np.double_t xm, ym
 */
  __pyx_v_r_num = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":404
 * 
 *     cdef np.double_t mx, my, r_num = 0, r_den, r
 *     cdef np.double_t sum_x = 0, sum_y = 0             # <<<<<<<<<<<<<<
 *     cdef np.double_t xm, ym
 *     cdef int i
 */
  __pyx_v_sum_x = 0.0;
  __pyx_v_sum_y = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":407
 *     cdef np.double_t xm, ym
 *     cdef int i
 *     mx = x[0]             # <<<<<<<<<<<<<<
 *     my = y[0]
 *     for i in range(1, n):
 */
  __pyx_t_1 = 0;
  __pyx_v_mx = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_1 * __pyx_v_x.strides[0]) )));

  /* "revealer/REVEALER_runbenchmark.pyx":408
 *     cdef int i
 *     mx = x[0]
 *     my = y[0]             # <<<<<<<<<<<<<<
 *     for i in range(1, n):
 *         mx += x[i]
 */
  __pyx_t_1 = 0;
  __pyx_v_my = (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_y.data + __pyx_t_1 * __pyx_v_y.strides[0]) )));

  /* "revealer/REVEALER_runbenchmark.pyx":409
 *     mx = x[0]
 *     my = y[0]
 *     for i in range(1, n):             # <<<<<<<<<<<<<<
 *         mx += x[i]
 *         my += y[i]
 */
  __pyx_t_2 = __pyx_v_n;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 1; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "revealer/REVEALER_runbenchmark.pyx":410
 *     my = y[0]
 *     for i in range(1, n):
 *         mx += x[i]             # <<<<<<<<<<<<<<
 *         my += y[i]
 *     mx = mx / n
 */
    __pyx_t_1 = __pyx_v_i;
    __pyx_v_mx = (__pyx_v_mx + (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_1 * __pyx_v_x.strides[0]) ))));

    /* "revealer/REVEALER_runbenchmark.pyx":411
 *     for i in range(1, n):
 *         mx += x[i]
 *         my += y[i]             # <<<<<<<<<<<<<<
 *     mx = mx / n
 *     my = my / n
 */
    __pyx_t_1 = __pyx_v_i;
    __pyx_v_my = (__pyx_v_my + (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_y.data + __pyx_t_1 * __pyx_v_y.strides[0]) ))));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":412
 *         mx += x[i]
 *         my += y[i]
 *     mx = mx / n             # <<<<<<<<<<<<<<
 *     my = my / n
 * 
 */
  __pyx_v_mx = (__pyx_v_mx / ((__pyx_t_5numpy_double_t)__pyx_v_n));

  /* "revealer/REVEALER_runbenchmark.pyx":413
 *         my += y[i]
 *     mx = mx / n
 *     my = my / n             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  __pyx_v_my = (__pyx_v_my / ((__pyx_t_5numpy_double_t)__pyx_v_n));

  /* "revealer/REVEALER_runbenchmark.pyx":415
 *     my = my / n
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         xm = x[i] - mx
 *         ym = y[i] - my
 */
  __pyx_t_2 = __pyx_v_n;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "revealer/REVEALER_runbenchmark.pyx":416
 * 
 *     for i in range(n):
 *         xm = x[i] - mx             # <<<<<<<<<<<<<<
 *         ym = y[i] - my
 *         r_num += xm * ym
 */
    __pyx_t_1 = __pyx_v_i;
    __pyx_v_xm = ((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_1 * __pyx_v_x.strides[0]) ))) - __pyx_v_mx);

    /* "revealer/REVEALER_runbenchmark.pyx":417
 *     for i in range(n):
 *         xm = x[i] - mx
 *         ym = y[i] - my             # <<<<<<<<<<<<<<
 *         r_num += xm * ym
 *         sum_x += xm ** 2
 */
    __pyx_t_1 = __pyx_v_i;
    __pyx_v_ym = ((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_y.data + __pyx_t_1 * __pyx_v_y.strides[0]) ))) - __pyx_v_my);

    /* "revealer/REVEALER_runbenchmark.pyx":418
 *         xm = x[i] - mx
 *         ym = y[i] - my
 *         r_num += xm * ym             # <<<<<<<<<<<<<<
 *         sum_x += xm ** 2
 *         sum_y += ym ** 2
 */
    __pyx_v_r_num = (__pyx_v_r_num + (__pyx_v_xm * __pyx_v_ym));

    /* "revealer/REVEALER_runbenchmark.pyx":419
 *         ym = y[i] - my
 *         r_num += xm * ym
 *         sum_x += xm ** 2             # <<<<<<<<<<<<<<
 *         sum_y += ym ** 2
 *     r_den = sqrt(sum_x * sum_y)
 */
    __pyx_v_sum_x = (__pyx_v_sum_x + pow(__pyx_v_xm, 2.0));

    /* "revealer/REVEALER_runbenchmark.pyx":420
 *         r_num += xm * ym
 *         sum_x += xm ** 2
 *         sum_y += ym ** 2             # <<<<<<<<<<<<<<
 *     r_den = sqrt(sum_x * sum_y)
 *     r = r_num / r_den
 */
    __pyx_v_sum_y = (__pyx_v_sum_y + pow(__pyx_v_ym, 2.0));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":421
 *         sum_x += xm ** 2
 *         sum_y += ym ** 2
 *     r_den = sqrt(sum_x * sum_y)             # <<<<<<<<<<<<<<
 *     r = r_num / r_den
 *     return r
 */
  __pyx_v_r_den = sqrt((__pyx_v_sum_x * __pyx_v_sum_y));

  /* "revealer/REVEALER_runbenchmark.pyx":422
 *         sum_y += ym ** 2
 *     r_den = sqrt(sum_x * sum_y)
 *     r = r_num / r_den             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
  __pyx_v_r = (__pyx_v_r_num / __pyx_v_r_den);

  /* "revealer/REVEALER_runbenchmark.pyx":423
 *     r_den = sqrt(sum_x * sum_y)
 *     r = r_num / r_den
 *     return r             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":393
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cdef np.double_t local_pearsonr(             # <<<<<<<<<<<<<<
 *     np.double_t[:] x,   #list x
 *     np.int_t[:] y,      #list y
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":429
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t binaryInformationCoefficient_cython(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y,           #Target
 *     np.int_t[:] x,              #Features to calculate correlation
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_3binaryInformationCoefficient_cython(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__Pyx_memviewslice __pyx_v_y, __Pyx_memviewslice __pyx_v_x, int __pyx_v_k, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_neighborhood, __pyx_t_5numpy_double_t __pyx_v_deltay, __pyx_t_5numpy_double_t __pyx_v_miny, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython *__pyx_optional_args) {
  __pyx_t_5numpy_double_t __pyx_v_cor;
  __pyx_t_5numpy_double_t __pyx_v_y_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_sigma_y;
  __pyx_t_5numpy_double_t __pyx_v_deltak;
  __pyx_t_5numpy_double_t __pyx_v_term_2_pi_sigma_y;
  __pyx_t_5numpy_double_t __pyx_v_integral;
  __pyx_t_5numpy_double_t __pyx_v_mutual_information;
  __pyx_t_5numpy_double_t __pyx_v_pX_0;
  __pyx_t_5numpy_double_t __pyx_v_pX_1;
  __pyx_t_5numpy_double_t __pyx_v_pysum;
  __pyx_t_5numpy_double_t __pyx_v_p_y_xsum;
  int __pyx_v_y_d;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_sumx;
  int __pyx_v_grid;
  __pyx_t_5numpy_double_t *__pyx_v_normy;
  __pyx_t_5numpy_double_t *__pyx_v_p_y_total;
  __pyx_t_5numpy_double_t *__pyx_v_p_y_1;
  __pyx_t_5numpy_double_t *__pyx_v_p_y_0;
  __pyx_t_5numpy_double_t *__pyx_v_kernel;
  int __pyx_v_index;
  __pyx_t_5numpy_double_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  long __pyx_t_6;
  long __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  if (__pyx_optional_args) {
  }

  /* "revealer/REVEALER_runbenchmark.pyx":455
 *     cdef np.double_t* p_y_0
 * 
 *     sumx = 0             # <<<<<<<<<<<<<<
 *     i = 0
 *     for i in range(size):
 */
  __pyx_v_sumx = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":456
 * 
 *     sumx = 0
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         sumx += <int>x[i]
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":457
 *     sumx = 0
 *     i = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         sumx += <int>x[i]
 * 
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":458
 *     i = 0
 *     for i in range(size):
 *         sumx += <int>x[i]             # <<<<<<<<<<<<<<
 * 
 *     # Calculate bandwidth
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_v_sumx = (__pyx_v_sumx + ((int)(*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":461
 * 
 *     # Calculate bandwidth
 *     cor = local_pearsonr(y, x, size)             # <<<<<<<<<<<<<<
 * 
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))
 */
  __pyx_v_cor = __pyx_f_8revealer_21REVEALER_runbenchmark_local_pearsonr(__pyx_v_y, __pyx_v_x, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":463
 *     cor = local_pearsonr(y, x, size)
 * 
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))             # <<<<<<<<<<<<<<
 * 
 *     deltak = y_bandwidth * neighborhood
 */
  __pyx_v_y_bandwidth = (__pyx_v_bandwidth * (__pyx_v_bandwidth_mult * (1.0 + (__pyx_v_bandwidth_adj * fabs(__pyx_v_cor)))));

  /* "revealer/REVEALER_runbenchmark.pyx":465
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))
 * 
 *     deltak = y_bandwidth * neighborhood             # <<<<<<<<<<<<<<
 *     grid = <int>(round(deltay/deltak*k))
 * 
 */
  __pyx_v_deltak = (__pyx_v_y_bandwidth * __pyx_v_neighborhood);

  /* "revealer/REVEALER_runbenchmark.pyx":466
 * 
 *     deltak = y_bandwidth * neighborhood
 *     grid = <int>(round(deltay/deltak*k))             # <<<<<<<<<<<<<<
 * 
 *     if grid < 2*k+1:
 */
  __pyx_v_grid = ((int)round(((__pyx_v_deltay / __pyx_v_deltak) * __pyx_v_k)));

  /* "revealer/REVEALER_runbenchmark.pyx":468
 *     grid = <int>(round(deltay/deltak*k))
 * 
 *     if grid < 2*k+1:             # <<<<<<<<<<<<<<
 *         grid = 2*k+1
 * 
 */
  __pyx_t_5 = ((__pyx_v_grid < ((2 * __pyx_v_k) + 1)) != 0);
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":469
 * 
 *     if grid < 2*k+1:
 *         grid = 2*k+1             # <<<<<<<<<<<<<<
 * 
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))
 */
    __pyx_v_grid = ((2 * __pyx_v_k) + 1);

    /* "revealer/REVEALER_runbenchmark.pyx":468
 *     grid = <int>(round(deltay/deltak*k))
 * 
 *     if grid < 2*k+1:             # <<<<<<<<<<<<<<
 *         grid = 2*k+1
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":471
 *         grid = 2*k+1
 * 
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)
 */
  __pyx_v_normy = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_size * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":472
 * 
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)
 * 
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":473
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))
 *     for i in range(size):
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)             # <<<<<<<<<<<<<<
 * 
 *     # Prepare grids
 */
    __pyx_t_4 = __pyx_v_i;
    (__pyx_v_normy[__pyx_v_i]) = ((((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_y.data + __pyx_t_4 * __pyx_v_y.strides[0]) ))) - __pyx_v_miny) / __pyx_v_deltay) * (__pyx_v_grid - 1));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":476
 * 
 *     # Prepare grids
 *     p_y_total = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_y_0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_y_1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_y_total = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":477
 *     # Prepare grids
 *     p_y_total = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_y_0 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_y_1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 * 
 */
  __pyx_v_p_y_0 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":478
 *     p_y_total = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_y_0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_y_1 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 * 
 *     sigma_y = (grid * y_bandwidth) / deltay
 */
  __pyx_v_p_y_1 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":480
 *     p_y_1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 * 
 *     sigma_y = (grid * y_bandwidth) / deltay             # <<<<<<<<<<<<<<
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 */
  __pyx_v_sigma_y = ((__pyx_v_grid * __pyx_v_y_bandwidth) / __pyx_v_deltay);

  /* "revealer/REVEALER_runbenchmark.pyx":481
 * 
 *     sigma_y = (grid * y_bandwidth) / deltay
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y             # <<<<<<<<<<<<<<
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 *     i = 0
 */
  __pyx_v_term_2_pi_sigma_y = ((2.0 * M_PI) * __pyx_v_sigma_y);

  /* "revealer/REVEALER_runbenchmark.pyx":482
 *     sigma_y = (grid * y_bandwidth) / deltay
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     i = 0
 *     for i in range(2*k):
 */
  __pyx_v_kernel = ((__pyx_t_5numpy_double_t *)malloc(((2 * __pyx_v_k) * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":483
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(2*k):
 *          kernel[i] = exp(-0.5*(((<np.double_t>i-<np.double_t>k)/sigma_y)**2))/term_2_pi_sigma_y
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":484
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 *     i = 0
 *     for i in range(2*k):             # <<<<<<<<<<<<<<
 *          kernel[i] = exp(-0.5*(((<np.double_t>i-<np.double_t>k)/sigma_y)**2))/term_2_pi_sigma_y
 * 
 */
  __pyx_t_6 = (2 * __pyx_v_k);
  __pyx_t_7 = __pyx_t_6;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_7; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "revealer/REVEALER_runbenchmark.pyx":485
 *     i = 0
 *     for i in range(2*k):
 *          kernel[i] = exp(-0.5*(((<np.double_t>i-<np.double_t>k)/sigma_y)**2))/term_2_pi_sigma_y             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
    (__pyx_v_kernel[__pyx_v_i]) = (((__pyx_t_5numpy_double_t)exp((-0.5 * pow(((((__pyx_t_5numpy_double_t)__pyx_v_i) - ((__pyx_t_5numpy_double_t)__pyx_v_k)) / __pyx_v_sigma_y), 2.0)))) / __pyx_v_term_2_pi_sigma_y);
  }

  /* "revealer/REVEALER_runbenchmark.pyx":487
 *          kernel[i] = exp(-0.5*(((<np.double_t>i-<np.double_t>k)/sigma_y)**2))/term_2_pi_sigma_y
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(grid):
 *         p_y_total[i] = 0.0
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":488
 * 
 *     i = 0
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         p_y_total[i] = 0.0
 *         p_y_1[i] = 0.0
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":489
 *     i = 0
 *     for i in range(grid):
 *         p_y_total[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_y_1[i] = 0.0
 *         p_y_0[i] = 0.0
 */
    (__pyx_v_p_y_total[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":490
 *     for i in range(grid):
 *         p_y_total[i] = 0.0
 *         p_y_1[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_y_0[i] = 0.0
 * 
 */
    (__pyx_v_p_y_1[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":491
 *         p_y_total[i] = 0.0
 *         p_y_1[i] = 0.0
 *         p_y_0[i] = 0.0             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
    (__pyx_v_p_y_0[__pyx_v_i]) = 0.0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":493
 *         p_y_0[i] = 0.0
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         y_d = <int>(round(normy[i]))
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":494
 * 
 *     i = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         y_d = <int>(round(normy[i]))
 *         for j in range(2*k):
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":495
 *     i = 0
 *     for i in range(size):
 *         y_d = <int>(round(normy[i]))             # <<<<<<<<<<<<<<
 *         for j in range(2*k):
 *             index = y_d - k + j
 */
    __pyx_v_y_d = ((int)round((__pyx_v_normy[__pyx_v_i])));

    /* "revealer/REVEALER_runbenchmark.pyx":496
 *     for i in range(size):
 *         y_d = <int>(round(normy[i]))
 *         for j in range(2*k):             # <<<<<<<<<<<<<<
 *             index = y_d - k + j
 *             if index < 0:
 */
    __pyx_t_6 = (2 * __pyx_v_k);
    __pyx_t_7 = __pyx_t_6;
    for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
      __pyx_v_j = __pyx_t_8;

      /* "revealer/REVEALER_runbenchmark.pyx":497
 *         y_d = <int>(round(normy[i]))
 *         for j in range(2*k):
 *             index = y_d - k + j             # <<<<<<<<<<<<<<
 *             if index < 0:
 *                 continue
 */
      __pyx_v_index = ((__pyx_v_y_d - __pyx_v_k) + __pyx_v_j);

      /* "revealer/REVEALER_runbenchmark.pyx":498
 *         for j in range(2*k):
 *             index = y_d - k + j
 *             if index < 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             if index >= grid:
 */
      __pyx_t_5 = ((__pyx_v_index < 0) != 0);
      if (__pyx_t_5) {

        /* "revealer/REVEALER_runbenchmark.pyx":499
 *             index = y_d - k + j
 *             if index < 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             if index >= grid:
 *                 continue
 */
        goto __pyx_L14_continue;

        /* "revealer/REVEALER_runbenchmark.pyx":498
 *         for j in range(2*k):
 *             index = y_d - k + j
 *             if index < 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             if index >= grid:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":500
 *             if index < 0:
 *                 continue
 *             if index >= grid:             # <<<<<<<<<<<<<<
 *                 continue
 *             p_y_total[index] += kernel[j]
 */
      __pyx_t_5 = ((__pyx_v_index >= __pyx_v_grid) != 0);
      if (__pyx_t_5) {

        /* "revealer/REVEALER_runbenchmark.pyx":501
 *                 continue
 *             if index >= grid:
 *                 continue             # <<<<<<<<<<<<<<
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i]:
 */
        goto __pyx_L14_continue;

        /* "revealer/REVEALER_runbenchmark.pyx":500
 *             if index < 0:
 *                 continue
 *             if index >= grid:             # <<<<<<<<<<<<<<
 *                 continue
 *             p_y_total[index] += kernel[j]
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":502
 *             if index >= grid:
 *                 continue
 *             p_y_total[index] += kernel[j]             # <<<<<<<<<<<<<<
 *             if 0 == x[i]:
 *                 p_y_0[index] += kernel[j]
 */
      __pyx_t_9 = __pyx_v_index;
      (__pyx_v_p_y_total[__pyx_t_9]) = ((__pyx_v_p_y_total[__pyx_t_9]) + (__pyx_v_kernel[__pyx_v_j]));

      /* "revealer/REVEALER_runbenchmark.pyx":503
 *                 continue
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i]:             # <<<<<<<<<<<<<<
 *                 p_y_0[index] += kernel[j]
 *             else:
 */
      __pyx_t_4 = __pyx_v_i;
      __pyx_t_5 = ((0 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))) != 0);
      if (__pyx_t_5) {

        /* "revealer/REVEALER_runbenchmark.pyx":504
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i]:
 *                 p_y_0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *             else:
 *                 p_y_1[index] += kernel[j]
 */
        __pyx_t_9 = __pyx_v_index;
        (__pyx_v_p_y_0[__pyx_t_9]) = ((__pyx_v_p_y_0[__pyx_t_9]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":503
 *                 continue
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i]:             # <<<<<<<<<<<<<<
 *                 p_y_0[index] += kernel[j]
 *             else:
 */
        goto __pyx_L18;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":506
 *                 p_y_0[index] += kernel[j]
 *             else:
 *                 p_y_1[index] += kernel[j]             # <<<<<<<<<<<<<<
 * 
 *     pysum = 0.0
 */
      /*else*/ {
        __pyx_t_9 = __pyx_v_index;
        (__pyx_v_p_y_1[__pyx_t_9]) = ((__pyx_v_p_y_1[__pyx_t_9]) + (__pyx_v_kernel[__pyx_v_j]));
      }
      __pyx_L18:;
      __pyx_L14_continue:;
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":508
 *                 p_y_1[index] += kernel[j]
 * 
 *     pysum = 0.0             # <<<<<<<<<<<<<<
 *     p_y_xsum = 0.0
 * 
 */
  __pyx_v_pysum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":509
 * 
 *     pysum = 0.0
 *     p_y_xsum = 0.0             # <<<<<<<<<<<<<<
 * 
 *     for i in range(grid):
 */
  __pyx_v_p_y_xsum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":511
 *     p_y_xsum = 0.0
 * 
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         p_y_total[i] = p_y_total[i] + EPS
 *         p_y_0[i] = p_y_0[i] + EPS
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":512
 * 
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i] + EPS             # <<<<<<<<<<<<<<
 *         p_y_0[i] = p_y_0[i] + EPS
 *         p_y_1[i] = p_y_1[i] + EPS
 */
    (__pyx_v_p_y_total[__pyx_v_i]) = ((__pyx_v_p_y_total[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":513
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i] + EPS
 *         p_y_0[i] = p_y_0[i] + EPS             # <<<<<<<<<<<<<<
 *         p_y_1[i] = p_y_1[i] + EPS
 *         pysum += p_y_total[i]
 */
    (__pyx_v_p_y_0[__pyx_v_i]) = ((__pyx_v_p_y_0[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":514
 *         p_y_total[i] = p_y_total[i] + EPS
 *         p_y_0[i] = p_y_0[i] + EPS
 *         p_y_1[i] = p_y_1[i] + EPS             # <<<<<<<<<<<<<<
 *         pysum += p_y_total[i]
 *         p_y_xsum += p_y_0[i] +  p_y_1[i]
 */
    (__pyx_v_p_y_1[__pyx_v_i]) = ((__pyx_v_p_y_1[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":515
 *         p_y_0[i] = p_y_0[i] + EPS
 *         p_y_1[i] = p_y_1[i] + EPS
 *         pysum += p_y_total[i]             # <<<<<<<<<<<<<<
 *         p_y_xsum += p_y_0[i] +  p_y_1[i]
 * 
 */
    __pyx_v_pysum = (__pyx_v_pysum + (__pyx_v_p_y_total[__pyx_v_i]));

    /* "revealer/REVEALER_runbenchmark.pyx":516
 *         p_y_1[i] = p_y_1[i] + EPS
 *         pysum += p_y_total[i]
 *         p_y_xsum += p_y_0[i] +  p_y_1[i]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(grid):
 */
    __pyx_v_p_y_xsum = (__pyx_v_p_y_xsum + ((__pyx_v_p_y_0[__pyx_v_i]) + (__pyx_v_p_y_1[__pyx_v_i])));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":518
 *         p_y_xsum += p_y_0[i] +  p_y_1[i]
 * 
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         p_y_total[i] = p_y_total[i]/pysum
 *         p_y_0[i] = p_y_0[i]/p_y_xsum
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":519
 * 
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i]/pysum             # <<<<<<<<<<<<<<
 *         p_y_0[i] = p_y_0[i]/p_y_xsum
 *         p_y_1[i] = p_y_1[i]/p_y_xsum
 */
    (__pyx_v_p_y_total[__pyx_v_i]) = ((__pyx_v_p_y_total[__pyx_v_i]) / __pyx_v_pysum);

    /* "revealer/REVEALER_runbenchmark.pyx":520
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i]/pysum
 *         p_y_0[i] = p_y_0[i]/p_y_xsum             # <<<<<<<<<<<<<<
 *         p_y_1[i] = p_y_1[i]/p_y_xsum
 * 
 */
    (__pyx_v_p_y_0[__pyx_v_i]) = ((__pyx_v_p_y_0[__pyx_v_i]) / __pyx_v_p_y_xsum);

    /* "revealer/REVEALER_runbenchmark.pyx":521
 *         p_y_total[i] = p_y_total[i]/pysum
 *         p_y_0[i] = p_y_0[i]/p_y_xsum
 *         p_y_1[i] = p_y_1[i]/p_y_xsum             # <<<<<<<<<<<<<<
 * 
 *     mutual_information = 0
 */
    (__pyx_v_p_y_1[__pyx_v_i]) = ((__pyx_v_p_y_1[__pyx_v_i]) / __pyx_v_p_y_xsum);
  }

  /* "revealer/REVEALER_runbenchmark.pyx":523
 *         p_y_1[i] = p_y_1[i]/p_y_xsum
 * 
 *     mutual_information = 0             # <<<<<<<<<<<<<<
 * 
 *     pX_1 = <double>sumx/<double>size
 */
  __pyx_v_mutual_information = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":525
 *     mutual_information = 0
 * 
 *     pX_1 = <double>sumx/<double>size             # <<<<<<<<<<<<<<
 *     pX_0 = <double>(size-sumx)/<double>size
 * 
 */
  __pyx_v_pX_1 = (((double)__pyx_v_sumx) / ((double)__pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":526
 * 
 *     pX_1 = <double>sumx/<double>size
 *     pX_0 = <double>(size-sumx)/<double>size             # <<<<<<<<<<<<<<
 * 
 *     mutual_information = 0.0
 */
  __pyx_v_pX_0 = (((double)(__pyx_v_size - __pyx_v_sumx)) / ((double)__pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":528
 *     pX_0 = <double>(size-sumx)/<double>size
 * 
 *     mutual_information = 0.0             # <<<<<<<<<<<<<<
 * 
 *     integral = 0.0
 */
  __pyx_v_mutual_information = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":530
 *     mutual_information = 0.0
 * 
 *     integral = 0.0             # <<<<<<<<<<<<<<
 *     for i in range(grid):
 *         integral = integral + (p_y_0[i] * log(p_y_0[i]/(p_y_total[i] * pX_0)))
 */
  __pyx_v_integral = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":531
 * 
 *     integral = 0.0
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         integral = integral + (p_y_0[i] * log(p_y_0[i]/(p_y_total[i] * pX_0)))
 * 
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":532
 *     integral = 0.0
 *     for i in range(grid):
 *         integral = integral + (p_y_0[i] * log(p_y_0[i]/(p_y_total[i] * pX_0)))             # <<<<<<<<<<<<<<
 * 
 *     mutual_information +=  integral
 */
    __pyx_v_integral = (__pyx_v_integral + ((__pyx_v_p_y_0[__pyx_v_i]) * log(((__pyx_v_p_y_0[__pyx_v_i]) / ((__pyx_v_p_y_total[__pyx_v_i]) * __pyx_v_pX_0)))));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":534
 *         integral = integral + (p_y_0[i] * log(p_y_0[i]/(p_y_total[i] * pX_0)))
 * 
 *     mutual_information +=  integral             # <<<<<<<<<<<<<<
 * 
 *     integral = 0.0
 */
  __pyx_v_mutual_information = (__pyx_v_mutual_information + __pyx_v_integral);

  /* "revealer/REVEALER_runbenchmark.pyx":536
 *     mutual_information +=  integral
 * 
 *     integral = 0.0             # <<<<<<<<<<<<<<
 *     for i in range(grid):
 *         integral = integral + (p_y_1[i] * log(p_y_1[i]/(p_y_total[i] * pX_1)))
 */
  __pyx_v_integral = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":537
 * 
 *     integral = 0.0
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         integral = integral + (p_y_1[i] * log(p_y_1[i]/(p_y_total[i] * pX_1)))
 * 
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":538
 *     integral = 0.0
 *     for i in range(grid):
 *         integral = integral + (p_y_1[i] * log(p_y_1[i]/(p_y_total[i] * pX_1)))             # <<<<<<<<<<<<<<
 * 
 *     mutual_information +=  integral
 */
    __pyx_v_integral = (__pyx_v_integral + ((__pyx_v_p_y_1[__pyx_v_i]) * log(((__pyx_v_p_y_1[__pyx_v_i]) / ((__pyx_v_p_y_total[__pyx_v_i]) * __pyx_v_pX_1)))));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":540
 *         integral = integral + (p_y_1[i] * log(p_y_1[i]/(p_y_total[i] * pX_1)))
 * 
 *     mutual_information +=  integral             # <<<<<<<<<<<<<<
 * 
 *     free(p_y_total)
 */
  __pyx_v_mutual_information = (__pyx_v_mutual_information + __pyx_v_integral);

  /* "revealer/REVEALER_runbenchmark.pyx":542
 *     mutual_information +=  integral
 * 
 *     free(p_y_total)             # <<<<<<<<<<<<<<
 *     free(p_y_0)
 *     free(p_y_1)
 */
  free(__pyx_v_p_y_total);

  /* "revealer/REVEALER_runbenchmark.pyx":543
 * 
 *     free(p_y_total)
 *     free(p_y_0)             # <<<<<<<<<<<<<<
 *     free(p_y_1)
 *     free(kernel)
 */
  free(__pyx_v_p_y_0);

  /* "revealer/REVEALER_runbenchmark.pyx":544
 *     free(p_y_total)
 *     free(p_y_0)
 *     free(p_y_1)             # <<<<<<<<<<<<<<
 *     free(kernel)
 *     free(normy)
 */
  free(__pyx_v_p_y_1);

  /* "revealer/REVEALER_runbenchmark.pyx":545
 *     free(p_y_0)
 *     free(p_y_1)
 *     free(kernel)             # <<<<<<<<<<<<<<
 *     free(normy)
 * 
 */
  free(__pyx_v_kernel);

  /* "revealer/REVEALER_runbenchmark.pyx":546
 *     free(p_y_1)
 *     free(kernel)
 *     free(normy)             # <<<<<<<<<<<<<<
 * 
 *     return (cor/fabs(cor)) * sqrt(1.0 - exp(-2.0 * mutual_information))
 */
  free(__pyx_v_normy);

  /* "revealer/REVEALER_runbenchmark.pyx":548
 *     free(normy)
 * 
 *     return (cor/fabs(cor)) * sqrt(1.0 - exp(-2.0 * mutual_information))             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = ((__pyx_v_cor / ((__pyx_t_5numpy_double_t)fabs(__pyx_v_cor))) * sqrt((1.0 - exp((-2.0 * __pyx_v_mutual_information)))));
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":429
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t binaryInformationCoefficient_cython(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y,           #Target
 *     np.int_t[:] x,              #Features to calculate correlation
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_3binaryInformationCoefficient_cython(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_2binaryInformationCoefficient_cython[] = " Calculate IC between continuous 'y' and binary 'x' ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_3binaryInformationCoefficient_cython(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_neighborhood;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_jitter;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("binaryInformationCoefficient_cython (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y,&__pyx_n_s_x,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_neighborhood,&__pyx_n_s_deltay,&__pyx_n_s_miny,&__pyx_n_s_jitter,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_x)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 1); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 2); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 3); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 4); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 5); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 6); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 7); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_deltay)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 8); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_miny)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, 9); __PYX_ERR(0, 429, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_jitter);
          if (value) { values[10] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "binaryInformationCoefficient_cython") < 0)) __PYX_ERR(0, 429, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_y = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_y.memview)) __PYX_ERR(0, 430, __pyx_L3_error)
    __pyx_v_x = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_x.memview)) __PYX_ERR(0, 431, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 432, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 433, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 434, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 435, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 436, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[7]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 437, __pyx_L3_error)
    __pyx_v_deltay = __pyx_PyFloat_AsDouble(values[8]); if (unlikely((__pyx_v_deltay == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
    __pyx_v_miny = __pyx_PyFloat_AsDouble(values[9]); if (unlikely((__pyx_v_miny == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 439, __pyx_L3_error)
    if (values[10]) {
      __pyx_v_jitter = __pyx_PyFloat_AsDouble(values[10]); if (unlikely((__pyx_v_jitter == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 440, __pyx_L3_error)
    } else {
      __pyx_v_jitter = ((__pyx_t_5numpy_double_t)1E-10);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("binaryInformationCoefficient_cython", 0, 10, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 429, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.binaryInformationCoefficient_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_2binaryInformationCoefficient_cython(__pyx_self, __pyx_v_y, __pyx_v_x, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, __pyx_v_jitter);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_2binaryInformationCoefficient_cython(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y, __Pyx_memviewslice __pyx_v_x, int __pyx_v_k, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_neighborhood, __pyx_t_5numpy_double_t __pyx_v_deltay, __pyx_t_5numpy_double_t __pyx_v_miny, __pyx_t_5numpy_double_t __pyx_v_jitter) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_double_t __pyx_t_1;
  struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("binaryInformationCoefficient_cython", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.jitter = __pyx_v_jitter;
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_v_y, __pyx_v_x, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, &__pyx_t_2); 
  __pyx_t_3 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.binaryInformationCoefficient_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":554
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t ConditionalInformationCoefficient_cython(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y,           #Target
 *     np.int_t[:] x,              #Feature that correlation is calculated
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_5ConditionalInformationCoefficient_cython(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __pyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython(__Pyx_memviewslice __pyx_v_y, __Pyx_memviewslice __pyx_v_x, __Pyx_memviewslice __pyx_v_z, int __pyx_v_k, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_neighborhood, __pyx_t_5numpy_double_t __pyx_v_deltay, __pyx_t_5numpy_double_t __pyx_v_miny, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython *__pyx_optional_args) {
  __pyx_t_5numpy_double_t __pyx_v_cor;
  __pyx_t_5numpy_double_t __pyx_v_sigma_y;
  __pyx_t_5numpy_double_t __pyx_v_term_2_pi_sigma_y;
  __pyx_t_5numpy_double_t __pyx_v_y_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_integral;
  __pyx_t_5numpy_double_t __pyx_v_deltak;
  __pyx_t_5numpy_double_t __pyx_v_conditional_mutual_information;
  __pyx_t_5numpy_double_t __pyx_v_pX0Z0;
  __pyx_t_5numpy_double_t __pyx_v_pX0Z1;
  __pyx_t_5numpy_double_t __pyx_v_pX1Z0;
  __pyx_t_5numpy_double_t __pyx_v_pX1Z1;
  __pyx_t_5numpy_double_t __pyx_v_pysum;
  CYTHON_UNUSED __pyx_t_5numpy_double_t __pyx_v_pyx0z0sum;
  CYTHON_UNUSED __pyx_t_5numpy_double_t __pyx_v_pyx0z1sum;
  CYTHON_UNUSED __pyx_t_5numpy_double_t __pyx_v_pyx1z0sum;
  CYTHON_UNUSED __pyx_t_5numpy_double_t __pyx_v_pyx1z1sum;
  CYTHON_UNUSED __pyx_t_5numpy_double_t __pyx_v_pyz0sum;
  CYTHON_UNUSED __pyx_t_5numpy_double_t __pyx_v_pyz1sum;
  __pyx_t_5numpy_double_t __pyx_v_pyxzsum;
  __pyx_t_5numpy_double_t __pyx_v_pyxsum;
  __pyx_t_5numpy_double_t __pyx_v_pyzsum;
  __pyx_t_5numpy_double_t *__pyx_v_kernel;
  __pyx_t_5numpy_double_t *__pyx_v_normy;
  __pyx_t_5numpy_double_t *__pyx_v_p_y_total;
  __pyx_t_5numpy_double_t *__pyx_v_p_x0z0;
  __pyx_t_5numpy_double_t *__pyx_v_p_x0z1;
  __pyx_t_5numpy_double_t *__pyx_v_p_x1z0;
  __pyx_t_5numpy_double_t *__pyx_v_p_x1z1;
  __pyx_t_5numpy_double_t *__pyx_v_p_z0;
  __pyx_t_5numpy_double_t *__pyx_v_p_z1;
  __pyx_t_5numpy_double_t *__pyx_v_p_x0;
  __pyx_t_5numpy_double_t *__pyx_v_p_x1;
  int *__pyx_v_saver;
  int __pyx_v_y_d;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_v_x0z0Count;
  int __pyx_v_x1z0Count;
  int __pyx_v_x0z1Count;
  int __pyx_v_x1z1Count;
  int __pyx_v_grid;
  int __pyx_v_sumz;
  int __pyx_v_index;
  double __pyx_v_pZ_1;
  double __pyx_v_pZ_0;
  CYTHON_UNUSED double __pyx_v_p_y_zsum;
  __pyx_t_5numpy_double_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  long __pyx_t_7;
  long __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  if (__pyx_optional_args) {
  }

  /* "revealer/REVEALER_runbenchmark.pyx":589
 *     cdef int y_d, i, j, sumx, x0z0Count, x1z0Count, x0z1Count, x1z1Count, grid,sumz
 * 
 *     cor = local_pearsonr(y, x, size)             # <<<<<<<<<<<<<<
 *     x0z0Count = 0
 *     x1z0Count = 0
 */
  __pyx_v_cor = __pyx_f_8revealer_21REVEALER_runbenchmark_local_pearsonr(__pyx_v_y, __pyx_v_x, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":590
 * 
 *     cor = local_pearsonr(y, x, size)
 *     x0z0Count = 0             # <<<<<<<<<<<<<<
 *     x1z0Count = 0
 *     x0z1Count = 0
 */
  __pyx_v_x0z0Count = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":591
 *     cor = local_pearsonr(y, x, size)
 *     x0z0Count = 0
 *     x1z0Count = 0             # <<<<<<<<<<<<<<
 *     x0z1Count = 0
 *     x1z1Count = 0
 */
  __pyx_v_x1z0Count = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":592
 *     x0z0Count = 0
 *     x1z0Count = 0
 *     x0z1Count = 0             # <<<<<<<<<<<<<<
 *     x1z1Count = 0
 * 
 */
  __pyx_v_x0z1Count = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":593
 *     x1z0Count = 0
 *     x0z1Count = 0
 *     x1z1Count = 0             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
  __pyx_v_x1z1Count = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":595
 *     x1z1Count = 0
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         if x[i] == 0 and z[i] == 0:
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":596
 * 
 *     i = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         if x[i] == 0 and z[i] == 0:
 *             x0z0Count += 1
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":597
 *     i = 0
 *     for i in range(size):
 *         if x[i] == 0 and z[i] == 0:             # <<<<<<<<<<<<<<
 *             x0z0Count += 1
 *         elif x[i] == 0 and z[i] == 1:
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) ))) == 0) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) ))) == 0) != 0);
    __pyx_t_4 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":598
 *     for i in range(size):
 *         if x[i] == 0 and z[i] == 0:
 *             x0z0Count += 1             # <<<<<<<<<<<<<<
 *         elif x[i] == 0 and z[i] == 1:
 *             x0z1Count += 1
 */
      __pyx_v_x0z0Count = (__pyx_v_x0z0Count + 1);

      /* "revealer/REVEALER_runbenchmark.pyx":597
 *     i = 0
 *     for i in range(size):
 *         if x[i] == 0 and z[i] == 0:             # <<<<<<<<<<<<<<
 *             x0z0Count += 1
 *         elif x[i] == 0 and z[i] == 1:
 */
      goto __pyx_L5;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":599
 *         if x[i] == 0 and z[i] == 0:
 *             x0z0Count += 1
 *         elif x[i] == 0 and z[i] == 1:             # <<<<<<<<<<<<<<
 *             x0z1Count += 1
 *         elif x[i] == 1 and z[i] == 0:
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) ))) == 0) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) ))) == 1) != 0);
    __pyx_t_4 = __pyx_t_6;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":600
 *             x0z0Count += 1
 *         elif x[i] == 0 and z[i] == 1:
 *             x0z1Count += 1             # <<<<<<<<<<<<<<
 *         elif x[i] == 1 and z[i] == 0:
 *             x1z0Count += 1
 */
      __pyx_v_x0z1Count = (__pyx_v_x0z1Count + 1);

      /* "revealer/REVEALER_runbenchmark.pyx":599
 *         if x[i] == 0 and z[i] == 0:
 *             x0z0Count += 1
 *         elif x[i] == 0 and z[i] == 1:             # <<<<<<<<<<<<<<
 *             x0z1Count += 1
 *         elif x[i] == 1 and z[i] == 0:
 */
      goto __pyx_L5;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":601
 *         elif x[i] == 0 and z[i] == 1:
 *             x0z1Count += 1
 *         elif x[i] == 1 and z[i] == 0:             # <<<<<<<<<<<<<<
 *             x1z0Count += 1
 *         elif x[i] == 1 and z[i] == 1:
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) ))) == 1) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) ))) == 0) != 0);
    __pyx_t_4 = __pyx_t_6;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":602
 *             x0z1Count += 1
 *         elif x[i] == 1 and z[i] == 0:
 *             x1z0Count += 1             # <<<<<<<<<<<<<<
 *         elif x[i] == 1 and z[i] == 1:
 *             x1z1Count += 1
 */
      __pyx_v_x1z0Count = (__pyx_v_x1z0Count + 1);

      /* "revealer/REVEALER_runbenchmark.pyx":601
 *         elif x[i] == 0 and z[i] == 1:
 *             x0z1Count += 1
 *         elif x[i] == 1 and z[i] == 0:             # <<<<<<<<<<<<<<
 *             x1z0Count += 1
 *         elif x[i] == 1 and z[i] == 1:
 */
      goto __pyx_L5;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":603
 *         elif x[i] == 1 and z[i] == 0:
 *             x1z0Count += 1
 *         elif x[i] == 1 and z[i] == 1:             # <<<<<<<<<<<<<<
 *             x1z1Count += 1
 * 
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) ))) == 1) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = (((*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) ))) == 1) != 0);
    __pyx_t_4 = __pyx_t_6;
    __pyx_L12_bool_binop_done:;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":604
 *             x1z0Count += 1
 *         elif x[i] == 1 and z[i] == 1:
 *             x1z1Count += 1             # <<<<<<<<<<<<<<
 * 
 *     sumz = 0
 */
      __pyx_v_x1z1Count = (__pyx_v_x1z1Count + 1);

      /* "revealer/REVEALER_runbenchmark.pyx":603
 *         elif x[i] == 1 and z[i] == 0:
 *             x1z0Count += 1
 *         elif x[i] == 1 and z[i] == 1:             # <<<<<<<<<<<<<<
 *             x1z1Count += 1
 * 
 */
    }
    __pyx_L5:;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":606
 *             x1z1Count += 1
 * 
 *     sumz = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         sumz += <int>z[i]
 */
  __pyx_v_sumz = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":607
 * 
 *     sumz = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         sumz += <int>z[i]
 * 
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":608
 *     sumz = 0
 *     for i in range(size):
 *         sumz += <int>z[i]             # <<<<<<<<<<<<<<
 * 
 *     saver = <int*> malloc(4 * sizeof(int))
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_v_sumz = (__pyx_v_sumz + ((int)(*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) )))));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":610
 *         sumz += <int>z[i]
 * 
 *     saver = <int*> malloc(4 * sizeof(int))             # <<<<<<<<<<<<<<
 *     for i in range(4):
 *         saver[i] = 0
 */
  __pyx_v_saver = ((int *)malloc((4 * (sizeof(int)))));

  /* "revealer/REVEALER_runbenchmark.pyx":611
 * 
 *     saver = <int*> malloc(4 * sizeof(int))
 *     for i in range(4):             # <<<<<<<<<<<<<<
 *         saver[i] = 0
 * 
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 4; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "revealer/REVEALER_runbenchmark.pyx":612
 *     saver = <int*> malloc(4 * sizeof(int))
 *     for i in range(4):
 *         saver[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     if x0z0Count > 1:
 */
    (__pyx_v_saver[__pyx_v_i]) = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":614
 *         saver[i] = 0
 * 
 *     if x0z0Count > 1:             # <<<<<<<<<<<<<<
 *         saver[0] = 1
 *     if x0z1Count > 1:
 */
  __pyx_t_4 = ((__pyx_v_x0z0Count > 1) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":615
 * 
 *     if x0z0Count > 1:
 *         saver[0] = 1             # <<<<<<<<<<<<<<
 *     if x0z1Count > 1:
 *         saver[1] = 1
 */
    (__pyx_v_saver[0]) = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":614
 *         saver[i] = 0
 * 
 *     if x0z0Count > 1:             # <<<<<<<<<<<<<<
 *         saver[0] = 1
 *     if x0z1Count > 1:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":616
 *     if x0z0Count > 1:
 *         saver[0] = 1
 *     if x0z1Count > 1:             # <<<<<<<<<<<<<<
 *         saver[1] = 1
 *     if x1z0Count > 1:
 */
  __pyx_t_4 = ((__pyx_v_x0z1Count > 1) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":617
 *         saver[0] = 1
 *     if x0z1Count > 1:
 *         saver[1] = 1             # <<<<<<<<<<<<<<
 *     if x1z0Count > 1:
 *         saver[2] = 1
 */
    (__pyx_v_saver[1]) = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":616
 *     if x0z0Count > 1:
 *         saver[0] = 1
 *     if x0z1Count > 1:             # <<<<<<<<<<<<<<
 *         saver[1] = 1
 *     if x1z0Count > 1:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":618
 *     if x0z1Count > 1:
 *         saver[1] = 1
 *     if x1z0Count > 1:             # <<<<<<<<<<<<<<
 *         saver[2] = 1
 *     if x1z1Count > 1:
 */
  __pyx_t_4 = ((__pyx_v_x1z0Count > 1) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":619
 *         saver[1] = 1
 *     if x1z0Count > 1:
 *         saver[2] = 1             # <<<<<<<<<<<<<<
 *     if x1z1Count > 1:
 *         saver[3] = 1
 */
    (__pyx_v_saver[2]) = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":618
 *     if x0z1Count > 1:
 *         saver[1] = 1
 *     if x1z0Count > 1:             # <<<<<<<<<<<<<<
 *         saver[2] = 1
 *     if x1z1Count > 1:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":620
 *     if x1z0Count > 1:
 *         saver[2] = 1
 *     if x1z1Count > 1:             # <<<<<<<<<<<<<<
 *         saver[3] = 1
 * 
 */
  __pyx_t_4 = ((__pyx_v_x1z1Count > 1) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":621
 *         saver[2] = 1
 *     if x1z1Count > 1:
 *         saver[3] = 1             # <<<<<<<<<<<<<<
 * 
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))
 */
    (__pyx_v_saver[3]) = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":620
 *     if x1z0Count > 1:
 *         saver[2] = 1
 *     if x1z1Count > 1:             # <<<<<<<<<<<<<<
 *         saver[3] = 1
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":623
 *         saver[3] = 1
 * 
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))             # <<<<<<<<<<<<<<
 *     deltak = y_bandwidth * neighborhood
 *     grid = <int>(round(deltay/deltak*k))
 */
  __pyx_v_y_bandwidth = (__pyx_v_bandwidth * (__pyx_v_bandwidth_mult * (1.0 + (__pyx_v_bandwidth_adj * fabs(__pyx_v_cor)))));

  /* "revealer/REVEALER_runbenchmark.pyx":624
 * 
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))
 *     deltak = y_bandwidth * neighborhood             # <<<<<<<<<<<<<<
 *     grid = <int>(round(deltay/deltak*k))
 *     #printf("grid is %.d\n",grid)
 */
  __pyx_v_deltak = (__pyx_v_y_bandwidth * __pyx_v_neighborhood);

  /* "revealer/REVEALER_runbenchmark.pyx":625
 *     y_bandwidth = bandwidth * (bandwidth_mult * (1 + (bandwidth_adj) * fabs(cor)))
 *     deltak = y_bandwidth * neighborhood
 *     grid = <int>(round(deltay/deltak*k))             # <<<<<<<<<<<<<<
 *     #printf("grid is %.d\n",grid)
 * 
 */
  __pyx_v_grid = ((int)round(((__pyx_v_deltay / __pyx_v_deltak) * __pyx_v_k)));

  /* "revealer/REVEALER_runbenchmark.pyx":628
 *     #printf("grid is %.d\n",grid)
 * 
 *     if grid < 2*k+1:             # <<<<<<<<<<<<<<
 *         grid = 2*k+1
 * 
 */
  __pyx_t_4 = ((__pyx_v_grid < ((2 * __pyx_v_k) + 1)) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":629
 * 
 *     if grid < 2*k+1:
 *         grid = 2*k+1             # <<<<<<<<<<<<<<
 * 
 *     # Prepare grids
 */
    __pyx_v_grid = ((2 * __pyx_v_k) + 1);

    /* "revealer/REVEALER_runbenchmark.pyx":628
 *     #printf("grid is %.d\n",grid)
 * 
 *     if grid < 2*k+1:             # <<<<<<<<<<<<<<
 *         grid = 2*k+1
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":632
 * 
 *     # Prepare grids
 *     p_y_total = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_y_total = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":633
 *     # Prepare grids
 *     p_y_total = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_z0 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":634
 *     p_y_total = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_x0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_z1 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":635
 *     p_z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_x1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_x0 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":636
 *     p_z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_x0z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_x1 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":637
 *     p_x0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_x0z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_x0z0 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":638
 *     p_x1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_x1z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 */
  __pyx_v_p_x0z1 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":639
 *     p_x0z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x0z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     p_x1z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     for i in range(grid):
 */
  __pyx_v_p_x1z0 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":640
 *     p_x0z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     for i in range(grid):
 *         p_y_total[i] = 0.0
 */
  __pyx_v_p_x1z1 = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_grid * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":641
 *     p_x1z0 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     p_x1z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         p_y_total[i] = 0.0
 *         p_z0[i] = 0.0
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":642
 *     p_x1z1 = <np.double_t*> malloc(grid * sizeof(np.double_t))
 *     for i in range(grid):
 *         p_y_total[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_z0[i] = 0.0
 *         p_z1[i] = 0.0
 */
    (__pyx_v_p_y_total[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":643
 *     for i in range(grid):
 *         p_y_total[i] = 0.0
 *         p_z0[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_z1[i] = 0.0
 *         p_x0[i] = 0.0
 */
    (__pyx_v_p_z0[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":644
 *         p_y_total[i] = 0.0
 *         p_z0[i] = 0.0
 *         p_z1[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_x0[i] = 0.0
 *         p_x1[i] = 0.0
 */
    (__pyx_v_p_z1[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":645
 *         p_z0[i] = 0.0
 *         p_z1[i] = 0.0
 *         p_x0[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_x1[i] = 0.0
 *         p_x0z0[i] = 0.0
 */
    (__pyx_v_p_x0[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":646
 *         p_z1[i] = 0.0
 *         p_x0[i] = 0.0
 *         p_x1[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_x0z0[i] = 0.0
 *         p_x0z1[i] = 0.0
 */
    (__pyx_v_p_x1[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":647
 *         p_x0[i] = 0.0
 *         p_x1[i] = 0.0
 *         p_x0z0[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_x0z1[i] = 0.0
 *         p_x1z0[i] = 0.0
 */
    (__pyx_v_p_x0z0[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":648
 *         p_x1[i] = 0.0
 *         p_x0z0[i] = 0.0
 *         p_x0z1[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_x1z0[i] = 0.0
 *         p_x1z1[i] = 0.0
 */
    (__pyx_v_p_x0z1[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":649
 *         p_x0z0[i] = 0.0
 *         p_x0z1[i] = 0.0
 *         p_x1z0[i] = 0.0             # <<<<<<<<<<<<<<
 *         p_x1z1[i] = 0.0
 * 
 */
    (__pyx_v_p_x1z0[__pyx_v_i]) = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":650
 *         p_x0z1[i] = 0.0
 *         p_x1z0[i] = 0.0
 *         p_x1z1[i] = 0.0             # <<<<<<<<<<<<<<
 * 
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))
 */
    (__pyx_v_p_x1z1[__pyx_v_i]) = 0.0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":652
 *         p_x1z1[i] = 0.0
 * 
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)
 */
  __pyx_v_normy = ((__pyx_t_5numpy_double_t *)malloc((__pyx_v_size * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":653
 * 
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)
 * 
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":654
 *     normy = <np.double_t*> malloc(size * sizeof(np.double_t))
 *     for i in range(size):
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)             # <<<<<<<<<<<<<<
 * 
 *     sigma_y = (grid * y_bandwidth) / deltay
 */
    __pyx_t_5 = __pyx_v_i;
    (__pyx_v_normy[__pyx_v_i]) = ((((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_y.data + __pyx_t_5 * __pyx_v_y.strides[0]) ))) - __pyx_v_miny) / __pyx_v_deltay) * (__pyx_v_grid - 1));
  }

  /* "revealer/REVEALER_runbenchmark.pyx":656
 *         normy[i] = (y[i] - miny) / deltay * (grid - 1)
 * 
 *     sigma_y = (grid * y_bandwidth) / deltay             # <<<<<<<<<<<<<<
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 */
  __pyx_v_sigma_y = ((__pyx_v_grid * __pyx_v_y_bandwidth) / __pyx_v_deltay);

  /* "revealer/REVEALER_runbenchmark.pyx":657
 * 
 *     sigma_y = (grid * y_bandwidth) / deltay
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y             # <<<<<<<<<<<<<<
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 * 
 */
  __pyx_v_term_2_pi_sigma_y = ((2.0 * M_PI) * __pyx_v_sigma_y);

  /* "revealer/REVEALER_runbenchmark.pyx":658
 *     sigma_y = (grid * y_bandwidth) / deltay
 *     term_2_pi_sigma_y = 2.0 * M_PI * sigma_y
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
  __pyx_v_kernel = ((__pyx_t_5numpy_double_t *)malloc(((2 * __pyx_v_k) * (sizeof(__pyx_t_5numpy_double_t)))));

  /* "revealer/REVEALER_runbenchmark.pyx":660
 *     kernel = <np.double_t*> malloc(2 * k * sizeof(np.double_t))
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(2*k):
 *         kernel[i] = exp(-0.5*(((i-k)/sigma_y)**2))/term_2_pi_sigma_y
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":661
 * 
 *     i = 0
 *     for i in range(2*k):             # <<<<<<<<<<<<<<
 *         kernel[i] = exp(-0.5*(((i-k)/sigma_y)**2))/term_2_pi_sigma_y
 * 
 */
  __pyx_t_7 = (2 * __pyx_v_k);
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_8; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "revealer/REVEALER_runbenchmark.pyx":662
 *     i = 0
 *     for i in range(2*k):
 *         kernel[i] = exp(-0.5*(((i-k)/sigma_y)**2))/term_2_pi_sigma_y             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
    (__pyx_v_kernel[__pyx_v_i]) = (((__pyx_t_5numpy_double_t)exp((-0.5 * pow((((__pyx_t_5numpy_double_t)(__pyx_v_i - __pyx_v_k)) / __pyx_v_sigma_y), 2.0)))) / __pyx_v_term_2_pi_sigma_y);
  }

  /* "revealer/REVEALER_runbenchmark.pyx":664
 *         kernel[i] = exp(-0.5*(((i-k)/sigma_y)**2))/term_2_pi_sigma_y
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(size):
 *         y_d = <int>(round(normy[i]))
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":665
 * 
 *     i = 0
 *     for i in range(size):             # <<<<<<<<<<<<<<
 *         y_d = <int>(round(normy[i]))
 *         for j in range(2*k):
 */
  __pyx_t_1 = __pyx_v_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":666
 *     i = 0
 *     for i in range(size):
 *         y_d = <int>(round(normy[i]))             # <<<<<<<<<<<<<<
 *         for j in range(2*k):
 *             index = y_d - k + j
 */
    __pyx_v_y_d = ((int)round((__pyx_v_normy[__pyx_v_i])));

    /* "revealer/REVEALER_runbenchmark.pyx":667
 *     for i in range(size):
 *         y_d = <int>(round(normy[i]))
 *         for j in range(2*k):             # <<<<<<<<<<<<<<
 *             index = y_d - k + j
 *             if index < 0:
 */
    __pyx_t_7 = (2 * __pyx_v_k);
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_j = __pyx_t_9;

      /* "revealer/REVEALER_runbenchmark.pyx":668
 *         y_d = <int>(round(normy[i]))
 *         for j in range(2*k):
 *             index = y_d - k + j             # <<<<<<<<<<<<<<
 *             if index < 0:
 *                 continue
 */
      __pyx_v_index = ((__pyx_v_y_d - __pyx_v_k) + __pyx_v_j);

      /* "revealer/REVEALER_runbenchmark.pyx":669
 *         for j in range(2*k):
 *             index = y_d - k + j
 *             if index < 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             if index >= grid:
 */
      __pyx_t_4 = ((__pyx_v_index < 0) != 0);
      if (__pyx_t_4) {

        /* "revealer/REVEALER_runbenchmark.pyx":670
 *             index = y_d - k + j
 *             if index < 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             if index >= grid:
 *                 continue
 */
        goto __pyx_L31_continue;

        /* "revealer/REVEALER_runbenchmark.pyx":669
 *         for j in range(2*k):
 *             index = y_d - k + j
 *             if index < 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             if index >= grid:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":671
 *             if index < 0:
 *                 continue
 *             if index >= grid:             # <<<<<<<<<<<<<<
 *                 continue
 *             p_y_total[index] += kernel[j]
 */
      __pyx_t_4 = ((__pyx_v_index >= __pyx_v_grid) != 0);
      if (__pyx_t_4) {

        /* "revealer/REVEALER_runbenchmark.pyx":672
 *                 continue
 *             if index >= grid:
 *                 continue             # <<<<<<<<<<<<<<
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i] and 0 == z[i] and saver[0] == 1:
 */
        goto __pyx_L31_continue;

        /* "revealer/REVEALER_runbenchmark.pyx":671
 *             if index < 0:
 *                 continue
 *             if index >= grid:             # <<<<<<<<<<<<<<
 *                 continue
 *             p_y_total[index] += kernel[j]
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":673
 *             if index >= grid:
 *                 continue
 *             p_y_total[index] += kernel[j]             # <<<<<<<<<<<<<<
 *             if 0 == x[i] and 0 == z[i] and saver[0] == 1:
 *                 p_x0z0[index] += kernel[j]
 */
      __pyx_t_10 = __pyx_v_index;
      (__pyx_v_p_y_total[__pyx_t_10]) = ((__pyx_v_p_y_total[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

      /* "revealer/REVEALER_runbenchmark.pyx":674
 *                 continue
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i] and 0 == z[i] and saver[0] == 1:             # <<<<<<<<<<<<<<
 *                 p_x0z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]
 */
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((0 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L36_bool_binop_done;
      }
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((0 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L36_bool_binop_done;
      }
      __pyx_t_6 = (((__pyx_v_saver[0]) == 1) != 0);
      __pyx_t_4 = __pyx_t_6;
      __pyx_L36_bool_binop_done:;
      if (__pyx_t_4) {

        /* "revealer/REVEALER_runbenchmark.pyx":675
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i] and 0 == z[i] and saver[0] == 1:
 *                 p_x0z0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_z0[index] += kernel[j]
 *                 p_x0[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x0z0[__pyx_t_10]) = ((__pyx_v_p_x0z0[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":676
 *             if 0 == x[i] and 0 == z[i] and saver[0] == 1:
 *                 p_x0z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_x0[index] += kernel[j]
 *             elif 0 == x[i] and 1 == z[i] and saver[1] == 1:
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_z0[__pyx_t_10]) = ((__pyx_v_p_z0[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":677
 *                 p_x0z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]
 *                 p_x0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *             elif 0 == x[i] and 1 == z[i] and saver[1] == 1:
 *                 p_x0z1[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x0[__pyx_t_10]) = ((__pyx_v_p_x0[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":674
 *                 continue
 *             p_y_total[index] += kernel[j]
 *             if 0 == x[i] and 0 == z[i] and saver[0] == 1:             # <<<<<<<<<<<<<<
 *                 p_x0z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]
 */
        goto __pyx_L35;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":678
 *                 p_z0[index] += kernel[j]
 *                 p_x0[index] += kernel[j]
 *             elif 0 == x[i] and 1 == z[i] and saver[1] == 1:             # <<<<<<<<<<<<<<
 *                 p_x0z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]
 */
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((0 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L39_bool_binop_done;
      }
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((1 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L39_bool_binop_done;
      }
      __pyx_t_6 = (((__pyx_v_saver[1]) == 1) != 0);
      __pyx_t_4 = __pyx_t_6;
      __pyx_L39_bool_binop_done:;
      if (__pyx_t_4) {

        /* "revealer/REVEALER_runbenchmark.pyx":679
 *                 p_x0[index] += kernel[j]
 *             elif 0 == x[i] and 1 == z[i] and saver[1] == 1:
 *                 p_x0z1[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_z1[index] += kernel[j]
 *                 p_x0[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x0z1[__pyx_t_10]) = ((__pyx_v_p_x0z1[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":680
 *             elif 0 == x[i] and 1 == z[i] and saver[1] == 1:
 *                 p_x0z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_x0[index] += kernel[j]
 *             elif 1 == x[i] and 0 == z[i] and saver[2] == 1:
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_z1[__pyx_t_10]) = ((__pyx_v_p_z1[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":681
 *                 p_x0z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]
 *                 p_x0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *             elif 1 == x[i] and 0 == z[i] and saver[2] == 1:
 *                 p_x1z0[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x0[__pyx_t_10]) = ((__pyx_v_p_x0[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":678
 *                 p_z0[index] += kernel[j]
 *                 p_x0[index] += kernel[j]
 *             elif 0 == x[i] and 1 == z[i] and saver[1] == 1:             # <<<<<<<<<<<<<<
 *                 p_x0z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]
 */
        goto __pyx_L35;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":682
 *                 p_z1[index] += kernel[j]
 *                 p_x0[index] += kernel[j]
 *             elif 1 == x[i] and 0 == z[i] and saver[2] == 1:             # <<<<<<<<<<<<<<
 *                 p_x1z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]
 */
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((1 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L42_bool_binop_done;
      }
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((0 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L42_bool_binop_done;
      }
      __pyx_t_6 = (((__pyx_v_saver[2]) == 1) != 0);
      __pyx_t_4 = __pyx_t_6;
      __pyx_L42_bool_binop_done:;
      if (__pyx_t_4) {

        /* "revealer/REVEALER_runbenchmark.pyx":683
 *                 p_x0[index] += kernel[j]
 *             elif 1 == x[i] and 0 == z[i] and saver[2] == 1:
 *                 p_x1z0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_z0[index] += kernel[j]
 *                 p_x1[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x1z0[__pyx_t_10]) = ((__pyx_v_p_x1z0[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":684
 *             elif 1 == x[i] and 0 == z[i] and saver[2] == 1:
 *                 p_x1z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_x1[index] += kernel[j]
 *             elif 1 == x[i] and 1 == z[i] and saver[3] == 1:
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_z0[__pyx_t_10]) = ((__pyx_v_p_z0[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":685
 *                 p_x1z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]
 *                 p_x1[index] += kernel[j]             # <<<<<<<<<<<<<<
 *             elif 1 == x[i] and 1 == z[i] and saver[3] == 1:
 *                 p_x1z1[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x1[__pyx_t_10]) = ((__pyx_v_p_x1[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":682
 *                 p_z1[index] += kernel[j]
 *                 p_x0[index] += kernel[j]
 *             elif 1 == x[i] and 0 == z[i] and saver[2] == 1:             # <<<<<<<<<<<<<<
 *                 p_x1z0[index] += kernel[j]
 *                 p_z0[index] += kernel[j]
 */
        goto __pyx_L35;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":686
 *                 p_z0[index] += kernel[j]
 *                 p_x1[index] += kernel[j]
 *             elif 1 == x[i] and 1 == z[i] and saver[3] == 1:             # <<<<<<<<<<<<<<
 *                 p_x1z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]
 */
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((1 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_5 * __pyx_v_x.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L45_bool_binop_done;
      }
      __pyx_t_5 = __pyx_v_i;
      __pyx_t_6 = ((1 == (*((__pyx_t_5numpy_int_t *) ( /* dim=0 */ (__pyx_v_z.data + __pyx_t_5 * __pyx_v_z.strides[0]) )))) != 0);
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L45_bool_binop_done;
      }
      __pyx_t_6 = (((__pyx_v_saver[3]) == 1) != 0);
      __pyx_t_4 = __pyx_t_6;
      __pyx_L45_bool_binop_done:;
      if (__pyx_t_4) {

        /* "revealer/REVEALER_runbenchmark.pyx":687
 *                 p_x1[index] += kernel[j]
 *             elif 1 == x[i] and 1 == z[i] and saver[3] == 1:
 *                 p_x1z1[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_z1[index] += kernel[j]
 *                 p_x1[index] += kernel[j]
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x1z1[__pyx_t_10]) = ((__pyx_v_p_x1z1[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":688
 *             elif 1 == x[i] and 1 == z[i] and saver[3] == 1:
 *                 p_x1z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]             # <<<<<<<<<<<<<<
 *                 p_x1[index] += kernel[j]
 * 
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_z1[__pyx_t_10]) = ((__pyx_v_p_z1[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":689
 *                 p_x1z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]
 *                 p_x1[index] += kernel[j]             # <<<<<<<<<<<<<<
 * 
 *     pZ_1 = <double>sumz/<double>size
 */
        __pyx_t_10 = __pyx_v_index;
        (__pyx_v_p_x1[__pyx_t_10]) = ((__pyx_v_p_x1[__pyx_t_10]) + (__pyx_v_kernel[__pyx_v_j]));

        /* "revealer/REVEALER_runbenchmark.pyx":686
 *                 p_z0[index] += kernel[j]
 *                 p_x1[index] += kernel[j]
 *             elif 1 == x[i] and 1 == z[i] and saver[3] == 1:             # <<<<<<<<<<<<<<
 *                 p_x1z1[index] += kernel[j]
 *                 p_z1[index] += kernel[j]
 */
      }
      __pyx_L35:;
      __pyx_L31_continue:;
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":691
 *                 p_x1[index] += kernel[j]
 * 
 *     pZ_1 = <double>sumz/<double>size             # <<<<<<<<<<<<<<
 *     pZ_0 = <double>(size - sumz)/<double>size
 *     conditional_mutual_information = 0.0
 */
  __pyx_v_pZ_1 = (((double)__pyx_v_sumz) / ((double)__pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":692
 * 
 *     pZ_1 = <double>sumz/<double>size
 *     pZ_0 = <double>(size - sumz)/<double>size             # <<<<<<<<<<<<<<
 *     conditional_mutual_information = 0.0
 * 
 */
  __pyx_v_pZ_0 = (((double)(__pyx_v_size - __pyx_v_sumz)) / ((double)__pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":693
 *     pZ_1 = <double>sumz/<double>size
 *     pZ_0 = <double>(size - sumz)/<double>size
 *     conditional_mutual_information = 0.0             # <<<<<<<<<<<<<<
 * 
 *     pysum = 0.0
 */
  __pyx_v_conditional_mutual_information = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":695
 *     conditional_mutual_information = 0.0
 * 
 *     pysum = 0.0             # <<<<<<<<<<<<<<
 *     pyx0z0sum = 0.0
 *     pyx0z1sum = 0.0
 */
  __pyx_v_pysum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":696
 * 
 *     pysum = 0.0
 *     pyx0z0sum = 0.0             # <<<<<<<<<<<<<<
 *     pyx0z1sum = 0.0
 *     pyx1z0sum = 0.0
 */
  __pyx_v_pyx0z0sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":697
 *     pysum = 0.0
 *     pyx0z0sum = 0.0
 *     pyx0z1sum = 0.0             # <<<<<<<<<<<<<<
 *     pyx1z0sum = 0.0
 *     pyx1z1sum = 0.0
 */
  __pyx_v_pyx0z1sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":698
 *     pyx0z0sum = 0.0
 *     pyx0z1sum = 0.0
 *     pyx1z0sum = 0.0             # <<<<<<<<<<<<<<
 *     pyx1z1sum = 0.0
 *     pyz0sum = 0.0
 */
  __pyx_v_pyx1z0sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":699
 *     pyx0z1sum = 0.0
 *     pyx1z0sum = 0.0
 *     pyx1z1sum = 0.0             # <<<<<<<<<<<<<<
 *     pyz0sum = 0.0
 *     pyz1sum = 0.0
 */
  __pyx_v_pyx1z1sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":700
 *     pyx1z0sum = 0.0
 *     pyx1z1sum = 0.0
 *     pyz0sum = 0.0             # <<<<<<<<<<<<<<
 *     pyz1sum = 0.0
 *     p_y_zsum = 0.0
 */
  __pyx_v_pyz0sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":701
 *     pyx1z1sum = 0.0
 *     pyz0sum = 0.0
 *     pyz1sum = 0.0             # <<<<<<<<<<<<<<
 *     p_y_zsum = 0.0
 *     pyxsum = 0.0
 */
  __pyx_v_pyz1sum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":702
 *     pyz0sum = 0.0
 *     pyz1sum = 0.0
 *     p_y_zsum = 0.0             # <<<<<<<<<<<<<<
 *     pyxsum = 0.0
 *     pyzsum = 0.0
 */
  __pyx_v_p_y_zsum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":703
 *     pyz1sum = 0.0
 *     p_y_zsum = 0.0
 *     pyxsum = 0.0             # <<<<<<<<<<<<<<
 *     pyzsum = 0.0
 *     pyxzsum = 0.0
 */
  __pyx_v_pyxsum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":704
 *     p_y_zsum = 0.0
 *     pyxsum = 0.0
 *     pyzsum = 0.0             # <<<<<<<<<<<<<<
 *     pyxzsum = 0.0
 * 
 */
  __pyx_v_pyzsum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":705
 *     pyxsum = 0.0
 *     pyzsum = 0.0
 *     pyxzsum = 0.0             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
  __pyx_v_pyxzsum = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":707
 *     pyxzsum = 0.0
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i] + EPS
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":708
 * 
 *     i = 0
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         p_y_total[i] = p_y_total[i] + EPS
 *         pysum += p_y_total[i]
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":709
 *     i = 0
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i] + EPS             # <<<<<<<<<<<<<<
 *         pysum += p_y_total[i]
 * 
 */
    (__pyx_v_p_y_total[__pyx_v_i]) = ((__pyx_v_p_y_total[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":710
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i] + EPS
 *         pysum += p_y_total[i]             # <<<<<<<<<<<<<<
 * 
 *         p_x0[i] = p_x0[i] + EPS
 */
    __pyx_v_pysum = (__pyx_v_pysum + (__pyx_v_p_y_total[__pyx_v_i]));

    /* "revealer/REVEALER_runbenchmark.pyx":712
 *         pysum += p_y_total[i]
 * 
 *         p_x0[i] = p_x0[i] + EPS             # <<<<<<<<<<<<<<
 *         p_x1[i] = p_x1[i] + EPS
 *         pyxsum += p_x0[i] + p_x1[i]
 */
    (__pyx_v_p_x0[__pyx_v_i]) = ((__pyx_v_p_x0[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":713
 * 
 *         p_x0[i] = p_x0[i] + EPS
 *         p_x1[i] = p_x1[i] + EPS             # <<<<<<<<<<<<<<
 *         pyxsum += p_x0[i] + p_x1[i]
 * 
 */
    (__pyx_v_p_x1[__pyx_v_i]) = ((__pyx_v_p_x1[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":714
 *         p_x0[i] = p_x0[i] + EPS
 *         p_x1[i] = p_x1[i] + EPS
 *         pyxsum += p_x0[i] + p_x1[i]             # <<<<<<<<<<<<<<
 * 
 *         p_z0[i] = p_z0[i] + EPS
 */
    __pyx_v_pyxsum = (__pyx_v_pyxsum + ((__pyx_v_p_x0[__pyx_v_i]) + (__pyx_v_p_x1[__pyx_v_i])));

    /* "revealer/REVEALER_runbenchmark.pyx":716
 *         pyxsum += p_x0[i] + p_x1[i]
 * 
 *         p_z0[i] = p_z0[i] + EPS             # <<<<<<<<<<<<<<
 *         p_z1[i] = p_z1[i] + EPS
 *         pyzsum += p_z0[i] + p_z1[i]
 */
    (__pyx_v_p_z0[__pyx_v_i]) = ((__pyx_v_p_z0[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":717
 * 
 *         p_z0[i] = p_z0[i] + EPS
 *         p_z1[i] = p_z1[i] + EPS             # <<<<<<<<<<<<<<
 *         pyzsum += p_z0[i] + p_z1[i]
 *         if saver[0] != 0:
 */
    (__pyx_v_p_z1[__pyx_v_i]) = ((__pyx_v_p_z1[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

    /* "revealer/REVEALER_runbenchmark.pyx":718
 *         p_z0[i] = p_z0[i] + EPS
 *         p_z1[i] = p_z1[i] + EPS
 *         pyzsum += p_z0[i] + p_z1[i]             # <<<<<<<<<<<<<<
 *         if saver[0] != 0:
 *             p_x0z0[i] = p_x0z0[i] + EPS
 */
    __pyx_v_pyzsum = (__pyx_v_pyzsum + ((__pyx_v_p_z0[__pyx_v_i]) + (__pyx_v_p_z1[__pyx_v_i])));

    /* "revealer/REVEALER_runbenchmark.pyx":719
 *         p_z1[i] = p_z1[i] + EPS
 *         pyzsum += p_z0[i] + p_z1[i]
 *         if saver[0] != 0:             # <<<<<<<<<<<<<<
 *             p_x0z0[i] = p_x0z0[i] + EPS
 *             pyxzsum += p_x0z0[i]
 */
    __pyx_t_4 = (((__pyx_v_saver[0]) != 0) != 0);
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":720
 *         pyzsum += p_z0[i] + p_z1[i]
 *         if saver[0] != 0:
 *             p_x0z0[i] = p_x0z0[i] + EPS             # <<<<<<<<<<<<<<
 *             pyxzsum += p_x0z0[i]
 *         if saver[1] != 0:
 */
      (__pyx_v_p_x0z0[__pyx_v_i]) = ((__pyx_v_p_x0z0[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

      /* "revealer/REVEALER_runbenchmark.pyx":721
 *         if saver[0] != 0:
 *             p_x0z0[i] = p_x0z0[i] + EPS
 *             pyxzsum += p_x0z0[i]             # <<<<<<<<<<<<<<
 *         if saver[1] != 0:
 *             p_x0z1[i] = p_x0z1[i] + EPS
 */
      __pyx_v_pyxzsum = (__pyx_v_pyxzsum + (__pyx_v_p_x0z0[__pyx_v_i]));

      /* "revealer/REVEALER_runbenchmark.pyx":719
 *         p_z1[i] = p_z1[i] + EPS
 *         pyzsum += p_z0[i] + p_z1[i]
 *         if saver[0] != 0:             # <<<<<<<<<<<<<<
 *             p_x0z0[i] = p_x0z0[i] + EPS
 *             pyxzsum += p_x0z0[i]
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":722
 *             p_x0z0[i] = p_x0z0[i] + EPS
 *             pyxzsum += p_x0z0[i]
 *         if saver[1] != 0:             # <<<<<<<<<<<<<<
 *             p_x0z1[i] = p_x0z1[i] + EPS
 *             pyxzsum += p_x0z1[i]
 */
    __pyx_t_4 = (((__pyx_v_saver[1]) != 0) != 0);
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":723
 *             pyxzsum += p_x0z0[i]
 *         if saver[1] != 0:
 *             p_x0z1[i] = p_x0z1[i] + EPS             # <<<<<<<<<<<<<<
 *             pyxzsum += p_x0z1[i]
 *         if saver[2] != 0:
 */
      (__pyx_v_p_x0z1[__pyx_v_i]) = ((__pyx_v_p_x0z1[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

      /* "revealer/REVEALER_runbenchmark.pyx":724
 *         if saver[1] != 0:
 *             p_x0z1[i] = p_x0z1[i] + EPS
 *             pyxzsum += p_x0z1[i]             # <<<<<<<<<<<<<<
 *         if saver[2] != 0:
 *             p_x1z0[i] = p_x1z0[i] + EPS
 */
      __pyx_v_pyxzsum = (__pyx_v_pyxzsum + (__pyx_v_p_x0z1[__pyx_v_i]));

      /* "revealer/REVEALER_runbenchmark.pyx":722
 *             p_x0z0[i] = p_x0z0[i] + EPS
 *             pyxzsum += p_x0z0[i]
 *         if saver[1] != 0:             # <<<<<<<<<<<<<<
 *             p_x0z1[i] = p_x0z1[i] + EPS
 *             pyxzsum += p_x0z1[i]
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":725
 *             p_x0z1[i] = p_x0z1[i] + EPS
 *             pyxzsum += p_x0z1[i]
 *         if saver[2] != 0:             # <<<<<<<<<<<<<<
 *             p_x1z0[i] = p_x1z0[i] + EPS
 *             pyxzsum += p_x1z0[i]
 */
    __pyx_t_4 = (((__pyx_v_saver[2]) != 0) != 0);
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":726
 *             pyxzsum += p_x0z1[i]
 *         if saver[2] != 0:
 *             p_x1z0[i] = p_x1z0[i] + EPS             # <<<<<<<<<<<<<<
 *             pyxzsum += p_x1z0[i]
 *         if saver[3] != 0:
 */
      (__pyx_v_p_x1z0[__pyx_v_i]) = ((__pyx_v_p_x1z0[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

      /* "revealer/REVEALER_runbenchmark.pyx":727
 *         if saver[2] != 0:
 *             p_x1z0[i] = p_x1z0[i] + EPS
 *             pyxzsum += p_x1z0[i]             # <<<<<<<<<<<<<<
 *         if saver[3] != 0:
 *             p_x1z1[i] = p_x1z1[i] + EPS
 */
      __pyx_v_pyxzsum = (__pyx_v_pyxzsum + (__pyx_v_p_x1z0[__pyx_v_i]));

      /* "revealer/REVEALER_runbenchmark.pyx":725
 *             p_x0z1[i] = p_x0z1[i] + EPS
 *             pyxzsum += p_x0z1[i]
 *         if saver[2] != 0:             # <<<<<<<<<<<<<<
 *             p_x1z0[i] = p_x1z0[i] + EPS
 *             pyxzsum += p_x1z0[i]
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":728
 *             p_x1z0[i] = p_x1z0[i] + EPS
 *             pyxzsum += p_x1z0[i]
 *         if saver[3] != 0:             # <<<<<<<<<<<<<<
 *             p_x1z1[i] = p_x1z1[i] + EPS
 *             pyxzsum += p_x1z1[i]
 */
    __pyx_t_4 = (((__pyx_v_saver[3]) != 0) != 0);
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":729
 *             pyxzsum += p_x1z0[i]
 *         if saver[3] != 0:
 *             p_x1z1[i] = p_x1z1[i] + EPS             # <<<<<<<<<<<<<<
 *             pyxzsum += p_x1z1[i]
 * 
 */
      (__pyx_v_p_x1z1[__pyx_v_i]) = ((__pyx_v_p_x1z1[__pyx_v_i]) + __pyx_v_8revealer_21REVEALER_runbenchmark_EPS);

      /* "revealer/REVEALER_runbenchmark.pyx":730
 *         if saver[3] != 0:
 *             p_x1z1[i] = p_x1z1[i] + EPS
 *             pyxzsum += p_x1z1[i]             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_pyxzsum = (__pyx_v_pyxzsum + (__pyx_v_p_x1z1[__pyx_v_i]));

      /* "revealer/REVEALER_runbenchmark.pyx":728
 *             p_x1z0[i] = p_x1z0[i] + EPS
 *             pyxzsum += p_x1z0[i]
 *         if saver[3] != 0:             # <<<<<<<<<<<<<<
 *             p_x1z1[i] = p_x1z1[i] + EPS
 *             pyxzsum += p_x1z1[i]
 */
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":735
 *         #pyxzsum += p_x0z0[i] + p_x0z1[i] + p_x1z0[i] + p_x1z1[i]
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i]/pysum
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":736
 * 
 *     i = 0
 *     for i in range(grid):             # <<<<<<<<<<<<<<
 *         p_y_total[i] = p_y_total[i]/pysum
 *         p_z0[i] = p_z0[i]/pyxzsum
 */
  __pyx_t_1 = __pyx_v_grid;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":737
 *     i = 0
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i]/pysum             # <<<<<<<<<<<<<<
 *         p_z0[i] = p_z0[i]/pyxzsum
 *         p_z1[i] = p_z1[i]/pyxzsum
 */
    (__pyx_v_p_y_total[__pyx_v_i]) = ((__pyx_v_p_y_total[__pyx_v_i]) / __pyx_v_pysum);

    /* "revealer/REVEALER_runbenchmark.pyx":738
 *     for i in range(grid):
 *         p_y_total[i] = p_y_total[i]/pysum
 *         p_z0[i] = p_z0[i]/pyxzsum             # <<<<<<<<<<<<<<
 *         p_z1[i] = p_z1[i]/pyxzsum
 *         p_x0[i] = p_x0[i]/pyxzsum
 */
    (__pyx_v_p_z0[__pyx_v_i]) = ((__pyx_v_p_z0[__pyx_v_i]) / __pyx_v_pyxzsum);

    /* "revealer/REVEALER_runbenchmark.pyx":739
 *         p_y_total[i] = p_y_total[i]/pysum
 *         p_z0[i] = p_z0[i]/pyxzsum
 *         p_z1[i] = p_z1[i]/pyxzsum             # <<<<<<<<<<<<<<
 *         p_x0[i] = p_x0[i]/pyxzsum
 *         p_x1[i] = p_x1[i]/pyxzsum
 */
    (__pyx_v_p_z1[__pyx_v_i]) = ((__pyx_v_p_z1[__pyx_v_i]) / __pyx_v_pyxzsum);

    /* "revealer/REVEALER_runbenchmark.pyx":740
 *         p_z0[i] = p_z0[i]/pyxzsum
 *         p_z1[i] = p_z1[i]/pyxzsum
 *         p_x0[i] = p_x0[i]/pyxzsum             # <<<<<<<<<<<<<<
 *         p_x1[i] = p_x1[i]/pyxzsum
 * 
 */
    (__pyx_v_p_x0[__pyx_v_i]) = ((__pyx_v_p_x0[__pyx_v_i]) / __pyx_v_pyxzsum);

    /* "revealer/REVEALER_runbenchmark.pyx":741
 *         p_z1[i] = p_z1[i]/pyxzsum
 *         p_x0[i] = p_x0[i]/pyxzsum
 *         p_x1[i] = p_x1[i]/pyxzsum             # <<<<<<<<<<<<<<
 * 
 *     if saver[0] != 0:
 */
    (__pyx_v_p_x1[__pyx_v_i]) = ((__pyx_v_p_x1[__pyx_v_i]) / __pyx_v_pyxzsum);
  }

  /* "revealer/REVEALER_runbenchmark.pyx":743
 *         p_x1[i] = p_x1[i]/pyxzsum
 * 
 *     if saver[0] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  __pyx_t_4 = (((__pyx_v_saver[0]) != 0) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":744
 * 
 *     if saver[0] != 0:
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             p_x0z0[i] = p_x0z0[i]/pyxzsum
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":745
 *     if saver[0] != 0:
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             p_x0z0[i] = p_x0z0[i]/pyxzsum
 *         pX0Z0 = <double>x0z0Count/<double>size
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":746
 *         i = 0
 *         for i in range(grid):
 *             p_x0z0[i] = p_x0z0[i]/pyxzsum             # <<<<<<<<<<<<<<
 *         pX0Z0 = <double>x0z0Count/<double>size
 *         integral = 0.0
 */
      (__pyx_v_p_x0z0[__pyx_v_i]) = ((__pyx_v_p_x0z0[__pyx_v_i]) / __pyx_v_pyxzsum);
    }

    /* "revealer/REVEALER_runbenchmark.pyx":747
 *         for i in range(grid):
 *             p_x0z0[i] = p_x0z0[i]/pyxzsum
 *         pX0Z0 = <double>x0z0Count/<double>size             # <<<<<<<<<<<<<<
 *         integral = 0.0
 *         i = 0
 */
    __pyx_v_pX0Z0 = (((double)__pyx_v_x0z0Count) / ((double)__pyx_v_size));

    /* "revealer/REVEALER_runbenchmark.pyx":748
 *             p_x0z0[i] = p_x0z0[i]/pyxzsum
 *         pX0Z0 = <double>x0z0Count/<double>size
 *         integral = 0.0             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
    __pyx_v_integral = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":749
 *         pX0Z0 = <double>x0z0Count/<double>size
 *         integral = 0.0
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             integral = integral + (p_x0z0[i] * log((p_x0z0[i] * pZ_0)/(p_z0[i] * pX0Z0)))
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":750
 *         integral = 0.0
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             integral = integral + (p_x0z0[i] * log((p_x0z0[i] * pZ_0)/(p_z0[i] * pX0Z0)))
 * 
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":751
 *         i = 0
 *         for i in range(grid):
 *             integral = integral + (p_x0z0[i] * log((p_x0z0[i] * pZ_0)/(p_z0[i] * pX0Z0)))             # <<<<<<<<<<<<<<
 * 
 *         conditional_mutual_information += integral
 */
      __pyx_v_integral = (__pyx_v_integral + ((__pyx_v_p_x0z0[__pyx_v_i]) * log((((__pyx_v_p_x0z0[__pyx_v_i]) * __pyx_v_pZ_0) / ((__pyx_v_p_z0[__pyx_v_i]) * __pyx_v_pX0Z0)))));
    }

    /* "revealer/REVEALER_runbenchmark.pyx":753
 *             integral = integral + (p_x0z0[i] * log((p_x0z0[i] * pZ_0)/(p_z0[i] * pX0Z0)))
 * 
 *         conditional_mutual_information += integral             # <<<<<<<<<<<<<<
 * 
 *     if saver[1] != 0:
 */
    __pyx_v_conditional_mutual_information = (__pyx_v_conditional_mutual_information + __pyx_v_integral);

    /* "revealer/REVEALER_runbenchmark.pyx":743
 *         p_x1[i] = p_x1[i]/pyxzsum
 * 
 *     if saver[0] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":755
 *         conditional_mutual_information += integral
 * 
 *     if saver[1] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  __pyx_t_4 = (((__pyx_v_saver[1]) != 0) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":756
 * 
 *     if saver[1] != 0:
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             p_x0z1[i] = p_x0z1[i]/pyxzsum
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":757
 *     if saver[1] != 0:
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             p_x0z1[i] = p_x0z1[i]/pyxzsum
 * 
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":758
 *         i = 0
 *         for i in range(grid):
 *             p_x0z1[i] = p_x0z1[i]/pyxzsum             # <<<<<<<<<<<<<<
 * 
 *         pX0Z1 = <double>x0z1Count/<double>size
 */
      (__pyx_v_p_x0z1[__pyx_v_i]) = ((__pyx_v_p_x0z1[__pyx_v_i]) / __pyx_v_pyxzsum);
    }

    /* "revealer/REVEALER_runbenchmark.pyx":760
 *             p_x0z1[i] = p_x0z1[i]/pyxzsum
 * 
 *         pX0Z1 = <double>x0z1Count/<double>size             # <<<<<<<<<<<<<<
 *         integral = 0.0
 *         i = 0
 */
    __pyx_v_pX0Z1 = (((double)__pyx_v_x0z1Count) / ((double)__pyx_v_size));

    /* "revealer/REVEALER_runbenchmark.pyx":761
 * 
 *         pX0Z1 = <double>x0z1Count/<double>size
 *         integral = 0.0             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
    __pyx_v_integral = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":762
 *         pX0Z1 = <double>x0z1Count/<double>size
 *         integral = 0.0
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             integral = integral + (p_x0z1[i] * log((p_x0z1[i] * pZ_1)/(p_z1[i] * pX0Z1)))
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":763
 *         integral = 0.0
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             integral = integral + (p_x0z1[i] * log((p_x0z1[i] * pZ_1)/(p_z1[i] * pX0Z1)))
 * 
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":764
 *         i = 0
 *         for i in range(grid):
 *             integral = integral + (p_x0z1[i] * log((p_x0z1[i] * pZ_1)/(p_z1[i] * pX0Z1)))             # <<<<<<<<<<<<<<
 * 
 *         conditional_mutual_information += integral
 */
      __pyx_v_integral = (__pyx_v_integral + ((__pyx_v_p_x0z1[__pyx_v_i]) * log((((__pyx_v_p_x0z1[__pyx_v_i]) * __pyx_v_pZ_1) / ((__pyx_v_p_z1[__pyx_v_i]) * __pyx_v_pX0Z1)))));
    }

    /* "revealer/REVEALER_runbenchmark.pyx":766
 *             integral = integral + (p_x0z1[i] * log((p_x0z1[i] * pZ_1)/(p_z1[i] * pX0Z1)))
 * 
 *         conditional_mutual_information += integral             # <<<<<<<<<<<<<<
 * 
 *     if saver[2] != 0:
 */
    __pyx_v_conditional_mutual_information = (__pyx_v_conditional_mutual_information + __pyx_v_integral);

    /* "revealer/REVEALER_runbenchmark.pyx":755
 *         conditional_mutual_information += integral
 * 
 *     if saver[1] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":768
 *         conditional_mutual_information += integral
 * 
 *     if saver[2] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  __pyx_t_4 = (((__pyx_v_saver[2]) != 0) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":769
 * 
 *     if saver[2] != 0:
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             p_x1z0[i] = p_x1z0[i]/pyxzsum
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":770
 *     if saver[2] != 0:
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             p_x1z0[i] = p_x1z0[i]/pyxzsum
 * 
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":771
 *         i = 0
 *         for i in range(grid):
 *             p_x1z0[i] = p_x1z0[i]/pyxzsum             # <<<<<<<<<<<<<<
 * 
 *         pX1Z0 = <double>x1z0Count/<double>size
 */
      (__pyx_v_p_x1z0[__pyx_v_i]) = ((__pyx_v_p_x1z0[__pyx_v_i]) / __pyx_v_pyxzsum);
    }

    /* "revealer/REVEALER_runbenchmark.pyx":773
 *             p_x1z0[i] = p_x1z0[i]/pyxzsum
 * 
 *         pX1Z0 = <double>x1z0Count/<double>size             # <<<<<<<<<<<<<<
 *         integral = 0.0
 *         i = 0
 */
    __pyx_v_pX1Z0 = (((double)__pyx_v_x1z0Count) / ((double)__pyx_v_size));

    /* "revealer/REVEALER_runbenchmark.pyx":774
 * 
 *         pX1Z0 = <double>x1z0Count/<double>size
 *         integral = 0.0             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
    __pyx_v_integral = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":775
 *         pX1Z0 = <double>x1z0Count/<double>size
 *         integral = 0.0
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             integral = integral + (p_x1z0[i] * log((p_x1z0[i] * pZ_0)/(p_z0[i] * pX1Z0)))
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":776
 *         integral = 0.0
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             integral = integral + (p_x1z0[i] * log((p_x1z0[i] * pZ_0)/(p_z0[i] * pX1Z0)))
 *         conditional_mutual_information += integral
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":777
 *         i = 0
 *         for i in range(grid):
 *             integral = integral + (p_x1z0[i] * log((p_x1z0[i] * pZ_0)/(p_z0[i] * pX1Z0)))             # <<<<<<<<<<<<<<
 *         conditional_mutual_information += integral
 * 
 */
      __pyx_v_integral = (__pyx_v_integral + ((__pyx_v_p_x1z0[__pyx_v_i]) * log((((__pyx_v_p_x1z0[__pyx_v_i]) * __pyx_v_pZ_0) / ((__pyx_v_p_z0[__pyx_v_i]) * __pyx_v_pX1Z0)))));
    }

    /* "revealer/REVEALER_runbenchmark.pyx":778
 *         for i in range(grid):
 *             integral = integral + (p_x1z0[i] * log((p_x1z0[i] * pZ_0)/(p_z0[i] * pX1Z0)))
 *         conditional_mutual_information += integral             # <<<<<<<<<<<<<<
 * 
 *     if saver[3] != 0:
 */
    __pyx_v_conditional_mutual_information = (__pyx_v_conditional_mutual_information + __pyx_v_integral);

    /* "revealer/REVEALER_runbenchmark.pyx":768
 *         conditional_mutual_information += integral
 * 
 *     if saver[2] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":780
 *         conditional_mutual_information += integral
 * 
 *     if saver[3] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  __pyx_t_4 = (((__pyx_v_saver[3]) != 0) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":781
 * 
 *     if saver[3] != 0:
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             p_x1z1[i] = p_x1z1[i]/pyxzsum
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":782
 *     if saver[3] != 0:
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             p_x1z1[i] = p_x1z1[i]/pyxzsum
 * 
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":783
 *         i = 0
 *         for i in range(grid):
 *             p_x1z1[i] = p_x1z1[i]/pyxzsum             # <<<<<<<<<<<<<<
 * 
 *         pX1Z1 = <double>x1z1Count/<double>size
 */
      (__pyx_v_p_x1z1[__pyx_v_i]) = ((__pyx_v_p_x1z1[__pyx_v_i]) / __pyx_v_pyxzsum);
    }

    /* "revealer/REVEALER_runbenchmark.pyx":785
 *             p_x1z1[i] = p_x1z1[i]/pyxzsum
 * 
 *         pX1Z1 = <double>x1z1Count/<double>size             # <<<<<<<<<<<<<<
 *         integral = 0.0
 *         i = 0
 */
    __pyx_v_pX1Z1 = (((double)__pyx_v_x1z1Count) / ((double)__pyx_v_size));

    /* "revealer/REVEALER_runbenchmark.pyx":786
 * 
 *         pX1Z1 = <double>x1z1Count/<double>size
 *         integral = 0.0             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
    __pyx_v_integral = 0.0;

    /* "revealer/REVEALER_runbenchmark.pyx":787
 *         pX1Z1 = <double>x1z1Count/<double>size
 *         integral = 0.0
 *         i = 0             # <<<<<<<<<<<<<<
 *         for i in range(grid):
 *             integral = integral + (p_x1z1[i] * log((p_x1z1[i] * pZ_1)/(p_z1[i] * pX1Z1)))
 */
    __pyx_v_i = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":788
 *         integral = 0.0
 *         i = 0
 *         for i in range(grid):             # <<<<<<<<<<<<<<
 *             integral = integral + (p_x1z1[i] * log((p_x1z1[i] * pZ_1)/(p_z1[i] * pX1Z1)))
 *         conditional_mutual_information += integral
 */
    __pyx_t_1 = __pyx_v_grid;
    __pyx_t_2 = __pyx_t_1;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "revealer/REVEALER_runbenchmark.pyx":789
 *         i = 0
 *         for i in range(grid):
 *             integral = integral + (p_x1z1[i] * log((p_x1z1[i] * pZ_1)/(p_z1[i] * pX1Z1)))             # <<<<<<<<<<<<<<
 *         conditional_mutual_information += integral
 * 
 */
      __pyx_v_integral = (__pyx_v_integral + ((__pyx_v_p_x1z1[__pyx_v_i]) * log((((__pyx_v_p_x1z1[__pyx_v_i]) * __pyx_v_pZ_1) / ((__pyx_v_p_z1[__pyx_v_i]) * __pyx_v_pX1Z1)))));
    }

    /* "revealer/REVEALER_runbenchmark.pyx":790
 *         for i in range(grid):
 *             integral = integral + (p_x1z1[i] * log((p_x1z1[i] * pZ_1)/(p_z1[i] * pX1Z1)))
 *         conditional_mutual_information += integral             # <<<<<<<<<<<<<<
 * 
 *     free(p_y_total)
 */
    __pyx_v_conditional_mutual_information = (__pyx_v_conditional_mutual_information + __pyx_v_integral);

    /* "revealer/REVEALER_runbenchmark.pyx":780
 *         conditional_mutual_information += integral
 * 
 *     if saver[3] != 0:             # <<<<<<<<<<<<<<
 *         i = 0
 *         for i in range(grid):
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":792
 *         conditional_mutual_information += integral
 * 
 *     free(p_y_total)             # <<<<<<<<<<<<<<
 *     free(p_z0)
 *     free(p_z1)
 */
  free(__pyx_v_p_y_total);

  /* "revealer/REVEALER_runbenchmark.pyx":793
 * 
 *     free(p_y_total)
 *     free(p_z0)             # <<<<<<<<<<<<<<
 *     free(p_z1)
 *     free(p_x0)
 */
  free(__pyx_v_p_z0);

  /* "revealer/REVEALER_runbenchmark.pyx":794
 *     free(p_y_total)
 *     free(p_z0)
 *     free(p_z1)             # <<<<<<<<<<<<<<
 *     free(p_x0)
 *     free(p_x1)
 */
  free(__pyx_v_p_z1);

  /* "revealer/REVEALER_runbenchmark.pyx":795
 *     free(p_z0)
 *     free(p_z1)
 *     free(p_x0)             # <<<<<<<<<<<<<<
 *     free(p_x1)
 *     free(p_x0z0)
 */
  free(__pyx_v_p_x0);

  /* "revealer/REVEALER_runbenchmark.pyx":796
 *     free(p_z1)
 *     free(p_x0)
 *     free(p_x1)             # <<<<<<<<<<<<<<
 *     free(p_x0z0)
 *     free(p_x0z1)
 */
  free(__pyx_v_p_x1);

  /* "revealer/REVEALER_runbenchmark.pyx":797
 *     free(p_x0)
 *     free(p_x1)
 *     free(p_x0z0)             # <<<<<<<<<<<<<<
 *     free(p_x0z1)
 *     free(p_x1z0)
 */
  free(__pyx_v_p_x0z0);

  /* "revealer/REVEALER_runbenchmark.pyx":798
 *     free(p_x1)
 *     free(p_x0z0)
 *     free(p_x0z1)             # <<<<<<<<<<<<<<
 *     free(p_x1z0)
 *     free(p_x1z1)
 */
  free(__pyx_v_p_x0z1);

  /* "revealer/REVEALER_runbenchmark.pyx":799
 *     free(p_x0z0)
 *     free(p_x0z1)
 *     free(p_x1z0)             # <<<<<<<<<<<<<<
 *     free(p_x1z1)
 *     free(kernel)
 */
  free(__pyx_v_p_x1z0);

  /* "revealer/REVEALER_runbenchmark.pyx":800
 *     free(p_x0z1)
 *     free(p_x1z0)
 *     free(p_x1z1)             # <<<<<<<<<<<<<<
 *     free(kernel)
 *     free(saver)
 */
  free(__pyx_v_p_x1z1);

  /* "revealer/REVEALER_runbenchmark.pyx":801
 *     free(p_x1z0)
 *     free(p_x1z1)
 *     free(kernel)             # <<<<<<<<<<<<<<
 *     free(saver)
 *     free(normy)
 */
  free(__pyx_v_kernel);

  /* "revealer/REVEALER_runbenchmark.pyx":802
 *     free(p_x1z1)
 *     free(kernel)
 *     free(saver)             # <<<<<<<<<<<<<<
 *     free(normy)
 * 
 */
  free(__pyx_v_saver);

  /* "revealer/REVEALER_runbenchmark.pyx":803
 *     free(kernel)
 *     free(saver)
 *     free(normy)             # <<<<<<<<<<<<<<
 * 
 *     return (cor/fabs(cor)) * sqrt(1.0 - exp(-2.0 * conditional_mutual_information))
 */
  free(__pyx_v_normy);

  /* "revealer/REVEALER_runbenchmark.pyx":805
 *     free(normy)
 * 
 *     return (cor/fabs(cor)) * sqrt(1.0 - exp(-2.0 * conditional_mutual_information))             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_r = ((__pyx_v_cor / ((__pyx_t_5numpy_double_t)fabs(__pyx_v_cor))) * sqrt((1.0 - exp((-2.0 * __pyx_v_conditional_mutual_information)))));
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":554
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t ConditionalInformationCoefficient_cython(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y,           #Target
 *     np.int_t[:] x,              #Feature that correlation is calculated
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_5ConditionalInformationCoefficient_cython(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_4ConditionalInformationCoefficient_cython[] = " \n    Calculate IC between continuous 'y' and binary 'x' given condition 'z' \n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_5ConditionalInformationCoefficient_cython(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_neighborhood;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_jitter;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ConditionalInformationCoefficient_cython (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y,&__pyx_n_s_x,&__pyx_n_s_z,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_neighborhood,&__pyx_n_s_deltay,&__pyx_n_s_miny,&__pyx_n_s_jitter,0};
    PyObject* values[12] = {0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_x)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 1); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_z)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 2); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 3); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 4); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 5); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 6); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 7); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 8); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_deltay)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 9); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_miny)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, 10); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_jitter);
          if (value) { values[11] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ConditionalInformationCoefficient_cython") < 0)) __PYX_ERR(0, 554, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_y = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_y.memview)) __PYX_ERR(0, 555, __pyx_L3_error)
    __pyx_v_x = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_x.memview)) __PYX_ERR(0, 556, __pyx_L3_error)
    __pyx_v_z = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[2], PyBUF_WRITABLE); if (unlikely(!__pyx_v_z.memview)) __PYX_ERR(0, 557, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 558, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 559, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 560, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 561, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 562, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[8]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 563, __pyx_L3_error)
    __pyx_v_deltay = __pyx_PyFloat_AsDouble(values[9]); if (unlikely((__pyx_v_deltay == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
    __pyx_v_miny = __pyx_PyFloat_AsDouble(values[10]); if (unlikely((__pyx_v_miny == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 565, __pyx_L3_error)
    if (values[11]) {
      __pyx_v_jitter = __pyx_PyFloat_AsDouble(values[11]); if (unlikely((__pyx_v_jitter == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 566, __pyx_L3_error)
    } else {
      __pyx_v_jitter = ((__pyx_t_5numpy_double_t)1E-10);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ConditionalInformationCoefficient_cython", 0, 11, 12, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 554, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.ConditionalInformationCoefficient_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_4ConditionalInformationCoefficient_cython(__pyx_self, __pyx_v_y, __pyx_v_x, __pyx_v_z, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, __pyx_v_jitter);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_4ConditionalInformationCoefficient_cython(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y, __Pyx_memviewslice __pyx_v_x, __Pyx_memviewslice __pyx_v_z, int __pyx_v_k, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_neighborhood, __pyx_t_5numpy_double_t __pyx_v_deltay, __pyx_t_5numpy_double_t __pyx_v_miny, __pyx_t_5numpy_double_t __pyx_v_jitter) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_double_t __pyx_t_1;
  struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ConditionalInformationCoefficient_cython", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.jitter = __pyx_v_jitter;
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython(__pyx_v_y, __pyx_v_x, __pyx_v_z, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, &__pyx_t_2); 
  __pyx_t_3 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.ConditionalInformationCoefficient_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":811
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef (np.int_t,np.double_t,np.double_t) findBestCIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:] z_in,           #Feature that CIC depend on
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_7findBestCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc __pyx_f_8revealer_21REVEALER_runbenchmark_findBestCIC(__Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_i;
  int __pyx_v_maxseedid;
  __pyx_t_5numpy_double_t __pyx_v_maxCIC;
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __pyx_t_5numpy_double_t __pyx_v_substart;
  __pyx_t_5numpy_double_t __pyx_v_spenttime;
  __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("findBestCIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":831
 *     '''
 * 
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":832
 * 
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_y_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":833
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:] z = np.asarray(z_in)
 *     cdef int i
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_xs_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":834
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)             # <<<<<<<<<<<<<<
 *     cdef int i
 *     cdef int maxseedid = 0
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_z_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(0, 834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_z = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":836
 *     cdef np.int_t[:] z = np.asarray(z_in)
 *     cdef int i
 *     cdef int maxseedid = 0             # <<<<<<<<<<<<<<
 *     cdef np.double_t maxCIC = 0.0
 *     cdef np.double_t miny = findmin(y, size)
 */
  __pyx_v_maxseedid = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":837
 *     cdef int i
 *     cdef int maxseedid = 0
 *     cdef np.double_t maxCIC = 0.0             # <<<<<<<<<<<<<<
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 */
  __pyx_v_maxCIC = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":838
 *     cdef int maxseedid = 0
 *     cdef np.double_t maxCIC = 0.0
 *     cdef np.double_t miny = findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 *     cdef np.double_t substart = time.time()
 */
  __pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":839
 *     cdef np.double_t maxCIC = 0.0
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t substart = time.time()
 * 
 */
  __pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_v_y, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":840
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 *     cdef np.double_t substart = time.time()             # <<<<<<<<<<<<<<
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_8 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_substart = __pyx_t_8;

  /* "revealer/REVEALER_runbenchmark.pyx":842
 *     cdef np.double_t substart = time.time()
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_9 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_11 = (__pyx_t_9 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_11 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_12) firstprivate(__pyx_t_7)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for firstprivate(__pyx_v_i) lastprivate(__pyx_v_i)
                    #endif /* _OPENMP */
                    for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_11; __pyx_t_10++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_10);

                            /* "revealer/REVEALER_runbenchmark.pyx":843
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,             # <<<<<<<<<<<<<<
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)
 */
                            __pyx_t_7.data = __pyx_v_x.data;
                            __pyx_t_7.memview = __pyx_v_x.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_7, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_x.strides[0];
        __pyx_t_7.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_7.shape[0] = __pyx_v_x.shape[1];
__pyx_t_7.strides[0] = __pyx_v_x.strides[1];
    __pyx_t_7.suboffsets[0] = -1;

__pyx_t_12 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":845
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 *     cdef np.double_t spenttime = time.time() - substart
 *     i = 0
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_12 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython(__pyx_v_y, __pyx_t_7, __pyx_v_z, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_7, 0);
                            __pyx_t_7.memview = NULL;
                            __pyx_t_7.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":842
 *     cdef np.double_t substart = time.time()
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":846
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)
 *     cdef np.double_t spenttime = time.time() - substart             # <<<<<<<<<<<<<<
 *     i = 0
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_substart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_8 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_spenttime = __pyx_t_8;

  /* "revealer/REVEALER_runbenchmark.pyx":847
 *                                                           neighborhood, deltay, miny)
 *     cdef np.double_t spenttime = time.time() - substart
 *     i = 0             # <<<<<<<<<<<<<<
 * 
 *     if direction == 'neg':
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":849
 *     i = 0
 * 
 *     if direction == 'neg':             # <<<<<<<<<<<<<<
 *         maxCIC = 10000
 *         for i in range(n):
 */
  __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_neg, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 849, __pyx_L1_error)
  if (__pyx_t_13) {

    /* "revealer/REVEALER_runbenchmark.pyx":850
 * 
 *     if direction == 'neg':
 *         maxCIC = 10000             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             if res[i] <= maxCIC:
 */
    __pyx_v_maxCIC = 10000.0;

    /* "revealer/REVEALER_runbenchmark.pyx":851
 *     if direction == 'neg':
 *         maxCIC = 10000
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             if res[i] <= maxCIC:
 *                 maxCIC = res[i]
 */
    __pyx_t_11 = __pyx_v_n;
    __pyx_t_10 = __pyx_t_11;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_10; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "revealer/REVEALER_runbenchmark.pyx":852
 *         maxCIC = 10000
 *         for i in range(n):
 *             if res[i] <= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      __pyx_t_12 = __pyx_v_i;
      __pyx_t_13 = (((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_12 * __pyx_v_res.strides[0]) ))) <= __pyx_v_maxCIC) != 0);
      if (__pyx_t_13) {

        /* "revealer/REVEALER_runbenchmark.pyx":853
 *         for i in range(n):
 *             if res[i] <= maxCIC:
 *                 maxCIC = res[i]             # <<<<<<<<<<<<<<
 *                 maxseedid = i + 1
 *     else:
 */
        __pyx_t_12 = __pyx_v_i;
        __pyx_v_maxCIC = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_12 * __pyx_v_res.strides[0]) )));

        /* "revealer/REVEALER_runbenchmark.pyx":854
 *             if res[i] <= maxCIC:
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1             # <<<<<<<<<<<<<<
 *     else:
 *         maxCIC = -10000
 */
        __pyx_v_maxseedid = (__pyx_v_i + 1);

        /* "revealer/REVEALER_runbenchmark.pyx":852
 *         maxCIC = 10000
 *         for i in range(n):
 *             if res[i] <= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      }
    }

    /* "revealer/REVEALER_runbenchmark.pyx":849
 *     i = 0
 * 
 *     if direction == 'neg':             # <<<<<<<<<<<<<<
 *         maxCIC = 10000
 *         for i in range(n):
 */
    goto __pyx_L12;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":856
 *                 maxseedid = i + 1
 *     else:
 *         maxCIC = -10000             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             if res[i] >= maxCIC:
 */
  /*else*/ {
    __pyx_v_maxCIC = -10000.0;

    /* "revealer/REVEALER_runbenchmark.pyx":857
 *     else:
 *         maxCIC = -10000
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             if res[i] >= maxCIC:
 *                 maxCIC = res[i]
 */
    __pyx_t_11 = __pyx_v_n;
    __pyx_t_10 = __pyx_t_11;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_10; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "revealer/REVEALER_runbenchmark.pyx":858
 *         maxCIC = -10000
 *         for i in range(n):
 *             if res[i] >= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      __pyx_t_12 = __pyx_v_i;
      __pyx_t_13 = (((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_12 * __pyx_v_res.strides[0]) ))) >= __pyx_v_maxCIC) != 0);
      if (__pyx_t_13) {

        /* "revealer/REVEALER_runbenchmark.pyx":859
 *         for i in range(n):
 *             if res[i] >= maxCIC:
 *                 maxCIC = res[i]             # <<<<<<<<<<<<<<
 *                 maxseedid = i + 1
 * 
 */
        __pyx_t_12 = __pyx_v_i;
        __pyx_v_maxCIC = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_12 * __pyx_v_res.strides[0]) )));

        /* "revealer/REVEALER_runbenchmark.pyx":860
 *             if res[i] >= maxCIC:
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1             # <<<<<<<<<<<<<<
 * 
 *     return maxseedid,maxCIC,spenttime
 */
        __pyx_v_maxseedid = (__pyx_v_i + 1);

        /* "revealer/REVEALER_runbenchmark.pyx":858
 *         maxCIC = -10000
 *         for i in range(n):
 *             if res[i] >= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      }
    }
  }
  __pyx_L12:;

  /* "revealer/REVEALER_runbenchmark.pyx":862
 *                 maxseedid = i + 1
 * 
 *     return maxseedid,maxCIC,spenttime             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_t_14.f0 = __pyx_v_maxseedid;
  __pyx_t_14.f1 = __pyx_v_maxCIC;
  __pyx_t_14.f2 = __pyx_v_spenttime;
  __pyx_r = __pyx_t_14;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":811
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef (np.int_t,np.double_t,np.double_t) findBestCIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:] z_in,           #Feature that CIC depend on
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_WriteUnraisable("revealer.REVEALER_runbenchmark.findBestCIC", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_7findBestCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_6findBestCIC[] = "\n    Function to find feature with best CIC among features\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_7findBestCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_y_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_xs_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  PyObject *__pyx_v_direction = 0;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("findBestCIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y_in,&__pyx_n_s_z_in,&__pyx_n_s_xs_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_direction,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[13] = {0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_z_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 1); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_xs_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 2); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 3); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 4); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 5); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 6); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 7); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 8); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 9); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 10); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 11); __PYX_ERR(0, 811, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, 12); __PYX_ERR(0, 811, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "findBestCIC") < 0)) __PYX_ERR(0, 811, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 13) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
    }
    __pyx_v_y_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_y_in.memview)) __PYX_ERR(0, 812, __pyx_L3_error)
    __pyx_v_z_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_z_in.memview)) __PYX_ERR(0, 813, __pyx_L3_error)
    __pyx_v_xs_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(values[2], PyBUF_WRITABLE); if (unlikely(!__pyx_v_xs_in.memview)) __PYX_ERR(0, 814, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 815, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 816, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[5]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 817, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 818, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 819, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[8]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 820, __pyx_L3_error)
    __pyx_v_direction = values[9];
    __pyx_v_grid = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 822, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[11]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 823, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[12]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 824, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("findBestCIC", 1, 13, 13, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 811, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.findBestCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_6findBestCIC(__pyx_self, __pyx_v_y_in, __pyx_v_z_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_6findBestCIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("findBestCIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_convert__to_py___pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc(__pyx_f_8revealer_21REVEALER_runbenchmark_findBestCIC(__pyx_v_y_in, __pyx_v_z_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.findBestCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_y_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_xs_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":868
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] rankCIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:] z_in,           #Feature that CIC depend on
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_9rankCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_rankCIC(__Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_v_i;
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rankCIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":888
 * 
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":889
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_y_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":890
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:] z = np.asarray(z_in)
 *     cdef np.double_t miny = findmin(y, size)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_xs_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":891
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)             # <<<<<<<<<<<<<<
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_z_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(0, 891, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_z = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":892
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)
 *     cdef np.double_t miny = findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 */
  __pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":893
 *     cdef np.int_t[:] z = np.asarray(z_in)
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)             # <<<<<<<<<<<<<<
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 */
  __pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_v_y, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":895
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_8 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_10 = (__pyx_t_8 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_10 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_11) firstprivate(__pyx_t_7)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for firstprivate(__pyx_v_i) lastprivate(__pyx_v_i)
                    #endif /* _OPENMP */
                    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_10; __pyx_t_9++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_9);

                            /* "revealer/REVEALER_runbenchmark.pyx":896
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,             # <<<<<<<<<<<<<<
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)
 */
                            __pyx_t_7.data = __pyx_v_x.data;
                            __pyx_t_7.memview = __pyx_v_x.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_7, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_x.strides[0];
        __pyx_t_7.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_7.shape[0] = __pyx_v_x.shape[1];
__pyx_t_7.strides[0] = __pyx_v_x.strides[1];
    __pyx_t_7.suboffsets[0] = -1;

__pyx_t_11 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":898
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 * 
 *     return res
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython(__pyx_v_y, __pyx_t_7, __pyx_v_z, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_7, 0);
                            __pyx_t_7.memview = NULL;
                            __pyx_t_7.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":895
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = ConditionalInformationCoefficient_cython(y, x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":900
 *                                                           neighborhood, deltay, miny)
 * 
 *     return res             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __PYX_INC_MEMVIEW(&__pyx_v_res, 0);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":868
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] rankCIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:] z_in,           #Feature that CIC depend on
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_7, 1);
  __pyx_r.data = NULL;
  __pyx_r.memview = NULL;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.rankCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  goto __pyx_L2;
  __pyx_L0:;
  if (unlikely(!__pyx_r.memview)) {
    PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
  }
  __pyx_L2:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_9rankCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_8rankCIC[] = "\n    Function to calculate bunch of CIC parallelly\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_9rankCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_y_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_xs_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rankCIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y_in,&__pyx_n_s_z_in,&__pyx_n_s_xs_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[12] = {0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_z_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 1); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_xs_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 2); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 3); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 4); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 5); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 6); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 7); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 8); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 9); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 10); __PYX_ERR(0, 868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, 11); __PYX_ERR(0, 868, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "rankCIC") < 0)) __PYX_ERR(0, 868, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 12) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
    }
    __pyx_v_y_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_y_in.memview)) __PYX_ERR(0, 869, __pyx_L3_error)
    __pyx_v_z_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_z_in.memview)) __PYX_ERR(0, 870, __pyx_L3_error)
    __pyx_v_xs_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(values[2], PyBUF_WRITABLE); if (unlikely(!__pyx_v_xs_in.memview)) __PYX_ERR(0, 871, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 872, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 873, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[5]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 874, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 875, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 876, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[8]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 877, __pyx_L3_error)
    __pyx_v_grid = __Pyx_PyInt_As_int(values[9]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 878, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 879, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[11]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 880, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rankCIC", 1, 12, 12, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 868, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.rankCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_8rankCIC(__pyx_self, __pyx_v_y_in, __pyx_v_z_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_8rankCIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rankCIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankCIC(__pyx_v_y_in, __pyx_v_z_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(0, 868, __pyx_L1_error)
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_t_1, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL;
  __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.rankCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_y_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_xs_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":905
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cpdef (np.int_t,np.double_t) findBestIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:,:] xs_in,        #List of features
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_11findBestIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t __pyx_f_8revealer_21REVEALER_runbenchmark_findBestIC(__Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_i;
  int __pyx_v_maxseedid;
  __pyx_t_5numpy_double_t __pyx_v_maxCIC;
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("findBestIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":924
 *     '''
 * 
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":925
 * 
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_y_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":926
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)             # <<<<<<<<<<<<<<
 * 
 *     cdef int i
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_xs_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 926, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":929
 * 
 *     cdef int i
 *     cdef int maxseedid = 0             # <<<<<<<<<<<<<<
 *     cdef np.double_t maxCIC = 0.0
 *     cdef np.double_t miny = findmin(y, size)
 */
  __pyx_v_maxseedid = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":930
 *     cdef int i
 *     cdef int maxseedid = 0
 *     cdef np.double_t maxCIC = 0.0             # <<<<<<<<<<<<<<
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 */
  __pyx_v_maxCIC = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":931
 *     cdef int maxseedid = 0
 *     cdef np.double_t maxCIC = 0.0
 *     cdef np.double_t miny = findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 */
  __pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":932
 *     cdef np.double_t maxCIC = 0.0
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)             # <<<<<<<<<<<<<<
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 */
  __pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_v_y, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":934
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_7 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_9 = (__pyx_t_7 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_9 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_11) firstprivate(__pyx_t_10)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for firstprivate(__pyx_v_i) lastprivate(__pyx_v_i)
                    #endif /* _OPENMP */
                    for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_9; __pyx_t_8++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_8);

                            /* "revealer/REVEALER_runbenchmark.pyx":935
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 */
                            __pyx_t_10.data = __pyx_v_x.data;
                            __pyx_t_10.memview = __pyx_v_x.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_10, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_x.strides[0];
        __pyx_t_10.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_10.shape[0] = __pyx_v_x.shape[1];
__pyx_t_10.strides[0] = __pyx_v_x.strides[1];
    __pyx_t_10.suboffsets[0] = -1;

__pyx_t_11 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":936
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_v_y, __pyx_t_10, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_10, 0);
                            __pyx_t_10.memview = NULL;
                            __pyx_t_10.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":934
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":938
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 * 
 *     if direction == 'neg':
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":940
 *     i = 0
 * 
 *     if direction == 'neg':             # <<<<<<<<<<<<<<
 *         maxCIC = 10000
 *         for i in range(n):
 */
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_neg, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 940, __pyx_L1_error)
  if (__pyx_t_12) {

    /* "revealer/REVEALER_runbenchmark.pyx":941
 * 
 *     if direction == 'neg':
 *         maxCIC = 10000             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             if res[i] <= maxCIC:
 */
    __pyx_v_maxCIC = 10000.0;

    /* "revealer/REVEALER_runbenchmark.pyx":942
 *     if direction == 'neg':
 *         maxCIC = 10000
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             if res[i] <= maxCIC:
 *                 maxCIC = res[i]
 */
    __pyx_t_9 = __pyx_v_n;
    __pyx_t_8 = __pyx_t_9;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_8; __pyx_t_7+=1) {
      __pyx_v_i = __pyx_t_7;

      /* "revealer/REVEALER_runbenchmark.pyx":943
 *         maxCIC = 10000
 *         for i in range(n):
 *             if res[i] <= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      __pyx_t_11 = __pyx_v_i;
      __pyx_t_12 = (((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) ))) <= __pyx_v_maxCIC) != 0);
      if (__pyx_t_12) {

        /* "revealer/REVEALER_runbenchmark.pyx":944
 *         for i in range(n):
 *             if res[i] <= maxCIC:
 *                 maxCIC = res[i]             # <<<<<<<<<<<<<<
 *                 maxseedid = i + 1
 *     else:
 */
        __pyx_t_11 = __pyx_v_i;
        __pyx_v_maxCIC = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) )));

        /* "revealer/REVEALER_runbenchmark.pyx":945
 *             if res[i] <= maxCIC:
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1             # <<<<<<<<<<<<<<
 *     else:
 *         maxCIC = -10000
 */
        __pyx_v_maxseedid = (__pyx_v_i + 1);

        /* "revealer/REVEALER_runbenchmark.pyx":943
 *         maxCIC = 10000
 *         for i in range(n):
 *             if res[i] <= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      }
    }

    /* "revealer/REVEALER_runbenchmark.pyx":940
 *     i = 0
 * 
 *     if direction == 'neg':             # <<<<<<<<<<<<<<
 *         maxCIC = 10000
 *         for i in range(n):
 */
    goto __pyx_L12;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":947
 *                 maxseedid = i + 1
 *     else:
 *         maxCIC = -10000             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             if res[i] >= maxCIC:
 */
  /*else*/ {
    __pyx_v_maxCIC = -10000.0;

    /* "revealer/REVEALER_runbenchmark.pyx":948
 *     else:
 *         maxCIC = -10000
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             if res[i] >= maxCIC:
 *                 maxCIC = res[i]
 */
    __pyx_t_9 = __pyx_v_n;
    __pyx_t_8 = __pyx_t_9;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_8; __pyx_t_7+=1) {
      __pyx_v_i = __pyx_t_7;

      /* "revealer/REVEALER_runbenchmark.pyx":949
 *         maxCIC = -10000
 *         for i in range(n):
 *             if res[i] >= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      __pyx_t_11 = __pyx_v_i;
      __pyx_t_12 = (((*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) ))) >= __pyx_v_maxCIC) != 0);
      if (__pyx_t_12) {

        /* "revealer/REVEALER_runbenchmark.pyx":950
 *         for i in range(n):
 *             if res[i] >= maxCIC:
 *                 maxCIC = res[i]             # <<<<<<<<<<<<<<
 *                 maxseedid = i + 1
 *     return maxseedid,maxCIC
 */
        __pyx_t_11 = __pyx_v_i;
        __pyx_v_maxCIC = (*((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) )));

        /* "revealer/REVEALER_runbenchmark.pyx":951
 *             if res[i] >= maxCIC:
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1             # <<<<<<<<<<<<<<
 *     return maxseedid,maxCIC
 * 
 */
        __pyx_v_maxseedid = (__pyx_v_i + 1);

        /* "revealer/REVEALER_runbenchmark.pyx":949
 *         maxCIC = -10000
 *         for i in range(n):
 *             if res[i] >= maxCIC:             # <<<<<<<<<<<<<<
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 */
      }
    }
  }
  __pyx_L12:;

  /* "revealer/REVEALER_runbenchmark.pyx":952
 *                 maxCIC = res[i]
 *                 maxseedid = i + 1
 *     return maxseedid,maxCIC             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_t_13.f0 = __pyx_v_maxseedid;
  __pyx_t_13.f1 = __pyx_v_maxCIC;
  __pyx_r = __pyx_t_13;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":905
 * @cython.wraparound(False)
 * @cython.cdivision(True)
 * cpdef (np.int_t,np.double_t) findBestIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:,:] xs_in,        #List of features
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __Pyx_WriteUnraisable("revealer.REVEALER_runbenchmark.findBestIC", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_11findBestIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_10findBestIC[] = "\n    Function to find feature with best IC among all features\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_11findBestIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_y_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_xs_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  PyObject *__pyx_v_direction = 0;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("findBestIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y_in,&__pyx_n_s_xs_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_direction,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[12] = {0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_xs_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 1); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 2); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 3); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 4); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 5); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 6); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 7); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 8); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 9); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 10); __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, 11); __PYX_ERR(0, 905, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "findBestIC") < 0)) __PYX_ERR(0, 905, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 12) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
    }
    __pyx_v_y_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_y_in.memview)) __PYX_ERR(0, 906, __pyx_L3_error)
    __pyx_v_xs_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_xs_in.memview)) __PYX_ERR(0, 907, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 908, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 909, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 910, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 911, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 912, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 913, __pyx_L3_error)
    __pyx_v_direction = values[8];
    __pyx_v_grid = __Pyx_PyInt_As_int(values[9]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 915, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 916, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[11]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 917, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("findBestIC", 1, 12, 12, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 905, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.findBestIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_10findBestIC(__pyx_self, __pyx_v_y_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_10findBestIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("findBestIC", 0);
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_y_in.memview)) { __Pyx_RaiseUnboundLocalError("y_in"); __PYX_ERR(0, 905, __pyx_L1_error) }
  if (unlikely(!__pyx_v_xs_in.memview)) { __Pyx_RaiseUnboundLocalError("xs_in"); __PYX_ERR(0, 905, __pyx_L1_error) }
  __pyx_t_1 = __pyx_convert__to_py___pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t(__pyx_f_8revealer_21REVEALER_runbenchmark_findBestIC(__pyx_v_y_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.findBestIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_y_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_xs_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":958
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cpdef np.double_t[:] rankIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:,:] xs_in,        #List of features
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_13rankIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_rankIC(__Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_i;
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rankIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":976
 *     '''
 * 
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":977
 * 
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef int i
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_y_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":978
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:] y = np.asarray(y_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)             # <<<<<<<<<<<<<<
 *     cdef int i
 *     cdef np.double_t miny = findmin(y, size)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_xs_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":980
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef int i
 *     cdef np.double_t miny = findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 */
  __pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":981
 *     cdef int i
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)             # <<<<<<<<<<<<<<
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 */
  __pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_v_y, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":983
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_7 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_9 = (__pyx_t_7 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_9 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_11) firstprivate(__pyx_t_10)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for firstprivate(__pyx_v_i) lastprivate(__pyx_v_i)
                    #endif /* _OPENMP */
                    for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_9; __pyx_t_8++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_8);

                            /* "revealer/REVEALER_runbenchmark.pyx":984
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 */
                            __pyx_t_10.data = __pyx_v_x.data;
                            __pyx_t_10.memview = __pyx_v_x.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_10, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_x.strides[0];
        __pyx_t_10.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_10.shape[0] = __pyx_v_x.shape[1];
__pyx_t_10.strides[0] = __pyx_v_x.strides[1];
    __pyx_t_10.suboffsets[0] = -1;

__pyx_t_11 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":985
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 * 
 *     return res
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_11 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_v_y, __pyx_t_10, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_10, 0);
                            __pyx_t_10.memview = NULL;
                            __pyx_t_10.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":983
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         res[i] = binaryInformationCoefficient_cython(y, x[i,:],k,size, bandwidth,bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":987
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 *     return res             # <<<<<<<<<<<<<<
 * 
 * def drawTarget(
 */
  __PYX_INC_MEMVIEW(&__pyx_v_res, 0);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":958
 * @cython.initializedcheck(False)
 * @cython.cdivision(True)
 * cpdef np.double_t[:] rankIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:] y_in,        #Target
 *     np.int_t[:,:] xs_in,        #List of features
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __pyx_r.data = NULL;
  __pyx_r.memview = NULL;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.rankIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  goto __pyx_L2;
  __pyx_L0:;
  if (unlikely(!__pyx_r.memview)) {
    PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
  }
  __pyx_L2:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_13rankIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_12rankIC[] = "\n    Function to run multiple IC in parallel\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_13rankIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_y_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_xs_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rankIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y_in,&__pyx_n_s_xs_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_xs_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 1); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 2); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 3); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 4); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 5); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 6); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 7); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 8); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 9); __PYX_ERR(0, 958, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, 10); __PYX_ERR(0, 958, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "rankIC") < 0)) __PYX_ERR(0, 958, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 11) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
    }
    __pyx_v_y_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_y_in.memview)) __PYX_ERR(0, 959, __pyx_L3_error)
    __pyx_v_xs_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_xs_in.memview)) __PYX_ERR(0, 960, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 961, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 962, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 963, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 964, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 965, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 966, __pyx_L3_error)
    __pyx_v_grid = __Pyx_PyInt_As_int(values[8]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 967, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[9]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 968, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 969, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rankIC", 1, 11, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 958, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.rankIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_12rankIC(__pyx_self, __pyx_v_y_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_12rankIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_y_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rankIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankIC(__pyx_v_y_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(0, 958, __pyx_L1_error)
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_t_1, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL;
  __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.rankIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_y_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_xs_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":989
 *     return res
 * 
 * def drawTarget(             # <<<<<<<<<<<<<<
 *     comb    #Combined dataframe
 *     ):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_15drawTarget(PyObject *__pyx_self, PyObject *__pyx_v_comb); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_14drawTarget[] = "\n    Function to plot target\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_15drawTarget = {"drawTarget", (PyCFunction)__pyx_pw_8revealer_21REVEALER_runbenchmark_15drawTarget, METH_O, __pyx_doc_8revealer_21REVEALER_runbenchmark_14drawTarget};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_15drawTarget(PyObject *__pyx_self, PyObject *__pyx_v_comb) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("drawTarget (wrapper)", 0);
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_14drawTarget(__pyx_self, ((PyObject *)__pyx_v_comb));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_14drawTarget(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb) {
  PyObject *__pyx_v_f = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("drawTarget", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":997
 *     '''
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(comb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=comb.iloc[0].mean())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_plt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_subplots); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_figsize, __pyx_tuple_) < 0) __PYX_ERR(0, 997, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 997, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) __PYX_ERR(0, 997, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 997, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_f = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_ax = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":998
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))
 *     ax = sns.heatmap(comb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=comb.iloc[0].mean())
 *     return f
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_int_0);
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cmap, __pyx_n_u_bwr) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 998, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":999
 *     f, ax = plt.subplots(figsize=(10, 1))
 *     ax = sns.heatmap(comb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=comb.iloc[0].mean())             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_mean); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_center, __pyx_t_6) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":998
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))
 *     ax = sns.heatmap(comb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=comb.iloc[0].mean())
 *     return f
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1000
 *     ax = sns.heatmap(comb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=comb.iloc[0].mean())
 *     return f             # <<<<<<<<<<<<<<
 * 
 * def drawFeature(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_f);
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":989
 *     return res
 * 
 * def drawTarget(             # <<<<<<<<<<<<<<
 *     comb    #Combined dataframe
 *     ):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.drawTarget", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1002
 *     return f
 * 
 * def drawFeature(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     featurecmap,    #Cmap to plot feature
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_17drawFeature(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_16drawFeature[] = "\n    Function to plot feature\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_17drawFeature = {"drawFeature", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_17drawFeature, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_16drawFeature};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_17drawFeature(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_seedID = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("drawFeature (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_comb,&__pyx_n_s_featurecmap,&__pyx_n_s_seed_name,&__pyx_n_s_seedID,0};
    PyObject* values[4] = {0,0,0,0};

    /* "revealer/REVEALER_runbenchmark.pyx":1005
 *     comb,           #Combined dataframe
 *     featurecmap,    #Cmap to plot feature
 *     seed_name=None, #Seed name to plot             # <<<<<<<<<<<<<<
 *     seedID=None     #Seed id to plot
 *     ):
 */
    values[2] = ((PyObject *)Py_None);

    /* "revealer/REVEALER_runbenchmark.pyx":1006
 *     featurecmap,    #Cmap to plot feature
 *     seed_name=None, #Seed name to plot
 *     seedID=None     #Seed id to plot             # <<<<<<<<<<<<<<
 *     ):
 * 
 */
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("drawFeature", 0, 2, 4, 1); __PYX_ERR(0, 1002, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedID);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "drawFeature") < 0)) __PYX_ERR(0, 1002, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_comb = values[0];
    __pyx_v_featurecmap = values[1];
    __pyx_v_seed_name = values[2];
    __pyx_v_seedID = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("drawFeature", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1002, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.drawFeature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_16drawFeature(__pyx_self, __pyx_v_comb, __pyx_v_featurecmap, __pyx_v_seed_name, __pyx_v_seedID);

  /* "revealer/REVEALER_runbenchmark.pyx":1002
 *     return f
 * 
 * def drawFeature(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     featurecmap,    #Cmap to plot feature
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_16drawFeature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_seedID) {
  PyObject *__pyx_v_f = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("drawFeature", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1013
 *     '''
 * 
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":1014
 * 
 *     if seed_name != None:
 *         f, ax = plt.subplots(figsize=(10, 1))             # <<<<<<<<<<<<<<
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,
 *                          yticklabels=False, xticklabels=False, cbar=False)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_plt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_subplots); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_figsize, __pyx_tuple_) < 0) __PYX_ERR(0, 1014, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1014, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      #else
      __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1014, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1014, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_5 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1014, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
      index = 0; __pyx_t_1 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1014, __pyx_L1_error)
      __pyx_t_6 = NULL;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L5_unpacking_done;
      __pyx_L4_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1014, __pyx_L1_error)
      __pyx_L5_unpacking_done:;
    }
    __pyx_v_f = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v_ax = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1015
 *     if seed_name != None:
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,             # <<<<<<<<<<<<<<
 *                          yticklabels=False, xticklabels=False, cbar=False)
 *         return f
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_sns); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_seed_name);
    __Pyx_GIVEREF(__pyx_v_seed_name);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_seed_name);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 1015, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 1015, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1016
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,
 *                          yticklabels=False, xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 *         return f
 *     else:
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 1015, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 1015, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 1015, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1015
 *     if seed_name != None:
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,             # <<<<<<<<<<<<<<
 *                          yticklabels=False, xticklabels=False, cbar=False)
 *         return f
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1017
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,
 *                          yticklabels=False, xticklabels=False, cbar=False)
 *         return f             # <<<<<<<<<<<<<<
 *     else:
 *         f, ax = plt.subplots(figsize=(10, 1))
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_f);
    __pyx_r = __pyx_v_f;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":1013
 *     '''
 * 
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.loc[[seed_name]].to_numpy(), cmap=featurecmap, annot=False,
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1019
 *         return f
 *     else:
 *         f, ax = plt.subplots(figsize=(10, 1))             # <<<<<<<<<<<<<<
 *         ax = sns.heatmap(comb.iloc[[seedID]].to_numpy(), cmap=featurecmap, annot=False,
 *                          yticklabels=False, xticklabels=False, cbar=False)
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplots); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_figsize, __pyx_tuple_) < 0) __PYX_ERR(0, 1019, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
      PyObject* sequence = __pyx_t_5;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1019, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_3 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = Py_TYPE(__pyx_t_3)->tp_iternext;
      index = 0; __pyx_t_7 = __pyx_t_6(__pyx_t_3); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_3); if (unlikely(!__pyx_t_4)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_3), 2) < 0) __PYX_ERR(0, 1019, __pyx_L1_error)
      __pyx_t_6 = NULL;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1019, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __pyx_v_f = __pyx_t_7;
    __pyx_t_7 = 0;
    __pyx_v_ax = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1020
 *     else:
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.iloc[[seedID]].to_numpy(), cmap=featurecmap, annot=False,             # <<<<<<<<<<<<<<
 *                          yticklabels=False, xticklabels=False, cbar=False)
 *         return f
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_seedID);
    __Pyx_GIVEREF(__pyx_v_seedID);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_seedID);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1021
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.iloc[[seedID]].to_numpy(), cmap=featurecmap, annot=False,
 *                          yticklabels=False, xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 *         return f
 * 
 */
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 1020, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1020
 *     else:
 *         f, ax = plt.subplots(figsize=(10, 1))
 *         ax = sns.heatmap(comb.iloc[[seedID]].to_numpy(), cmap=featurecmap, annot=False,             # <<<<<<<<<<<<<<
 *                          yticklabels=False, xticklabels=False, cbar=False)
 *         return f
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1022
 *         ax = sns.heatmap(comb.iloc[[seedID]].to_numpy(), cmap=featurecmap, annot=False,
 *                          yticklabels=False, xticklabels=False, cbar=False)
 *         return f             # <<<<<<<<<<<<<<
 * 
 * def drawSeed(
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_f);
    __pyx_r = __pyx_v_f;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1002
 *     return f
 * 
 * def drawFeature(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     featurecmap,    #Cmap to plot feature
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.drawFeature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1024
 *         return f
 * 
 * def drawSeed(             # <<<<<<<<<<<<<<
 *     seed,       #Seed list
 *     seedcmap    #Cmap to draw seed
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_19drawSeed(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_18drawSeed[] = "\n    Function to draw seed\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_19drawSeed = {"drawSeed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_19drawSeed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_18drawSeed};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_19drawSeed(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_seed = 0;
  PyObject *__pyx_v_seedcmap = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("drawSeed (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_seed,&__pyx_n_s_seedcmap,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("drawSeed", 1, 2, 2, 1); __PYX_ERR(0, 1024, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "drawSeed") < 0)) __PYX_ERR(0, 1024, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_seed = values[0];
    __pyx_v_seedcmap = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("drawSeed", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1024, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.drawSeed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_18drawSeed(__pyx_self, __pyx_v_seed, __pyx_v_seedcmap);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_18drawSeed(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_seed, PyObject *__pyx_v_seedcmap) {
  PyObject *__pyx_v_f = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("drawSeed", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1033
 *     '''
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap([seed], cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_plt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_subplots); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_figsize, __pyx_tuple_) < 0) __PYX_ERR(0, 1033, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1033, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1033, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1033, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_f = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_ax = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1034
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))
 *     ax = sns.heatmap([seed], cmap=seedcmap, annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False)
 *     return f
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_seed);
  __Pyx_GIVEREF(__pyx_v_seed);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_seed);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 1034, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 1034, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 1034, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1035
 *     f, ax = plt.subplots(figsize=(10, 1))
 *     ax = sns.heatmap([seed], cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 1034, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 1034, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1034
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))
 *     ax = sns.heatmap([seed], cmap=seedcmap, annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False)
 *     return f
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1036
 *     ax = sns.heatmap([seed], cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * def seedCombine(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_f);
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1024
 *         return f
 * 
 * def drawSeed(             # <<<<<<<<<<<<<<
 *     seed,       #Seed list
 *     seedcmap    #Cmap to draw seed
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.drawSeed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1038
 *     return f
 * 
 * def seedCombine(             # <<<<<<<<<<<<<<
 *     currentseed,    #Current seed
 *     newseed         #New seed to be added
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_21seedCombine(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_20seedCombine[] = "\n    Function to combine two seed\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_21seedCombine = {"seedCombine", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_21seedCombine, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_20seedCombine};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_21seedCombine(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_currentseed = 0;
  PyObject *__pyx_v_newseed = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seedCombine (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_currentseed,&__pyx_n_s_newseed,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_currentseed)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_newseed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("seedCombine", 1, 2, 2, 1); __PYX_ERR(0, 1038, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "seedCombine") < 0)) __PYX_ERR(0, 1038, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_currentseed = values[0];
    __pyx_v_newseed = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("seedCombine", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1038, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.seedCombine", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_20seedCombine(__pyx_self, __pyx_v_currentseed, __pyx_v_newseed);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_20seedCombine(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_currentseed, PyObject *__pyx_v_newseed) {
  PyObject *__pyx_v_seed = NULL;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seedCombine", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1047
 *     '''
 * 
 *     seed = []             # <<<<<<<<<<<<<<
 *     for i in range(len(currentseed)):
 *         if currentseed[i] == 1 or newseed[i] == 1:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_seed = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1048
 * 
 *     seed = []
 *     for i in range(len(currentseed)):             # <<<<<<<<<<<<<<
 *         if currentseed[i] == 1 or newseed[i] == 1:
 *             seed.append(1)
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_currentseed); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1048, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "revealer/REVEALER_runbenchmark.pyx":1049
 *     seed = []
 *     for i in range(len(currentseed)):
 *         if currentseed[i] == 1 or newseed[i] == 1:             # <<<<<<<<<<<<<<
 *             seed.append(1)
 *         else:
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_currentseed, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_newseed, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_6, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __pyx_t_7;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":1050
 *     for i in range(len(currentseed)):
 *         if currentseed[i] == 1 or newseed[i] == 1:
 *             seed.append(1)             # <<<<<<<<<<<<<<
 *         else:
 *             seed.append(0)
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seed, __pyx_int_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1050, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1049
 *     seed = []
 *     for i in range(len(currentseed)):
 *         if currentseed[i] == 1 or newseed[i] == 1:             # <<<<<<<<<<<<<<
 *             seed.append(1)
 *         else:
 */
      goto __pyx_L5;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1052
 *             seed.append(1)
 *         else:
 *             seed.append(0)             # <<<<<<<<<<<<<<
 * 
 *     return seed
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seed, __pyx_int_0); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1052, __pyx_L1_error)
    }
    __pyx_L5:;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1054
 *             seed.append(0)
 * 
 *     return seed             # <<<<<<<<<<<<<<
 * 
 * cpdef topmatch(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_seed);
  __pyx_r = __pyx_v_seed;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1038
 *     return f
 * 
 * def seedCombine(             # <<<<<<<<<<<<<<
 *     currentseed,    #Current seed
 *     newseed         #New seed to be added
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.seedCombine", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_seed);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1056
 *     return seed
 * 
 * cpdef topmatch(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     currentseed,    #Current seed to run IC/CIC
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_23topmatch(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_topmatch(PyObject *__pyx_v_comb, PyObject *__pyx_v_currentseed, PyObject *__pyx_v_y, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_direction, PyObject *__pyx_v_num_top, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_ifSeed, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_collapse, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_target_name, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_CICs = NULL;
  PyObject *__pyx_v_pVals = NULL;
  PyObject *__pyx_v_bootstraps = NULL;
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  PyObject *__pyx_v_cythonseed = NULL;
  PyObject *__pyx_v_rank = NULL;
  PyObject *__pyx_v_IC = NULL;
  PyObject *__pyx_v_bootstrap = NULL;
  PyObject *__pyx_v_pVal = NULL;
  PyObject *__pyx_v_rankdf = NULL;
  PyObject *__pyx_v_pilesize = NULL;
  PyObject *__pyx_v_pileres = NULL;
  PyObject *__pyx_v_ICs = NULL;
  PyObject *__pyx_v_pilename = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_rankfeature = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_3;
  __Pyx_memviewslice __pyx_t_4 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_t_11;
  __pyx_t_5numpy_double_t __pyx_t_12;
  __pyx_t_5numpy_double_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  Py_ssize_t __pyx_t_19;
  PyObject *(*__pyx_t_20)(PyObject *);
  PyObject *(*__pyx_t_21)(PyObject *);
  Py_ssize_t __pyx_t_22;
  int __pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("topmatch", 0);
  __Pyx_INCREF(__pyx_v_currentseed);

  /* "revealer/REVEALER_runbenchmark.pyx":1091
 *     '''
 * 
 *     CICs = []             # <<<<<<<<<<<<<<
 *     pVals = []
 *     bootstraps = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_CICs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1092
 * 
 *     CICs = []
 *     pVals = []             # <<<<<<<<<<<<<<
 *     bootstraps = []
 *     cdef np.double_t miny = findmin(y, size)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pVals = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1093
 *     CICs = []
 *     pVals = []
 *     bootstraps = []             # <<<<<<<<<<<<<<
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bootstraps = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1094
 *     pVals = []
 *     bootstraps = []
 *     cdef np.double_t miny = findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_v_y, PyBUF_WRITABLE); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1094, __pyx_L1_error)
  __pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_2, __pyx_t_3);
  __PYX_XDEC_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL;
  __pyx_t_2.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":1095
 *     bootstraps = []
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)             # <<<<<<<<<<<<<<
 * 
 *     if ifSeed == True:
 */
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_v_y, PyBUF_WRITABLE); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(0, 1095, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1095, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_v_y, PyBUF_WRITABLE); if (unlikely(!__pyx_t_4.memview)) __PYX_ERR(0, 1095, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1095, __pyx_L1_error)
  __pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_t_2, __pyx_t_3) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_4, __pyx_t_5));
  __PYX_XDEC_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL;
  __pyx_t_2.data = NULL;
  __PYX_XDEC_MEMVIEW(&__pyx_t_4, 1);
  __pyx_t_4.memview = NULL;
  __pyx_t_4.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":1097
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     if ifSeed == True:             # <<<<<<<<<<<<<<
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_ifSeed, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "revealer/REVEALER_runbenchmark.pyx":1098
 * 
 *     if ifSeed == True:
 *         cythonseed = np.asarray(currentseed).astype(int)             # <<<<<<<<<<<<<<
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,
 *                           bandwidth_mult=bandwidth_mult, bandwidth_adj=bandwidth_adj,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_asarray); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_8, __pyx_v_currentseed) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_v_currentseed);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_astype); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_9, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_cythonseed = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1099
 *     if ifSeed == True:
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,             # <<<<<<<<<<<<<<
 *                           bandwidth_mult=bandwidth_mult, bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood,seed=cythonseed)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_topMatches); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_comb, __pyx_v_comb) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_y, __pyx_v_y) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth, __pyx_v_bandwidth) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1100
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,
 *                           bandwidth_mult=bandwidth_mult, bandwidth_adj=bandwidth_adj,             # <<<<<<<<<<<<<<
 *                           thread_number=thread_number, neighborhood = neighborhood,seed=cythonseed)
 * 
 */
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1101
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,
 *                           bandwidth_mult=bandwidth_mult, bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood,seed=cythonseed)             # <<<<<<<<<<<<<<
 * 
 *         IC = binaryInformationCoefficient_cython(y, cythonseed, k, size, bandwidth, bandwidth_mult,
 */
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_seed, __pyx_v_cythonseed) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1099
 *     if ifSeed == True:
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,             # <<<<<<<<<<<<<<
 *                           bandwidth_mult=bandwidth_mult, bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood,seed=cythonseed)
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_rank = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1103
 *                           thread_number=thread_number, neighborhood = neighborhood,seed=cythonseed)
 * 
 *         IC = binaryInformationCoefficient_cython(y, cythonseed, k, size, bandwidth, bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_v_y, PyBUF_WRITABLE); if (unlikely(!__pyx_t_4.memview)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_v_cythonseed, PyBUF_WRITABLE); if (unlikely(!__pyx_t_10.memview)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1103, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1103, __pyx_L1_error)
    __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_11 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1103, __pyx_L1_error)
    __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_12 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1103, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1104
 * 
 *         IC = binaryInformationCoefficient_cython(y, cythonseed, k, size, bandwidth, bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 * 
 *         CICs.append(IC)
 */
    __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_13 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1104, __pyx_L1_error)
    __pyx_t_14 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_14 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1104, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1103
 *                           thread_number=thread_number, neighborhood = neighborhood,seed=cythonseed)
 * 
 *         IC = binaryInformationCoefficient_cython(y, cythonseed, k, size, bandwidth, bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 */
    __pyx_t_7 = PyFloat_FromDouble(__pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_t_4, __pyx_t_10, __pyx_t_5, __pyx_t_3, __pyx_t_11, __pyx_t_12, __pyx_t_13, __pyx_t_14, __pyx_v_deltay, __pyx_v_miny, 0, NULL)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __PYX_XDEC_MEMVIEW(&__pyx_t_4, 1);
    __pyx_t_4.memview = NULL;
    __pyx_t_4.data = NULL;
    __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
    __pyx_t_10.memview = NULL;
    __pyx_t_10.data = NULL;
    __pyx_v_IC = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1106
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 * 
 *         CICs.append(IC)             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 */
    __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_v_IC); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1106, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1107
 * 
 *         CICs.append(IC)
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1107, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1108
 *         CICs.append(IC)
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_calcBootstrapIC); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pd); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_18 = __Pyx_GetItemInt(__pyx_t_17, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_tolist); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      __pyx_t_18 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
        __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_17);
        if (likely(__pyx_t_18)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_18);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_17, function);
        }
      }
      __pyx_t_8 = (__pyx_t_18) ? __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_18) : __Pyx_PyObject_CallNoArg(__pyx_t_17);
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = PyList_New(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_GIVEREF(__pyx_t_8);
      PyList_SET_ITEM(__pyx_t_17, 0, __pyx_t_8);
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyList_SET_ITEM(__pyx_t_17, 1, __pyx_v_currentseed);
      __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
        }
      }
      __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_8, __pyx_t_17) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_17);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_subcomb, __pyx_t_1) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1109
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth, __pyx_v_bandwidth) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1110
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1111
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1112
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             bootstraps.append(bootstrap)
 * 
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1108
 *         CICs.append(IC)
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_bootstrap = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1113
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 * 
 *         if if_pval == True:
 */
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1113, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1107
 * 
 *         CICs.append(IC)
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1115
 *             bootstraps.append(bootstrap)
 * 
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1115, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1115, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1116
 * 
 *         if if_pval == True:
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_calcIndivisualPvalIC); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pd); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_18 = __Pyx_GetItemInt(__pyx_t_8, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      __pyx_t_18 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_18)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_18);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_16 = (__pyx_t_18) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_18) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_16);
      PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_16);
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyList_SET_ITEM(__pyx_t_8, 1, __pyx_v_currentseed);
      __pyx_t_16 = 0;
      __pyx_t_16 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
        __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
        if (likely(__pyx_t_16)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_17, function);
        }
      }
      __pyx_t_7 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_16, __pyx_t_8) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_subcomb, __pyx_t_7) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1117
 *         if if_pval == True:
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth, __pyx_v_bandwidth) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1118
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number =thread_number, IC = IC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1119
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                         thread_number =thread_number, IC = IC, neighborhood = neighborhood)
 *             pVals.append(pVal)
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1120
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number =thread_number, IC = IC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             pVals.append(pVal)
 * 
 */
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1116
 * 
 *         if if_pval == True:
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_pVal = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1121
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number =thread_number, IC = IC, neighborhood = neighborhood)
 *             pVals.append(pVal)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_v_pVal); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1121, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1115
 *             bootstraps.append(bootstrap)
 * 
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1097
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 * 
 *     if ifSeed == True:             # <<<<<<<<<<<<<<
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb, y=y, grid=grid, k=k, size=size, bandwidth=bandwidth,
 */
    goto __pyx_L3;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1124
 * 
 *     else:
 *         currentseed = [0]*len(comb.columns)             # <<<<<<<<<<<<<<
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb,y = y,grid=grid,k=k,size = size,bandwidth = bandwidth,
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_19 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1124, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyList_New(1 * ((__pyx_t_19<0) ? 0:__pyx_t_19)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    { Py_ssize_t __pyx_temp;
      for (__pyx_temp=0; __pyx_temp < __pyx_t_19; __pyx_temp++) {
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyList_SET_ITEM(__pyx_t_7, __pyx_temp, __pyx_int_0);
      }
    }
    __Pyx_DECREF_SET(__pyx_v_currentseed, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1125
 *     else:
 *         currentseed = [0]*len(comb.columns)
 *         cythonseed = np.asarray(currentseed).astype(int)             # <<<<<<<<<<<<<<
 *         rank = topMatches(comb=comb,y = y,grid=grid,k=k,size = size,bandwidth = bandwidth,
 *                           bandwidth_mult=bandwidth_mult,bandwidth_adj=bandwidth_adj,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_17);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_17, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_1, __pyx_v_currentseed) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_v_currentseed);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_astype); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_17);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_17, function);
      }
    }
    __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_9, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_17, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_v_cythonseed = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1126
 *         currentseed = [0]*len(comb.columns)
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb,y = y,grid=grid,k=k,size = size,bandwidth = bandwidth,             # <<<<<<<<<<<<<<
 *                           bandwidth_mult=bandwidth_mult,bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_topMatches); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_17 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_comb, __pyx_v_comb) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_y, __pyx_v_y) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_bandwidth, __pyx_v_bandwidth) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1127
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb,y = y,grid=grid,k=k,size = size,bandwidth = bandwidth,
 *                           bandwidth_mult=bandwidth_mult,bandwidth_adj=bandwidth_adj,             # <<<<<<<<<<<<<<
 *                           thread_number=thread_number, neighborhood = neighborhood)
 *         CICs.append('')
 */
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1128
 *         rank = topMatches(comb=comb,y = y,grid=grid,k=k,size = size,bandwidth = bandwidth,
 *                           bandwidth_mult=bandwidth_mult,bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *         CICs.append('')
 *         if if_bootstrap == True:
 */
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1126
 *         currentseed = [0]*len(comb.columns)
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         rank = topMatches(comb=comb,y = y,grid=grid,k=k,size = size,bandwidth = bandwidth,             # <<<<<<<<<<<<<<
 *                           bandwidth_mult=bandwidth_mult,bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood)
 */
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_17); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_v_rank = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1129
 *                           bandwidth_mult=bandwidth_mult,bandwidth_adj=bandwidth_adj,
 *                           thread_number=thread_number, neighborhood = neighborhood)
 *         CICs.append('')             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             bootstraps.append('')
 */
    __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_kp_u__2); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1129, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1130
 *                           thread_number=thread_number, neighborhood = neighborhood)
 *         CICs.append('')
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstraps.append('')
 *         if if_pval == True:
 */
    __pyx_t_9 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1131
 *         CICs.append('')
 *         if if_bootstrap == True:
 *             bootstraps.append('')             # <<<<<<<<<<<<<<
 *         if if_pval == True:
 *             pVals.append('')
 */
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_kp_u__2); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1131, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1130
 *                           thread_number=thread_number, neighborhood = neighborhood)
 *         CICs.append('')
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstraps.append('')
 *         if if_pval == True:
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1132
 *         if if_bootstrap == True:
 *             bootstraps.append('')
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVals.append('')
 * 
 */
    __pyx_t_9 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1132, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1133
 *             bootstraps.append('')
 *         if if_pval == True:
 *             pVals.append('')             # <<<<<<<<<<<<<<
 * 
 *     rankdf = pd.DataFrame(rank)
 */
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_kp_u__2); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1133, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1132
 *         if if_bootstrap == True:
 *             bootstraps.append('')
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVals.append('')
 * 
 */
    }
  }
  __pyx_L3:;

  /* "revealer/REVEALER_runbenchmark.pyx":1135
 *             pVals.append('')
 * 
 *     rankdf = pd.DataFrame(rank)             # <<<<<<<<<<<<<<
 *     if direction == 'pos':
 *         rankdf.sort_values(by=1, ascending=False, inplace=True)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_pd); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_9 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_17, __pyx_v_rank) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_rank);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_rankdf = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1136
 * 
 *     rankdf = pd.DataFrame(rank)
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         rankdf.sort_values(by=1, ascending=False, inplace=True)
 *         rank = rankdf.to_numpy()
 */
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_pos, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1136, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "revealer/REVEALER_runbenchmark.pyx":1137
 *     rankdf = pd.DataFrame(rank)
 *     if direction == 'pos':
 *         rankdf.sort_values(by=1, ascending=False, inplace=True)             # <<<<<<<<<<<<<<
 *         rank = rankdf.to_numpy()
 *     else:
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankdf, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_by, __pyx_int_1) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
    __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1138
 *     if direction == 'pos':
 *         rankdf.sort_values(by=1, ascending=False, inplace=True)
 *         rank = rankdf.to_numpy()             # <<<<<<<<<<<<<<
 *     else:
 *         rankdf.sort_values(by=1, ascending=True, inplace=True)
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankdf, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_17 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_rank, __pyx_t_17);
    __pyx_t_17 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1136
 * 
 *     rankdf = pd.DataFrame(rank)
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         rankdf.sort_values(by=1, ascending=False, inplace=True)
 *         rank = rankdf.to_numpy()
 */
    goto __pyx_L8;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1140
 *         rank = rankdf.to_numpy()
 *     else:
 *         rankdf.sort_values(by=1, ascending=True, inplace=True)             # <<<<<<<<<<<<<<
 *         rank = rankdf.to_numpy()
 * 
 */
  /*else*/ {
    __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankdf, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_by, __pyx_int_1) < 0) __PYX_ERR(0, 1140, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ascending, Py_True) < 0) __PYX_ERR(0, 1140, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 1140, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1141
 *     else:
 *         rankdf.sort_values(by=1, ascending=True, inplace=True)
 *         rank = rankdf.to_numpy()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankdf, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_17 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_17)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_17);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_9 = (__pyx_t_17) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_17) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_rank, __pyx_t_9);
    __pyx_t_9 = 0;
  }
  __pyx_L8:;

  /* "revealer/REVEALER_runbenchmark.pyx":1144
 * 
 * 
 *     pilesize = []             # <<<<<<<<<<<<<<
 *     if collapse == True:
 *         pileres,ICs = pileRank(rank,num_top,prefix,out_folder,nitr)
 */
  __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_v_pilesize = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1145
 * 
 *     pilesize = []
 *     if collapse == True:             # <<<<<<<<<<<<<<
 *         pileres,ICs = pileRank(rank,num_top,prefix,out_folder,nitr)
 *         pilename = []
 */
  __pyx_t_9 = PyObject_RichCompare(__pyx_v_collapse, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__pyx_t_6) {

    /* "revealer/REVEALER_runbenchmark.pyx":1146
 *     pilesize = []
 *     if collapse == True:
 *         pileres,ICs = pileRank(rank,num_top,prefix,out_folder,nitr)             # <<<<<<<<<<<<<<
 *         pilename = []
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pileRank); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_17 = NULL;
    __pyx_t_14 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_17)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_17);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_14 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[6] = {__pyx_t_17, __pyx_v_rank, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_out_folder, __pyx_v_nitr};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_14, 5+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[6] = {__pyx_t_17, __pyx_v_rank, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_out_folder, __pyx_v_nitr};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_14, 5+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(5+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__pyx_t_17) {
        __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_17); __pyx_t_17 = NULL;
      }
      __Pyx_INCREF(__pyx_v_rank);
      __Pyx_GIVEREF(__pyx_v_rank);
      PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_14, __pyx_v_rank);
      __Pyx_INCREF(__pyx_v_num_top);
      __Pyx_GIVEREF(__pyx_v_num_top);
      PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_14, __pyx_v_num_top);
      __Pyx_INCREF(__pyx_v_prefix);
      __Pyx_GIVEREF(__pyx_v_prefix);
      PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_14, __pyx_v_prefix);
      __Pyx_INCREF(__pyx_v_out_folder);
      __Pyx_GIVEREF(__pyx_v_out_folder);
      PyTuple_SET_ITEM(__pyx_t_1, 3+__pyx_t_14, __pyx_v_out_folder);
      __Pyx_INCREF(__pyx_v_nitr);
      __Pyx_GIVEREF(__pyx_v_nitr);
      PyTuple_SET_ITEM(__pyx_t_1, 4+__pyx_t_14, __pyx_v_nitr);
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_9))) || (PyList_CheckExact(__pyx_t_9))) {
      PyObject* sequence = __pyx_t_9;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1146, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      #else
      __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_17 = PyObject_GetIter(__pyx_t_9); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_20 = Py_TYPE(__pyx_t_17)->tp_iternext;
      index = 0; __pyx_t_7 = __pyx_t_20(__pyx_t_17); if (unlikely(!__pyx_t_7)) goto __pyx_L10_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      index = 1; __pyx_t_1 = __pyx_t_20(__pyx_t_17); if (unlikely(!__pyx_t_1)) goto __pyx_L10_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_20(__pyx_t_17), 2) < 0) __PYX_ERR(0, 1146, __pyx_L1_error)
      __pyx_t_20 = NULL;
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      goto __pyx_L11_unpacking_done;
      __pyx_L10_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_20 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1146, __pyx_L1_error)
      __pyx_L11_unpacking_done:;
    }
    __pyx_v_pileres = __pyx_t_7;
    __pyx_t_7 = 0;
    __pyx_v_ICs = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1147
 *     if collapse == True:
 *         pileres,ICs = pileRank(rank,num_top,prefix,out_folder,nitr)
 *         pilename = []             # <<<<<<<<<<<<<<
 * 
 *         for i in range(len(pileres)):
 */
    __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_v_pilename = ((PyObject*)__pyx_t_9);
    __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1149
 *         pilename = []
 * 
 *         for i in range(len(pileres)):             # <<<<<<<<<<<<<<
 *             pilename.append(pileres[i][0][0])
 *             pilesize.append(len(pileres[i]))
 */
    __pyx_t_19 = PyObject_Length(__pyx_v_pileres); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1149, __pyx_L1_error)
    __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_9 = __pyx_t_1; __Pyx_INCREF(__pyx_t_9); __pyx_t_19 = 0;
      __pyx_t_21 = NULL;
    } else {
      __pyx_t_19 = -1; __pyx_t_9 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_21 = Py_TYPE(__pyx_t_9)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1149, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_21)) {
        if (likely(PyList_CheckExact(__pyx_t_9))) {
          if (__pyx_t_19 >= PyList_GET_SIZE(__pyx_t_9)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_19); __Pyx_INCREF(__pyx_t_1); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1149, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_9, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1149, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          if (__pyx_t_19 >= PyTuple_GET_SIZE(__pyx_t_9)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_9, __pyx_t_19); __Pyx_INCREF(__pyx_t_1); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1149, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_9, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1149, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_21(__pyx_t_9);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1149, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1150
 * 
 *         for i in range(len(pileres)):
 *             pilename.append(pileres[i][0][0])             # <<<<<<<<<<<<<<
 *             pilesize.append(len(pileres[i]))
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[pilename]])
 */
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_pileres, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_7, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pilename, __pyx_t_1); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1151
 *         for i in range(len(pileres)):
 *             pilename.append(pileres[i][0][0])
 *             pilesize.append(len(pileres[i]))             # <<<<<<<<<<<<<<
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[pilename]])
 *         CICs = CICs + list(ICs)
 */
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_pileres, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_22 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_22 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_22); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pilesize, __pyx_t_1); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1149
 *         pilename = []
 * 
 *         for i in range(len(pileres)):             # <<<<<<<<<<<<<<
 *             pilename.append(pileres[i][0][0])
 *             pilesize.append(len(pileres[i]))
 */
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1152
 *             pilename.append(pileres[i][0][0])
 *             pilesize.append(len(pileres[i]))
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[pilename]])             # <<<<<<<<<<<<<<
 *         CICs = CICs + list(ICs)
 *     else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_concat); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_17 = PyList_New(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_17, 0, __pyx_int_0);
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_17); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_17, __pyx_v_pilename); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = PyList_New(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_17, 0, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_17, 1, __pyx_t_1);
    __pyx_t_8 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_t_17) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_17);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_rankfeature = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1153
 *             pilesize.append(len(pileres[i]))
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[pilename]])
 *         CICs = CICs + list(ICs)             # <<<<<<<<<<<<<<
 *     else:
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[rank[:,0][:num_top]]])
 */
    __pyx_t_9 = PySequence_List(__pyx_v_ICs); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = PyNumber_Add(__pyx_v_CICs, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_CICs, ((PyObject*)__pyx_t_7));
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1145
 * 
 *     pilesize = []
 *     if collapse == True:             # <<<<<<<<<<<<<<
 *         pileres,ICs = pileRank(rank,num_top,prefix,out_folder,nitr)
 *         pilename = []
 */
    goto __pyx_L9;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1155
 *         CICs = CICs + list(ICs)
 *     else:
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[rank[:,0][:num_top]]])             # <<<<<<<<<<<<<<
 *         CICs = CICs + list(rank[:,1][:num_top])
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pd); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_concat); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_rank, __pyx_tuple__4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_16 = __Pyx_PyObject_GetSlice(__pyx_t_9, 0, 0, NULL, &__pyx_v_num_top, NULL, 0, 0, 1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyList_New(2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyList_SET_ITEM(__pyx_t_16, 1, __pyx_t_9);
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_17);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_17, function);
      }
    }
    __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_9, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_v_rankfeature = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1156
 *     else:
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[rank[:,0][:num_top]]])
 *         CICs = CICs + list(rank[:,1][:num_top])             # <<<<<<<<<<<<<<
 * 
 *     if ifSeed == True:
 */
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_rank, __pyx_tuple__5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_17 = __Pyx_PyObject_GetSlice(__pyx_t_7, 0, 0, NULL, &__pyx_v_num_top, NULL, 0, 0, 1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PySequence_List(__pyx_t_17); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = PyNumber_Add(__pyx_v_CICs, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_CICs, ((PyObject*)__pyx_t_17));
    __pyx_t_17 = 0;
  }
  __pyx_L9:;

  /* "revealer/REVEALER_runbenchmark.pyx":1158
 *         CICs = CICs + list(rank[:,1][:num_top])
 * 
 *     if ifSeed == True:             # <<<<<<<<<<<<<<
 *         if if_pval==True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 */
  __pyx_t_17 = PyObject_RichCompare(__pyx_v_ifSeed, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_17); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (__pyx_t_6) {

    /* "revealer/REVEALER_runbenchmark.pyx":1159
 * 
 *     if ifSeed == True:
 *         if if_pval==True:             # <<<<<<<<<<<<<<
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 */
    __pyx_t_17 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_17); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1159, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1159, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1160
 *     if ifSeed == True:
 *         if if_pval==True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,             # <<<<<<<<<<<<<<
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_17 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalCIC(__pyx_v_comb, __pyx_v_cythonseed, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1160, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_v_results = __pyx_t_17;
      __pyx_t_17 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1164
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 *                                   thread_number =thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     pVals.append(pVals[-1])
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
        }
      }
      __pyx_t_17 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_19 = PyObject_Length(__pyx_t_17); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_16 = PyTuple_New(2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_17);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_t_17);
      __pyx_t_17 = 0;
      __pyx_t_17 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_16, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      if (likely(PyList_CheckExact(__pyx_t_17)) || PyTuple_CheckExact(__pyx_t_17)) {
        __pyx_t_16 = __pyx_t_17; __Pyx_INCREF(__pyx_t_16); __pyx_t_19 = 0;
        __pyx_t_21 = NULL;
      } else {
        __pyx_t_19 = -1; __pyx_t_16 = PyObject_GetIter(__pyx_t_17); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1164, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_21 = Py_TYPE(__pyx_t_16)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1164, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      for (;;) {
        if (likely(!__pyx_t_21)) {
          if (likely(PyList_CheckExact(__pyx_t_16))) {
            if (__pyx_t_19 >= PyList_GET_SIZE(__pyx_t_16)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_17 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_19); __Pyx_INCREF(__pyx_t_17); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1164, __pyx_L1_error)
            #else
            __pyx_t_17 = PySequence_ITEM(__pyx_t_16, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1164, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
          } else {
            if (__pyx_t_19 >= PyTuple_GET_SIZE(__pyx_t_16)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_17 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_19); __Pyx_INCREF(__pyx_t_17); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1164, __pyx_L1_error)
            #else
            __pyx_t_17 = PySequence_ITEM(__pyx_t_16, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1164, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
          }
        } else {
          __pyx_t_17 = __pyx_t_21(__pyx_t_16);
          if (unlikely(!__pyx_t_17)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1164, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_17);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_17);
        __pyx_t_17 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1165
 *                                   thread_number =thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     pVals.append(pVals[-1])
 *                 else:
 */
        __pyx_t_17 = __Pyx_PyInt_NeObjC(__pyx_v_i, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (__pyx_t_23) {
        } else {
          __pyx_t_6 = __pyx_t_23;
          goto __pyx_L19_bool_binop_done;
        }
        __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyObject_RichCompare(__pyx_t_17, __pyx_t_9, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1165, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_6 = __pyx_t_23;
        __pyx_L19_bool_binop_done:;
        if (__pyx_t_6) {

          /* "revealer/REVEALER_runbenchmark.pyx":1166
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     pVals.append(pVals[-1])             # <<<<<<<<<<<<<<
 *                 else:
 *                     #print('CIC:'+str(CICs[i]))
 */
          __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_pVals, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1166, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_t_7); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1166, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1165
 *                                   thread_number =thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     pVals.append(pVals[-1])
 *                 else:
 */
          goto __pyx_L18;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1169
 *                 else:
 *                     #print('CIC:'+str(CICs[i]))
 *                     pVals.append(calcPvalCIC(results = results, IC = CICs[i], direction = direction))             # <<<<<<<<<<<<<<
 * 
 *         if if_bootstrap==True:
 */
        /*else*/ {
          __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1169, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_9 = __pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalCIC(__pyx_v_results, __pyx_t_7, __pyx_v_direction, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1169, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_t_9); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1169, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_L18:;

        /* "revealer/REVEALER_runbenchmark.pyx":1164
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 *                                   thread_number =thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     pVals.append(pVals[-1])
 */
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1159
 * 
 *     if ifSeed == True:
 *         if if_pval==True:             # <<<<<<<<<<<<<<
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1171
 *                     pVals.append(calcPvalCIC(results = results, IC = CICs[i], direction = direction))
 * 
 *         if if_bootstrap==True:             # <<<<<<<<<<<<<<
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 */
    __pyx_t_16 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_16); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1171, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1171, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1172
 * 
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     bootstraps.append(bootstraps[-1])
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_16 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_19 = PyObject_Length(__pyx_t_16); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_16);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_16);
      __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_7, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (likely(PyList_CheckExact(__pyx_t_16)) || PyTuple_CheckExact(__pyx_t_16)) {
        __pyx_t_7 = __pyx_t_16; __Pyx_INCREF(__pyx_t_7); __pyx_t_19 = 0;
        __pyx_t_21 = NULL;
      } else {
        __pyx_t_19 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_16); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1172, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_21 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1172, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      for (;;) {
        if (likely(!__pyx_t_21)) {
          if (likely(PyList_CheckExact(__pyx_t_7))) {
            if (__pyx_t_19 >= PyList_GET_SIZE(__pyx_t_7)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_19); __Pyx_INCREF(__pyx_t_16); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1172, __pyx_L1_error)
            #else
            __pyx_t_16 = PySequence_ITEM(__pyx_t_7, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1172, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
          } else {
            if (__pyx_t_19 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_19); __Pyx_INCREF(__pyx_t_16); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1172, __pyx_L1_error)
            #else
            __pyx_t_16 = PySequence_ITEM(__pyx_t_7, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1172, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
          }
        } else {
          __pyx_t_16 = __pyx_t_21(__pyx_t_7);
          if (unlikely(!__pyx_t_16)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1172, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_16);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_16);
        __pyx_t_16 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1173
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 */
        __pyx_t_16 = __Pyx_PyInt_NeObjC(__pyx_v_i, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (__pyx_t_23) {
        } else {
          __pyx_t_6 = __pyx_t_23;
          goto __pyx_L25_bool_binop_done;
        }
        __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_9 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_9); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyObject_RichCompare(__pyx_t_16, __pyx_t_17, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1173, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_6 = __pyx_t_23;
        __pyx_L25_bool_binop_done:;
        if (__pyx_t_6) {

          /* "revealer/REVEALER_runbenchmark.pyx":1174
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     bootstraps.append(bootstraps[-1])             # <<<<<<<<<<<<<<
 *                 else:
 *                     bootstrap = calcBootstrap(subcomb = rankfeature.iloc[[0,i],],
 */
          __pyx_t_9 = __Pyx_GetItemInt_List(__pyx_v_bootstraps, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1174, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_t_9); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1174, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1173
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 */
          goto __pyx_L24;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1176
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 *                     bootstrap = calcBootstrap(subcomb = rankfeature.iloc[[0,i],],             # <<<<<<<<<<<<<<
 *                                               cythonseed = cythonseed, size = size,
 *                                               bandwidth = bandwidth, k = k,
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_calcBootstrap); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_17 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_iloc); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          PyList_SET_ITEM(__pyx_t_8, 0, __pyx_int_0);
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyList_SET_ITEM(__pyx_t_8, 1, __pyx_v_i);
          __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_8);
          __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_16, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_subcomb, __pyx_t_8) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1177
 *                 else:
 *                     bootstrap = calcBootstrap(subcomb = rankfeature.iloc[[0,i],],
 *                                               cythonseed = cythonseed, size = size,             # <<<<<<<<<<<<<<
 *                                               bandwidth = bandwidth, k = k,
 *                                               bandwidth_mult = bandwidth_mult,
 */
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_cythonseed, __pyx_v_cythonseed) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1178
 *                     bootstrap = calcBootstrap(subcomb = rankfeature.iloc[[0,i],],
 *                                               cythonseed = cythonseed, size = size,
 *                                               bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                               bandwidth_mult = bandwidth_mult,
 *                                               bandwidth_adj = bandwidth_adj, grid = grid,
 */
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_bandwidth, __pyx_v_bandwidth) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1179
 *                                               cythonseed = cythonseed, size = size,
 *                                               bandwidth = bandwidth, k = k,
 *                                               bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                               bandwidth_adj = bandwidth_adj, grid = grid,
 *                                               thread_number = thread_number, IC = IC,
 */
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1180
 *                                               bandwidth = bandwidth, k = k,
 *                                               bandwidth_mult = bandwidth_mult,
 *                                               bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                               thread_number = thread_number, IC = IC,
 *                                               neighborhood = neighborhood)
 */
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1181
 *                                               bandwidth_mult = bandwidth_mult,
 *                                               bandwidth_adj = bandwidth_adj, grid = grid,
 *                                               thread_number = thread_number, IC = IC,             # <<<<<<<<<<<<<<
 *                                               neighborhood = neighborhood)
 *                     bootstraps.append(bootstrap)
 */
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
          if (unlikely(!__pyx_v_IC)) { __Pyx_RaiseUnboundLocalError("IC"); __PYX_ERR(0, 1181, __pyx_L1_error) }
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1182
 *                                               bandwidth_adj = bandwidth_adj, grid = grid,
 *                                               thread_number = thread_number, IC = IC,
 *                                               neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *                     bootstraps.append(bootstrap)
 *     else:
 */
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1176
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 *                     bootstrap = calcBootstrap(subcomb = rankfeature.iloc[[0,i],],             # <<<<<<<<<<<<<<
 *                                               cythonseed = cythonseed, size = size,
 *                                               bandwidth = bandwidth, k = k,
 */
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_17); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1176, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF_SET(__pyx_v_bootstrap, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1183
 *                                               thread_number = thread_number, IC = IC,
 *                                               neighborhood = neighborhood)
 *                     bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 *     else:
 *         if if_pval==True:
 */
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1183, __pyx_L1_error)
        }
        __pyx_L24:;

        /* "revealer/REVEALER_runbenchmark.pyx":1172
 * 
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     bootstraps.append(bootstraps[-1])
 */
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1171
 *                     pVals.append(calcPvalCIC(results = results, IC = CICs[i], direction = direction))
 * 
 *         if if_bootstrap==True:             # <<<<<<<<<<<<<<
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1158
 *         CICs = CICs + list(rank[:,1][:num_top])
 * 
 *     if ifSeed == True:             # <<<<<<<<<<<<<<
 *         if if_pval==True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 */
    goto __pyx_L14;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1185
 *                     bootstraps.append(bootstrap)
 *     else:
 *         if if_pval==True:             # <<<<<<<<<<<<<<
 *             results = prepPvalIC(comb = comb, size = size,
 *                                  bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 */
  /*else*/ {
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1185, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1185, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1186
 *     else:
 *         if if_pval==True:
 *             results = prepPvalIC(comb = comb, size = size,             # <<<<<<<<<<<<<<
 *                                  bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 *                                  bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_7 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalIC(__pyx_v_comb, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_results = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1190
 *                                  bandwidth_adj = bandwidth_adj, grid = grid,
 *                                  thread_number = thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     pVals.append(pVals[-1])
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_index); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_tolist); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_17);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_17, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_17);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_19 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_17 = PyTuple_New(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_17, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
        __pyx_t_17 = __pyx_t_7; __Pyx_INCREF(__pyx_t_17); __pyx_t_19 = 0;
        __pyx_t_21 = NULL;
      } else {
        __pyx_t_19 = -1; __pyx_t_17 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_21 = Py_TYPE(__pyx_t_17)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1190, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      for (;;) {
        if (likely(!__pyx_t_21)) {
          if (likely(PyList_CheckExact(__pyx_t_17))) {
            if (__pyx_t_19 >= PyList_GET_SIZE(__pyx_t_17)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyList_GET_ITEM(__pyx_t_17, __pyx_t_19); __Pyx_INCREF(__pyx_t_7); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1190, __pyx_L1_error)
            #else
            __pyx_t_7 = PySequence_ITEM(__pyx_t_17, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1190, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          } else {
            if (__pyx_t_19 >= PyTuple_GET_SIZE(__pyx_t_17)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_17, __pyx_t_19); __Pyx_INCREF(__pyx_t_7); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1190, __pyx_L1_error)
            #else
            __pyx_t_7 = PySequence_ITEM(__pyx_t_17, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1190, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          }
        } else {
          __pyx_t_7 = __pyx_t_21(__pyx_t_17);
          if (unlikely(!__pyx_t_7)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1190, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1191
 *                                  thread_number = thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     pVals.append(pVals[-1])
 *                 else:
 */
        __pyx_t_7 = __Pyx_PyInt_NeObjC(__pyx_v_i, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_23) {
        } else {
          __pyx_t_6 = __pyx_t_23;
          goto __pyx_L31_bool_binop_done;
        }
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_RichCompare(__pyx_t_7, __pyx_t_9, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_6 = __pyx_t_23;
        __pyx_L31_bool_binop_done:;
        if (__pyx_t_6) {

          /* "revealer/REVEALER_runbenchmark.pyx":1192
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     pVals.append(pVals[-1])             # <<<<<<<<<<<<<<
 *                 else:
 *                     #print('CIC:'+str(CICs[i]))
 */
          __pyx_t_8 = __Pyx_GetItemInt_List(__pyx_v_pVals, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_t_8); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1192, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1191
 *                                  thread_number = thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     pVals.append(pVals[-1])
 *                 else:
 */
          goto __pyx_L30;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1195
 *                 else:
 *                     #print('CIC:'+str(CICs[i]))
 *                     pVals.append(calcPvalIC(results = results, IC = CICs[i], direction = direction))             # <<<<<<<<<<<<<<
 * 
 *         if if_bootstrap==True:
 */
        /*else*/ {
          __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1195, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = __pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalIC(__pyx_v_results, __pyx_t_8, __pyx_v_direction, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1195, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_t_9); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1195, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_L30:;

        /* "revealer/REVEALER_runbenchmark.pyx":1190
 *                                  bandwidth_adj = bandwidth_adj, grid = grid,
 *                                  thread_number = thread_number, neighborhood = neighborhood)
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     pVals.append(pVals[-1])
 */
      }
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1185
 *                     bootstraps.append(bootstrap)
 *     else:
 *         if if_pval==True:             # <<<<<<<<<<<<<<
 *             results = prepPvalIC(comb = comb, size = size,
 *                                  bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1197
 *                     pVals.append(calcPvalIC(results = results, IC = CICs[i], direction = direction))
 * 
 *         if if_bootstrap==True:             # <<<<<<<<<<<<<<
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 */
    __pyx_t_17 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_17); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":1198
 * 
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     bootstraps.append(bootstraps[-1])
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_17 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_19 = PyObject_Length(__pyx_t_17); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_17);
      PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_17);
      __pyx_t_17 = 0;
      __pyx_t_17 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_8, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (likely(PyList_CheckExact(__pyx_t_17)) || PyTuple_CheckExact(__pyx_t_17)) {
        __pyx_t_8 = __pyx_t_17; __Pyx_INCREF(__pyx_t_8); __pyx_t_19 = 0;
        __pyx_t_21 = NULL;
      } else {
        __pyx_t_19 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_17); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1198, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_21 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1198, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      for (;;) {
        if (likely(!__pyx_t_21)) {
          if (likely(PyList_CheckExact(__pyx_t_8))) {
            if (__pyx_t_19 >= PyList_GET_SIZE(__pyx_t_8)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_17 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_19); __Pyx_INCREF(__pyx_t_17); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1198, __pyx_L1_error)
            #else
            __pyx_t_17 = PySequence_ITEM(__pyx_t_8, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1198, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
          } else {
            if (__pyx_t_19 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_17 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_19); __Pyx_INCREF(__pyx_t_17); __pyx_t_19++; if (unlikely(0 < 0)) __PYX_ERR(0, 1198, __pyx_L1_error)
            #else
            __pyx_t_17 = PySequence_ITEM(__pyx_t_8, __pyx_t_19); __pyx_t_19++; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1198, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
          }
        } else {
          __pyx_t_17 = __pyx_t_21(__pyx_t_8);
          if (unlikely(!__pyx_t_17)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1198, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_17);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_17);
        __pyx_t_17 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1199
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 */
        __pyx_t_17 = __Pyx_PyInt_NeObjC(__pyx_v_i, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (__pyx_t_23) {
        } else {
          __pyx_t_6 = __pyx_t_23;
          goto __pyx_L37_bool_binop_done;
        }
        __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_9 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyObject_RichCompare(__pyx_t_17, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1199, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_6 = __pyx_t_23;
        __pyx_L37_bool_binop_done:;
        if (__pyx_t_6) {

          /* "revealer/REVEALER_runbenchmark.pyx":1200
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     bootstraps.append(bootstraps[-1])             # <<<<<<<<<<<<<<
 *                 else:
 *                     bootstrap = calcBootstrapIC(subcomb = rankfeature.iloc[[0,i],], size = size,
 */
          __pyx_t_9 = __Pyx_GetItemInt_List(__pyx_v_bootstraps, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1200, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_t_9); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1200, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1199
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:             # <<<<<<<<<<<<<<
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 */
          goto __pyx_L36;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1202
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 *                     bootstrap = calcBootstrapIC(subcomb = rankfeature.iloc[[0,i],], size = size,             # <<<<<<<<<<<<<<
 *                                                 bandwidth = bandwidth, k = k,
 *                                                 bandwidth_mult = bandwidth_mult,
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_calcBootstrapIC); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_7 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_iloc); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_i);
          __pyx_t_16 = PyTuple_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_17, __pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_subcomb, __pyx_t_1) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1203
 *                 else:
 *                     bootstrap = calcBootstrapIC(subcomb = rankfeature.iloc[[0,i],], size = size,
 *                                                 bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                                 bandwidth_mult = bandwidth_mult,
 *                                                 bandwidth_adj = bandwidth_adj,
 */
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_bandwidth, __pyx_v_bandwidth) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1204
 *                     bootstrap = calcBootstrapIC(subcomb = rankfeature.iloc[[0,i],], size = size,
 *                                                 bandwidth = bandwidth, k = k,
 *                                                 bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                                 bandwidth_adj = bandwidth_adj,
 *                                                 grid = grid, thread_number = thread_number,
 */
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1205
 *                                                 bandwidth = bandwidth, k = k,
 *                                                 bandwidth_mult = bandwidth_mult,
 *                                                 bandwidth_adj = bandwidth_adj,             # <<<<<<<<<<<<<<
 *                                                 grid = grid, thread_number = thread_number,
 *                                                 IC = CICs[i], neighborhood = neighborhood)
 */
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1206
 *                                                 bandwidth_mult = bandwidth_mult,
 *                                                 bandwidth_adj = bandwidth_adj,
 *                                                 grid = grid, thread_number = thread_number,             # <<<<<<<<<<<<<<
 *                                                 IC = CICs[i], neighborhood = neighborhood)
 *                     bootstraps.append(bootstrap)
 */
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1207
 *                                                 bandwidth_adj = bandwidth_adj,
 *                                                 grid = grid, thread_number = thread_number,
 *                                                 IC = CICs[i], neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *                     bootstraps.append(bootstrap)
 * 
 */
          __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1207, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_IC, __pyx_t_1) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1202, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":1202
 *                     bootstraps.append(bootstraps[-1])
 *                 else:
 *                     bootstrap = calcBootstrapIC(subcomb = rankfeature.iloc[[0,i],], size = size,             # <<<<<<<<<<<<<<
 *                                                 bandwidth = bandwidth, k = k,
 *                                                 bandwidth_mult = bandwidth_mult,
 */
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF_SET(__pyx_v_bootstrap, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1208
 *                                                 grid = grid, thread_number = thread_number,
 *                                                 IC = CICs[i], neighborhood = neighborhood)
 *                     bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 * 
 *     savetopfig(plotcomb = rankfeature.copy(), CICs = CICs, cythonseed = cythonseed,
 */
          __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1208, __pyx_L1_error)
        }
        __pyx_L36:;

        /* "revealer/REVEALER_runbenchmark.pyx":1198
 * 
 *         if if_bootstrap==True:
 *             for i in range(1,len(rankfeature.index.tolist())):             # <<<<<<<<<<<<<<
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 *                     bootstraps.append(bootstraps[-1])
 */
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1197
 *                     pVals.append(calcPvalIC(results = results, IC = CICs[i], direction = direction))
 * 
 *         if if_bootstrap==True:             # <<<<<<<<<<<<<<
 *             for i in range(1,len(rankfeature.index.tolist())):
 *                 if i != 1 and CICs[i] == CICs[i-1]:
 */
    }
  }
  __pyx_L14:;

  /* "revealer/REVEALER_runbenchmark.pyx":1210
 *                     bootstraps.append(bootstrap)
 * 
 *     savetopfig(plotcomb = rankfeature.copy(), CICs = CICs, cythonseed = cythonseed,             # <<<<<<<<<<<<<<
 *                seedcmap = seedcmap, featurecmap = featurecmap, prefix = prefix,
 *                figure_format = figure_format, pVals = pVals, num_top = num_top,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_savetopfig); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(17); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_copy); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_7 = (__pyx_t_16) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_16) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_plotcomb, __pyx_t_7) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CICs, __pyx_v_CICs) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_cythonseed, __pyx_v_cythonseed) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1211
 * 
 *     savetopfig(plotcomb = rankfeature.copy(), CICs = CICs, cythonseed = cythonseed,
 *                seedcmap = seedcmap, featurecmap = featurecmap, prefix = prefix,             # <<<<<<<<<<<<<<
 *                figure_format = figure_format, pVals = pVals, num_top = num_top,
 *                bootstraps = bootstraps.copy(), pilesize = pilesize, nitr = nitr, gmt = gmt,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_seedcmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_featurecmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_prefix, __pyx_v_prefix) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1212
 *     savetopfig(plotcomb = rankfeature.copy(), CICs = CICs, cythonseed = cythonseed,
 *                seedcmap = seedcmap, featurecmap = featurecmap, prefix = prefix,
 *                figure_format = figure_format, pVals = pVals, num_top = num_top,             # <<<<<<<<<<<<<<
 *                bootstraps = bootstraps.copy(), pilesize = pilesize, nitr = nitr, gmt = gmt,
 *                out_folder = out_folder, target_name = target_name, seed_name = seed_name,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_figure_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pVals, __pyx_v_pVals) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_num_top, __pyx_v_num_top) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1213
 *                seedcmap = seedcmap, featurecmap = featurecmap, prefix = prefix,
 *                figure_format = figure_format, pVals = pVals, num_top = num_top,
 *                bootstraps = bootstraps.copy(), pilesize = pilesize, nitr = nitr, gmt = gmt,             # <<<<<<<<<<<<<<
 *                out_folder = out_folder, target_name = target_name, seed_name = seed_name,
 *                locusdic = locusdic)
 */
  __pyx_t_7 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_copy, __pyx_v_bootstraps); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_bootstraps, __pyx_t_7) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pilesize, __pyx_v_pilesize) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_nitr, __pyx_v_nitr) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_gmt, __pyx_v_gmt) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1214
 *                figure_format = figure_format, pVals = pVals, num_top = num_top,
 *                bootstraps = bootstraps.copy(), pilesize = pilesize, nitr = nitr, gmt = gmt,
 *                out_folder = out_folder, target_name = target_name, seed_name = seed_name,             # <<<<<<<<<<<<<<
 *                locusdic = locusdic)
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_out_folder, __pyx_v_out_folder) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_target_name, __pyx_v_target_name) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_seed_name, __pyx_v_seed_name) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1215
 *                bootstraps = bootstraps.copy(), pilesize = pilesize, nitr = nitr, gmt = gmt,
 *                out_folder = out_folder, target_name = target_name, seed_name = seed_name,
 *                locusdic = locusdic)             # <<<<<<<<<<<<<<
 * 
 *     if if_cluster == True and collapse == False:
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_locusdic, __pyx_v_locusdic) < 0) __PYX_ERR(0, 1210, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1210
 *                     bootstraps.append(bootstrap)
 * 
 *     savetopfig(plotcomb = rankfeature.copy(), CICs = CICs, cythonseed = cythonseed,             # <<<<<<<<<<<<<<
 *                seedcmap = seedcmap, featurecmap = featurecmap, prefix = prefix,
 *                figure_format = figure_format, pVals = pVals, num_top = num_top,
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1217
 *                locusdic = locusdic)
 * 
 *     if if_cluster == True and collapse == False:             # <<<<<<<<<<<<<<
 *         plotCluster(plotcomb = rankfeature.copy(), CICs = CICs, size = size,
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,
 */
  __pyx_t_7 = PyObject_RichCompare(__pyx_v_if_cluster, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_23) {
  } else {
    __pyx_t_6 = __pyx_t_23;
    goto __pyx_L40_bool_binop_done;
  }
  __pyx_t_7 = PyObject_RichCompare(__pyx_v_collapse, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_6 = __pyx_t_23;
  __pyx_L40_bool_binop_done:;
  if (__pyx_t_6) {

    /* "revealer/REVEALER_runbenchmark.pyx":1218
 * 
 *     if if_cluster == True and collapse == False:
 *         plotCluster(plotcomb = rankfeature.copy(), CICs = CICs, size = size,             # <<<<<<<<<<<<<<
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,
 *                     prefix = prefix, figure_format = figure_format, pVals = pVals,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plotCluster); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(17); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_rankfeature, __pyx_n_s_copy); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_16 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_16)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_16);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_8 = (__pyx_t_16) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_16) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_plotcomb, __pyx_t_8) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_CICs, __pyx_v_CICs) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_size, __pyx_v_size) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1219
 *     if if_cluster == True and collapse == False:
 *         plotCluster(plotcomb = rankfeature.copy(), CICs = CICs, size = size,
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,             # <<<<<<<<<<<<<<
 *                     prefix = prefix, figure_format = figure_format, pVals = pVals,
 *                     num_top = num_top, bootstraps = bootstraps, nitr = nitr, gmt = gmt,
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_cythonseed, __pyx_v_cythonseed) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_seedcmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_featurecmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1220
 *         plotCluster(plotcomb = rankfeature.copy(), CICs = CICs, size = size,
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,
 *                     prefix = prefix, figure_format = figure_format, pVals = pVals,             # <<<<<<<<<<<<<<
 *                     num_top = num_top, bootstraps = bootstraps, nitr = nitr, gmt = gmt,
 *                     out_folder = out_folder, target_name = target_name, seed_name = seed_name,
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_prefix, __pyx_v_prefix) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_figure_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_pVals, __pyx_v_pVals) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1221
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,
 *                     prefix = prefix, figure_format = figure_format, pVals = pVals,
 *                     num_top = num_top, bootstraps = bootstraps, nitr = nitr, gmt = gmt,             # <<<<<<<<<<<<<<
 *                     out_folder = out_folder, target_name = target_name, seed_name = seed_name,
 *                     locusdic = locusdic)
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_num_top, __pyx_v_num_top) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_bootstraps, __pyx_v_bootstraps) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_nitr, __pyx_v_nitr) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_gmt, __pyx_v_gmt) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1222
 *                     prefix = prefix, figure_format = figure_format, pVals = pVals,
 *                     num_top = num_top, bootstraps = bootstraps, nitr = nitr, gmt = gmt,
 *                     out_folder = out_folder, target_name = target_name, seed_name = seed_name,             # <<<<<<<<<<<<<<
 *                     locusdic = locusdic)
 * 
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_out_folder, __pyx_v_out_folder) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_target_name, __pyx_v_target_name) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_seed_name, __pyx_v_seed_name) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1223
 *                     num_top = num_top, bootstraps = bootstraps, nitr = nitr, gmt = gmt,
 *                     out_folder = out_folder, target_name = target_name, seed_name = seed_name,
 *                     locusdic = locusdic)             # <<<<<<<<<<<<<<
 * 
 *     return comb,rank,rankfeature
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_locusdic, __pyx_v_locusdic) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1218
 * 
 *     if if_cluster == True and collapse == False:
 *         plotCluster(plotcomb = rankfeature.copy(), CICs = CICs, size = size,             # <<<<<<<<<<<<<<
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,
 *                     prefix = prefix, figure_format = figure_format, pVals = pVals,
 */
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1217
 *                locusdic = locusdic)
 * 
 *     if if_cluster == True and collapse == False:             # <<<<<<<<<<<<<<
 *         plotCluster(plotcomb = rankfeature.copy(), CICs = CICs, size = size,
 *                     cythonseed = cythonseed, seedcmap = seedcmap, featurecmap = featurecmap,
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1225
 *                     locusdic = locusdic)
 * 
 *     return comb,rank,rankfeature             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_v_comb);
  __Pyx_GIVEREF(__pyx_v_comb);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_comb);
  __Pyx_INCREF(__pyx_v_rank);
  __Pyx_GIVEREF(__pyx_v_rank);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_rank);
  __Pyx_INCREF(__pyx_v_rankfeature);
  __Pyx_GIVEREF(__pyx_v_rankfeature);
  PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_v_rankfeature);
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1056
 *     return seed
 * 
 * cpdef topmatch(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     currentseed,    #Current seed to run IC/CIC
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_2, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_4, 1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.topmatch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_CICs);
  __Pyx_XDECREF(__pyx_v_pVals);
  __Pyx_XDECREF(__pyx_v_bootstraps);
  __Pyx_XDECREF(__pyx_v_cythonseed);
  __Pyx_XDECREF(__pyx_v_rank);
  __Pyx_XDECREF(__pyx_v_IC);
  __Pyx_XDECREF(__pyx_v_bootstrap);
  __Pyx_XDECREF(__pyx_v_pVal);
  __Pyx_XDECREF(__pyx_v_rankdf);
  __Pyx_XDECREF(__pyx_v_pilesize);
  __Pyx_XDECREF(__pyx_v_pileres);
  __Pyx_XDECREF(__pyx_v_ICs);
  __Pyx_XDECREF(__pyx_v_pilename);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_rankfeature);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_currentseed);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_23topmatch(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_22topmatch[] = "\n    Function to create intermediate file for each run to report top features in each run\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_23topmatch(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_currentseed = 0;
  PyObject *__pyx_v_y = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_direction = 0;
  PyObject *__pyx_v_num_top = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_ifSeed = 0;
  PyObject *__pyx_v_if_pval = 0;
  PyObject *__pyx_v_if_bootstrap = 0;
  PyObject *__pyx_v_if_cluster = 0;
  PyObject *__pyx_v_collapse = 0;
  PyObject *__pyx_v_seedcmap = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_nitr = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_gmt = 0;
  PyObject *__pyx_v_locusdic = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("topmatch (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_comb,&__pyx_n_s_currentseed,&__pyx_n_s_y,&__pyx_n_s_grid,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_thread_number,&__pyx_n_s_direction,&__pyx_n_s_num_top,&__pyx_n_s_prefix,&__pyx_n_s_figure_format,&__pyx_n_s_ifSeed,&__pyx_n_s_if_pval,&__pyx_n_s_if_bootstrap,&__pyx_n_s_if_cluster,&__pyx_n_s_collapse,&__pyx_n_s_seedcmap,&__pyx_n_s_featurecmap,&__pyx_n_s_nitr,&__pyx_n_s_out_folder,&__pyx_n_s_seed_name,&__pyx_n_s_target_name,&__pyx_n_s_gmt,&__pyx_n_s_locusdic,&__pyx_n_s_neighborhood,0};
    PyObject* values[28] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 28: values[27] = PyTuple_GET_ITEM(__pyx_args, 27);
        CYTHON_FALLTHROUGH;
        case 27: values[26] = PyTuple_GET_ITEM(__pyx_args, 26);
        CYTHON_FALLTHROUGH;
        case 26: values[25] = PyTuple_GET_ITEM(__pyx_args, 25);
        CYTHON_FALLTHROUGH;
        case 25: values[24] = PyTuple_GET_ITEM(__pyx_args, 24);
        CYTHON_FALLTHROUGH;
        case 24: values[23] = PyTuple_GET_ITEM(__pyx_args, 23);
        CYTHON_FALLTHROUGH;
        case 23: values[22] = PyTuple_GET_ITEM(__pyx_args, 22);
        CYTHON_FALLTHROUGH;
        case 22: values[21] = PyTuple_GET_ITEM(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = PyTuple_GET_ITEM(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_currentseed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 1); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 2); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 3); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 4); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 5); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 6); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 7); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 8); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 9); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 10); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_top)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 11); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 12); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 13); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (likely((values[14] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ifSeed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 14); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (likely((values[15] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_pval)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 15); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (likely((values[16] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_bootstrap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 16); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (likely((values[17] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_cluster)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 17); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (likely((values[18] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_collapse)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 18); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 19:
        if (likely((values[19] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 19); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 20:
        if (likely((values[20] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 20); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 21:
        if (likely((values[21] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nitr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 21); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 22:
        if (likely((values[22] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 22); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 23:
        if (likely((values[23] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 23); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 24:
        if (likely((values[24] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 24); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 25:
        if (likely((values[25] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 25); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 26:
        if (likely((values[26] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_locusdic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 26); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 27:
        if (likely((values[27] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, 27); __PYX_ERR(0, 1056, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "topmatch") < 0)) __PYX_ERR(0, 1056, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 28) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
      values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
      values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
      values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
      values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
      values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
      values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
      values[20] = PyTuple_GET_ITEM(__pyx_args, 20);
      values[21] = PyTuple_GET_ITEM(__pyx_args, 21);
      values[22] = PyTuple_GET_ITEM(__pyx_args, 22);
      values[23] = PyTuple_GET_ITEM(__pyx_args, 23);
      values[24] = PyTuple_GET_ITEM(__pyx_args, 24);
      values[25] = PyTuple_GET_ITEM(__pyx_args, 25);
      values[26] = PyTuple_GET_ITEM(__pyx_args, 26);
      values[27] = PyTuple_GET_ITEM(__pyx_args, 27);
    }
    __pyx_v_comb = values[0];
    __pyx_v_currentseed = values[1];
    __pyx_v_y = values[2];
    __pyx_v_grid = values[3];
    __pyx_v_k = values[4];
    __pyx_v_size = values[5];
    __pyx_v_bandwidth = values[6];
    __pyx_v_bandwidth_mult = values[7];
    __pyx_v_bandwidth_adj = values[8];
    __pyx_v_thread_number = values[9];
    __pyx_v_direction = values[10];
    __pyx_v_num_top = values[11];
    __pyx_v_prefix = values[12];
    __pyx_v_figure_format = values[13];
    __pyx_v_ifSeed = values[14];
    __pyx_v_if_pval = values[15];
    __pyx_v_if_bootstrap = values[16];
    __pyx_v_if_cluster = values[17];
    __pyx_v_collapse = values[18];
    __pyx_v_seedcmap = values[19];
    __pyx_v_featurecmap = values[20];
    __pyx_v_nitr = values[21];
    __pyx_v_out_folder = values[22];
    __pyx_v_seed_name = values[23];
    __pyx_v_target_name = values[24];
    __pyx_v_gmt = values[25];
    __pyx_v_locusdic = values[26];
    __pyx_v_neighborhood = values[27];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("topmatch", 1, 28, 28, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1056, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.topmatch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_22topmatch(__pyx_self, __pyx_v_comb, __pyx_v_currentseed, __pyx_v_y, __pyx_v_grid, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_thread_number, __pyx_v_direction, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_ifSeed, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_collapse, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_nitr, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_target_name, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_22topmatch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_currentseed, PyObject *__pyx_v_y, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_direction, PyObject *__pyx_v_num_top, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_ifSeed, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_collapse, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_target_name, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("topmatch", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_topmatch(__pyx_v_comb, __pyx_v_currentseed, __pyx_v_y, __pyx_v_grid, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_thread_number, __pyx_v_direction, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_ifSeed, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_collapse, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_nitr, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_target_name, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.topmatch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1229
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef runBenchmark(target_file='no', # gct file for target(continuous or binary             # <<<<<<<<<<<<<<
 *                   feature_file='no', # gct file for features(binary)
 *                   seed_file='no', # file for seed, if not provided, feature file is used directly
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_25runBenchmark(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_runBenchmark(CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_runBenchmark *__pyx_optional_args) {
  PyObject *__pyx_v_target_file = ((PyObject *)__pyx_n_u_no);
  PyObject *__pyx_v_feature_file = ((PyObject *)__pyx_n_u_no);
  PyObject *__pyx_v_seed_file = ((PyObject *)__pyx_n_u_no);
  PyObject *__pyx_v_target_df = ((PyObject *)__pyx_n_u_no);
  PyObject *__pyx_v_feature_df = ((PyObject *)__pyx_n_u_no);
  PyObject *__pyx_v_seed_df = ((PyObject *)__pyx_n_u_no);
  PyObject *__pyx_v_prefix = ((PyObject *)__pyx_n_u_test);

  /* "revealer/REVEALER_runbenchmark.pyx":1236
 *                   seed_df='no', # dataframe for seed
 *                   prefix='test', # prefix for result files
 *                   seed_name=None, # names for seed, should be a list of string indicating the name of seed             # <<<<<<<<<<<<<<
 *                   grid=34, # number of grid, default is 34
 *                   target_name=0, # name/index of target in target file. can be int n for nth row, or string s for row with index s
 */
  PyObject *__pyx_v_seed_name = ((PyObject *)Py_None);
  PyObject *__pyx_v_grid = ((PyObject *)__pyx_int_34);
  PyObject *__pyx_v_target_name = ((PyObject *)__pyx_int_0);
  PyObject *__pyx_v_k = ((PyObject *)__pyx_int_5);
  PyObject *__pyx_v_bandwidth_mult = ((PyObject *)__pyx_float_0_65);
  PyObject *__pyx_v_bandwidth_adj = __pyx_k__6;
  PyObject *__pyx_v_direction = ((PyObject *)__pyx_n_u_pos);
  PyObject *__pyx_v_mode = ((PyObject *)__pyx_n_u_single);
  PyObject *__pyx_v_num_top = ((PyObject *)__pyx_int_30);
  PyObject *__pyx_v_low_threshold = ((PyObject *)__pyx_int_3);
  PyObject *__pyx_v_high_threshold = ((PyObject *)__pyx_int_100);

  /* "revealer/REVEALER_runbenchmark.pyx":1247
 *                   low_threshold=3, # lowest threshold that feature with less than this value occurence will be removed
 *                   high_threshold=100, # highest threshold that feature with less than this value occurence will be removed
 *                   collapse=True, # indicate if same features are collapsed together for intermediate files             # <<<<<<<<<<<<<<
 *                   normalize='zerobase', # normalize method for target
 *                   gene_locus='None', # gene_locus file indicating gene name and location of that gene
 */
  PyObject *__pyx_v_collapse = ((PyObject *)Py_True);
  PyObject *__pyx_v_normalize = ((PyObject *)__pyx_n_u_zerobase);
  PyObject *__pyx_v_gene_locus = ((PyObject *)__pyx_n_u_None);
  PyObject *__pyx_v_verbose = ((PyObject *)__pyx_int_1);
  PyObject *__pyx_v_max_iteration = ((PyObject *)__pyx_int_neg_1);
  PyObject *__pyx_v_thread_number = ((PyObject *)__pyx_int_1);
  PyObject *__pyx_v_figure_format = ((PyObject *)__pyx_n_u_pdf);
  PyObject *__pyx_v_subset = ((PyObject *)__pyx_n_u_no);

  /* "revealer/REVEALER_runbenchmark.pyx":1255
 *                   figure_format='pdf', # format for result figure
 *                   subset='no', # if list of string passed, only columns in this list is picked for calculation
 *                   if_pval=True, # if True, p-values are calculated for all result             # <<<<<<<<<<<<<<
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF
 */
  PyObject *__pyx_v_if_pval = ((PyObject *)Py_True);

  /* "revealer/REVEALER_runbenchmark.pyx":1256
 *                   subset='no', # if list of string passed, only columns in this list is picked for calculation
 *                   if_pval=True, # if True, p-values are calculated for all result
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result             # <<<<<<<<<<<<<<
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported
 */
  PyObject *__pyx_v_if_bootstrap = ((PyObject *)Py_True);

  /* "revealer/REVEALER_runbenchmark.pyx":1257
 *                   if_pval=True, # if True, p-values are calculated for all result
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF             # <<<<<<<<<<<<<<
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported
 *                   out_folder='.', # folder to put output files inside
 */
  PyObject *__pyx_v_if_cluster = ((PyObject *)Py_False);

  /* "revealer/REVEALER_runbenchmark.pyx":1258
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported             # <<<<<<<<<<<<<<
 *                   out_folder='.', # folder to put output files inside
 *                   gene_set=None,
 */
  PyObject *__pyx_v_if_intermediate = ((PyObject *)Py_False);
  PyObject *__pyx_v_out_folder = ((PyObject *)__pyx_kp_u__7);

  /* "revealer/REVEALER_runbenchmark.pyx":1260
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported
 *                   out_folder='.', # folder to put output files inside
 *                   gene_set=None,             # <<<<<<<<<<<<<<
 *                   gene_separator='_',
 *                   gmt_file = None,
 */
  PyObject *__pyx_v_gene_set = ((PyObject *)Py_None);
  PyObject *__pyx_v_gene_separator = ((PyObject *)__pyx_n_u__8);

  /* "revealer/REVEALER_runbenchmark.pyx":1262
 *                   gene_set=None,
 *                   gene_separator='_',
 *                   gmt_file = None,             # <<<<<<<<<<<<<<
 *                   alpha = 1,
 *                   neighborhood = 4,
 */
  PyObject *__pyx_v_gmt_file = ((PyObject *)Py_None);
  PyObject *__pyx_v_alpha = ((PyObject *)__pyx_int_1);
  PyObject *__pyx_v_neighborhood = ((PyObject *)__pyx_int_4);

  /* "revealer/REVEALER_runbenchmark.pyx":1265
 *                   alpha = 1,
 *                   neighborhood = 4,
 *                   tissue_file = None,             # <<<<<<<<<<<<<<
 *                   gzip = True
 *                  ):
 */
  PyObject *__pyx_v_tissue_file = ((PyObject *)Py_None);

  /* "revealer/REVEALER_runbenchmark.pyx":1266
 *                   neighborhood = 4,
 *                   tissue_file = None,
 *                   gzip = True             # <<<<<<<<<<<<<<
 *                  ):
 * 
 */
  PyObject *__pyx_v_gzip = ((PyObject *)Py_True);
  PyObject *__pyx_v_report = NULL;
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_comb = NULL;
  PyObject *__pyx_v_locusdic = NULL;
  PyObject *__pyx_v_rmrow = NULL;
  PyObject *__pyx_v_i = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_origcomb = NULL;
  PyObject *__pyx_v_gmt = NULL;
  Py_ssize_t __pyx_v_ind;
  CYTHON_UNUSED PyObject *__pyx_v_featuresdf = NULL;
  PyObject *__pyx_v_seed = NULL;
  PyObject *__pyx_v_CICs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runBenchmark", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_target_file = __pyx_optional_args->target_file;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_feature_file = __pyx_optional_args->feature_file;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_seed_file = __pyx_optional_args->seed_file;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_target_df = __pyx_optional_args->target_df;
            if (__pyx_optional_args->__pyx_n > 4) {
              __pyx_v_feature_df = __pyx_optional_args->feature_df;
              if (__pyx_optional_args->__pyx_n > 5) {
                __pyx_v_seed_df = __pyx_optional_args->seed_df;
                if (__pyx_optional_args->__pyx_n > 6) {
                  __pyx_v_prefix = __pyx_optional_args->prefix;
                  if (__pyx_optional_args->__pyx_n > 7) {
                    __pyx_v_seed_name = __pyx_optional_args->seed_name;
                    if (__pyx_optional_args->__pyx_n > 8) {
                      __pyx_v_grid = __pyx_optional_args->grid;
                      if (__pyx_optional_args->__pyx_n > 9) {
                        __pyx_v_target_name = __pyx_optional_args->target_name;
                        if (__pyx_optional_args->__pyx_n > 10) {
                          __pyx_v_k = __pyx_optional_args->k;
                          if (__pyx_optional_args->__pyx_n > 11) {
                            __pyx_v_bandwidth_mult = __pyx_optional_args->bandwidth_mult;
                            if (__pyx_optional_args->__pyx_n > 12) {
                              __pyx_v_bandwidth_adj = __pyx_optional_args->bandwidth_adj;
                              if (__pyx_optional_args->__pyx_n > 13) {
                                __pyx_v_direction = __pyx_optional_args->direction;
                                if (__pyx_optional_args->__pyx_n > 14) {
                                  __pyx_v_mode = __pyx_optional_args->mode;
                                  if (__pyx_optional_args->__pyx_n > 15) {
                                    __pyx_v_num_top = __pyx_optional_args->num_top;
                                    if (__pyx_optional_args->__pyx_n > 16) {
                                      __pyx_v_low_threshold = __pyx_optional_args->low_threshold;
                                      if (__pyx_optional_args->__pyx_n > 17) {
                                        __pyx_v_high_threshold = __pyx_optional_args->high_threshold;
                                        if (__pyx_optional_args->__pyx_n > 18) {
                                          __pyx_v_collapse = __pyx_optional_args->collapse;
                                          if (__pyx_optional_args->__pyx_n > 19) {
                                            __pyx_v_normalize = __pyx_optional_args->normalize;
                                            if (__pyx_optional_args->__pyx_n > 20) {
                                              __pyx_v_gene_locus = __pyx_optional_args->gene_locus;
                                              if (__pyx_optional_args->__pyx_n > 21) {
                                                __pyx_v_verbose = __pyx_optional_args->verbose;
                                                if (__pyx_optional_args->__pyx_n > 22) {
                                                  __pyx_v_max_iteration = __pyx_optional_args->max_iteration;
                                                  if (__pyx_optional_args->__pyx_n > 23) {
                                                    __pyx_v_thread_number = __pyx_optional_args->thread_number;
                                                    if (__pyx_optional_args->__pyx_n > 24) {
                                                      __pyx_v_figure_format = __pyx_optional_args->figure_format;
                                                      if (__pyx_optional_args->__pyx_n > 25) {
                                                        __pyx_v_subset = __pyx_optional_args->subset;
                                                        if (__pyx_optional_args->__pyx_n > 26) {
                                                          __pyx_v_if_pval = __pyx_optional_args->if_pval;
                                                          if (__pyx_optional_args->__pyx_n > 27) {
                                                            __pyx_v_if_bootstrap = __pyx_optional_args->if_bootstrap;
                                                            if (__pyx_optional_args->__pyx_n > 28) {
                                                              __pyx_v_if_cluster = __pyx_optional_args->if_cluster;
                                                              if (__pyx_optional_args->__pyx_n > 29) {
                                                                __pyx_v_if_intermediate = __pyx_optional_args->if_intermediate;
                                                                if (__pyx_optional_args->__pyx_n > 30) {
                                                                  __pyx_v_out_folder = __pyx_optional_args->out_folder;
                                                                  if (__pyx_optional_args->__pyx_n > 31) {
                                                                    __pyx_v_gene_set = __pyx_optional_args->gene_set;
                                                                    if (__pyx_optional_args->__pyx_n > 32) {
                                                                      __pyx_v_gene_separator = __pyx_optional_args->gene_separator;
                                                                      if (__pyx_optional_args->__pyx_n > 33) {
                                                                        __pyx_v_gmt_file = __pyx_optional_args->gmt_file;
                                                                        if (__pyx_optional_args->__pyx_n > 34) {
                                                                          __pyx_v_alpha = __pyx_optional_args->alpha;
                                                                          if (__pyx_optional_args->__pyx_n > 35) {
                                                                            __pyx_v_neighborhood = __pyx_optional_args->neighborhood;
                                                                            if (__pyx_optional_args->__pyx_n > 36) {
                                                                              __pyx_v_tissue_file = __pyx_optional_args->tissue_file;
                                                                              if (__pyx_optional_args->__pyx_n > 37) {
                                                                                __pyx_v_gzip = __pyx_optional_args->gzip;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  __Pyx_INCREF(__pyx_v_seed_file);
  __Pyx_INCREF(__pyx_v_target_df);
  __Pyx_INCREF(__pyx_v_seed_df);
  __Pyx_INCREF(__pyx_v_thread_number);
  __Pyx_INCREF(__pyx_v_out_folder);

  /* "revealer/REVEALER_runbenchmark.pyx":1269
 *                  ):
 * 
 *     report = ''             # <<<<<<<<<<<<<<
 * 
 *     if verbose != 0:
 */
  __Pyx_INCREF(__pyx_kp_u__2);
  __pyx_v_report = __pyx_kp_u__2;

  /* "revealer/REVEALER_runbenchmark.pyx":1271
 *     report = ''
 * 
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print(prefix+' start!')
 *     report = report + 'Run name: ' + str(prefix) + '\n'
 */
  __pyx_t_1 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":1272
 * 
 *     if verbose != 0:
 *         print(prefix+' start!')             # <<<<<<<<<<<<<<
 *     report = report + 'Run name: ' + str(prefix) + '\n'
 * 
 */
    __pyx_t_1 = PyNumber_Add(__pyx_v_prefix, __pyx_kp_u_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1271
 *     report = ''
 * 
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print(prefix+' start!')
 *     report = report + 'Run name: ' + str(prefix) + '\n'
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1273
 *     if verbose != 0:
 *         print(prefix+' start!')
 *     report = report + 'Run name: ' + str(prefix) + '\n'             # <<<<<<<<<<<<<<
 * 
 *     # if / is not at the end of output folder, add it.
 */
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_v_report, __pyx_kp_u_Run_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1276
 * 
 *     # if / is not at the end of output folder, add it.
 *     if out_folder[-1] != '/':             # <<<<<<<<<<<<<<
 *         out_folder = out_folder + '/'
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_out_folder, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__10, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":1277
 *     # if / is not at the end of output folder, add it.
 *     if out_folder[-1] != '/':
 *         out_folder = out_folder + '/'             # <<<<<<<<<<<<<<
 * 
 *     # if output folder does not exist, make it
 */
    __pyx_t_1 = PyNumber_Add(__pyx_v_out_folder, __pyx_kp_u__10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_out_folder, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1276
 * 
 *     # if / is not at the end of output folder, add it.
 *     if out_folder[-1] != '/':             # <<<<<<<<<<<<<<
 *         out_folder = out_folder + '/'
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1280
 * 
 *     # if output folder does not exist, make it
 *     if not os.path.exists(out_folder):             # <<<<<<<<<<<<<<
 *         os.makedirs(out_folder)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exists); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, __pyx_v_out_folder) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_out_folder);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = ((!__pyx_t_2) != 0);
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1281
 *     # if output folder does not exist, make it
 *     if not os.path.exists(out_folder):
 *         os.makedirs(out_folder)             # <<<<<<<<<<<<<<
 * 
 *     start = time.time()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_makedirs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_out_folder) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_out_folder);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1280
 * 
 *     # if output folder does not exist, make it
 *     if not os.path.exists(out_folder):             # <<<<<<<<<<<<<<
 *         os.makedirs(out_folder)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1283
 *         os.makedirs(out_folder)
 * 
 *     start = time.time()             # <<<<<<<<<<<<<<
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \
 *        (target_file == 'no' or feature_file == 'no') :
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1284
 * 
 *     start = time.time()
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \             # <<<<<<<<<<<<<<
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")
 */
  __pyx_t_2 = PyUnicode_Check(__pyx_v_target_df); 
  __pyx_t_6 = (__pyx_t_2 != 0);
  if (!__pyx_t_6) {
  } else {
    goto __pyx_L8_next_and;
  }
  __pyx_t_6 = PyUnicode_Check(__pyx_v_feature_df); 
  __pyx_t_2 = (__pyx_t_6 != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_5 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_L8_next_and:;

  /* "revealer/REVEALER_runbenchmark.pyx":1285
 *     start = time.time()
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \
 *        (target_file == 'no' or feature_file == 'no') :             # <<<<<<<<<<<<<<
 *         raise Exception("Please put input!")
 *     if mp.cpu_count() <thread_number:
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_target_file, __pyx_n_u_no, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1285, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_5 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_feature_file, __pyx_n_u_no, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1285, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;

  /* "revealer/REVEALER_runbenchmark.pyx":1284
 * 
 *     start = time.time()
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \             # <<<<<<<<<<<<<<
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")
 */
  if (unlikely(__pyx_t_5)) {

    /* "revealer/REVEALER_runbenchmark.pyx":1286
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")             # <<<<<<<<<<<<<<
 *     if mp.cpu_count() <thread_number:
 *         if verbose != 0:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1286, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1284
 * 
 *     start = time.time()
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \             # <<<<<<<<<<<<<<
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1287
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")
 *     if mp.cpu_count() <thread_number:             # <<<<<<<<<<<<<<
 *         if verbose != 0:
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_mp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_cpu_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_v_thread_number, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1288
 *         raise Exception("Please put input!")
 *     if mp.cpu_count() <thread_number:
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 *         thread_number = mp.cpu_count()
 */
    __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1288, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":1289
 *     if mp.cpu_count() <thread_number:
 *         if verbose != 0:
 *             print('Indicated Core Number exceed maximum available core. All core is used')             # <<<<<<<<<<<<<<
 *         thread_number = mp.cpu_count()
 *     if thread_number == -1:
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1288
 *         raise Exception("Please put input!")
 *     if mp.cpu_count() <thread_number:
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 *         thread_number = mp.cpu_count()
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1290
 *         if verbose != 0:
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 *         thread_number = mp.cpu_count()             # <<<<<<<<<<<<<<
 *     if thread_number == -1:
 *         thread_number = mp.cpu_count()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_mp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_cpu_count); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_thread_number, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1287
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")
 *     if mp.cpu_count() <thread_number:             # <<<<<<<<<<<<<<
 *         if verbose != 0:
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1291
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 *         thread_number = mp.cpu_count()
 *     if thread_number == -1:             # <<<<<<<<<<<<<<
 *         thread_number = mp.cpu_count()
 *         if verbose != 0:
 */
  __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_thread_number, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1292
 *         thread_number = mp.cpu_count()
 *     if thread_number == -1:
 *         thread_number = mp.cpu_count()             # <<<<<<<<<<<<<<
 *         if verbose != 0:
 *             print('All core('+str(thread_number)+') Used')
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_mp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_cpu_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_thread_number, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1293
 *     if thread_number == -1:
 *         thread_number = mp.cpu_count()
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('All core('+str(thread_number)+') Used')
 *     report = report + 'Number of thread used: ' + str(thread_number) + '\n'
 */
    __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1293, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":1294
 *         thread_number = mp.cpu_count()
 *         if verbose != 0:
 *             print('All core('+str(thread_number)+') Used')             # <<<<<<<<<<<<<<
 *     report = report + 'Number of thread used: ' + str(thread_number) + '\n'
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_thread_number); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1294, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u_All_core, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1294, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u_Used); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1294, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1294, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1293
 *     if thread_number == -1:
 *         thread_number = mp.cpu_count()
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('All core('+str(thread_number)+') Used')
 *     report = report + 'Number of thread used: ' + str(thread_number) + '\n'
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1291
 *             print('Indicated Core Number exceed maximum available core. All core is used')
 *         thread_number = mp.cpu_count()
 *     if thread_number == -1:             # <<<<<<<<<<<<<<
 *         thread_number = mp.cpu_count()
 *         if verbose != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1295
 *         if verbose != 0:
 *             print('All core('+str(thread_number)+') Used')
 *     report = report + 'Number of thread used: ' + str(thread_number) + '\n'             # <<<<<<<<<<<<<<
 * 
 *     if seed_file == 'no':
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Number_of_thread_used); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_thread_number); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1297
 *     report = report + 'Number of thread used: ' + str(thread_number) + '\n'
 * 
 *     if seed_file == 'no':             # <<<<<<<<<<<<<<
 *         seed_file = feature_file
 *     if isinstance(feature_df,str):
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_seed_file, __pyx_n_u_no, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1297, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1298
 * 
 *     if seed_file == 'no':
 *         seed_file = feature_file             # <<<<<<<<<<<<<<
 *     if isinstance(feature_df,str):
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,
 */
    __Pyx_INCREF(__pyx_v_feature_file);
    __Pyx_DECREF_SET(__pyx_v_seed_file, __pyx_v_feature_file);

    /* "revealer/REVEALER_runbenchmark.pyx":1297
 *     report = report + 'Number of thread used: ' + str(thread_number) + '\n'
 * 
 *     if seed_file == 'no':             # <<<<<<<<<<<<<<
 *         seed_file = feature_file
 *     if isinstance(feature_df,str):
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1299
 *     if seed_file == 'no':
 *         seed_file = feature_file
 *     if isinstance(feature_df,str):             # <<<<<<<<<<<<<<
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,
 */
  __pyx_t_5 = PyUnicode_Check(__pyx_v_feature_df); 
  __pyx_t_2 = (__pyx_t_5 != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":1300
 *         seed_file = feature_file
 *     if isinstance(feature_df,str):
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,             # <<<<<<<<<<<<<<
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,
 *                          direction = direction, gene_locus = gene_locus,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_readInput); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_target_file, __pyx_v_target_file) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_feature_file, __pyx_v_feature_file) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1301
 *     if isinstance(feature_df,str):
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,             # <<<<<<<<<<<<<<
 *                          direction = direction, gene_locus = gene_locus,
 *                          low_threshold = low_threshold, high_threshold = high_threshold,
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_seed_file, __pyx_v_seed_file) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_seed_name, __pyx_v_seed_name) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_target_name, __pyx_v_target_name) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1302
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,
 *                          direction = direction, gene_locus = gene_locus,             # <<<<<<<<<<<<<<
 *                          low_threshold = low_threshold, high_threshold = high_threshold,
 *                          subset = subset, gene_set = gene_set,
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_direction, __pyx_v_direction) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_gene_locus, __pyx_v_gene_locus) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1303
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,
 *                          direction = direction, gene_locus = gene_locus,
 *                          low_threshold = low_threshold, high_threshold = high_threshold,             # <<<<<<<<<<<<<<
 *                          subset = subset, gene_set = gene_set,
 *                          gene_separator = gene_separator, thread_number = thread_number,
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_low_threshold, __pyx_v_low_threshold) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_high_threshold, __pyx_v_high_threshold) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1304
 *                          direction = direction, gene_locus = gene_locus,
 *                          low_threshold = low_threshold, high_threshold = high_threshold,
 *                          subset = subset, gene_set = gene_set,             # <<<<<<<<<<<<<<
 *                          gene_separator = gene_separator, thread_number = thread_number,
 *                          tissue_file = tissue_file)
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_subset, __pyx_v_subset) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_gene_set, __pyx_v_gene_set) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1305
 *                          low_threshold = low_threshold, high_threshold = high_threshold,
 *                          subset = subset, gene_set = gene_set,
 *                          gene_separator = gene_separator, thread_number = thread_number,             # <<<<<<<<<<<<<<
 *                          tissue_file = tissue_file)
 *     else:
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_gene_separator, __pyx_v_gene_separator) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1306
 *                          subset = subset, gene_set = gene_set,
 *                          gene_separator = gene_separator, thread_number = thread_number,
 *                          tissue_file = tissue_file)             # <<<<<<<<<<<<<<
 *     else:
 *         if isinstance(seed_df,str):
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_tissue_file, __pyx_v_tissue_file) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1300
 *         seed_file = feature_file
 *     if isinstance(feature_df,str):
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,             # <<<<<<<<<<<<<<
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,
 *                          direction = direction, gene_locus = gene_locus,
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1300, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L17_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L17_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 1300, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L18_unpacking_done;
      __pyx_L17_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1300, __pyx_L1_error)
      __pyx_L18_unpacking_done:;
    }
    __pyx_v_comb = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_locusdic = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1299
 *     if seed_file == 'no':
 *         seed_file = feature_file
 *     if isinstance(feature_df,str):             # <<<<<<<<<<<<<<
 *         comb,locusdic = readInput(target_file = target_file, feature_file = feature_file,
 *                          seed_file = seed_file, seed_name = seed_name, target_name = target_name,
 */
    goto __pyx_L16;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1308
 *                          tissue_file = tissue_file)
 *     else:
 *         if isinstance(seed_df,str):             # <<<<<<<<<<<<<<
 *             comb = pd.concat([target_df,feature_df], join='inner')
 *         else:
 */
  /*else*/ {
    __pyx_t_2 = PyUnicode_Check(__pyx_v_seed_df); 
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":1309
 *     else:
 *         if isinstance(seed_df,str):
 *             comb = pd.concat([target_df,feature_df], join='inner')             # <<<<<<<<<<<<<<
 *         else:
 *             comb = pd.concat([target_df,seed_df,feature_df], join='inner')
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_concat); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_target_df);
      __Pyx_GIVEREF(__pyx_v_target_df);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_target_df);
      __Pyx_INCREF(__pyx_v_feature_df);
      __Pyx_GIVEREF(__pyx_v_feature_df);
      PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_feature_df);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_join, __pyx_n_u_inner) < 0) __PYX_ERR(0, 1309, __pyx_L1_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_comb = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1308
 *                          tissue_file = tissue_file)
 *     else:
 *         if isinstance(seed_df,str):             # <<<<<<<<<<<<<<
 *             comb = pd.concat([target_df,feature_df], join='inner')
 *         else:
 */
      goto __pyx_L19;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1311
 *             comb = pd.concat([target_df,feature_df], join='inner')
 *         else:
 *             comb = pd.concat([target_df,seed_df,feature_df], join='inner')             # <<<<<<<<<<<<<<
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pd); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_concat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_target_df);
      __Pyx_GIVEREF(__pyx_v_target_df);
      PyList_SET_ITEM(__pyx_t_7, 0, __pyx_v_target_df);
      __Pyx_INCREF(__pyx_v_seed_df);
      __Pyx_GIVEREF(__pyx_v_seed_df);
      PyList_SET_ITEM(__pyx_t_7, 1, __pyx_v_seed_df);
      __Pyx_INCREF(__pyx_v_feature_df);
      __Pyx_GIVEREF(__pyx_v_feature_df);
      PyList_SET_ITEM(__pyx_t_7, 2, __pyx_v_feature_df);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_join, __pyx_n_u_inner) < 0) __PYX_ERR(0, 1311, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_comb = __pyx_t_3;
      __pyx_t_3 = 0;
    }
    __pyx_L19:;

    /* "revealer/REVEALER_runbenchmark.pyx":1312
 *         else:
 *             comb = pd.concat([target_df,seed_df,feature_df], join='inner')
 *         rmrow=[]             # <<<<<<<<<<<<<<
 *         for i in comb.index.tolist()[2:]:
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_rmrow = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1313
 *             comb = pd.concat([target_df,seed_df,feature_df], join='inner')
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:             # <<<<<<<<<<<<<<
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_3, 2, 0, NULL, NULL, &__pyx_slice__13, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3); __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1313, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 1313, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 1313, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1313, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_10(__pyx_t_3);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1313, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1314
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \             # <<<<<<<<<<<<<<
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 *                 rmrow.append(i)
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_7, __pyx_v_low_threshold, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_2) {
      } else {
        __pyx_t_5 = __pyx_t_2;
        goto __pyx_L23_bool_binop_done;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1315
 *         for i in comb.index.tolist()[2:]:
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \
 *                sum(comb.loc[i].tolist()) >= high_threshold:             # <<<<<<<<<<<<<<
 *                 rmrow.append(i)
 *         comb = comb.drop(index=rmrow)
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_7, __pyx_v_high_threshold, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1315, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __pyx_t_2;
      __pyx_L23_bool_binop_done:;

      /* "revealer/REVEALER_runbenchmark.pyx":1314
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \             # <<<<<<<<<<<<<<
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 *                 rmrow.append(i)
 */
      if (__pyx_t_5) {

        /* "revealer/REVEALER_runbenchmark.pyx":1316
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 *                 rmrow.append(i)             # <<<<<<<<<<<<<<
 *         comb = comb.drop(index=rmrow)
 *         comb = comb.rename(index={seed_name[0]: 'firstseed'})
 */
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_rmrow, __pyx_v_i); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 1316, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":1314
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \             # <<<<<<<<<<<<<<
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 *                 rmrow.append(i)
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1313
 *             comb = pd.concat([target_df,seed_df,feature_df], join='inner')
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:             # <<<<<<<<<<<<<<
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1317
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 *                 rmrow.append(i)
 *         comb = comb.drop(index=rmrow)             # <<<<<<<<<<<<<<
 *         comb = comb.rename(index={seed_name[0]: 'firstseed'})
 *         origcomb = comb.copy()
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_drop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_index, __pyx_v_rmrow) < 0) __PYX_ERR(0, 1317, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1318
 *                 rmrow.append(i)
 *         comb = comb.drop(index=rmrow)
 *         comb = comb.rename(index={seed_name[0]: 'firstseed'})             # <<<<<<<<<<<<<<
 *         origcomb = comb.copy()
 *         #seed_name = ['firstseed']
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_rename); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_3, __pyx_t_1, __pyx_n_u_firstseed) < 0) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_index, __pyx_t_3) < 0) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1319
 *         comb = comb.drop(index=rmrow)
 *         comb = comb.rename(index={seed_name[0]: 'firstseed'})
 *         origcomb = comb.copy()             # <<<<<<<<<<<<<<
 *         #seed_name = ['firstseed']
 *         locusdic = None
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_origcomb = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1321
 *         origcomb = comb.copy()
 *         #seed_name = ['firstseed']
 *         locusdic = None             # <<<<<<<<<<<<<<
 *     if verbose != 0:
 *         print('Time used to read input: %s second(s)'%(int(time.time() - start)))
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_locusdic = Py_None;
  }
  __pyx_L16:;

  /* "revealer/REVEALER_runbenchmark.pyx":1322
 *         #seed_name = ['firstseed']
 *         locusdic = None
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('Time used to read input: %s second(s)'%(int(time.time() - start)))
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1323
 *         locusdic = None
 *     if verbose != 0:
 *         print('Time used to read input: %s second(s)'%(int(time.time() - start)))             # <<<<<<<<<<<<<<
 * 
 *     if gmt_file != None:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Subtract(__pyx_t_3, __pyx_v_start); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Time_used_to_read_input_s_second, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1322
 *         #seed_name = ['firstseed']
 *         locusdic = None
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('Time used to read input: %s second(s)'%(int(time.time() - start)))
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1325
 *         print('Time used to read input: %s second(s)'%(int(time.time() - start)))
 * 
 *     if gmt_file != None:             # <<<<<<<<<<<<<<
 *         gmt = pd.read_csv(gmt_file,sep='\t',header=None,index_col=0)
 *         gmt = gmt.drop(columns=gmt.columns[0])
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_gmt_file, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1326
 * 
 *     if gmt_file != None:
 *         gmt = pd.read_csv(gmt_file,sep='\t',header=None,index_col=0)             # <<<<<<<<<<<<<<
 *         gmt = gmt.drop(columns=gmt.columns[0])
 *         gmt.index = gmt.index.str.replace("-", "_")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_gmt_file);
    __Pyx_GIVEREF(__pyx_v_gmt_file);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_gmt_file);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_header, Py_None) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_gmt = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1327
 *     if gmt_file != None:
 *         gmt = pd.read_csv(gmt_file,sep='\t',header=None,index_col=0)
 *         gmt = gmt.drop(columns=gmt.columns[0])             # <<<<<<<<<<<<<<
 *         gmt.index = gmt.index.str.replace("-", "_")
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_gmt, __pyx_n_s_drop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_gmt, __pyx_n_s_columns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_columns, __pyx_t_7) < 0) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_gmt, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1328
 *         gmt = pd.read_csv(gmt_file,sep='\t',header=None,index_col=0)
 *         gmt = gmt.drop(columns=gmt.columns[0])
 *         gmt.index = gmt.index.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_replace); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_gmt, __pyx_n_s_index, __pyx_t_4) < 0) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1329
 *         gmt = gmt.drop(columns=gmt.columns[0])
 *         gmt.index = gmt.index.str.replace("-", "_")
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')
 *             gmt = None
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PySet_New(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PySet_New(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_And(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PySequence_List(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = PyList_GET_SIZE(__pyx_t_3); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = ((__pyx_t_9 == 0) != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_5 = __pyx_t_2;
      goto __pyx_L28_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __pyx_t_2;
    __pyx_L28_bool_binop_done:;
    if (__pyx_t_5) {

      /* "revealer/REVEALER_runbenchmark.pyx":1330
 *         gmt.index = gmt.index.str.replace("-", "_")
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')             # <<<<<<<<<<<<<<
 *             gmt = None
 *     else:
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1331
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')
 *             gmt = None             # <<<<<<<<<<<<<<
 *     else:
 *         gmt = None
 */
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_gmt, Py_None);

      /* "revealer/REVEALER_runbenchmark.pyx":1329
 *         gmt = gmt.drop(columns=gmt.columns[0])
 *         gmt.index = gmt.index.str.replace("-", "_")
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')
 *             gmt = None
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1325
 *         print('Time used to read input: %s second(s)'%(int(time.time() - start)))
 * 
 *     if gmt_file != None:             # <<<<<<<<<<<<<<
 *         gmt = pd.read_csv(gmt_file,sep='\t',header=None,index_col=0)
 *         gmt = gmt.drop(columns=gmt.columns[0])
 */
    goto __pyx_L26;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1333
 *             gmt = None
 *     else:
 *         gmt = None             # <<<<<<<<<<<<<<
 * 
 *     if mode == 'multi':
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_gmt = Py_None;
  }
  __pyx_L26:;

  /* "revealer/REVEALER_runbenchmark.pyx":1335
 *         gmt = None
 * 
 *     if mode == 'multi':             # <<<<<<<<<<<<<<
 *         for ind in range(len(prefix)):
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_mode, __pyx_n_u_multi, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1335, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1336
 * 
 *     if mode == 'multi':
 *         for ind in range(len(prefix)):             # <<<<<<<<<<<<<<
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,
 *                                                            grid = grid[ind], k = k[ind],
 */
    __pyx_t_9 = PyObject_Length(__pyx_v_prefix); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1336, __pyx_L1_error)
    __pyx_t_12 = __pyx_t_9;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_ind = __pyx_t_13;

      /* "revealer/REVEALER_runbenchmark.pyx":1337
 *     if mode == 'multi':
 *         for ind in range(len(prefix)):
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,             # <<<<<<<<<<<<<<
 *                                                            grid = grid[ind], k = k[ind],
 *                                                            bandwidth_mult = bandwidth_mult[ind],
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_prefix, __pyx_v_ind, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "revealer/REVEALER_runbenchmark.pyx":1338
 *         for ind in range(len(prefix)):
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,
 *                                                            grid = grid[ind], k = k[ind],             # <<<<<<<<<<<<<<
 *                                                            bandwidth_mult = bandwidth_mult[ind],
 *                                                            bandwidth_adj = bandwidth_adj[ind],
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_grid, __pyx_v_ind, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_k, __pyx_v_ind, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "revealer/REVEALER_runbenchmark.pyx":1339
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,
 *                                                            grid = grid[ind], k = k[ind],
 *                                                            bandwidth_mult = bandwidth_mult[ind],             # <<<<<<<<<<<<<<
 *                                                            bandwidth_adj = bandwidth_adj[ind],
 *                                                            direction = direction, num_top = num_top,
 */
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_bandwidth_mult, __pyx_v_ind, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1339, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "revealer/REVEALER_runbenchmark.pyx":1340
 *                                                            grid = grid[ind], k = k[ind],
 *                                                            bandwidth_mult = bandwidth_mult[ind],
 *                                                            bandwidth_adj = bandwidth_adj[ind],             # <<<<<<<<<<<<<<
 *                                                            direction = direction, num_top = num_top,
 *                                                            verbose = verbose,
 */
      __pyx_t_14 = __Pyx_GetItemInt(__pyx_v_bandwidth_adj, __pyx_v_ind, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1340, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);

      /* "revealer/REVEALER_runbenchmark.pyx":1337
 *     if mode == 'multi':
 *         for ind in range(len(prefix)):
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,             # <<<<<<<<<<<<<<
 *                                                            grid = grid[ind], k = k[ind],
 *                                                            bandwidth_mult = bandwidth_mult[ind],
 */
      __pyx_t_15 = __pyx_f_8revealer_21REVEALER_runbenchmark_REVEALERInner(__pyx_t_3, __pyx_v_comb, __pyx_t_4, __pyx_t_1, __pyx_t_7, __pyx_t_14, __pyx_v_direction, __pyx_v_num_top, __pyx_v_verbose, __pyx_v_max_iteration, __pyx_v_collapse, __pyx_v_thread_number, __pyx_v_figure_format, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_if_intermediate, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_normalize, __pyx_v_target_name, __pyx_v_report, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_alpha, __pyx_v_neighborhood, __pyx_v_tissue_file, __pyx_v_gzip, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_15))) || (PyList_CheckExact(__pyx_t_15))) {
        PyObject* sequence = __pyx_t_15;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1337, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_14 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_14 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_1 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        #else
        __pyx_t_14 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext;
        index = 0; __pyx_t_14 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_14)) goto __pyx_L33_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_14);
        index = 1; __pyx_t_7 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_7)) goto __pyx_L33_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 2; __pyx_t_1 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L33_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_4), 3) < 0) __PYX_ERR(0, 1337, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L34_unpacking_done;
        __pyx_L33_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1337, __pyx_L1_error)
        __pyx_L34_unpacking_done:;
      }
      __Pyx_DECREF_SET(__pyx_v_target_df, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_DECREF_SET(__pyx_v_seed_df, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_featuresdf, __pyx_t_1);
      __pyx_t_1 = 0;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1335
 *         gmt = None
 * 
 *     if mode == 'multi':             # <<<<<<<<<<<<<<
 *         for ind in range(len(prefix)):
 *             target_df, seed_df, featuresdf = REVEALERInner(prefix = prefix[ind], comb = comb,
 */
    goto __pyx_L30;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1362
 *                                                            gzip = gzip)
 * 
 *     elif mode == 'single':             # <<<<<<<<<<<<<<
 *         #target_df, seed_df, featuresdf
 *         seed, CICs = REVEALERInner(prefix = prefix, comb = comb, grid = grid,
 */
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_mode, __pyx_n_u_single, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1362, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":1364
 *     elif mode == 'single':
 *         #target_df, seed_df, featuresdf
 *         seed, CICs = REVEALERInner(prefix = prefix, comb = comb, grid = grid,             # <<<<<<<<<<<<<<
 *                                                        k = k, bandwidth_mult = bandwidth_mult,
 *                                                        normalize = normalize,
 */
    __pyx_t_15 = __pyx_f_8revealer_21REVEALER_runbenchmark_REVEALERInner(__pyx_v_prefix, __pyx_v_comb, __pyx_v_grid, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_num_top, __pyx_v_verbose, __pyx_v_max_iteration, __pyx_v_collapse, __pyx_v_thread_number, __pyx_v_figure_format, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_if_intermediate, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_normalize, __pyx_v_target_name, __pyx_v_report, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_alpha, __pyx_v_neighborhood, __pyx_v_tissue_file, __pyx_v_gzip, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    if ((likely(PyTuple_CheckExact(__pyx_t_15))) || (PyList_CheckExact(__pyx_t_15))) {
      PyObject* sequence = __pyx_t_15;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1364, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_14 = PyObject_GetIter(__pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_14)->tp_iternext;
      index = 0; __pyx_t_1 = __pyx_t_8(__pyx_t_14); if (unlikely(!__pyx_t_1)) goto __pyx_L35_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 1; __pyx_t_7 = __pyx_t_8(__pyx_t_14); if (unlikely(!__pyx_t_7)) goto __pyx_L35_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_14), 2) < 0) __PYX_ERR(0, 1364, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      goto __pyx_L36_unpacking_done;
      __pyx_L35_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1364, __pyx_L1_error)
      __pyx_L36_unpacking_done:;
    }
    __pyx_v_seed = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v_CICs = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1362
 *                                                            gzip = gzip)
 * 
 *     elif mode == 'single':             # <<<<<<<<<<<<<<
 *         #target_df, seed_df, featuresdf
 *         seed, CICs = REVEALERInner(prefix = prefix, comb = comb, grid = grid,
 */
  }
  __pyx_L30:;

  /* "revealer/REVEALER_runbenchmark.pyx":1388
 *                                                        gzip = gzip)
 * 
 *     return seed, CICs#target_df, seed_df, featuresdf             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_seed)) { __Pyx_RaiseUnboundLocalError("seed"); __PYX_ERR(0, 1388, __pyx_L1_error) }
  if (unlikely(!__pyx_v_CICs)) { __Pyx_RaiseUnboundLocalError("CICs"); __PYX_ERR(0, 1388, __pyx_L1_error) }
  __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_INCREF(__pyx_v_seed);
  __Pyx_GIVEREF(__pyx_v_seed);
  PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_v_seed);
  __Pyx_INCREF(__pyx_v_CICs);
  __Pyx_GIVEREF(__pyx_v_CICs);
  PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_v_CICs);
  __pyx_r = __pyx_t_15;
  __pyx_t_15 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1229
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef runBenchmark(target_file='no', # gct file for target(continuous or binary             # <<<<<<<<<<<<<<
 *                   feature_file='no', # gct file for features(binary)
 *                   seed_file='no', # file for seed, if not provided, feature file is used directly
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBenchmark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_report);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_comb);
  __Pyx_XDECREF(__pyx_v_locusdic);
  __Pyx_XDECREF(__pyx_v_rmrow);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_origcomb);
  __Pyx_XDECREF(__pyx_v_gmt);
  __Pyx_XDECREF(__pyx_v_featuresdf);
  __Pyx_XDECREF(__pyx_v_seed);
  __Pyx_XDECREF(__pyx_v_CICs);
  __Pyx_XDECREF(__pyx_v_seed_file);
  __Pyx_XDECREF(__pyx_v_target_df);
  __Pyx_XDECREF(__pyx_v_seed_df);
  __Pyx_XDECREF(__pyx_v_thread_number);
  __Pyx_XDECREF(__pyx_v_out_folder);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_25runBenchmark(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_25runBenchmark(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_target_file = 0;
  PyObject *__pyx_v_feature_file = 0;
  PyObject *__pyx_v_seed_file = 0;
  PyObject *__pyx_v_target_df = 0;
  PyObject *__pyx_v_feature_df = 0;
  PyObject *__pyx_v_seed_df = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_direction = 0;
  PyObject *__pyx_v_mode = 0;
  PyObject *__pyx_v_num_top = 0;
  PyObject *__pyx_v_low_threshold = 0;
  PyObject *__pyx_v_high_threshold = 0;
  PyObject *__pyx_v_collapse = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_gene_locus = 0;
  PyObject *__pyx_v_verbose = 0;
  PyObject *__pyx_v_max_iteration = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_subset = 0;
  PyObject *__pyx_v_if_pval = 0;
  PyObject *__pyx_v_if_bootstrap = 0;
  PyObject *__pyx_v_if_cluster = 0;
  PyObject *__pyx_v_if_intermediate = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_gene_set = 0;
  PyObject *__pyx_v_gene_separator = 0;
  PyObject *__pyx_v_gmt_file = 0;
  PyObject *__pyx_v_alpha = 0;
  PyObject *__pyx_v_neighborhood = 0;
  PyObject *__pyx_v_tissue_file = 0;
  PyObject *__pyx_v_gzip = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("runBenchmark (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_target_file,&__pyx_n_s_feature_file,&__pyx_n_s_seed_file,&__pyx_n_s_target_df,&__pyx_n_s_feature_df,&__pyx_n_s_seed_df,&__pyx_n_s_prefix,&__pyx_n_s_seed_name,&__pyx_n_s_grid,&__pyx_n_s_target_name,&__pyx_n_s_k,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_direction,&__pyx_n_s_mode,&__pyx_n_s_num_top,&__pyx_n_s_low_threshold,&__pyx_n_s_high_threshold,&__pyx_n_s_collapse,&__pyx_n_s_normalize,&__pyx_n_s_gene_locus,&__pyx_n_s_verbose,&__pyx_n_s_max_iteration,&__pyx_n_s_thread_number,&__pyx_n_s_figure_format,&__pyx_n_s_subset,&__pyx_n_s_if_pval,&__pyx_n_s_if_bootstrap,&__pyx_n_s_if_cluster,&__pyx_n_s_if_intermediate,&__pyx_n_s_out_folder,&__pyx_n_s_gene_set,&__pyx_n_s_gene_separator,&__pyx_n_s_gmt_file,&__pyx_n_s_alpha,&__pyx_n_s_neighborhood,&__pyx_n_s_tissue_file,&__pyx_n_s_gzip,0};
    PyObject* values[38] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    values[0] = ((PyObject *)__pyx_n_u_no);
    values[1] = ((PyObject *)__pyx_n_u_no);
    values[2] = ((PyObject *)__pyx_n_u_no);
    values[3] = ((PyObject *)__pyx_n_u_no);
    values[4] = ((PyObject *)__pyx_n_u_no);
    values[5] = ((PyObject *)__pyx_n_u_no);
    values[6] = ((PyObject *)__pyx_n_u_test);

    /* "revealer/REVEALER_runbenchmark.pyx":1236
 *                   seed_df='no', # dataframe for seed
 *                   prefix='test', # prefix for result files
 *                   seed_name=None, # names for seed, should be a list of string indicating the name of seed             # <<<<<<<<<<<<<<
 *                   grid=34, # number of grid, default is 34
 *                   target_name=0, # name/index of target in target file. can be int n for nth row, or string s for row with index s
 */
    values[7] = ((PyObject *)Py_None);
    values[8] = ((PyObject *)__pyx_int_34);
    values[9] = ((PyObject *)__pyx_int_0);
    values[10] = ((PyObject *)__pyx_int_5);
    values[11] = ((PyObject *)__pyx_float_0_65);
    values[12] = __pyx_k__6;
    values[13] = ((PyObject *)__pyx_n_u_pos);
    values[14] = ((PyObject *)__pyx_n_u_single);
    values[15] = ((PyObject *)__pyx_int_30);
    values[16] = ((PyObject *)__pyx_int_3);
    values[17] = ((PyObject *)__pyx_int_100);

    /* "revealer/REVEALER_runbenchmark.pyx":1247
 *                   low_threshold=3, # lowest threshold that feature with less than this value occurence will be removed
 *                   high_threshold=100, # highest threshold that feature with less than this value occurence will be removed
 *                   collapse=True, # indicate if same features are collapsed together for intermediate files             # <<<<<<<<<<<<<<
 *                   normalize='zerobase', # normalize method for target
 *                   gene_locus='None', # gene_locus file indicating gene name and location of that gene
 */
    values[18] = ((PyObject *)Py_True);
    values[19] = ((PyObject *)__pyx_n_u_zerobase);
    values[20] = ((PyObject *)__pyx_n_u_None);
    values[21] = ((PyObject *)__pyx_int_1);
    values[22] = ((PyObject *)__pyx_int_neg_1);
    values[23] = ((PyObject *)__pyx_int_1);
    values[24] = ((PyObject *)__pyx_n_u_pdf);
    values[25] = ((PyObject *)__pyx_n_u_no);

    /* "revealer/REVEALER_runbenchmark.pyx":1255
 *                   figure_format='pdf', # format for result figure
 *                   subset='no', # if list of string passed, only columns in this list is picked for calculation
 *                   if_pval=True, # if True, p-values are calculated for all result             # <<<<<<<<<<<<<<
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF
 */
    values[26] = ((PyObject *)Py_True);

    /* "revealer/REVEALER_runbenchmark.pyx":1256
 *                   subset='no', # if list of string passed, only columns in this list is picked for calculation
 *                   if_pval=True, # if True, p-values are calculated for all result
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result             # <<<<<<<<<<<<<<
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported
 */
    values[27] = ((PyObject *)Py_True);

    /* "revealer/REVEALER_runbenchmark.pyx":1257
 *                   if_pval=True, # if True, p-values are calculated for all result
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF             # <<<<<<<<<<<<<<
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported
 *                   out_folder='.', # folder to put output files inside
 */
    values[28] = ((PyObject *)Py_False);

    /* "revealer/REVEALER_runbenchmark.pyx":1258
 *                   if_bootstrap=True, # if True, variance by bootstrap is calculated for all result
 *                   if_cluster=False, # if True, features in intermediate files are clustered with NMF
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported             # <<<<<<<<<<<<<<
 *                   out_folder='.', # folder to put output files inside
 *                   gene_set=None,
 */
    values[29] = ((PyObject *)Py_False);
    values[30] = ((PyObject *)__pyx_kp_u__7);

    /* "revealer/REVEALER_runbenchmark.pyx":1260
 *                   if_intermediate=False, # if True, intermediate result with top CIC value features are reported
 *                   out_folder='.', # folder to put output files inside
 *                   gene_set=None,             # <<<<<<<<<<<<<<
 *                   gene_separator='_',
 *                   gmt_file = None,
 */
    values[31] = ((PyObject *)Py_None);
    values[32] = ((PyObject *)__pyx_n_u__8);

    /* "revealer/REVEALER_runbenchmark.pyx":1262
 *                   gene_set=None,
 *                   gene_separator='_',
 *                   gmt_file = None,             # <<<<<<<<<<<<<<
 *                   alpha = 1,
 *                   neighborhood = 4,
 */
    values[33] = ((PyObject *)Py_None);
    values[34] = ((PyObject *)__pyx_int_1);
    values[35] = ((PyObject *)__pyx_int_4);

    /* "revealer/REVEALER_runbenchmark.pyx":1265
 *                   alpha = 1,
 *                   neighborhood = 4,
 *                   tissue_file = None,             # <<<<<<<<<<<<<<
 *                   gzip = True
 *                  ):
 */
    values[36] = ((PyObject *)Py_None);

    /* "revealer/REVEALER_runbenchmark.pyx":1266
 *                   neighborhood = 4,
 *                   tissue_file = None,
 *                   gzip = True             # <<<<<<<<<<<<<<
 *                  ):
 * 
 */
    values[37] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 38: values[37] = PyTuple_GET_ITEM(__pyx_args, 37);
        CYTHON_FALLTHROUGH;
        case 37: values[36] = PyTuple_GET_ITEM(__pyx_args, 36);
        CYTHON_FALLTHROUGH;
        case 36: values[35] = PyTuple_GET_ITEM(__pyx_args, 35);
        CYTHON_FALLTHROUGH;
        case 35: values[34] = PyTuple_GET_ITEM(__pyx_args, 34);
        CYTHON_FALLTHROUGH;
        case 34: values[33] = PyTuple_GET_ITEM(__pyx_args, 33);
        CYTHON_FALLTHROUGH;
        case 33: values[32] = PyTuple_GET_ITEM(__pyx_args, 32);
        CYTHON_FALLTHROUGH;
        case 32: values[31] = PyTuple_GET_ITEM(__pyx_args, 31);
        CYTHON_FALLTHROUGH;
        case 31: values[30] = PyTuple_GET_ITEM(__pyx_args, 30);
        CYTHON_FALLTHROUGH;
        case 30: values[29] = PyTuple_GET_ITEM(__pyx_args, 29);
        CYTHON_FALLTHROUGH;
        case 29: values[28] = PyTuple_GET_ITEM(__pyx_args, 28);
        CYTHON_FALLTHROUGH;
        case 28: values[27] = PyTuple_GET_ITEM(__pyx_args, 27);
        CYTHON_FALLTHROUGH;
        case 27: values[26] = PyTuple_GET_ITEM(__pyx_args, 26);
        CYTHON_FALLTHROUGH;
        case 26: values[25] = PyTuple_GET_ITEM(__pyx_args, 25);
        CYTHON_FALLTHROUGH;
        case 25: values[24] = PyTuple_GET_ITEM(__pyx_args, 24);
        CYTHON_FALLTHROUGH;
        case 24: values[23] = PyTuple_GET_ITEM(__pyx_args, 23);
        CYTHON_FALLTHROUGH;
        case 23: values[22] = PyTuple_GET_ITEM(__pyx_args, 22);
        CYTHON_FALLTHROUGH;
        case 22: values[21] = PyTuple_GET_ITEM(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = PyTuple_GET_ITEM(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_file);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_feature_file);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_file);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_df);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_feature_df);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_df);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid);
          if (value) { values[8] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name);
          if (value) { values[9] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k);
          if (value) { values[10] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult);
          if (value) { values[11] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj);
          if (value) { values[12] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction);
          if (value) { values[13] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mode);
          if (value) { values[14] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_top);
          if (value) { values[15] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_low_threshold);
          if (value) { values[16] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_high_threshold);
          if (value) { values[17] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_collapse);
          if (value) { values[18] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 19:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_normalize);
          if (value) { values[19] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 20:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_locus);
          if (value) { values[20] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 21:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_verbose);
          if (value) { values[21] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 22:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_iteration);
          if (value) { values[22] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 23:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number);
          if (value) { values[23] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 24:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format);
          if (value) { values[24] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 25:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_subset);
          if (value) { values[25] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 26:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_pval);
          if (value) { values[26] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 27:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_bootstrap);
          if (value) { values[27] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 28:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_cluster);
          if (value) { values[28] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 29:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_intermediate);
          if (value) { values[29] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 30:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder);
          if (value) { values[30] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 31:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_set);
          if (value) { values[31] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 32:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_separator);
          if (value) { values[32] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 33:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt_file);
          if (value) { values[33] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 34:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_alpha);
          if (value) { values[34] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 35:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood);
          if (value) { values[35] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 36:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tissue_file);
          if (value) { values[36] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 37:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gzip);
          if (value) { values[37] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "runBenchmark") < 0)) __PYX_ERR(0, 1229, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 38: values[37] = PyTuple_GET_ITEM(__pyx_args, 37);
        CYTHON_FALLTHROUGH;
        case 37: values[36] = PyTuple_GET_ITEM(__pyx_args, 36);
        CYTHON_FALLTHROUGH;
        case 36: values[35] = PyTuple_GET_ITEM(__pyx_args, 35);
        CYTHON_FALLTHROUGH;
        case 35: values[34] = PyTuple_GET_ITEM(__pyx_args, 34);
        CYTHON_FALLTHROUGH;
        case 34: values[33] = PyTuple_GET_ITEM(__pyx_args, 33);
        CYTHON_FALLTHROUGH;
        case 33: values[32] = PyTuple_GET_ITEM(__pyx_args, 32);
        CYTHON_FALLTHROUGH;
        case 32: values[31] = PyTuple_GET_ITEM(__pyx_args, 31);
        CYTHON_FALLTHROUGH;
        case 31: values[30] = PyTuple_GET_ITEM(__pyx_args, 30);
        CYTHON_FALLTHROUGH;
        case 30: values[29] = PyTuple_GET_ITEM(__pyx_args, 29);
        CYTHON_FALLTHROUGH;
        case 29: values[28] = PyTuple_GET_ITEM(__pyx_args, 28);
        CYTHON_FALLTHROUGH;
        case 28: values[27] = PyTuple_GET_ITEM(__pyx_args, 27);
        CYTHON_FALLTHROUGH;
        case 27: values[26] = PyTuple_GET_ITEM(__pyx_args, 26);
        CYTHON_FALLTHROUGH;
        case 26: values[25] = PyTuple_GET_ITEM(__pyx_args, 25);
        CYTHON_FALLTHROUGH;
        case 25: values[24] = PyTuple_GET_ITEM(__pyx_args, 24);
        CYTHON_FALLTHROUGH;
        case 24: values[23] = PyTuple_GET_ITEM(__pyx_args, 23);
        CYTHON_FALLTHROUGH;
        case 23: values[22] = PyTuple_GET_ITEM(__pyx_args, 22);
        CYTHON_FALLTHROUGH;
        case 22: values[21] = PyTuple_GET_ITEM(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = PyTuple_GET_ITEM(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_target_file = values[0];
    __pyx_v_feature_file = values[1];
    __pyx_v_seed_file = values[2];
    __pyx_v_target_df = values[3];
    __pyx_v_feature_df = values[4];
    __pyx_v_seed_df = values[5];
    __pyx_v_prefix = values[6];
    __pyx_v_seed_name = values[7];
    __pyx_v_grid = values[8];
    __pyx_v_target_name = values[9];
    __pyx_v_k = values[10];
    __pyx_v_bandwidth_mult = values[11];
    __pyx_v_bandwidth_adj = values[12];
    __pyx_v_direction = values[13];
    __pyx_v_mode = values[14];
    __pyx_v_num_top = values[15];
    __pyx_v_low_threshold = values[16];
    __pyx_v_high_threshold = values[17];
    __pyx_v_collapse = values[18];
    __pyx_v_normalize = values[19];
    __pyx_v_gene_locus = values[20];
    __pyx_v_verbose = values[21];
    __pyx_v_max_iteration = values[22];
    __pyx_v_thread_number = values[23];
    __pyx_v_figure_format = values[24];
    __pyx_v_subset = values[25];
    __pyx_v_if_pval = values[26];
    __pyx_v_if_bootstrap = values[27];
    __pyx_v_if_cluster = values[28];
    __pyx_v_if_intermediate = values[29];
    __pyx_v_out_folder = values[30];
    __pyx_v_gene_set = values[31];
    __pyx_v_gene_separator = values[32];
    __pyx_v_gmt_file = values[33];
    __pyx_v_alpha = values[34];
    __pyx_v_neighborhood = values[35];
    __pyx_v_tissue_file = values[36];
    __pyx_v_gzip = values[37];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("runBenchmark", 0, 0, 38, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1229, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBenchmark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_24runBenchmark(__pyx_self, __pyx_v_target_file, __pyx_v_feature_file, __pyx_v_seed_file, __pyx_v_target_df, __pyx_v_feature_df, __pyx_v_seed_df, __pyx_v_prefix, __pyx_v_seed_name, __pyx_v_grid, __pyx_v_target_name, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_mode, __pyx_v_num_top, __pyx_v_low_threshold, __pyx_v_high_threshold, __pyx_v_collapse, __pyx_v_normalize, __pyx_v_gene_locus, __pyx_v_verbose, __pyx_v_max_iteration, __pyx_v_thread_number, __pyx_v_figure_format, __pyx_v_subset, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_if_intermediate, __pyx_v_out_folder, __pyx_v_gene_set, __pyx_v_gene_separator, __pyx_v_gmt_file, __pyx_v_alpha, __pyx_v_neighborhood, __pyx_v_tissue_file, __pyx_v_gzip);

  /* "revealer/REVEALER_runbenchmark.pyx":1229
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef runBenchmark(target_file='no', # gct file for target(continuous or binary             # <<<<<<<<<<<<<<
 *                   feature_file='no', # gct file for features(binary)
 *                   seed_file='no', # file for seed, if not provided, feature file is used directly
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_24runBenchmark(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_target_file, PyObject *__pyx_v_feature_file, PyObject *__pyx_v_seed_file, PyObject *__pyx_v_target_df, PyObject *__pyx_v_feature_df, PyObject *__pyx_v_seed_df, PyObject *__pyx_v_prefix, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_grid, PyObject *__pyx_v_target_name, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, PyObject *__pyx_v_mode, PyObject *__pyx_v_num_top, PyObject *__pyx_v_low_threshold, PyObject *__pyx_v_high_threshold, PyObject *__pyx_v_collapse, PyObject *__pyx_v_normalize, PyObject *__pyx_v_gene_locus, PyObject *__pyx_v_verbose, PyObject *__pyx_v_max_iteration, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_subset, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_if_intermediate, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_gene_set, PyObject *__pyx_v_gene_separator, PyObject *__pyx_v_gmt_file, PyObject *__pyx_v_alpha, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_tissue_file, PyObject *__pyx_v_gzip) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_8revealer_21REVEALER_runbenchmark_runBenchmark __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runBenchmark", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 38;
  __pyx_t_2.target_file = __pyx_v_target_file;
  __pyx_t_2.feature_file = __pyx_v_feature_file;
  __pyx_t_2.seed_file = __pyx_v_seed_file;
  __pyx_t_2.target_df = __pyx_v_target_df;
  __pyx_t_2.feature_df = __pyx_v_feature_df;
  __pyx_t_2.seed_df = __pyx_v_seed_df;
  __pyx_t_2.prefix = __pyx_v_prefix;
  __pyx_t_2.seed_name = __pyx_v_seed_name;
  __pyx_t_2.grid = __pyx_v_grid;
  __pyx_t_2.target_name = __pyx_v_target_name;
  __pyx_t_2.k = __pyx_v_k;
  __pyx_t_2.bandwidth_mult = __pyx_v_bandwidth_mult;
  __pyx_t_2.bandwidth_adj = __pyx_v_bandwidth_adj;
  __pyx_t_2.direction = __pyx_v_direction;
  __pyx_t_2.mode = __pyx_v_mode;
  __pyx_t_2.num_top = __pyx_v_num_top;
  __pyx_t_2.low_threshold = __pyx_v_low_threshold;
  __pyx_t_2.high_threshold = __pyx_v_high_threshold;
  __pyx_t_2.collapse = __pyx_v_collapse;
  __pyx_t_2.normalize = __pyx_v_normalize;
  __pyx_t_2.gene_locus = __pyx_v_gene_locus;
  __pyx_t_2.verbose = __pyx_v_verbose;
  __pyx_t_2.max_iteration = __pyx_v_max_iteration;
  __pyx_t_2.thread_number = __pyx_v_thread_number;
  __pyx_t_2.figure_format = __pyx_v_figure_format;
  __pyx_t_2.subset = __pyx_v_subset;
  __pyx_t_2.if_pval = __pyx_v_if_pval;
  __pyx_t_2.if_bootstrap = __pyx_v_if_bootstrap;
  __pyx_t_2.if_cluster = __pyx_v_if_cluster;
  __pyx_t_2.if_intermediate = __pyx_v_if_intermediate;
  __pyx_t_2.out_folder = __pyx_v_out_folder;
  __pyx_t_2.gene_set = __pyx_v_gene_set;
  __pyx_t_2.gene_separator = __pyx_v_gene_separator;
  __pyx_t_2.gmt_file = __pyx_v_gmt_file;
  __pyx_t_2.alpha = __pyx_v_alpha;
  __pyx_t_2.neighborhood = __pyx_v_neighborhood;
  __pyx_t_2.tissue_file = __pyx_v_tissue_file;
  __pyx_t_2.gzip = __pyx_v_gzip;
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_runBenchmark(0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBenchmark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1392
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef REVEALERInner(             # <<<<<<<<<<<<<<
 *     prefix,             #Prefix for generated files
 *     comb,               #Combined dataframe
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_27REVEALERInner(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_REVEALERInner(PyObject *__pyx_v_prefix, PyObject *__pyx_v_comb, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, PyObject *__pyx_v_num_top, PyObject *__pyx_v_verbose, PyObject *__pyx_v_max_iteration, PyObject *__pyx_v_collapse, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_if_intermediate, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_seed_name, CYTHON_UNUSED PyObject *__pyx_v_normalize, PyObject *__pyx_v_target_name, PyObject *__pyx_v_report, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_alpha, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_tissue_file, CYTHON_UNUSED PyObject *__pyx_v_gzip, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_seedcmap = NULL;
  PyObject *__pyx_v_featurecmap = NULL;
  PyObject *__pyx_v_newpheno = NULL;
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_v_targetmean = NULL;
  PyObject *__pyx_v_targetstd = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_patient = NULL;
  PyObject *__pyx_v_combpatient = NULL;
  PyObject *__pyx_v_corr = NULL;
  PyObject *__pyx_v_start = NULL;
  int __pyx_v_size;
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __Pyx_memviewslice __pyx_v_cythonseed = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_seedids = NULL;
  PyObject *__pyx_v_CICs = NULL;
  PyObject *__pyx_v_seedIC = NULL;
  PyObject *__pyx_v_pVals = NULL;
  PyObject *__pyx_v_bootstraps = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_addseed = NULL;
  PyObject *__pyx_v_savecomb = NULL;
  PyObject *__pyx_v_seedlists = NULL;
  __pyx_t_5numpy_int_t __pyx_v_seedid;
  PyObject *__pyx_v_IC = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_v_pVal = NULL;
  PyObject *__pyx_v_bootstrap = NULL;
  PyObject *__pyx_v_currentseed = NULL;
  PyObject *__pyx_v_subcomb = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_CIC = NULL;
  PyObject *__pyx_v_spenttime = NULL;
  PyObject *__pyx_v_newseed = NULL;
  PyObject *__pyx_v_newIC = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_14 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_t_15;
  __pyx_t_5numpy_double_t __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  __pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t __pyx_t_20;
  __pyx_t_5numpy_int_t __pyx_t_21;
  __Pyx_memviewslice __pyx_t_22 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_23;
  __pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc __pyx_t_24;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("REVEALERInner", 0);
  __Pyx_INCREF(__pyx_v_comb);
  __Pyx_INCREF(__pyx_v_grid);
  __Pyx_INCREF(__pyx_v_report);

  /* "revealer/REVEALER_runbenchmark.pyx":1423
 *     ):
 * 
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],             # <<<<<<<<<<<<<<
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_clr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_LinearSegmentedColormap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_from_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_tuple__18);
  __Pyx_INCREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_tuple__19);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_u_custom_greys);
  __Pyx_GIVEREF(__pyx_kp_u_custom_greys);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_custom_greys);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1424
 * 
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],
 *                                                      N=256)             # <<<<<<<<<<<<<<
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 *                                                         [(<double>(176)/<double>(255),
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_N, __pyx_int_256) < 0) __PYX_ERR(0, 1424, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1423
 *     ):
 * 
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],             # <<<<<<<<<<<<<<
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_seedcmap = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1425
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',             # <<<<<<<<<<<<<<
 *                                                         [(<double>(176)/<double>(255),
 *                                                         <double>(196)/<double>(255),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_clr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_LinearSegmentedColormap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_from_list); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1426
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 *                                                         [(<double>(176)/<double>(255),             # <<<<<<<<<<<<<<
 *                                                         <double>(196)/<double>(255),
 *                                                         <double>(222)/<double>(255)),
 */
  __pyx_t_2 = PyFloat_FromDouble((((double)0xB0) / ((double)0xFF))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "revealer/REVEALER_runbenchmark.pyx":1427
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 *                                                         [(<double>(176)/<double>(255),
 *                                                         <double>(196)/<double>(255),             # <<<<<<<<<<<<<<
 *                                                         <double>(222)/<double>(255)),
 *                                                         (0,0,<double>(139)/<double>(255))], N=256)
 */
  __pyx_t_3 = PyFloat_FromDouble((((double)0xC4) / ((double)0xFF))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "revealer/REVEALER_runbenchmark.pyx":1428
 *                                                         [(<double>(176)/<double>(255),
 *                                                         <double>(196)/<double>(255),
 *                                                         <double>(222)/<double>(255)),             # <<<<<<<<<<<<<<
 *                                                         (0,0,<double>(139)/<double>(255))], N=256)
 * 
 */
  __pyx_t_1 = PyFloat_FromDouble((((double)0xDE) / ((double)0xFF))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "revealer/REVEALER_runbenchmark.pyx":1426
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 *                                                         [(<double>(176)/<double>(255),             # <<<<<<<<<<<<<<
 *                                                         <double>(196)/<double>(255),
 *                                                         <double>(222)/<double>(255)),
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1429
 *                                                         <double>(196)/<double>(255),
 *                                                         <double>(222)/<double>(255)),
 *                                                         (0,0,<double>(139)/<double>(255))], N=256)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyFloat_FromDouble((((double)0x8B) / ((double)0xFF))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1426
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 *                                                         [(<double>(176)/<double>(255),             # <<<<<<<<<<<<<<
 *                                                         <double>(196)/<double>(255),
 *                                                         <double>(222)/<double>(255)),
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
  __pyx_t_5 = 0;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1425
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',             # <<<<<<<<<<<<<<
 *                                                         [(<double>(176)/<double>(255),
 *                                                         <double>(196)/<double>(255),
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_u_custom_greys);
  __Pyx_GIVEREF(__pyx_kp_u_custom_greys);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_custom_greys);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1429
 *                                                         <double>(196)/<double>(255),
 *                                                         <double>(222)/<double>(255)),
 *                                                         (0,0,<double>(139)/<double>(255))], N=256)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_N, __pyx_int_256) < 0) __PYX_ERR(0, 1429, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1425
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',             # <<<<<<<<<<<<<<
 *                                                         [(<double>(176)/<double>(255),
 *                                                         <double>(196)/<double>(255),
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_featurecmap = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1432
 * 
 * 
 *     newpheno = []             # <<<<<<<<<<<<<<
 *     target = comb.iloc[0].tolist()
 *     targetmean = np.mean(target)
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_newpheno = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1433
 * 
 *     newpheno = []
 *     target = comb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 *     targetmean = np.mean(target)
 *     targetstd = np.std(target)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_target = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1434
 *     newpheno = []
 *     target = comb.iloc[0].tolist()
 *     targetmean = np.mean(target)             # <<<<<<<<<<<<<<
 *     targetstd = np.std(target)
 *     comb.iloc[0] = (target - targetmean)/targetstd
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_mean); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_v_target) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_target);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_targetmean = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1435
 *     target = comb.iloc[0].tolist()
 *     targetmean = np.mean(target)
 *     targetstd = np.std(target)             # <<<<<<<<<<<<<<
 *     comb.iloc[0] = (target - targetmean)/targetstd
 *     for i in comb.iloc[0].tolist():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_std); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_v_target) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_target);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_targetstd = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1436
 *     targetmean = np.mean(target)
 *     targetstd = np.std(target)
 *     comb.iloc[0] = (target - targetmean)/targetstd             # <<<<<<<<<<<<<<
 *     for i in comb.iloc[0].tolist():
 *         newpheno.append(np.sign(i)*(abs(i)**alpha))
 */
  __pyx_t_5 = PyNumber_Subtract(__pyx_v_target, __pyx_v_targetmean); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_t_5, __pyx_v_targetstd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely(__Pyx_SetItemInt(__pyx_t_5, 0, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 0, 0, 0) < 0)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1437
 *     targetstd = np.std(target)
 *     comb.iloc[0] = (target - targetmean)/targetstd
 *     for i in comb.iloc[0].tolist():             # <<<<<<<<<<<<<<
 *         newpheno.append(np.sign(i)*(abs(i)**alpha))
 *     comb.iloc[0] = newpheno
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1437, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1437, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1437, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1437, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1437, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_5);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1437, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1438
 *     comb.iloc[0] = (target - targetmean)/targetstd
 *     for i in comb.iloc[0].tolist():
 *         newpheno.append(np.sign(i)*(abs(i)**alpha))             # <<<<<<<<<<<<<<
 *     comb.iloc[0] = newpheno
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_sign); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, __pyx_v_i) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_i);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyNumber_Absolute(__pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Power(__pyx_t_4, __pyx_v_alpha, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_newpheno, __pyx_t_4); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1437
 *     targetstd = np.std(target)
 *     comb.iloc[0] = (target - targetmean)/targetstd
 *     for i in comb.iloc[0].tolist():             # <<<<<<<<<<<<<<
 *         newpheno.append(np.sign(i)*(abs(i)**alpha))
 *     comb.iloc[0] = newpheno
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1439
 *     for i in comb.iloc[0].tolist():
 *         newpheno.append(np.sign(i)*(abs(i)**alpha))
 *     comb.iloc[0] = newpheno             # <<<<<<<<<<<<<<
 * 
 *     if tissue_file:
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely(__Pyx_SetItemInt(__pyx_t_5, 0, __pyx_v_newpheno, long, 1, __Pyx_PyInt_From_long, 0, 0, 0) < 0)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1441
 *     comb.iloc[0] = newpheno
 * 
 *     if tissue_file:             # <<<<<<<<<<<<<<
 *         patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *         patient = patient.drop(columns=patient.columns[0])
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_tissue_file); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1441, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1442
 * 
 *     if tissue_file:
 *         patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *         patient = patient.drop(columns=patient.columns[0])
 *         patient.columns = patient.columns.str.replace("-", "_")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_tissue_file);
    __Pyx_GIVEREF(__pyx_v_tissue_file);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tissue_file);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    PyList_SET_ITEM(__pyx_t_1, 1, __pyx_int_1);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_skiprows, __pyx_t_1) < 0) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 1442, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 1442, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_patient = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1443
 *     if tissue_file:
 *         patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *         patient = patient.drop(columns=patient.columns[0])             # <<<<<<<<<<<<<<
 *         patient.columns = patient.columns.str.replace("-", "_")
 *         patient = patient[comb.columns]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_drop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_columns, __pyx_t_4) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_patient, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1444
 *         patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *         patient = patient.drop(columns=patient.columns[0])
 *         patient.columns = patient.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *         patient = patient[comb.columns]
 *         combpatient = pd.concat([comb.iloc[[0]],patient])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_replace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_patient, __pyx_n_s_columns, __pyx_t_3) < 0) __PYX_ERR(0, 1444, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1445
 *         patient = patient.drop(columns=patient.columns[0])
 *         patient.columns = patient.columns.str.replace("-", "_")
 *         patient = patient[comb.columns]             # <<<<<<<<<<<<<<
 *         combpatient = pd.concat([comb.iloc[[0]],patient])
 *         corr = []
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_patient, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_patient, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1446
 *         patient.columns = patient.columns.str.replace("-", "_")
 *         patient = patient[comb.columns]
 *         combpatient = pd.concat([comb.iloc[[0]],patient])             # <<<<<<<<<<<<<<
 *         corr = []
 *         for i in combpatient.index.tolist()[1:]:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_concat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_int_0);
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_patient);
    __Pyx_GIVEREF(__pyx_v_patient);
    PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_patient);
    __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_combpatient = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1447
 *         patient = patient[comb.columns]
 *         combpatient = pd.concat([comb.iloc[[0]],patient])
 *         corr = []             # <<<<<<<<<<<<<<
 *         for i in combpatient.index.tolist()[1:]:
 *             if combpatient.loc[i].sum() == 0:
 */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_corr = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1448
 *         combpatient = pd.concat([comb.iloc[[0]],patient])
 *         corr = []
 *         for i in combpatient.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *             if combpatient.loc[i].sum() == 0:
 *                 corr.append(-100)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_combpatient, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_t_4, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_4 = __pyx_t_5; __Pyx_INCREF(__pyx_t_4); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1448, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1448, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1448, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1448, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1448, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_7(__pyx_t_4);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1448, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1449
 *         corr = []
 *         for i in combpatient.index.tolist()[1:]:
 *             if combpatient.loc[i].sum() == 0:             # <<<<<<<<<<<<<<
 *                 corr.append(-100)
 *             else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_combpatient, __pyx_n_s_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sum); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_5 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_5, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1449, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_9) {

        /* "revealer/REVEALER_runbenchmark.pyx":1450
 *         for i in combpatient.index.tolist()[1:]:
 *             if combpatient.loc[i].sum() == 0:
 *                 corr.append(-100)             # <<<<<<<<<<<<<<
 *             else:
 *                 corr.append(stats.pearsonr(combpatient.iloc[0],combpatient.loc[i])[0])
 */
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_corr, __pyx_int_neg_100); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1450, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":1449
 *         corr = []
 *         for i in combpatient.index.tolist()[1:]:
 *             if combpatient.loc[i].sum() == 0:             # <<<<<<<<<<<<<<
 *                 corr.append(-100)
 *             else:
 */
        goto __pyx_L8;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1452
 *                 corr.append(-100)
 *             else:
 *                 corr.append(stats.pearsonr(combpatient.iloc[0],combpatient.loc[i])[0])             # <<<<<<<<<<<<<<
 *         combpatient['corr'] = [1]+corr
 *         combpatient = combpatient.sort_values('corr',ascending=False).drop(columns= ['corr'])
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_stats); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_pearsonr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_combpatient, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_combpatient, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_i); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_3, __pyx_t_10};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1452, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_3, __pyx_t_10};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1452, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1452, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_10);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_10);
          __pyx_t_3 = 0;
          __pyx_t_10 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1452, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_corr, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1452, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L8:;

      /* "revealer/REVEALER_runbenchmark.pyx":1448
 *         combpatient = pd.concat([comb.iloc[[0]],patient])
 *         corr = []
 *         for i in combpatient.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *             if combpatient.loc[i].sum() == 0:
 *                 corr.append(-100)
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1453
 *             else:
 *                 corr.append(stats.pearsonr(combpatient.iloc[0],combpatient.loc[i])[0])
 *         combpatient['corr'] = [1]+corr             # <<<<<<<<<<<<<<
 *         combpatient = combpatient.sort_values('corr',ascending=False).drop(columns= ['corr'])
 * 
 */
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_int_1);
    __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_v_corr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(PyObject_SetItem(__pyx_v_combpatient, __pyx_n_u_corr, __pyx_t_2) < 0)) __PYX_ERR(0, 1453, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1454
 *                 corr.append(stats.pearsonr(combpatient.iloc[0],combpatient.loc[i])[0])
 *         combpatient['corr'] = [1]+corr
 *         combpatient = combpatient.sort_values('corr',ascending=False).drop(columns= ['corr'])             # <<<<<<<<<<<<<<
 * 
 *         patientfig(df = combpatient, seedcmap = seedcmap, featurecmap = featurecmap,
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_combpatient, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 1454, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__21, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_drop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_u_corr);
    __Pyx_GIVEREF(__pyx_n_u_corr);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_corr);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_combpatient, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1456
 *         combpatient = combpatient.sort_values('corr',ascending=False).drop(columns= ['corr'])
 * 
 *         patientfig(df = combpatient, seedcmap = seedcmap, featurecmap = featurecmap,             # <<<<<<<<<<<<<<
 *                    prefix = prefix, figure_format = figure_format, out_folder = out_folder,
 *                    target_name = target_name)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_patientfig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_df, __pyx_v_combpatient) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_seedcmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_featurecmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1457
 * 
 *         patientfig(df = combpatient, seedcmap = seedcmap, featurecmap = featurecmap,
 *                    prefix = prefix, figure_format = figure_format, out_folder = out_folder,             # <<<<<<<<<<<<<<
 *                    target_name = target_name)
 * 
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_prefix, __pyx_v_prefix) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_figure_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_out_folder, __pyx_v_out_folder) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1458
 *         patientfig(df = combpatient, seedcmap = seedcmap, featurecmap = featurecmap,
 *                    prefix = prefix, figure_format = figure_format, out_folder = out_folder,
 *                    target_name = target_name)             # <<<<<<<<<<<<<<
 * 
 *     plt.plot(comb.iloc[0].tolist())
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_target_name, __pyx_v_target_name) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1456
 *         combpatient = combpatient.sort_values('corr',ascending=False).drop(columns= ['corr'])
 * 
 *         patientfig(df = combpatient, seedcmap = seedcmap, featurecmap = featurecmap,             # <<<<<<<<<<<<<<
 *                    prefix = prefix, figure_format = figure_format, out_folder = out_folder,
 *                    target_name = target_name)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1441
 *     comb.iloc[0] = newpheno
 * 
 *     if tissue_file:             # <<<<<<<<<<<<<<
 *         patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *         patient = patient.drop(columns=patient.columns[0])
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1460
 *                    target_name = target_name)
 * 
 *     plt.plot(comb.iloc[0].tolist())             # <<<<<<<<<<<<<<
 *     plt.savefig(out_folder + prefix+'_PhenotypeDistribution.'+figure_format,format=figure_format)
 *     plt.close()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_plt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_12, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_tolist); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_12, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1461
 * 
 *     plt.plot(comb.iloc[0].tolist())
 *     plt.savefig(out_folder + prefix+'_PhenotypeDistribution.'+figure_format,format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_savefig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_kp_u_PhenotypeDistribution); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_v_figure_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 1461, __pyx_L1_error)
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1462
 *     plt.plot(comb.iloc[0].tolist())
 *     plt.savefig(out_folder + prefix+'_PhenotypeDistribution.'+figure_format,format=figure_format)
 *     plt.close()             # <<<<<<<<<<<<<<
 * 
 *     if verbose != 0:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_close); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1464
 *     plt.close()
 * 
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         if seed_name != None:
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-2))
 */
  __pyx_t_12 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1465
 * 
 *     if verbose != 0:
 *         if seed_name != None:             # <<<<<<<<<<<<<<
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-2))
 *         else:
 */
    __pyx_t_12 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1465, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1465, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1466
 *     if verbose != 0:
 *         if seed_name != None:
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-2))             # <<<<<<<<<<<<<<
 *         else:
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-1))
 */
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_6 = PyObject_Length(__pyx_t_12); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = PyInt_FromSsize_t((__pyx_t_6 - 2)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Number_of_features_that_pass_the, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1465
 * 
 *     if verbose != 0:
 *         if seed_name != None:             # <<<<<<<<<<<<<<
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-2))
 *         else:
 */
      goto __pyx_L10;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1468
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-2))
 *         else:
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-1))             # <<<<<<<<<<<<<<
 * 
 *     if seed_name != None:
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1468, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyInt_FromSsize_t((__pyx_t_6 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Number_of_features_that_pass_the, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __pyx_L10:;

    /* "revealer/REVEALER_runbenchmark.pyx":1464
 *     plt.close()
 * 
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         if seed_name != None:
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-2))
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1470
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-1))
 * 
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         report = report + 'Number of features passing threshold is: ' + str(len(comb.index)-2)+'\n'
 *     else:
 */
  __pyx_t_12 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1470, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1471
 * 
 *     if seed_name != None:
 *         report = report + 'Number of features passing threshold is: ' + str(len(comb.index)-2)+'\n'             # <<<<<<<<<<<<<<
 *     else:
 *         report = report + 'Number of features passing threshold is: ' + str(len(comb.index)-1)+'\n'
 */
    __pyx_t_12 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Number_of_features_passing_thres); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t((__pyx_t_6 - 2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_12, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1470
 *             print("Number of features that pass the threshold is: "+str(len(comb.index)-1))
 * 
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         report = report + 'Number of features passing threshold is: ' + str(len(comb.index)-2)+'\n'
 *     else:
 */
    goto __pyx_L11;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1473
 *         report = report + 'Number of features passing threshold is: ' + str(len(comb.index)-2)+'\n'
 *     else:
 *         report = report + 'Number of features passing threshold is: ' + str(len(comb.index)-1)+'\n'             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_4 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Number_of_features_passing_thres); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t((__pyx_t_6 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_12);
    __pyx_t_12 = 0;
  }
  __pyx_L11:;

  /* "revealer/REVEALER_runbenchmark.pyx":1476
 * 
 * 
 *     start= time.time()             # <<<<<<<<<<<<<<
 *     cdef int size = len(comb.iloc[0])
 *     cdef np.double_t[:] y = np.ascontiguousarray(np.asarray(comb.iloc[0].tolist()))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_12 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start = __pyx_t_12;
  __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1477
 * 
 *     start= time.time()
 *     cdef int size = len(comb.iloc[0])             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:] y = np.ascontiguousarray(np.asarray(comb.iloc[0].tolist()))
 *     cdef np.double_t miny = findmin(y, size)
 */
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_12, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_6 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_size = __pyx_t_6;

  /* "revealer/REVEALER_runbenchmark.pyx":1478
 *     start= time.time()
 *     cdef int size = len(comb.iloc[0])
 *     cdef np.double_t[:] y = np.ascontiguousarray(np.asarray(comb.iloc[0].tolist()))             # <<<<<<<<<<<<<<
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_np); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_12 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_10, __pyx_t_12) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_12);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(0, 1478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_y = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":1479
 *     cdef int size = len(comb.iloc[0])
 *     cdef np.double_t[:] y = np.ascontiguousarray(np.asarray(comb.iloc[0].tolist()))
 *     cdef np.double_t miny = findmin(y, size)             # <<<<<<<<<<<<<<
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 *     i = 0
 */
  __pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size);

  /* "revealer/REVEALER_runbenchmark.pyx":1480
 *     cdef np.double_t[:] y = np.ascontiguousarray(np.asarray(comb.iloc[0].tolist()))
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)             # <<<<<<<<<<<<<<
 *     i = 0
 *     cdef np.double_t bandwidth = calc_bandwidth(y,size)/2
 */
  __pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_v_y, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_v_y, __pyx_v_size));

  /* "revealer/REVEALER_runbenchmark.pyx":1481
 *     cdef np.double_t miny = findmin(y, size)
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 *     i = 0             # <<<<<<<<<<<<<<
 *     cdef np.double_t bandwidth = calc_bandwidth(y,size)/2
 * 
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_XDECREF_SET(__pyx_v_i, __pyx_int_0);

  /* "revealer/REVEALER_runbenchmark.pyx":1482
 *     cdef np.double_t deltay = findmax(y, size) - findmin(y, size)
 *     i = 0
 *     cdef np.double_t bandwidth = calc_bandwidth(y,size)/2             # <<<<<<<<<<<<<<
 * 
 *     cdef np.int_t[:] cythonseed
 */
  __pyx_v_bandwidth = (__pyx_f_8revealer_21REVEALER_runbenchmark_calc_bandwidth(__pyx_v_y, __pyx_v_size, 0, NULL) / 2.0);

  /* "revealer/REVEALER_runbenchmark.pyx":1486
 *     cdef np.int_t[:] cythonseed
 * 
 *     seedids = []             # <<<<<<<<<<<<<<
 *     CICs = []
 *     seedIC = []
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_seedids = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1487
 * 
 *     seedids = []
 *     CICs = []             # <<<<<<<<<<<<<<
 *     seedIC = []
 *     pVals = []
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_CICs = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1488
 *     seedids = []
 *     CICs = []
 *     seedIC = []             # <<<<<<<<<<<<<<
 *     pVals = []
 *     bootstraps = []
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_seedIC = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1489
 *     CICs = []
 *     seedIC = []
 *     pVals = []             # <<<<<<<<<<<<<<
 *     bootstraps = []
 *     addseed = 0
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_pVals = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1490
 *     seedIC = []
 *     pVals = []
 *     bootstraps = []             # <<<<<<<<<<<<<<
 *     addseed = 0
 * 
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_bootstraps = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1491
 *     pVals = []
 *     bootstraps = []
 *     addseed = 0             # <<<<<<<<<<<<<<
 * 
 *     if grid == None:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_addseed = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":1493
 *     addseed = 0
 * 
 *     if grid == None:             # <<<<<<<<<<<<<<
 *         grid = len(comb.columns.tolist())+1
 *     if verbose != 0:
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_grid, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1493, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1493, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1494
 * 
 *     if grid == None:
 *         grid = len(comb.columns.tolist())+1             # <<<<<<<<<<<<<<
 *     if verbose != 0:
 *         print('grid size: '+str(grid))
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyInt_FromSsize_t((__pyx_t_6 + 1)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_grid, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1493
 *     addseed = 0
 * 
 *     if grid == None:             # <<<<<<<<<<<<<<
 *         grid = len(comb.columns.tolist())+1
 *     if verbose != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1495
 *     if grid == None:
 *         grid = len(comb.columns.tolist())+1
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('grid size: '+str(grid))
 *     if verbose != 0:
 */
  __pyx_t_4 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1495, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1496
 *         grid = len(comb.columns.tolist())+1
 *     if verbose != 0:
 *         print('grid size: '+str(grid))             # <<<<<<<<<<<<<<
 *     if verbose != 0:
 *         print('bandwidth: '+str(bandwidth))
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyUnicode_Concat(__pyx_kp_u_grid_size, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1495
 *     if grid == None:
 *         grid = len(comb.columns.tolist())+1
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('grid size: '+str(grid))
 *     if verbose != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1497
 *     if verbose != 0:
 *         print('grid size: '+str(grid))
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('bandwidth: '+str(bandwidth))
 * 
 */
  __pyx_t_4 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1498
 *         print('grid size: '+str(grid))
 *     if verbose != 0:
 *         print('bandwidth: '+str(bandwidth))             # <<<<<<<<<<<<<<
 * 
 *     report = report + 'Grid size is: ' + str(grid) + '\n'
 */
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_bandwidth_2, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1497
 *     if verbose != 0:
 *         print('grid size: '+str(grid))
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('bandwidth: '+str(bandwidth))
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1500
 *         print('bandwidth: '+str(bandwidth))
 * 
 *     report = report + 'Grid size is: ' + str(grid) + '\n'             # <<<<<<<<<<<<<<
 *     report = report + 'Universal bandwidth is: ' + str(bandwidth) + '\n'
 * 
 */
  __pyx_t_12 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Grid_size_is); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyNumber_Add(__pyx_t_12, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1501
 * 
 *     report = report + 'Grid size is: ' + str(grid) + '\n'
 *     report = report + 'Universal bandwidth is: ' + str(bandwidth) + '\n'             # <<<<<<<<<<<<<<
 * 
 *     savecomb = comb.copy()
 */
  __pyx_t_4 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Universal_bandwidth_is); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_12);
  __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1503
 *     report = report + 'Universal bandwidth is: ' + str(bandwidth) + '\n'
 * 
 *     savecomb = comb.copy()             # <<<<<<<<<<<<<<
 *     seedlists = []
 *     if seed_name == None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_savecomb = __pyx_t_12;
  __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1504
 * 
 *     savecomb = comb.copy()
 *     seedlists = []             # <<<<<<<<<<<<<<
 *     if seed_name == None:
 *         seedlists.append([0]*len(comb.columns.tolist()))
 */
  __pyx_t_12 = PyList_New(0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_v_seedlists = ((PyObject*)__pyx_t_12);
  __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1505
 *     savecomb = comb.copy()
 *     seedlists = []
 *     if seed_name == None:             # <<<<<<<<<<<<<<
 *         seedlists.append([0]*len(comb.columns.tolist()))
 *         CICs.append('')
 */
  __pyx_t_12 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1505, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1505, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1506
 *     seedlists = []
 *     if seed_name == None:
 *         seedlists.append([0]*len(comb.columns.tolist()))             # <<<<<<<<<<<<<<
 *         CICs.append('')
 *         if verbose != 0:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_12 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_t_12); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyList_New(1 * ((__pyx_t_6<0) ? 0:__pyx_t_6)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    { Py_ssize_t __pyx_temp;
      for (__pyx_temp=0; __pyx_temp < __pyx_t_6; __pyx_temp++) {
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyList_SET_ITEM(__pyx_t_12, __pyx_temp, __pyx_int_0);
      }
    }
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedlists, __pyx_t_12); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1506, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1507
 *     if seed_name == None:
 *         seedlists.append([0]*len(comb.columns.tolist()))
 *         CICs.append('')             # <<<<<<<<<<<<<<
 *         if verbose != 0:
 *             print('seed Search...')
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_kp_u__2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1507, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1508
 *         seedlists.append([0]*len(comb.columns.tolist()))
 *         CICs.append('')
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('seed Search...')
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
    __pyx_t_12 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1508, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1509
 *         CICs.append('')
 *         if verbose != 0:
 *             print('seed Search...')             # <<<<<<<<<<<<<<
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                              k, int(len(comb.index)-1), size, bandwidth,
 */
      __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1509, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1508
 *         seedlists.append([0]*len(comb.columns.tolist()))
 *         CICs.append('')
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('seed Search...')
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1510
 *         if verbose != 0:
 *             print('seed Search...')
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                              k, int(len(comb.index)-1), size, bandwidth,
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_values); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_astype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_10 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_12 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1511
 *             print('seed Search...')
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                              k, int(len(comb.index)-1), size, bandwidth,             # <<<<<<<<<<<<<<
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)
 *         if if_pval == True:
 */
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1511, __pyx_L1_error)
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_6 = PyObject_Length(__pyx_t_12); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1511, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1512
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                              k, int(len(comb.index)-1), size, bandwidth,
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)             # <<<<<<<<<<<<<<
 *         if if_pval == True:
 *             pVals.append('')
 */
    __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1512, __pyx_L1_error)
    __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1512, __pyx_L1_error)
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1512, __pyx_L1_error)
    __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1512, __pyx_L1_error)
    __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1512, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1510
 *         if verbose != 0:
 *             print('seed Search...')
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                              k, int(len(comb.index)-1), size, bandwidth,
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)
 */
    __pyx_t_20 = __pyx_f_8revealer_21REVEALER_runbenchmark_findBestIC(__pyx_v_y, __pyx_t_14, __pyx_t_11, ((int)(__pyx_t_6 - 1)), __pyx_v_size, __pyx_v_bandwidth, __pyx_t_15, __pyx_t_16, __pyx_v_direction, __pyx_t_17, __pyx_t_18, __pyx_t_19, 0);
    __PYX_XDEC_MEMVIEW(&__pyx_t_14, 1);
    __pyx_t_14.memview = NULL;
    __pyx_t_14.data = NULL;
    __pyx_t_21 = __pyx_t_20.f0;
    __pyx_t_12 = PyFloat_FromDouble(__pyx_t_20.f1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_v_seedid = __pyx_t_21;
    __pyx_v_IC = __pyx_t_12;
    __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1513
 *                              k, int(len(comb.index)-1), size, bandwidth,
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVals.append('')
 *             results = prepPvalIC(comb = comb, size = size, bandwidth = bandwidth, k = k,
 */
    __pyx_t_12 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1513, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1513, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1514
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)
 *         if if_pval == True:
 *             pVals.append('')             # <<<<<<<<<<<<<<
 *             results = prepPvalIC(comb = comb, size = size, bandwidth = bandwidth, k = k,
 *                                  bandwidth_mult = bandwidth_mult, bandwidth_adj = bandwidth_adj,
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_kp_u__2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1514, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1515
 *         if if_pval == True:
 *             pVals.append('')
 *             results = prepPvalIC(comb = comb, size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                  bandwidth_mult = bandwidth_mult, bandwidth_adj = bandwidth_adj,
 *                                  grid = grid, thread_number = thread_number, neighborhood = neighborhood)
 */
      __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "revealer/REVEALER_runbenchmark.pyx":1517
 *             results = prepPvalIC(comb = comb, size = size, bandwidth = bandwidth, k = k,
 *                                  bandwidth_mult = bandwidth_mult, bandwidth_adj = bandwidth_adj,
 *                                  grid = grid, thread_number = thread_number, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             pVal = calcPvalIC(results = results, IC = IC, direction = direction)
 *             pVals.append(pVal)
 */
      __pyx_t_4 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalIC(__pyx_v_comb, __pyx_v_k, __pyx_t_12, __pyx_t_1, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_results = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1518
 *                                  bandwidth_mult = bandwidth_mult, bandwidth_adj = bandwidth_adj,
 *                                  grid = grid, thread_number = thread_number, neighborhood = neighborhood)
 *             pVal = calcPvalIC(results = results, IC = IC, direction = direction)             # <<<<<<<<<<<<<<
 *             pVals.append(pVal)
 *             pVals.append(pVal)
 */
      __pyx_t_4 = __pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalIC(__pyx_v_results, __pyx_v_IC, __pyx_v_direction, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1518, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_pVal = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1519
 *                                  grid = grid, thread_number = thread_number, neighborhood = neighborhood)
 *             pVal = calcPvalIC(results = results, IC = IC, direction = direction)
 *             pVals.append(pVal)             # <<<<<<<<<<<<<<
 *             pVals.append(pVal)
 * 
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_v_pVal); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1519, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1520
 *             pVal = calcPvalIC(results = results, IC = IC, direction = direction)
 *             pVals.append(pVal)
 *             pVals.append(pVal)             # <<<<<<<<<<<<<<
 * 
 *         if if_bootstrap == True:
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_v_pVal); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1520, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1513
 *                              k, int(len(comb.index)-1), size, bandwidth,
 *                              bandwidth_mult, bandwidth_adj, direction,grid,thread_number, neighborhood)
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVals.append('')
 *             results = prepPvalIC(comb = comb, size = size, bandwidth = bandwidth, k = k,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1522
 *             pVals.append(pVal)
 * 
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstraps.append('')
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1522, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1522, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1523
 * 
 *         if if_bootstrap == True:
 *             bootstraps.append('')             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,
 *                                         bandwidth = bandwidth, k = k,
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_kp_u__2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1523, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1524
 *         if if_bootstrap == True:
 *             bootstraps.append('')
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,             # <<<<<<<<<<<<<<
 *                                         bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_calcBootstrapIC); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_3 = __Pyx_PyInt_From_npy_long(__pyx_v_seedid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = PyList_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_10, 0, __pyx_int_0);
      __Pyx_GIVEREF(__pyx_t_3);
      PyList_SET_ITEM(__pyx_t_10, 1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_10);
      __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_12, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_subcomb, __pyx_t_10) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_size, __pyx_t_10) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1525
 *             bootstraps.append('')
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,
 *                                         bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_10 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_bandwidth, __pyx_t_10) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1526
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,
 *                                         bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1527
 *                                         bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 */
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1528
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             bootstraps.append(bootstrap)
 *             bootstraps.append(bootstrap)
 */
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1524
 *         if if_bootstrap == True:
 *             bootstraps.append('')
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,             # <<<<<<<<<<<<<<
 *                                         bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_bootstrap = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1529
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 *             bootstraps.append(bootstrap)
 * 
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1529, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1530
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 *             bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 * 
 *         CICs.append(IC)
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1530, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1522
 *             pVals.append(pVal)
 * 
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstraps.append('')
 *             bootstrap = calcBootstrapIC(subcomb = comb.iloc[[0,seedid],], size = size,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1532
 *             bootstraps.append(bootstrap)
 * 
 *         CICs.append(IC)             # <<<<<<<<<<<<<<
 *         CICs.append(IC)
 * 
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_v_IC); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1532, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1533
 * 
 *         CICs.append(IC)
 *         CICs.append(IC)             # <<<<<<<<<<<<<<
 * 
 *         if if_intermediate == True:
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_v_IC); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1533, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1535
 *         CICs.append(IC)
 * 
 *         if if_intermediate == True:             # <<<<<<<<<<<<<<
 *             topmatch(comb = comb, currentseed = [0]*len(comb.columns.tolist()), y = y, grid = grid,
 *                      k = k, size = size, bandwidth = bandwidth, bandwidth_mult = bandwidth_mult,
 */
    __pyx_t_10 = PyObject_RichCompare(__pyx_v_if_intermediate, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1535, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1535, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1536
 * 
 *         if if_intermediate == True:
 *             topmatch(comb = comb, currentseed = [0]*len(comb.columns.tolist()), y = y, grid = grid,             # <<<<<<<<<<<<<<
 *                      k = k, size = size, bandwidth = bandwidth, bandwidth_mult = bandwidth_mult,
 *                      bandwidth_adj = bandwidth_adj,thread_number =thread_number,
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_10 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = PyObject_Length(__pyx_t_10); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyList_New(1 * ((__pyx_t_6<0) ? 0:__pyx_t_6)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      { Py_ssize_t __pyx_temp;
        for (__pyx_temp=0; __pyx_temp < __pyx_t_6; __pyx_temp++) {
          __Pyx_INCREF(__pyx_int_0);
          __Pyx_GIVEREF(__pyx_int_0);
          PyList_SET_ITEM(__pyx_t_10, __pyx_temp, __pyx_int_0);
        }
      }
      __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_y, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "revealer/REVEALER_runbenchmark.pyx":1537
 *         if if_intermediate == True:
 *             topmatch(comb = comb, currentseed = [0]*len(comb.columns.tolist()), y = y, grid = grid,
 *                      k = k, size = size, bandwidth = bandwidth, bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                      bandwidth_adj = bandwidth_adj,thread_number =thread_number,
 *                      direction = direction, num_top = num_top, prefix = prefix, locusdic = locusdic,
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "revealer/REVEALER_runbenchmark.pyx":1536
 * 
 *         if if_intermediate == True:
 *             topmatch(comb = comb, currentseed = [0]*len(comb.columns.tolist()), y = y, grid = grid,             # <<<<<<<<<<<<<<
 *                      k = k, size = size, bandwidth = bandwidth, bandwidth_mult = bandwidth_mult,
 *                      bandwidth_adj = bandwidth_adj,thread_number =thread_number,
 */
      __pyx_t_12 = __pyx_f_8revealer_21REVEALER_runbenchmark_topmatch(__pyx_v_comb, __pyx_t_10, __pyx_t_4, __pyx_v_grid, __pyx_v_k, __pyx_t_1, __pyx_t_3, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_thread_number, __pyx_v_direction, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_figure_format, Py_False, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_collapse, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_int_0, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_target_name, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1535
 *         CICs.append(IC)
 * 
 *         if if_intermediate == True:             # <<<<<<<<<<<<<<
 *             topmatch(comb = comb, currentseed = [0]*len(comb.columns.tolist()), y = y, grid = grid,
 *                      k = k, size = size, bandwidth = bandwidth, bandwidth_mult = bandwidth_mult,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1546
 *                      neighborhood = neighborhood)
 * 
 *         currentseed = comb.iloc[seedid].tolist()             # <<<<<<<<<<<<<<
 *         seedlists.append(currentseed)
 *         addseed = currentseed
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_12 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_currentseed = __pyx_t_12;
    __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1547
 * 
 *         currentseed = comb.iloc[seedid].tolist()
 *         seedlists.append(currentseed)             # <<<<<<<<<<<<<<
 *         addseed = currentseed
 *         seedids.append(comb.index[seedid])
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedlists, __pyx_v_currentseed); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1547, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1548
 *         currentseed = comb.iloc[seedid].tolist()
 *         seedlists.append(currentseed)
 *         addseed = currentseed             # <<<<<<<<<<<<<<
 *         seedids.append(comb.index[seedid])
 *         if verbose != 0:
 */
    __Pyx_INCREF(__pyx_v_currentseed);
    __Pyx_DECREF_SET(__pyx_v_addseed, __pyx_v_currentseed);

    /* "revealer/REVEALER_runbenchmark.pyx":1549
 *         seedlists.append(currentseed)
 *         addseed = currentseed
 *         seedids.append(comb.index[seedid])             # <<<<<<<<<<<<<<
 *         if verbose != 0:
 *             print('Picked seed is: '+ comb.index[seedid])
 */
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_12, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedids, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1549, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1550
 *         addseed = currentseed
 *         seedids.append(comb.index[seedid])
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Picked seed is: '+ comb.index[seedid])
 *         report = report + 'Picked seed is: '+ comb.index[seedid] + '\n'
 */
    __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1550, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1551
 *         seedids.append(comb.index[seedid])
 *         if verbose != 0:
 *             print('Picked seed is: '+ comb.index[seedid])             # <<<<<<<<<<<<<<
 *         report = report + 'Picked seed is: '+ comb.index[seedid] + '\n'
 *         comb = comb.drop(index = comb.index[seedid])
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Picked_seed_is, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1550
 *         addseed = currentseed
 *         seedids.append(comb.index[seedid])
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Picked seed is: '+ comb.index[seedid])
 *         report = report + 'Picked seed is: '+ comb.index[seedid] + '\n'
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1552
 *         if verbose != 0:
 *             print('Picked seed is: '+ comb.index[seedid])
 *         report = report + 'Picked seed is: '+ comb.index[seedid] + '\n'             # <<<<<<<<<<<<<<
 *         comb = comb.drop(index = comb.index[seedid])
 *     else:
 */
    __pyx_t_12 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Picked_seed_is); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_12, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1553
 *             print('Picked seed is: '+ comb.index[seedid])
 *         report = report + 'Picked seed is: '+ comb.index[seedid] + '\n'
 *         comb = comb.drop(index = comb.index[seedid])             # <<<<<<<<<<<<<<
 *     else:
 *         currentseed = comb.loc['firstseed'].tolist()
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_drop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_12, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_index, __pyx_t_4) < 0) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1505
 *     savecomb = comb.copy()
 *     seedlists = []
 *     if seed_name == None:             # <<<<<<<<<<<<<<
 *         seedlists.append([0]*len(comb.columns.tolist()))
 *         CICs.append('')
 */
    goto __pyx_L15;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1555
 *         comb = comb.drop(index = comb.index[seedid])
 *     else:
 *         currentseed = comb.loc['firstseed'].tolist()             # <<<<<<<<<<<<<<
 *         seedlists.append(currentseed)
 *         cythonseed = np.asarray(currentseed).astype(int)
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_u_firstseed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_currentseed = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1556
 *     else:
 *         currentseed = comb.loc['firstseed'].tolist()
 *         seedlists.append(currentseed)             # <<<<<<<<<<<<<<
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedlists, __pyx_v_currentseed); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1556, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1557
 *         currentseed = comb.loc['firstseed'].tolist()
 *         seedlists.append(currentseed)
 *         cythonseed = np.asarray(currentseed).astype(int)             # <<<<<<<<<<<<<<
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_1, __pyx_v_currentseed) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_currentseed);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_astype); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_3, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_12, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_22 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_22.memview)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_cythonseed = __pyx_t_22;
    __pyx_t_22.memview = NULL;
    __pyx_t_22.data = NULL;

    /* "revealer/REVEALER_runbenchmark.pyx":1558
 *         seedlists.append(currentseed)
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,             # <<<<<<<<<<<<<<
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 */
    __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1558, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1559
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 */
    __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1559, __pyx_L1_error)
    __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1559, __pyx_L1_error)
    __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1559, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1558
 *         seedlists.append(currentseed)
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,             # <<<<<<<<<<<<<<
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 */
    __pyx_t_4 = PyFloat_FromDouble(__pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_v_y, __pyx_v_cythonseed, __pyx_t_19, __pyx_v_size, __pyx_v_bandwidth, __pyx_t_16, __pyx_t_15, __pyx_t_18, __pyx_v_deltay, __pyx_v_miny, 0, NULL)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_IC = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1560
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1560, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1560, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1561
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_calcBootstrapIC); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_12 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_currentseed);
      __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_subcomb, __pyx_t_3) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1562
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_size, __pyx_t_3) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_bandwidth, __pyx_t_3) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1563
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1564
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 */
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1565
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             bootstraps.append(bootstrap)
 *         if if_pval == True:
 */
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1561, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1561
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_v_bootstrap = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1566
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 *         if if_pval == True:
 *             subcomb = comb.copy()
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1566, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1560
 *         IC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                  bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1567
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             subcomb = comb.copy()
 *             subcomb.iloc[1] = currentseed
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1567, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1567, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1568
 *             bootstraps.append(bootstrap)
 *         if if_pval == True:
 *             subcomb = comb.copy()             # <<<<<<<<<<<<<<
 *             subcomb.iloc[1] = currentseed
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 */
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_copy); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_v_subcomb = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1569
 *         if if_pval == True:
 *             subcomb = comb.copy()
 *             subcomb.iloc[1] = currentseed             # <<<<<<<<<<<<<<
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__Pyx_SetItemInt(__pyx_t_3, 1, __pyx_v_currentseed, long, 1, __Pyx_PyInt_From_long, 0, 0, 0) < 0)) __PYX_ERR(0, 1569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1570
 *             subcomb = comb.copy()
 *             subcomb.iloc[1] = currentseed
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_calcIndivisualPvalIC); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pd); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_10 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_10);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_10);
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_currentseed);
      __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_10, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_subcomb, __pyx_t_4) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1571
 *             subcomb.iloc[1] = currentseed
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_size, __pyx_t_4) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_bandwidth, __pyx_t_4) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1572
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1573
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 *             pVals.append(pVal)
 */
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1574
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             pVals.append(pVal)
 * 
 */
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1570, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1570
 *             subcomb = comb.copy()
 *             subcomb.iloc[1] = currentseed
 *             pVal = calcIndivisualPvalIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_v_pVal = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1575
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number = thread_number,IC = IC, neighborhood = neighborhood)
 *             pVals.append(pVal)             # <<<<<<<<<<<<<<
 * 
 *         CICs.append(IC)
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_v_pVal); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1575, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1567
 *                                         thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             subcomb = comb.copy()
 *             subcomb.iloc[1] = currentseed
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1577
 *             pVals.append(pVal)
 * 
 *         CICs.append(IC)             # <<<<<<<<<<<<<<
 *         addseed = currentseed
 *         comb = comb.drop(index=['firstseed'])
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_v_IC); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1577, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1578
 * 
 *         CICs.append(IC)
 *         addseed = currentseed             # <<<<<<<<<<<<<<
 *         comb = comb.drop(index=['firstseed'])
 * 
 */
    __Pyx_INCREF(__pyx_v_currentseed);
    __Pyx_DECREF_SET(__pyx_v_addseed, __pyx_v_currentseed);

    /* "revealer/REVEALER_runbenchmark.pyx":1579
 *         CICs.append(IC)
 *         addseed = currentseed
 *         comb = comb.drop(index=['firstseed'])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_drop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_n_u_firstseed);
    __Pyx_GIVEREF(__pyx_n_u_firstseed);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_firstseed);
    if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_index, __pyx_t_3) < 0) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L15:;

  /* "revealer/REVEALER_runbenchmark.pyx":1582
 * 
 * 
 *     n=1             # <<<<<<<<<<<<<<
 *     while (max_iteration == -1 or n <= max_iteration) and (len(comb.index.tolist()) > 1):
 * 
 */
  __Pyx_INCREF(__pyx_int_1);
  __pyx_v_n = __pyx_int_1;

  /* "revealer/REVEALER_runbenchmark.pyx":1583
 * 
 *     n=1
 *     while (max_iteration == -1 or n <= max_iteration) and (len(comb.index.tolist()) > 1):             # <<<<<<<<<<<<<<
 * 
 *         if verbose != 0:
 */
  while (1) {
    __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_max_iteration, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_23) {
    } else {
      goto __pyx_L26_next_and;
    }
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_n, __pyx_v_max_iteration, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_23) {
    } else {
      __pyx_t_9 = __pyx_t_23;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_L26_next_and:;
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_23 = ((__pyx_t_6 > 1) != 0);
    __pyx_t_9 = __pyx_t_23;
    __pyx_L25_bool_binop_done:;
    if (!__pyx_t_9) break;

    /* "revealer/REVEALER_runbenchmark.pyx":1585
 *     while (max_iteration == -1 or n <= max_iteration) and (len(comb.index.tolist()) > 1):
 * 
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print("Iteration" + str(n) + ':')
 *         cythonseed = np.asarray(currentseed).astype(int)
 */
    __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1586
 * 
 *         if verbose != 0:
 *             print("Iteration" + str(n) + ':')             # <<<<<<<<<<<<<<
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         #substart = time.time()
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_n_u_Iteration, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__23); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1585
 *     while (max_iteration == -1 or n <= max_iteration) and (len(comb.index.tolist()) > 1):
 * 
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print("Iteration" + str(n) + ':')
 *         cythonseed = np.asarray(currentseed).astype(int)
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1587
 *         if verbose != 0:
 *             print("Iteration" + str(n) + ':')
 *         cythonseed = np.asarray(currentseed).astype(int)             # <<<<<<<<<<<<<<
 *         #substart = time.time()
 *         seedid,CIC,spenttime = findBestCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_np); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_12, __pyx_v_currentseed) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_currentseed);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_astype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_22 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_22.memview)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_XDEC_MEMVIEW(&__pyx_v_cythonseed, 1);
    __pyx_v_cythonseed = __pyx_t_22;
    __pyx_t_22.memview = NULL;
    __pyx_t_22.data = NULL;

    /* "revealer/REVEALER_runbenchmark.pyx":1589
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         #substart = time.time()
 *         seedid,CIC,spenttime = findBestCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, direction, grid,thread_number, neighborhood)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_GetSlice(__pyx_t_1, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_astype); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_12 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_1, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_10, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_2 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_10, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1590
 *         #substart = time.time()
 *         seedid,CIC,spenttime = findBestCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, direction, grid,thread_number, neighborhood)
 * 
 */
    __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1590, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1590, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1591
 *         seedid,CIC,spenttime = findBestCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, direction, grid,thread_number, neighborhood)             # <<<<<<<<<<<<<<
 * 
 * #         if verbose != 0:
 */
    __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1591, __pyx_L1_error)
    __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1591, __pyx_L1_error)
    __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1591, __pyx_L1_error)
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1591, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1591, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1589
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         #substart = time.time()
 *         seedid,CIC,spenttime = findBestCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, direction, grid,thread_number, neighborhood)
 */
    __pyx_t_24 = __pyx_f_8revealer_21REVEALER_runbenchmark_findBestCIC(__pyx_v_y, __pyx_v_cythonseed, __pyx_t_14, __pyx_t_18, ((int)(__pyx_t_6 - 1)), __pyx_v_size, __pyx_v_bandwidth, __pyx_t_15, __pyx_t_16, __pyx_v_direction, __pyx_t_19, __pyx_t_17, __pyx_t_11, 0);
    __PYX_XDEC_MEMVIEW(&__pyx_t_14, 1);
    __pyx_t_14.memview = NULL;
    __pyx_t_14.data = NULL;
    __pyx_t_21 = __pyx_t_24.f0;
    __pyx_t_4 = PyFloat_FromDouble(__pyx_t_24.f1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyFloat_FromDouble(__pyx_t_24.f2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_seedid = __pyx_t_21;
    __Pyx_XDECREF_SET(__pyx_v_CIC, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_spenttime, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1597
 * #         report = report + 'Time used to run one loop: %s second(s)'%(int(time.time() - substart)) + '\n'
 * 
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Time used to run one loop: %s second(s)'%(int(spenttime)))
 *         report = report + 'Time used to run one loop: %s second(s)'%(int(spenttime)) + '\n'
 */
    __pyx_t_3 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1597, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1598
 * 
 *         if verbose != 0:
 *             print('Time used to run one loop: %s second(s)'%(int(spenttime)))             # <<<<<<<<<<<<<<
 *         report = report + 'Time used to run one loop: %s second(s)'%(int(spenttime)) + '\n'
 * 
 */
      __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_v_spenttime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Time_used_to_run_one_loop_s_seco, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1597
 * #         report = report + 'Time used to run one loop: %s second(s)'%(int(time.time() - substart)) + '\n'
 * 
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print('Time used to run one loop: %s second(s)'%(int(spenttime)))
 *         report = report + 'Time used to run one loop: %s second(s)'%(int(spenttime)) + '\n'
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1599
 *         if verbose != 0:
 *             print('Time used to run one loop: %s second(s)'%(int(spenttime)))
 *         report = report + 'Time used to run one loop: %s second(s)'%(int(spenttime)) + '\n'             # <<<<<<<<<<<<<<
 * 
 *         newseed = comb.iloc[seedid].tolist()
 */
    __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_v_spenttime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Time_used_to_run_one_loop_s_seco, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_v_report, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1601
 *         report = report + 'Time used to run one loop: %s second(s)'%(int(spenttime)) + '\n'
 * 
 *         newseed = comb.iloc[seedid].tolist()             # <<<<<<<<<<<<<<
 * 
 *         if if_intermediate == True:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_newseed, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1603
 *         newseed = comb.iloc[seedid].tolist()
 * 
 *         if if_intermediate == True:             # <<<<<<<<<<<<<<
 *             topmatch(comb = comb, currentseed = currentseed, y = y, grid = grid, k = k, size = size,
 *                      bandwidth = bandwidth, bandwidth_mult = bandwidth_mult, locusdic = locusdic,
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_if_intermediate, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1603, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1603, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1604
 * 
 *         if if_intermediate == True:
 *             topmatch(comb = comb, currentseed = currentseed, y = y, grid = grid, k = k, size = size,             # <<<<<<<<<<<<<<
 *                      bandwidth = bandwidth, bandwidth_mult = bandwidth_mult, locusdic = locusdic,
 *                      bandwidth_adj = bandwidth_adj,thread_number =thread_number,
 */
      __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_y, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "revealer/REVEALER_runbenchmark.pyx":1605
 *         if if_intermediate == True:
 *             topmatch(comb = comb, currentseed = currentseed, y = y, grid = grid, k = k, size = size,
 *                      bandwidth = bandwidth, bandwidth_mult = bandwidth_mult, locusdic = locusdic,             # <<<<<<<<<<<<<<
 *                      bandwidth_adj = bandwidth_adj,thread_number =thread_number,
 *                      direction = direction, num_top = num_top, prefix = prefix,
 */
      __pyx_t_2 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "revealer/REVEALER_runbenchmark.pyx":1604
 * 
 *         if if_intermediate == True:
 *             topmatch(comb = comb, currentseed = currentseed, y = y, grid = grid, k = k, size = size,             # <<<<<<<<<<<<<<
 *                      bandwidth = bandwidth, bandwidth_mult = bandwidth_mult, locusdic = locusdic,
 *                      bandwidth_adj = bandwidth_adj,thread_number =thread_number,
 */
      __pyx_t_10 = __pyx_f_8revealer_21REVEALER_runbenchmark_topmatch(__pyx_v_comb, __pyx_v_currentseed, __pyx_t_4, __pyx_v_grid, __pyx_v_k, __pyx_t_3, __pyx_t_2, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_thread_number, __pyx_v_direction, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_figure_format, Py_True, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_collapse, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_n, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_target_name, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1603
 *         newseed = comb.iloc[seedid].tolist()
 * 
 *         if if_intermediate == True:             # <<<<<<<<<<<<<<
 *             topmatch(comb = comb, currentseed = currentseed, y = y, grid = grid, k = k, size = size,
 *                      bandwidth = bandwidth, bandwidth_mult = bandwidth_mult, locusdic = locusdic,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1614
 *                      neighborhood = neighborhood)
 * 
 *         currentseed = seedCombine(currentseed,newseed)             # <<<<<<<<<<<<<<
 *         seedids.append(comb.index[seedid])
 *         CICs.append(CIC)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_seedCombine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_currentseed, __pyx_v_newseed};
      __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1614, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_currentseed, __pyx_v_newseed};
      __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1614, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1614, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_11, __pyx_v_currentseed);
      __Pyx_INCREF(__pyx_v_newseed);
      __Pyx_GIVEREF(__pyx_v_newseed);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_11, __pyx_v_newseed);
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1614, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_currentseed, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1615
 * 
 *         currentseed = seedCombine(currentseed,newseed)
 *         seedids.append(comb.index[seedid])             # <<<<<<<<<<<<<<
 *         CICs.append(CIC)
 *         seedlists.append(currentseed)
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_10, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedids, __pyx_t_2); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1615, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1616
 *         currentseed = seedCombine(currentseed,newseed)
 *         seedids.append(comb.index[seedid])
 *         CICs.append(CIC)             # <<<<<<<<<<<<<<
 *         seedlists.append(currentseed)
 *         if if_pval == True:
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_v_CIC); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1616, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1617
 *         seedids.append(comb.index[seedid])
 *         CICs.append(CIC)
 *         seedlists.append(currentseed)             # <<<<<<<<<<<<<<
 *         if if_pval == True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedlists, __pyx_v_currentseed); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1617, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1618
 *         CICs.append(CIC)
 *         seedlists.append(currentseed)
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 */
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1618, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1618, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1619
 *         seedlists.append(currentseed)
 *         if if_pval == True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,             # <<<<<<<<<<<<<<
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_cythonseed, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "revealer/REVEALER_runbenchmark.pyx":1620
 *         if if_pval == True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 *                                   thread_number =thread_number, neighborhood = neighborhood)
 */
      __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1620, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "revealer/REVEALER_runbenchmark.pyx":1619
 *         seedlists.append(currentseed)
 *         if if_pval == True:
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,             # <<<<<<<<<<<<<<
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_3 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalCIC(__pyx_v_comb, __pyx_t_2, __pyx_v_k, __pyx_t_10, __pyx_t_4, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_results, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1623
 *                                   bandwidth_adj = bandwidth_adj, grid = grid,
 *                                   thread_number =thread_number, neighborhood = neighborhood)
 *             pVals.append(calcPvalCIC(results = results, IC = CIC, direction = direction))             # <<<<<<<<<<<<<<
 * 
 *         if if_bootstrap == True:
 */
      __pyx_t_3 = __pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalCIC(__pyx_v_results, __pyx_v_CIC, __pyx_v_direction, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1623, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1618
 *         CICs.append(CIC)
 *         seedlists.append(currentseed)
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             results = prepPvalCIC(comb = comb, cythonseed = cythonseed, size = size,
 *                                   bandwidth = bandwidth, k = k, bandwidth_mult = bandwidth_mult,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1625
 *             pVals.append(calcPvalCIC(results = results, IC = CIC, direction = direction))
 * 
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrap(subcomb = comb.iloc[[0,seedid],], cythonseed = cythonseed,
 *                                       size = size, bandwidth = bandwidth, k = k,
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1625, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1625, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1626
 * 
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrap(subcomb = comb.iloc[[0,seedid],], cythonseed = cythonseed,             # <<<<<<<<<<<<<<
 *                                       size = size, bandwidth = bandwidth, k = k,
 *                                       bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_calcBootstrap); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_2 = __Pyx_PyInt_From_npy_long(__pyx_v_seedid); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_12 = PyList_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_12, 0, __pyx_int_0);
      __Pyx_GIVEREF(__pyx_t_2);
      PyList_SET_ITEM(__pyx_t_12, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_subcomb, __pyx_t_12) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __pyx_memoryview_fromslice(__pyx_v_cythonseed, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_cythonseed, __pyx_t_12) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1627
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrap(subcomb = comb.iloc[[0,seedid],], cythonseed = cythonseed,
 *                                       size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                       bandwidth_mult = bandwidth_mult,
 *                                       bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_size, __pyx_t_12) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_bandwidth, __pyx_t_12) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1628
 *             bootstrap = calcBootstrap(subcomb = comb.iloc[[0,seedid],], cythonseed = cythonseed,
 *                                       size = size, bandwidth = bandwidth, k = k,
 *                                       bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                       bandwidth_adj = bandwidth_adj, grid = grid,
 *                                       thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1629
 *                                       size = size, bandwidth = bandwidth, k = k,
 *                                       bandwidth_mult = bandwidth_mult,
 *                                       bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                       thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 */
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1630
 *                                       bandwidth_mult = bandwidth_mult,
 *                                       bandwidth_adj = bandwidth_adj, grid = grid,
 *                                       thread_number = thread_number, IC = IC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             bootstraps.append(bootstrap)
 * 
 */
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_IC, __pyx_v_IC) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1626, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1626
 * 
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrap(subcomb = comb.iloc[[0,seedid],], cythonseed = cythonseed,             # <<<<<<<<<<<<<<
 *                                       size = size, bandwidth = bandwidth, k = k,
 *                                       bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_bootstrap, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1631
 *                                       bandwidth_adj = bandwidth_adj, grid = grid,
 *                                       thread_number = thread_number, IC = IC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1631, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1625
 *             pVals.append(calcPvalCIC(results = results, IC = CIC, direction = direction))
 * 
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrap(subcomb = comb.iloc[[0,seedid],], cythonseed = cythonseed,
 *                                       size = size, bandwidth = bandwidth, k = k,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1635
 * 
 *         # Update cythonseed after calculating bootstrap and p-value
 *         cythonseed = np.asarray(currentseed).astype(int)             # <<<<<<<<<<<<<<
 *         if verbose != 0:
 *             print("CIC calculated in this round is: " + str(CIC))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_currentseed) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_currentseed);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_astype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_22 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_22.memview)) __PYX_ERR(0, 1635, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __PYX_XDEC_MEMVIEW(&__pyx_v_cythonseed, 1);
    __pyx_v_cythonseed = __pyx_t_22;
    __pyx_t_22.memview = NULL;
    __pyx_t_22.data = NULL;

    /* "revealer/REVEALER_runbenchmark.pyx":1636
 *         # Update cythonseed after calculating bootstrap and p-value
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print("CIC calculated in this round is: " + str(CIC))
 *             print("Best feature choosen in this round is: "+comb.index[seedid])
 */
    __pyx_t_12 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1636, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1637
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         if verbose != 0:
 *             print("CIC calculated in this round is: " + str(CIC))             # <<<<<<<<<<<<<<
 *             print("Best feature choosen in this round is: "+comb.index[seedid])
 *         report = report + "Round " + str(n) + '\n'
 */
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_CIC); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_CIC_calculated_in_this_round_is, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1638
 *         if verbose != 0:
 *             print("CIC calculated in this round is: " + str(CIC))
 *             print("Best feature choosen in this round is: "+comb.index[seedid])             # <<<<<<<<<<<<<<
 *         report = report + "Round " + str(n) + '\n'
 *         report = report + "CIC calculated in this round is: " + str(CIC) + '\n'
 */
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_12, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = PyNumber_Add(__pyx_kp_u_Best_feature_choosen_in_this_rou, __pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1636
 *         # Update cythonseed after calculating bootstrap and p-value
 *         cythonseed = np.asarray(currentseed).astype(int)
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print("CIC calculated in this round is: " + str(CIC))
 *             print("Best feature choosen in this round is: "+comb.index[seedid])
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1639
 *             print("CIC calculated in this round is: " + str(CIC))
 *             print("Best feature choosen in this round is: "+comb.index[seedid])
 *         report = report + "Round " + str(n) + '\n'             # <<<<<<<<<<<<<<
 *         report = report + "CIC calculated in this round is: " + str(CIC) + '\n'
 *         report = report + "Best feature choosen in this round is: "+comb.index[seedid] + '\n'
 */
    __pyx_t_2 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Round); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_n); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_12);
    __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1640
 *             print("Best feature choosen in this round is: "+comb.index[seedid])
 *         report = report + "Round " + str(n) + '\n'
 *         report = report + "CIC calculated in this round is: " + str(CIC) + '\n'             # <<<<<<<<<<<<<<
 *         report = report + "Best feature choosen in this round is: "+comb.index[seedid] + '\n'
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 */
    __pyx_t_12 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_CIC_calculated_in_this_round_is); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_CIC); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_Add(__pyx_t_12, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1641
 *         report = report + "Round " + str(n) + '\n'
 *         report = report + "CIC calculated in this round is: " + str(CIC) + '\n'
 *         report = report + "Best feature choosen in this round is: "+comb.index[seedid] + '\n'             # <<<<<<<<<<<<<<
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 */
    __pyx_t_4 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_Best_feature_choosen_in_this_rou); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_2, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_12);
    __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1642
 *         report = report + "CIC calculated in this round is: " + str(CIC) + '\n'
 *         report = report + "Best feature choosen in this round is: "+comb.index[seedid] + '\n'
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,             # <<<<<<<<<<<<<<
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 */
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1642, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1643
 *         report = report + "Best feature choosen in this round is: "+comb.index[seedid] + '\n'
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 */
    __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1643, __pyx_L1_error)
    __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1643, __pyx_L1_error)
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1643, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1642
 *         report = report + "CIC calculated in this round is: " + str(CIC) + '\n'
 *         report = report + "Best feature choosen in this round is: "+comb.index[seedid] + '\n'
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,             # <<<<<<<<<<<<<<
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 */
    __pyx_t_12 = PyFloat_FromDouble(__pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_v_y, __pyx_v_cythonseed, __pyx_t_11, __pyx_v_size, __pyx_v_bandwidth, __pyx_t_16, __pyx_t_15, __pyx_t_17, __pyx_v_deltay, __pyx_v_miny, 0, NULL)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_XDECREF_SET(__pyx_v_newIC, __pyx_t_12);
    __pyx_t_12 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1644
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    __pyx_t_12 = PyObject_RichCompare(__pyx_v_if_bootstrap, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1644, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1644, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1645
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_calcBootstrapIC); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_2 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_3);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_currentseed);
      __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_subcomb, __pyx_t_4) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1646
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_size, __pyx_t_4) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_bandwidth, __pyx_t_4) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_k, __pyx_v_k) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1647
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number =thread_number, IC = newIC, neighborhood = neighborhood)
 */
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_bandwidth_mult, __pyx_v_bandwidth_mult) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1648
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,             # <<<<<<<<<<<<<<
 *                                         thread_number =thread_number, IC = newIC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)
 */
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_bandwidth_adj, __pyx_v_bandwidth_adj) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_grid, __pyx_v_grid) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1649
 *                                         bandwidth_mult = bandwidth_mult,
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number =thread_number, IC = newIC, neighborhood = neighborhood)             # <<<<<<<<<<<<<<
 *             bootstraps.append(bootstrap)
 * 
 */
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_thread_number, __pyx_v_thread_number) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_IC, __pyx_v_newIC) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_neighborhood, __pyx_v_neighborhood) < 0) __PYX_ERR(0, 1645, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1645
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),             # <<<<<<<<<<<<<<
 *                                         size = size, bandwidth = bandwidth, k = k,
 *                                         bandwidth_mult = bandwidth_mult,
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_bootstrap, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1650
 *                                         bandwidth_adj = bandwidth_adj, grid = grid,
 *                                         thread_number =thread_number, IC = newIC, neighborhood = neighborhood)
 *             bootstraps.append(bootstrap)             # <<<<<<<<<<<<<<
 * 
 *         if if_pval == True:
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_bootstraps, __pyx_v_bootstrap); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1650, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1644
 *         newIC = binaryInformationCoefficient_cython(y, cythonseed,k,size,bandwidth,
 *                                                     bandwidth_mult,bandwidth_adj, neighborhood, deltay, miny)
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             bootstrap = calcBootstrapIC(subcomb = pd.DataFrame([comb.iloc[0].tolist(),currentseed]),
 *                                         size = size, bandwidth = bandwidth, k = k,
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1652
 *             bootstraps.append(bootstrap)
 * 
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVals.append(0)
 * 
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1652, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1652, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1653
 * 
 *         if if_pval == True:
 *             pVals.append(0)             # <<<<<<<<<<<<<<
 * 
 *         if verbose != 0:
 */
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_pVals, __pyx_int_0); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1653, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":1652
 *             bootstraps.append(bootstrap)
 * 
 *         if if_pval == True:             # <<<<<<<<<<<<<<
 *             pVals.append(0)
 * 
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1655
 *             pVals.append(0)
 * 
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print("IC of new seed is: "+str(newIC))
 *         report = report + "IC of new seed is: "+str(newIC) + '\n'
 */
    __pyx_t_4 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1655, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1656
 * 
 *         if verbose != 0:
 *             print("IC of new seed is: "+str(newIC))             # <<<<<<<<<<<<<<
 *         report = report + "IC of new seed is: "+str(newIC) + '\n'
 *         seedIC.append(newIC)
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_newIC); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_IC_of_new_seed_is, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1655
 *             pVals.append(0)
 * 
 *         if verbose != 0:             # <<<<<<<<<<<<<<
 *             print("IC of new seed is: "+str(newIC))
 *         report = report + "IC of new seed is: "+str(newIC) + '\n'
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1657
 *         if verbose != 0:
 *             print("IC of new seed is: "+str(newIC))
 *         report = report + "IC of new seed is: "+str(newIC) + '\n'             # <<<<<<<<<<<<<<
 *         seedIC.append(newIC)
 *         CICs.append(newIC)
 */
    __pyx_t_4 = PyNumber_Add(__pyx_v_report, __pyx_kp_u_IC_of_new_seed_is); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_newIC); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = PyNumber_Add(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_12, __pyx_kp_u__9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1658
 *             print("IC of new seed is: "+str(newIC))
 *         report = report + "IC of new seed is: "+str(newIC) + '\n'
 *         seedIC.append(newIC)             # <<<<<<<<<<<<<<
 *         CICs.append(newIC)
 *         comb = comb.drop(index = [comb.index[seedid]])
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_seedIC, __pyx_v_newIC); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1658, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1659
 *         report = report + "IC of new seed is: "+str(newIC) + '\n'
 *         seedIC.append(newIC)
 *         CICs.append(newIC)             # <<<<<<<<<<<<<<
 *         comb = comb.drop(index = [comb.index[seedid]])
 * 
 */
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_CICs, __pyx_v_newIC); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1659, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1660
 *         seedIC.append(newIC)
 *         CICs.append(newIC)
 *         comb = comb.drop(index = [comb.index[seedid]])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_drop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_4, __pyx_v_seedid, __pyx_t_5numpy_int_t, 1, __Pyx_PyInt_From_npy_long, 0, 1, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_10);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_10);
    __pyx_t_10 = 0;
    if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_index, __pyx_t_4) < 0) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1663
 * 
 * 
 *         if max_iteration == -1:             # <<<<<<<<<<<<<<
 *             if direction == 'pos':
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:
 */
    __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_max_iteration, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1663, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":1664
 * 
 *         if max_iteration == -1:
 *             if direction == 'pos':             # <<<<<<<<<<<<<<
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:
 *                     seedids = seedids[:-1]
 */
      __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_pos, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1664, __pyx_L1_error)
      if (__pyx_t_9) {

        /* "revealer/REVEALER_runbenchmark.pyx":1665
 *         if max_iteration == -1:
 *             if direction == 'pos':
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:             # <<<<<<<<<<<<<<
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]
 */
        __pyx_t_6 = PyList_GET_SIZE(__pyx_v_seedIC); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1665, __pyx_L1_error)
        __pyx_t_23 = ((__pyx_t_6 >= 2) != 0);
        if (__pyx_t_23) {
        } else {
          __pyx_t_9 = __pyx_t_23;
          goto __pyx_L40_bool_binop_done;
        }
        __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_seedIC, -2L, long, 1, __Pyx_PyInt_From_long, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1665, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = PyObject_RichCompare(__pyx_v_newIC, __pyx_t_4, Py_LE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1665, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1665, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_9 = __pyx_t_23;
        __pyx_L40_bool_binop_done:;
        if (__pyx_t_9) {

          /* "revealer/REVEALER_runbenchmark.pyx":1666
 *             if direction == 'pos':
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:
 *                     seedids = seedids[:-1]             # <<<<<<<<<<<<<<
 *                     CICs = CICs[:-2]
 *                     pVals = pVals[:-2]
 */
          __pyx_t_12 = __Pyx_PyList_GetSlice(__pyx_v_seedids, 0, -1L); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1666, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_seedids, ((PyObject*)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1667
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]             # <<<<<<<<<<<<<<
 *                     pVals = pVals[:-2]
 *                     seedlists = seedlists[:-1]
 */
          __pyx_t_12 = __Pyx_PyList_GetSlice(__pyx_v_CICs, 0, -2L); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1667, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_CICs, ((PyObject*)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1668
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]
 *                     pVals = pVals[:-2]             # <<<<<<<<<<<<<<
 *                     seedlists = seedlists[:-1]
 *                     bootstraps = bootstraps[:-2]
 */
          __pyx_t_12 = __Pyx_PyList_GetSlice(__pyx_v_pVals, 0, -2L); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1668, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_pVals, ((PyObject*)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1669
 *                     CICs = CICs[:-2]
 *                     pVals = pVals[:-2]
 *                     seedlists = seedlists[:-1]             # <<<<<<<<<<<<<<
 *                     bootstraps = bootstraps[:-2]
 *                     break
 */
          __pyx_t_12 = __Pyx_PyList_GetSlice(__pyx_v_seedlists, 0, -1L); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1669, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_seedlists, ((PyObject*)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1670
 *                     pVals = pVals[:-2]
 *                     seedlists = seedlists[:-1]
 *                     bootstraps = bootstraps[:-2]             # <<<<<<<<<<<<<<
 *                     break
 *             elif direction == 'neg':
 */
          __pyx_t_12 = __Pyx_PyList_GetSlice(__pyx_v_bootstraps, 0, -2L); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1670, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_bootstraps, ((PyObject*)__pyx_t_12));
          __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1671
 *                     seedlists = seedlists[:-1]
 *                     bootstraps = bootstraps[:-2]
 *                     break             # <<<<<<<<<<<<<<
 *             elif direction == 'neg':
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:
 */
          goto __pyx_L24_break;

          /* "revealer/REVEALER_runbenchmark.pyx":1665
 *         if max_iteration == -1:
 *             if direction == 'pos':
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:             # <<<<<<<<<<<<<<
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]
 */
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1664
 * 
 *         if max_iteration == -1:
 *             if direction == 'pos':             # <<<<<<<<<<<<<<
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:
 *                     seedids = seedids[:-1]
 */
        goto __pyx_L38;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1672
 *                     bootstraps = bootstraps[:-2]
 *                     break
 *             elif direction == 'neg':             # <<<<<<<<<<<<<<
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:
 *                     seedids = seedids[:-1]
 */
      __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_neg, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1672, __pyx_L1_error)
      if (__pyx_t_9) {

        /* "revealer/REVEALER_runbenchmark.pyx":1673
 *                     break
 *             elif direction == 'neg':
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:             # <<<<<<<<<<<<<<
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]
 */
        __pyx_t_6 = PyList_GET_SIZE(__pyx_v_seedIC); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1673, __pyx_L1_error)
        __pyx_t_23 = ((__pyx_t_6 >= 2) != 0);
        if (__pyx_t_23) {
        } else {
          __pyx_t_9 = __pyx_t_23;
          goto __pyx_L43_bool_binop_done;
        }
        __pyx_t_12 = __Pyx_GetItemInt_List(__pyx_v_seedIC, -2L, long, 1, __Pyx_PyInt_From_long, 1, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1673, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_4 = PyObject_RichCompare(__pyx_v_newIC, __pyx_t_12, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1673, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1673, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_9 = __pyx_t_23;
        __pyx_L43_bool_binop_done:;
        if (__pyx_t_9) {

          /* "revealer/REVEALER_runbenchmark.pyx":1674
 *             elif direction == 'neg':
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:
 *                     seedids = seedids[:-1]             # <<<<<<<<<<<<<<
 *                     CICs = CICs[:-2]
 *                     pVals = pVals[:-2]
 */
          __pyx_t_4 = __Pyx_PyList_GetSlice(__pyx_v_seedids, 0, -1L); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1674, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_seedids, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1675
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]             # <<<<<<<<<<<<<<
 *                     pVals = pVals[:-2]
 *                     seedlists = seedlists[:-1]
 */
          __pyx_t_4 = __Pyx_PyList_GetSlice(__pyx_v_CICs, 0, -2L); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1675, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_CICs, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1676
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]
 *                     pVals = pVals[:-2]             # <<<<<<<<<<<<<<
 *                     seedlists = seedlists[:-1]
 *                     bootstraps = bootstraps[:-2]
 */
          __pyx_t_4 = __Pyx_PyList_GetSlice(__pyx_v_pVals, 0, -2L); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1676, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_pVals, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1677
 *                     CICs = CICs[:-2]
 *                     pVals = pVals[:-2]
 *                     seedlists = seedlists[:-1]             # <<<<<<<<<<<<<<
 *                     bootstraps = bootstraps[:-2]
 *                     break
 */
          __pyx_t_4 = __Pyx_PyList_GetSlice(__pyx_v_seedlists, 0, -1L); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1677, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_seedlists, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1678
 *                     pVals = pVals[:-2]
 *                     seedlists = seedlists[:-1]
 *                     bootstraps = bootstraps[:-2]             # <<<<<<<<<<<<<<
 *                     break
 *         n=n+1
 */
          __pyx_t_4 = __Pyx_PyList_GetSlice(__pyx_v_bootstraps, 0, -2L); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1678, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_bootstraps, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1679
 *                     seedlists = seedlists[:-1]
 *                     bootstraps = bootstraps[:-2]
 *                     break             # <<<<<<<<<<<<<<
 *         n=n+1
 * 
 */
          goto __pyx_L24_break;

          /* "revealer/REVEALER_runbenchmark.pyx":1673
 *                     break
 *             elif direction == 'neg':
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:             # <<<<<<<<<<<<<<
 *                     seedids = seedids[:-1]
 *                     CICs = CICs[:-2]
 */
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1672
 *                     bootstraps = bootstraps[:-2]
 *                     break
 *             elif direction == 'neg':             # <<<<<<<<<<<<<<
 *                 if len(seedIC) >= 2 and newIC >= seedIC[-2]:
 *                     seedids = seedids[:-1]
 */
      }
      __pyx_L38:;

      /* "revealer/REVEALER_runbenchmark.pyx":1663
 * 
 * 
 *         if max_iteration == -1:             # <<<<<<<<<<<<<<
 *             if direction == 'pos':
 *                 if len(seedIC) >= 2 and newIC <= seedIC[-2]:
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1680
 *                     bootstraps = bootstraps[:-2]
 *                     break
 *         n=n+1             # <<<<<<<<<<<<<<
 * 
 *     if len(comb.index.tolist()) == 1:
 */
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L24_break:;

  /* "revealer/REVEALER_runbenchmark.pyx":1682
 *         n=n+1
 * 
 *     if len(comb.index.tolist()) == 1:             # <<<<<<<<<<<<<<
 *         'Loop ended before it reach requirement because no unused feature left!'
 * 
 */
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_4 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = ((__pyx_t_6 == 1) != 0);
  if (__pyx_t_9) {
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1685
 *         'Loop ended before it reach requirement because no unused feature left!'
 * 
 *     if if_pval == True:             # <<<<<<<<<<<<<<
 *         pVal = updatePval(pVals=pVals, CICs=CICs, seedlists=seedlists,
 *                           target = comb.iloc[0].tolist(), size = size, bandwidth = bandwidth, k = k,
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1685, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1687
 *     if if_pval == True:
 *         pVal = updatePval(pVals=pVals, CICs=CICs, seedlists=seedlists,
 *                           target = comb.iloc[0].tolist(), size = size, bandwidth = bandwidth, k = k,             # <<<<<<<<<<<<<<
 *                           bandwidth_mult = bandwidth_mult, bandwidth_adj = bandwidth_adj,
 *                           grid = grid, thread_number =thread_number, seed_name = seed_name,
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_4 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = PyFloat_FromDouble(__pyx_v_bandwidth); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);

    /* "revealer/REVEALER_runbenchmark.pyx":1686
 * 
 *     if if_pval == True:
 *         pVal = updatePval(pVals=pVals, CICs=CICs, seedlists=seedlists,             # <<<<<<<<<<<<<<
 *                           target = comb.iloc[0].tolist(), size = size, bandwidth = bandwidth, k = k,
 *                           bandwidth_mult = bandwidth_mult, bandwidth_adj = bandwidth_adj,
 */
    __pyx_t_10 = __pyx_f_8revealer_21REVEALER_runbenchmark_updatePval(__pyx_v_pVals, __pyx_v_CICs, __pyx_v_seedlists, __pyx_t_4, __pyx_t_2, __pyx_t_12, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_seed_name, __pyx_v_direction, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pVal, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1685
 *         'Loop ended before it reach requirement because no unused feature left!'
 * 
 *     if if_pval == True:             # <<<<<<<<<<<<<<
 *         pVal = updatePval(pVals=pVals, CICs=CICs, seedlists=seedlists,
 *                           target = comb.iloc[0].tolist(), size = size, bandwidth = bandwidth, k = k,
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1691
 *                           grid = grid, thread_number =thread_number, seed_name = seed_name,
 *                           direction = direction, neighborhood = neighborhood)
 *     if if_pval == True:             # <<<<<<<<<<<<<<
 *         saveresfigWithPval(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,
 *                            figure_format, pVals, bootstraps, out_folder, target_name, seed_name,
 */
  __pyx_t_10 = PyObject_RichCompare(__pyx_v_if_pval, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1691, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1692
 *                           direction = direction, neighborhood = neighborhood)
 *     if if_pval == True:
 *         saveresfigWithPval(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,             # <<<<<<<<<<<<<<
 *                            figure_format, pVals, bootstraps, out_folder, target_name, seed_name,
 *                            locusdic, gmt)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_saveresfigWithPval); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);

    /* "revealer/REVEALER_runbenchmark.pyx":1694
 *         saveresfigWithPval(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,
 *                            figure_format, pVals, bootstraps, out_folder, target_name, seed_name,
 *                            locusdic, gmt)             # <<<<<<<<<<<<<<
 *     else:
 *         saveresfig(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,
 */
    __pyx_t_2 = NULL;
    __pyx_t_17 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
        __pyx_t_17 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_12)) {
      PyObject *__pyx_temp[16] = {__pyx_t_2, __pyx_v_savecomb, __pyx_v_seedids, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_pVals, __pyx_v_bootstraps, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt};
      __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_17, 15+__pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1692, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
      PyObject *__pyx_temp[16] = {__pyx_t_2, __pyx_v_savecomb, __pyx_v_seedids, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_pVals, __pyx_v_bootstraps, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt};
      __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_17, 15+__pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1692, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(15+__pyx_t_17); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_INCREF(__pyx_v_savecomb);
      __Pyx_GIVEREF(__pyx_v_savecomb);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_17, __pyx_v_savecomb);
      __Pyx_INCREF(__pyx_v_seedids);
      __Pyx_GIVEREF(__pyx_v_seedids);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_17, __pyx_v_seedids);
      __Pyx_INCREF(__pyx_v_CICs);
      __Pyx_GIVEREF(__pyx_v_CICs);
      PyTuple_SET_ITEM(__pyx_t_4, 2+__pyx_t_17, __pyx_v_CICs);
      __Pyx_INCREF(__pyx_v_seedlists);
      __Pyx_GIVEREF(__pyx_v_seedlists);
      PyTuple_SET_ITEM(__pyx_t_4, 3+__pyx_t_17, __pyx_v_seedlists);
      __Pyx_INCREF(__pyx_v_seedcmap);
      __Pyx_GIVEREF(__pyx_v_seedcmap);
      PyTuple_SET_ITEM(__pyx_t_4, 4+__pyx_t_17, __pyx_v_seedcmap);
      __Pyx_INCREF(__pyx_v_featurecmap);
      __Pyx_GIVEREF(__pyx_v_featurecmap);
      PyTuple_SET_ITEM(__pyx_t_4, 5+__pyx_t_17, __pyx_v_featurecmap);
      __Pyx_INCREF(__pyx_v_prefix);
      __Pyx_GIVEREF(__pyx_v_prefix);
      PyTuple_SET_ITEM(__pyx_t_4, 6+__pyx_t_17, __pyx_v_prefix);
      __Pyx_INCREF(__pyx_v_figure_format);
      __Pyx_GIVEREF(__pyx_v_figure_format);
      PyTuple_SET_ITEM(__pyx_t_4, 7+__pyx_t_17, __pyx_v_figure_format);
      __Pyx_INCREF(__pyx_v_pVals);
      __Pyx_GIVEREF(__pyx_v_pVals);
      PyTuple_SET_ITEM(__pyx_t_4, 8+__pyx_t_17, __pyx_v_pVals);
      __Pyx_INCREF(__pyx_v_bootstraps);
      __Pyx_GIVEREF(__pyx_v_bootstraps);
      PyTuple_SET_ITEM(__pyx_t_4, 9+__pyx_t_17, __pyx_v_bootstraps);
      __Pyx_INCREF(__pyx_v_out_folder);
      __Pyx_GIVEREF(__pyx_v_out_folder);
      PyTuple_SET_ITEM(__pyx_t_4, 10+__pyx_t_17, __pyx_v_out_folder);
      __Pyx_INCREF(__pyx_v_target_name);
      __Pyx_GIVEREF(__pyx_v_target_name);
      PyTuple_SET_ITEM(__pyx_t_4, 11+__pyx_t_17, __pyx_v_target_name);
      __Pyx_INCREF(__pyx_v_seed_name);
      __Pyx_GIVEREF(__pyx_v_seed_name);
      PyTuple_SET_ITEM(__pyx_t_4, 12+__pyx_t_17, __pyx_v_seed_name);
      __Pyx_INCREF(__pyx_v_locusdic);
      __Pyx_GIVEREF(__pyx_v_locusdic);
      PyTuple_SET_ITEM(__pyx_t_4, 13+__pyx_t_17, __pyx_v_locusdic);
      __Pyx_INCREF(__pyx_v_gmt);
      __Pyx_GIVEREF(__pyx_v_gmt);
      PyTuple_SET_ITEM(__pyx_t_4, 14+__pyx_t_17, __pyx_v_gmt);
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_4, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1691
 *                           grid = grid, thread_number =thread_number, seed_name = seed_name,
 *                           direction = direction, neighborhood = neighborhood)
 *     if if_pval == True:             # <<<<<<<<<<<<<<
 *         saveresfigWithPval(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,
 *                            figure_format, pVals, bootstraps, out_folder, target_name, seed_name,
 */
    goto __pyx_L47;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1696
 *                            locusdic, gmt)
 *     else:
 *         saveresfig(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,             # <<<<<<<<<<<<<<
 *                    figure_format, bootstraps, out_folder, target_name, seed_name, locusdic, gmt)
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_saveresfig); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);

    /* "revealer/REVEALER_runbenchmark.pyx":1697
 *     else:
 *         saveresfig(savecomb, seedids, CICs, seedlists, seedcmap, featurecmap, prefix,
 *                    figure_format, bootstraps, out_folder, target_name, seed_name, locusdic, gmt)             # <<<<<<<<<<<<<<
 * 
 *     if verbose != 0:
 */
    __pyx_t_4 = NULL;
    __pyx_t_17 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
        __pyx_t_17 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_12)) {
      PyObject *__pyx_temp[15] = {__pyx_t_4, __pyx_v_savecomb, __pyx_v_seedids, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_bootstraps, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt};
      __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_17, 14+__pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1696, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
      PyObject *__pyx_temp[15] = {__pyx_t_4, __pyx_v_savecomb, __pyx_v_seedids, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_bootstraps, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt};
      __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_17, 14+__pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1696, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(14+__pyx_t_17); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(__pyx_v_savecomb);
      __Pyx_GIVEREF(__pyx_v_savecomb);
      PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_17, __pyx_v_savecomb);
      __Pyx_INCREF(__pyx_v_seedids);
      __Pyx_GIVEREF(__pyx_v_seedids);
      PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_17, __pyx_v_seedids);
      __Pyx_INCREF(__pyx_v_CICs);
      __Pyx_GIVEREF(__pyx_v_CICs);
      PyTuple_SET_ITEM(__pyx_t_2, 2+__pyx_t_17, __pyx_v_CICs);
      __Pyx_INCREF(__pyx_v_seedlists);
      __Pyx_GIVEREF(__pyx_v_seedlists);
      PyTuple_SET_ITEM(__pyx_t_2, 3+__pyx_t_17, __pyx_v_seedlists);
      __Pyx_INCREF(__pyx_v_seedcmap);
      __Pyx_GIVEREF(__pyx_v_seedcmap);
      PyTuple_SET_ITEM(__pyx_t_2, 4+__pyx_t_17, __pyx_v_seedcmap);
      __Pyx_INCREF(__pyx_v_featurecmap);
      __Pyx_GIVEREF(__pyx_v_featurecmap);
      PyTuple_SET_ITEM(__pyx_t_2, 5+__pyx_t_17, __pyx_v_featurecmap);
      __Pyx_INCREF(__pyx_v_prefix);
      __Pyx_GIVEREF(__pyx_v_prefix);
      PyTuple_SET_ITEM(__pyx_t_2, 6+__pyx_t_17, __pyx_v_prefix);
      __Pyx_INCREF(__pyx_v_figure_format);
      __Pyx_GIVEREF(__pyx_v_figure_format);
      PyTuple_SET_ITEM(__pyx_t_2, 7+__pyx_t_17, __pyx_v_figure_format);
      __Pyx_INCREF(__pyx_v_bootstraps);
      __Pyx_GIVEREF(__pyx_v_bootstraps);
      PyTuple_SET_ITEM(__pyx_t_2, 8+__pyx_t_17, __pyx_v_bootstraps);
      __Pyx_INCREF(__pyx_v_out_folder);
      __Pyx_GIVEREF(__pyx_v_out_folder);
      PyTuple_SET_ITEM(__pyx_t_2, 9+__pyx_t_17, __pyx_v_out_folder);
      __Pyx_INCREF(__pyx_v_target_name);
      __Pyx_GIVEREF(__pyx_v_target_name);
      PyTuple_SET_ITEM(__pyx_t_2, 10+__pyx_t_17, __pyx_v_target_name);
      __Pyx_INCREF(__pyx_v_seed_name);
      __Pyx_GIVEREF(__pyx_v_seed_name);
      PyTuple_SET_ITEM(__pyx_t_2, 11+__pyx_t_17, __pyx_v_seed_name);
      __Pyx_INCREF(__pyx_v_locusdic);
      __Pyx_GIVEREF(__pyx_v_locusdic);
      PyTuple_SET_ITEM(__pyx_t_2, 12+__pyx_t_17, __pyx_v_locusdic);
      __Pyx_INCREF(__pyx_v_gmt);
      __Pyx_GIVEREF(__pyx_v_gmt);
      PyTuple_SET_ITEM(__pyx_t_2, 13+__pyx_t_17, __pyx_v_gmt);
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_2, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __pyx_L47:;

  /* "revealer/REVEALER_runbenchmark.pyx":1699
 *                    figure_format, bootstraps, out_folder, target_name, seed_name, locusdic, gmt)
 * 
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('Time used to run loops: %s second(s)'%(int(time.time() - start)))
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'
 */
  __pyx_t_10 = __Pyx_PyInt_NeObjC(__pyx_v_verbose, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":1700
 * 
 *     if verbose != 0:
 *         print('Time used to run loops: %s second(s)'%(int(time.time() - start)))             # <<<<<<<<<<<<<<
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_time); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Subtract(__pyx_t_10, __pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Time_used_to_run_loops_s_second, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1699
 *                    figure_format, bootstraps, out_folder, target_name, seed_name, locusdic, gmt)
 * 
 *     if verbose != 0:             # <<<<<<<<<<<<<<
 *         print('Time used to run loops: %s second(s)'%(int(time.time() - start)))
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1701
 *     if verbose != 0:
 *         print('Time used to run loops: %s second(s)'%(int(time.time() - start)))
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'             # <<<<<<<<<<<<<<
 * 
 *     with open(out_folder + prefix + 'report.txt','w') as f:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_10 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = PyNumber_Subtract(__pyx_t_10, __pyx_v_start); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyNumber_Int(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Time_used_to_run_loops_s_second, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyNumber_Add(__pyx_v_report, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = PyNumber_Add(__pyx_t_10, __pyx_kp_u__9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF_SET(__pyx_v_report, __pyx_t_12);
  __pyx_t_12 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1703
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'
 * 
 *     with open(out_folder + prefix + 'report.txt','w') as f:             # <<<<<<<<<<<<<<
 *         f.write(report)
 * 
 */
  /*with:*/ {
    __pyx_t_12 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_10 = PyNumber_Add(__pyx_t_12, __pyx_kp_u_report_txt); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10);
    __Pyx_INCREF(__pyx_n_u_w);
    __Pyx_GIVEREF(__pyx_n_u_w);
    PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_n_u_w);
    __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_12, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_25 = __Pyx_PyObject_LookupSpecial(__pyx_t_10, __pyx_n_s_exit); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_25);
    __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_10, __pyx_n_s_enter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1703, __pyx_L49_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1703, __pyx_L49_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __pyx_t_12;
    __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_26, &__pyx_t_27, &__pyx_t_28);
        __Pyx_XGOTREF(__pyx_t_26);
        __Pyx_XGOTREF(__pyx_t_27);
        __Pyx_XGOTREF(__pyx_t_28);
        /*try:*/ {
          __pyx_v_f = __pyx_t_2;
          __pyx_t_2 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1704
 * 
 *     with open(out_folder + prefix + 'report.txt','w') as f:
 *         f.write(report)             # <<<<<<<<<<<<<<
 * 
 * #    if gzip == True:
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_write); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1704, __pyx_L53_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          __pyx_t_2 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_12, __pyx_v_report) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_report);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1704, __pyx_L53_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1703
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'
 * 
 *     with open(out_folder + prefix + 'report.txt','w') as f:             # <<<<<<<<<<<<<<
 *         f.write(report)
 * 
 */
        }
        __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
        __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
        __Pyx_XDECREF(__pyx_t_28); __pyx_t_28 = 0;
        goto __pyx_L58_try_end;
        __pyx_L53_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __PYX_XDEC_MEMVIEW(&__pyx_t_13, 1);
        __PYX_XDEC_MEMVIEW(&__pyx_t_14, 1);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_XDEC_MEMVIEW(&__pyx_t_22, 1);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.REVEALERInner", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_10, &__pyx_t_12) < 0) __PYX_ERR(0, 1703, __pyx_L55_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_4 = PyTuple_Pack(3, __pyx_t_2, __pyx_t_10, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1703, __pyx_L55_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_29 = __Pyx_PyObject_Call(__pyx_t_25, __pyx_t_4, NULL);
          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 1703, __pyx_L55_except_error)
          __Pyx_GOTREF(__pyx_t_29);
          __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_29);
          __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
          if (__pyx_t_9 < 0) __PYX_ERR(0, 1703, __pyx_L55_except_error)
          __pyx_t_23 = ((!(__pyx_t_9 != 0)) != 0);
          if (__pyx_t_23) {
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_GIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_10, __pyx_t_12);
            __pyx_t_2 = 0; __pyx_t_10 = 0; __pyx_t_12 = 0; 
            __PYX_ERR(0, 1703, __pyx_L55_except_error)
          }
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          goto __pyx_L54_exception_handled;
        }
        __pyx_L55_except_error:;
        __Pyx_XGIVEREF(__pyx_t_26);
        __Pyx_XGIVEREF(__pyx_t_27);
        __Pyx_XGIVEREF(__pyx_t_28);
        __Pyx_ExceptionReset(__pyx_t_26, __pyx_t_27, __pyx_t_28);
        goto __pyx_L1_error;
        __pyx_L54_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_26);
        __Pyx_XGIVEREF(__pyx_t_27);
        __Pyx_XGIVEREF(__pyx_t_28);
        __Pyx_ExceptionReset(__pyx_t_26, __pyx_t_27, __pyx_t_28);
        __pyx_L58_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_25) {
          __pyx_t_28 = __Pyx_PyObject_Call(__pyx_t_25, __pyx_tuple__24, NULL);
          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
          if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 1703, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_28);
          __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
        }
        goto __pyx_L52;
      }
      __pyx_L52:;
    }
    goto __pyx_L62;
    __pyx_L49_error:;
    __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
    goto __pyx_L1_error;
    __pyx_L62:;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1710
 * #            tar.add(out_folder, arcname=os.path.basename(out_folder))
 * 
 *     if seed_name == None:             # <<<<<<<<<<<<<<
 *         return savecomb.iloc[[0]], None, savecomb.iloc[1:]
 *     else:
 */
  __pyx_t_12 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1710, __pyx_L1_error)
  __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_23 < 0)) __PYX_ERR(0, 1710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (__pyx_t_23) {

    /* "revealer/REVEALER_runbenchmark.pyx":1711
 * 
 *     if seed_name == None:
 *         return savecomb.iloc[[0]], None, savecomb.iloc[1:]             # <<<<<<<<<<<<<<
 *     else:
 *         return seedids, CICs#savecomb.iloc[[0]], savecomb.loc[['firstseed']], savecomb.iloc[1:].drop(index=['firstseed'])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_savecomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_10 = PyList_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_10, 0, __pyx_int_0);
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_savecomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_12 = __Pyx_PyObject_GetSlice(__pyx_t_10, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_10, 1, Py_None);
    __Pyx_GIVEREF(__pyx_t_12);
    PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_12);
    __pyx_t_2 = 0;
    __pyx_t_12 = 0;
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":1710
 * #            tar.add(out_folder, arcname=os.path.basename(out_folder))
 * 
 *     if seed_name == None:             # <<<<<<<<<<<<<<
 *         return savecomb.iloc[[0]], None, savecomb.iloc[1:]
 *     else:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1713
 *         return savecomb.iloc[[0]], None, savecomb.iloc[1:]
 *     else:
 *         return seedids, CICs#savecomb.iloc[[0]], savecomb.loc[['firstseed']], savecomb.iloc[1:].drop(index=['firstseed'])             # <<<<<<<<<<<<<<
 * 
 * cpdef updatePval(
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_INCREF(__pyx_v_seedids);
    __Pyx_GIVEREF(__pyx_v_seedids);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_seedids);
    __Pyx_INCREF(__pyx_v_CICs);
    __Pyx_GIVEREF(__pyx_v_CICs);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_v_CICs);
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1392
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef REVEALERInner(             # <<<<<<<<<<<<<<
 *     prefix,             #Prefix for generated files
 *     comb,               #Combined dataframe
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XDEC_MEMVIEW(&__pyx_t_13, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_14, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_22, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.REVEALERInner", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_seedcmap);
  __Pyx_XDECREF(__pyx_v_featurecmap);
  __Pyx_XDECREF(__pyx_v_newpheno);
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF(__pyx_v_targetmean);
  __Pyx_XDECREF(__pyx_v_targetstd);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_patient);
  __Pyx_XDECREF(__pyx_v_combpatient);
  __Pyx_XDECREF(__pyx_v_corr);
  __Pyx_XDECREF(__pyx_v_start);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_cythonseed, 1);
  __Pyx_XDECREF(__pyx_v_seedids);
  __Pyx_XDECREF(__pyx_v_CICs);
  __Pyx_XDECREF(__pyx_v_seedIC);
  __Pyx_XDECREF(__pyx_v_pVals);
  __Pyx_XDECREF(__pyx_v_bootstraps);
  __Pyx_XDECREF(__pyx_v_addseed);
  __Pyx_XDECREF(__pyx_v_savecomb);
  __Pyx_XDECREF(__pyx_v_seedlists);
  __Pyx_XDECREF(__pyx_v_IC);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_pVal);
  __Pyx_XDECREF(__pyx_v_bootstrap);
  __Pyx_XDECREF(__pyx_v_currentseed);
  __Pyx_XDECREF(__pyx_v_subcomb);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_CIC);
  __Pyx_XDECREF(__pyx_v_spenttime);
  __Pyx_XDECREF(__pyx_v_newseed);
  __Pyx_XDECREF(__pyx_v_newIC);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_comb);
  __Pyx_XDECREF(__pyx_v_grid);
  __Pyx_XDECREF(__pyx_v_report);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_27REVEALERInner(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_27REVEALERInner(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_direction = 0;
  PyObject *__pyx_v_num_top = 0;
  PyObject *__pyx_v_verbose = 0;
  PyObject *__pyx_v_max_iteration = 0;
  PyObject *__pyx_v_collapse = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_if_pval = 0;
  PyObject *__pyx_v_if_bootstrap = 0;
  PyObject *__pyx_v_if_cluster = 0;
  PyObject *__pyx_v_if_intermediate = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_report = 0;
  PyObject *__pyx_v_gmt = 0;
  PyObject *__pyx_v_locusdic = 0;
  PyObject *__pyx_v_alpha = 0;
  PyObject *__pyx_v_neighborhood = 0;
  PyObject *__pyx_v_tissue_file = 0;
  PyObject *__pyx_v_gzip = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("REVEALERInner (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_prefix,&__pyx_n_s_comb,&__pyx_n_s_grid,&__pyx_n_s_k,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_direction,&__pyx_n_s_num_top,&__pyx_n_s_verbose,&__pyx_n_s_max_iteration,&__pyx_n_s_collapse,&__pyx_n_s_thread_number,&__pyx_n_s_figure_format,&__pyx_n_s_if_pval,&__pyx_n_s_if_bootstrap,&__pyx_n_s_if_cluster,&__pyx_n_s_if_intermediate,&__pyx_n_s_out_folder,&__pyx_n_s_seed_name,&__pyx_n_s_normalize,&__pyx_n_s_target_name,&__pyx_n_s_report,&__pyx_n_s_gmt,&__pyx_n_s_locusdic,&__pyx_n_s_alpha,&__pyx_n_s_neighborhood,&__pyx_n_s_tissue_file,&__pyx_n_s_gzip,0};
    PyObject* values[28] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 28: values[27] = PyTuple_GET_ITEM(__pyx_args, 27);
        CYTHON_FALLTHROUGH;
        case 27: values[26] = PyTuple_GET_ITEM(__pyx_args, 26);
        CYTHON_FALLTHROUGH;
        case 26: values[25] = PyTuple_GET_ITEM(__pyx_args, 25);
        CYTHON_FALLTHROUGH;
        case 25: values[24] = PyTuple_GET_ITEM(__pyx_args, 24);
        CYTHON_FALLTHROUGH;
        case 24: values[23] = PyTuple_GET_ITEM(__pyx_args, 23);
        CYTHON_FALLTHROUGH;
        case 23: values[22] = PyTuple_GET_ITEM(__pyx_args, 22);
        CYTHON_FALLTHROUGH;
        case 22: values[21] = PyTuple_GET_ITEM(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = PyTuple_GET_ITEM(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 1); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 2); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 3); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 4); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 5); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 6); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_top)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 7); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_verbose)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 8); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_iteration)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 9); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_collapse)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 10); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 11); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 12); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_pval)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 13); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (likely((values[14] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_bootstrap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 14); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (likely((values[15] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_cluster)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 15); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (likely((values[16] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_if_intermediate)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 16); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (likely((values[17] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 17); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (likely((values[18] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 18); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 19:
        if (likely((values[19] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_normalize)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 19); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 20:
        if (likely((values[20] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 20); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 21:
        if (likely((values[21] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_report)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 21); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 22:
        if (likely((values[22] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 22); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 23:
        if (likely((values[23] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_locusdic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 23); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 24:
        if (likely((values[24] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_alpha)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 24); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 25:
        if (likely((values[25] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 25); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 26:
        if (likely((values[26] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tissue_file)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 26); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 27:
        if (likely((values[27] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gzip)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, 27); __PYX_ERR(0, 1392, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "REVEALERInner") < 0)) __PYX_ERR(0, 1392, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 28) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
      values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
      values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
      values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
      values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
      values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
      values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
      values[20] = PyTuple_GET_ITEM(__pyx_args, 20);
      values[21] = PyTuple_GET_ITEM(__pyx_args, 21);
      values[22] = PyTuple_GET_ITEM(__pyx_args, 22);
      values[23] = PyTuple_GET_ITEM(__pyx_args, 23);
      values[24] = PyTuple_GET_ITEM(__pyx_args, 24);
      values[25] = PyTuple_GET_ITEM(__pyx_args, 25);
      values[26] = PyTuple_GET_ITEM(__pyx_args, 26);
      values[27] = PyTuple_GET_ITEM(__pyx_args, 27);
    }
    __pyx_v_prefix = values[0];
    __pyx_v_comb = values[1];
    __pyx_v_grid = values[2];
    __pyx_v_k = values[3];
    __pyx_v_bandwidth_mult = values[4];
    __pyx_v_bandwidth_adj = values[5];
    __pyx_v_direction = values[6];
    __pyx_v_num_top = values[7];
    __pyx_v_verbose = values[8];
    __pyx_v_max_iteration = values[9];
    __pyx_v_collapse = values[10];
    __pyx_v_thread_number = values[11];
    __pyx_v_figure_format = values[12];
    __pyx_v_if_pval = values[13];
    __pyx_v_if_bootstrap = values[14];
    __pyx_v_if_cluster = values[15];
    __pyx_v_if_intermediate = values[16];
    __pyx_v_out_folder = values[17];
    __pyx_v_seed_name = values[18];
    __pyx_v_normalize = values[19];
    __pyx_v_target_name = values[20];
    __pyx_v_report = values[21];
    __pyx_v_gmt = values[22];
    __pyx_v_locusdic = values[23];
    __pyx_v_alpha = values[24];
    __pyx_v_neighborhood = values[25];
    __pyx_v_tissue_file = values[26];
    __pyx_v_gzip = values[27];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("REVEALERInner", 1, 28, 28, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1392, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.REVEALERInner", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_26REVEALERInner(__pyx_self, __pyx_v_prefix, __pyx_v_comb, __pyx_v_grid, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_num_top, __pyx_v_verbose, __pyx_v_max_iteration, __pyx_v_collapse, __pyx_v_thread_number, __pyx_v_figure_format, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_if_intermediate, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_normalize, __pyx_v_target_name, __pyx_v_report, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_alpha, __pyx_v_neighborhood, __pyx_v_tissue_file, __pyx_v_gzip);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_26REVEALERInner(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_prefix, PyObject *__pyx_v_comb, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_direction, PyObject *__pyx_v_num_top, PyObject *__pyx_v_verbose, PyObject *__pyx_v_max_iteration, PyObject *__pyx_v_collapse, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_if_pval, PyObject *__pyx_v_if_bootstrap, PyObject *__pyx_v_if_cluster, PyObject *__pyx_v_if_intermediate, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_normalize, PyObject *__pyx_v_target_name, PyObject *__pyx_v_report, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_alpha, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_tissue_file, PyObject *__pyx_v_gzip) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("REVEALERInner", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_REVEALERInner(__pyx_v_prefix, __pyx_v_comb, __pyx_v_grid, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_direction, __pyx_v_num_top, __pyx_v_verbose, __pyx_v_max_iteration, __pyx_v_collapse, __pyx_v_thread_number, __pyx_v_figure_format, __pyx_v_if_pval, __pyx_v_if_bootstrap, __pyx_v_if_cluster, __pyx_v_if_intermediate, __pyx_v_out_folder, __pyx_v_seed_name, __pyx_v_normalize, __pyx_v_target_name, __pyx_v_report, __pyx_v_gmt, __pyx_v_locusdic, __pyx_v_alpha, __pyx_v_neighborhood, __pyx_v_tissue_file, __pyx_v_gzip, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.REVEALERInner", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1715
 *         return seedids, CICs#savecomb.iloc[[0]], savecomb.loc[['firstseed']], savecomb.iloc[1:].drop(index=['firstseed'])
 * 
 * cpdef updatePval(             # <<<<<<<<<<<<<<
 *     pVals,          #List of p-values
 *     CICs,           #List of CIC/IC
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_29updatePval(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_updatePval(PyObject *__pyx_v_pVals, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_target, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_direction, PyObject *__pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_v_seedcomb = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  double __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("updatePval", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1736
 *     '''
 * 
 *     results = []             # <<<<<<<<<<<<<<
 *     if seed_name != None:
 *         seedcomb = pd.DataFrame(seedlists)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_results = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1737
 * 
 *     results = []
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         seedcomb = pd.DataFrame(seedlists)
 *     else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1737, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1737, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":1738
 *     results = []
 *     if seed_name != None:
 *         seedcomb = pd.DataFrame(seedlists)             # <<<<<<<<<<<<<<
 *     else:
 *         seedcomb = pd.DataFrame(seedlists[1:])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, __pyx_v_seedlists) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_seedlists);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_seedcomb = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1737
 * 
 *     results = []
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         seedcomb = pd.DataFrame(seedlists)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1740
 *         seedcomb = pd.DataFrame(seedlists)
 *     else:
 *         seedcomb = pd.DataFrame(seedlists[1:])             # <<<<<<<<<<<<<<
 * 
 *     #Calculate ICs using seeds
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_seedlists, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_seedcomb = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "revealer/REVEALER_runbenchmark.pyx":1743
 * 
 *     #Calculate ICs using seeds
 *     results = prepPvalICInd(seedcomb, target, size, bandwidth, k, bandwidth_mult,bandwidth_adj,             # <<<<<<<<<<<<<<
 *                             grid, thread_number, neighborhood)
 * 
 */
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalICInd(__pyx_v_seedcomb, __pyx_v_target, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_results, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1747
 * 
 *     #Calculate each pVals based on CIC/IC at that position
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_pos, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1747, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":1748
 *     #Calculate each pVals based on CIC/IC at that position
 *     if direction == 'pos':
 *         if seed_name != None:             # <<<<<<<<<<<<<<
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1748, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1748, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":1749
 *     if direction == 'pos':
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_pVals); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1749, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyInt_FromDouble((((double)(__pyx_t_6 + 1)) / 2.0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1749, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1749, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1749, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1749, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1749, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_7(__pyx_t_1);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1749, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1750
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0             # <<<<<<<<<<<<<<
 *                 for j in results:
 *                     if CICs[i*2] <= j:
 */
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_XDECREF_SET(__pyx_v_count, __pyx_int_0);

        /* "revealer/REVEALER_runbenchmark.pyx":1751
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] <= j:
 *                         count += 1
 */
        if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
          __pyx_t_3 = __pyx_v_results; __Pyx_INCREF(__pyx_t_3); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1751, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1751, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_3))) {
              if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_3)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1751, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1751, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            } else {
              if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1751, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1751, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            }
          } else {
            __pyx_t_4 = __pyx_t_9(__pyx_t_3);
            if (unlikely(!__pyx_t_4)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1751, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1752
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] <= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1752, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1752, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_v_j, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1752, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1752, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (__pyx_t_2) {

            /* "revealer/REVEALER_runbenchmark.pyx":1753
 *                 for j in results:
 *                     if CICs[i*2] <= j:
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 if count == 0:
 *                     pVals[i*2] = len(results)
 */
            __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1753, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_4);
            __pyx_t_4 = 0;

            /* "revealer/REVEALER_runbenchmark.pyx":1752
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] <= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          }

          /* "revealer/REVEALER_runbenchmark.pyx":1751
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] <= j:
 *                         count += 1
 */
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1754
 *                     if CICs[i*2] <= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1754, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1754, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":1755
 *                         count += 1
 *                 if count == 0:
 *                     pVals[i*2] = len(results)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))
 */
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1755, __pyx_L1_error)
          __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1755, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1755, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_3) < 0)) __PYX_ERR(0, 1755, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1754
 *                     if CICs[i*2] <= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
          goto __pyx_L11;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1757
 *                     pVals[i*2] = len(results)
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))             # <<<<<<<<<<<<<<
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_AsDouble(__pyx_v_count); if (unlikely(__pyx_t_10 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1757, __pyx_L1_error)
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1757, __pyx_L1_error)
          if (unlikely(((double)__pyx_t_8) == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "float division");
            __PYX_ERR(0, 1757, __pyx_L1_error)
          }
          __pyx_t_3 = PyFloat_FromDouble((__pyx_t_10 / ((double)__pyx_t_8))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1757, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1757, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_3) < 0)) __PYX_ERR(0, 1757, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_L11:;

        /* "revealer/REVEALER_runbenchmark.pyx":1749
 *     if direction == 'pos':
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1748
 *     #Calculate each pVals based on CIC/IC at that position
 *     if direction == 'pos':
 *         if seed_name != None:             # <<<<<<<<<<<<<<
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 */
      goto __pyx_L5;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1759
 *                     pVals[i*2] = float(count)/float(len(results))
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
    /*else*/ {
      __pyx_t_6 = PyObject_Length(__pyx_v_pVals); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1759, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyInt_FromDouble((((double)(__pyx_t_6 + 1)) / 2.0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1759, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1759, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1759, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1759, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1759, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1759, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1759, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1759, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1759, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_7(__pyx_t_3);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1759, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1760
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):
 *                 count = 0             # <<<<<<<<<<<<<<
 *                 for j in results:
 *                     if CICs[i*2] <= j:
 */
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_XDECREF_SET(__pyx_v_count, __pyx_int_0);

        /* "revealer/REVEALER_runbenchmark.pyx":1761
 *             for i in range(1,int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] <= j:
 *                         count += 1
 */
        if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
          __pyx_t_1 = __pyx_v_results; __Pyx_INCREF(__pyx_t_1); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1761, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_9 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1761, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_1))) {
              if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1761, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1761, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            } else {
              if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1761, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1761, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            }
          } else {
            __pyx_t_4 = __pyx_t_9(__pyx_t_1);
            if (unlikely(!__pyx_t_4)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1761, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1762
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] <= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1762, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1762, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_v_j, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1762, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1762, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (__pyx_t_2) {

            /* "revealer/REVEALER_runbenchmark.pyx":1763
 *                 for j in results:
 *                     if CICs[i*2] <= j:
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 if count == 0:
 *                     pVals[i*2] = len(results)
 */
            __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1763, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_4);
            __pyx_t_4 = 0;

            /* "revealer/REVEALER_runbenchmark.pyx":1762
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] <= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          }

          /* "revealer/REVEALER_runbenchmark.pyx":1761
 *             for i in range(1,int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] <= j:
 *                         count += 1
 */
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1764
 *                     if CICs[i*2] <= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
        __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1764, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1764, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":1765
 *                         count += 1
 *                 if count == 0:
 *                     pVals[i*2] = len(results)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))
 */
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1765, __pyx_L1_error)
          __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1765, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1765, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_1) < 0)) __PYX_ERR(0, 1765, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1764
 *                     if CICs[i*2] <= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
          goto __pyx_L17;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1767
 *                     pVals[i*2] = len(results)
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))             # <<<<<<<<<<<<<<
 *     else:
 *         if seed_name != None:
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_AsDouble(__pyx_v_count); if (unlikely(__pyx_t_10 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1767, __pyx_L1_error)
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1767, __pyx_L1_error)
          if (unlikely(((double)__pyx_t_8) == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "float division");
            __PYX_ERR(0, 1767, __pyx_L1_error)
          }
          __pyx_t_1 = PyFloat_FromDouble((__pyx_t_10 / ((double)__pyx_t_8))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1767, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1767, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_1) < 0)) __PYX_ERR(0, 1767, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L17:;

        /* "revealer/REVEALER_runbenchmark.pyx":1759
 *                     pVals[i*2] = float(count)/float(len(results))
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L5:;

    /* "revealer/REVEALER_runbenchmark.pyx":1747
 * 
 *     #Calculate each pVals based on CIC/IC at that position
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):
 */
    goto __pyx_L4;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1769
 *                     pVals[i*2] = float(count)/float(len(results))
 *     else:
 *         if seed_name != None:             # <<<<<<<<<<<<<<
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 */
  /*else*/ {
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1769, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1769, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":1770
 *     else:
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_pVals); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1770, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyInt_FromDouble((((double)(__pyx_t_6 + 1)) / 2.0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1770, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1770, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1770, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1770, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1770, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1770, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1770, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1770, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_7(__pyx_t_3);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1770, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1771
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0             # <<<<<<<<<<<<<<
 *                 for j in results:
 *                     if CICs[i*2] >= j:
 */
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_XDECREF_SET(__pyx_v_count, __pyx_int_0);

        /* "revealer/REVEALER_runbenchmark.pyx":1772
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] >= j:
 *                         count += 1
 */
        if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
          __pyx_t_1 = __pyx_v_results; __Pyx_INCREF(__pyx_t_1); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1772, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_9 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1772, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_1))) {
              if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1772, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1772, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            } else {
              if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1772, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1772, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            }
          } else {
            __pyx_t_4 = __pyx_t_9(__pyx_t_1);
            if (unlikely(!__pyx_t_4)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1772, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1773
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] >= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1773, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1773, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_v_j, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1773, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1773, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (__pyx_t_2) {

            /* "revealer/REVEALER_runbenchmark.pyx":1774
 *                 for j in results:
 *                     if CICs[i*2] >= j:
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 if count == 0:
 *                     pVals[i*2] = len(results)
 */
            __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1774, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_4);
            __pyx_t_4 = 0;

            /* "revealer/REVEALER_runbenchmark.pyx":1773
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] >= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          }

          /* "revealer/REVEALER_runbenchmark.pyx":1772
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] >= j:
 *                         count += 1
 */
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1775
 *                     if CICs[i*2] >= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
        __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1775, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1775, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":1776
 *                         count += 1
 *                 if count == 0:
 *                     pVals[i*2] = len(results)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))
 */
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1776, __pyx_L1_error)
          __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1776, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1776, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_1) < 0)) __PYX_ERR(0, 1776, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1775
 *                     if CICs[i*2] >= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
          goto __pyx_L24;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1778
 *                     pVals[i*2] = len(results)
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))             # <<<<<<<<<<<<<<
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_AsDouble(__pyx_v_count); if (unlikely(__pyx_t_10 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1778, __pyx_L1_error)
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1778, __pyx_L1_error)
          if (unlikely(((double)__pyx_t_8) == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "float division");
            __PYX_ERR(0, 1778, __pyx_L1_error)
          }
          __pyx_t_1 = PyFloat_FromDouble((__pyx_t_10 / ((double)__pyx_t_8))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1778, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1778, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_1) < 0)) __PYX_ERR(0, 1778, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L24:;

        /* "revealer/REVEALER_runbenchmark.pyx":1770
 *     else:
 *         if seed_name != None:
 *             for i in range(int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1769
 *                     pVals[i*2] = float(count)/float(len(results))
 *     else:
 *         if seed_name != None:             # <<<<<<<<<<<<<<
 *             for i in range(int((len(pVals)+1)/2)):
 *                 count = 0
 */
      goto __pyx_L18;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":1780
 *                     pVals[i*2] = float(count)/float(len(results))
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
    /*else*/ {
      __pyx_t_6 = PyObject_Length(__pyx_v_pVals); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1780, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyInt_FromDouble((((double)(__pyx_t_6 + 1)) / 2.0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1780, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1780, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_int_1);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1780, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1780, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1780, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1780, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1780, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1780, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_7(__pyx_t_1);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1780, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1781
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):
 *                 count = 0             # <<<<<<<<<<<<<<
 *                 for j in results:
 *                     if CICs[i*2] >= j:
 */
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_XDECREF_SET(__pyx_v_count, __pyx_int_0);

        /* "revealer/REVEALER_runbenchmark.pyx":1782
 *             for i in range(1,int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] >= j:
 *                         count += 1
 */
        if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
          __pyx_t_3 = __pyx_v_results; __Pyx_INCREF(__pyx_t_3); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1782, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1782, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_3))) {
              if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_3)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1782, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1782, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            } else {
              if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1782, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1782, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            }
          } else {
            __pyx_t_4 = __pyx_t_9(__pyx_t_3);
            if (unlikely(!__pyx_t_4)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1782, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1783
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] >= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1783, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1783, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_v_j, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1783, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1783, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (__pyx_t_2) {

            /* "revealer/REVEALER_runbenchmark.pyx":1784
 *                 for j in results:
 *                     if CICs[i*2] >= j:
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 if count == 0:
 *                     pVals[i*2] = len(results)
 */
            __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1784, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_4);
            __pyx_t_4 = 0;

            /* "revealer/REVEALER_runbenchmark.pyx":1783
 *                 count = 0
 *                 for j in results:
 *                     if CICs[i*2] >= j:             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 if count == 0:
 */
          }

          /* "revealer/REVEALER_runbenchmark.pyx":1782
 *             for i in range(1,int((len(pVals)+1)/2)):
 *                 count = 0
 *                 for j in results:             # <<<<<<<<<<<<<<
 *                     if CICs[i*2] >= j:
 *                         count += 1
 */
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1785
 *                     if CICs[i*2] >= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1785, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1785, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":1786
 *                         count += 1
 *                 if count == 0:
 *                     pVals[i*2] = len(results)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))
 */
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1786, __pyx_L1_error)
          __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1786, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1786, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_3) < 0)) __PYX_ERR(0, 1786, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":1785
 *                     if CICs[i*2] >= j:
 *                         count += 1
 *                 if count == 0:             # <<<<<<<<<<<<<<
 *                     pVals[i*2] = len(results)
 *                 else:
 */
          goto __pyx_L30;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":1788
 *                     pVals[i*2] = len(results)
 *                 else:
 *                     pVals[i*2] = float(count)/float(len(results))             # <<<<<<<<<<<<<<
 * 
 *     return pVals
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_AsDouble(__pyx_v_count); if (unlikely(__pyx_t_10 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1788, __pyx_L1_error)
          __pyx_t_8 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1788, __pyx_L1_error)
          if (unlikely(((double)__pyx_t_8) == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "float division");
            __PYX_ERR(0, 1788, __pyx_L1_error)
          }
          __pyx_t_3 = PyFloat_FromDouble((__pyx_t_10 / ((double)__pyx_t_8))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1788, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1788, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyObject_SetItem(__pyx_v_pVals, __pyx_t_4, __pyx_t_3) < 0)) __PYX_ERR(0, 1788, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_L30:;

        /* "revealer/REVEALER_runbenchmark.pyx":1780
 *                     pVals[i*2] = float(count)/float(len(results))
 *         else:
 *             for i in range(1,int((len(pVals)+1)/2)):             # <<<<<<<<<<<<<<
 *                 count = 0
 *                 for j in results:
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L18:;
  }
  __pyx_L4:;

  /* "revealer/REVEALER_runbenchmark.pyx":1790
 *                     pVals[i*2] = float(count)/float(len(results))
 * 
 *     return pVals             # <<<<<<<<<<<<<<
 * 
 * def patientfig(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pVals);
  __pyx_r = __pyx_v_pVals;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1715
 *         return seedids, CICs#savecomb.iloc[[0]], savecomb.loc[['firstseed']], savecomb.iloc[1:].drop(index=['firstseed'])
 * 
 * cpdef updatePval(             # <<<<<<<<<<<<<<
 *     pVals,          #List of p-values
 *     CICs,           #List of CIC/IC
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.updatePval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_seedcomb);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_29updatePval(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_28updatePval[] = "\n    Function to update p-value based on seeds and originally calculated CICs\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_29updatePval(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_pVals = 0;
  PyObject *__pyx_v_CICs = 0;
  PyObject *__pyx_v_seedlists = 0;
  PyObject *__pyx_v_target = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_direction = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("updatePval (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pVals,&__pyx_n_s_CICs,&__pyx_n_s_seedlists,&__pyx_n_s_target,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_k,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_seed_name,&__pyx_n_s_direction,&__pyx_n_s_neighborhood,0};
    PyObject* values[14] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pVals)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_CICs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 1); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedlists)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 2); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 3); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 4); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 5); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 6); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 7); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 8); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 9); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 10); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 11); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 12); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, 13); __PYX_ERR(0, 1715, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "updatePval") < 0)) __PYX_ERR(0, 1715, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 14) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
    }
    __pyx_v_pVals = values[0];
    __pyx_v_CICs = values[1];
    __pyx_v_seedlists = values[2];
    __pyx_v_target = values[3];
    __pyx_v_size = values[4];
    __pyx_v_bandwidth = values[5];
    __pyx_v_k = values[6];
    __pyx_v_bandwidth_mult = values[7];
    __pyx_v_bandwidth_adj = values[8];
    __pyx_v_grid = values[9];
    __pyx_v_thread_number = values[10];
    __pyx_v_seed_name = values[11];
    __pyx_v_direction = values[12];
    __pyx_v_neighborhood = values[13];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("updatePval", 1, 14, 14, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1715, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.updatePval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_28updatePval(__pyx_self, __pyx_v_pVals, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_target, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_seed_name, __pyx_v_direction, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_28updatePval(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_pVals, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_target, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_direction, PyObject *__pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("updatePval", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_updatePval(__pyx_v_pVals, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_target, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_seed_name, __pyx_v_direction, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.updatePval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1792
 *     return pVals
 * 
 * def patientfig(             # <<<<<<<<<<<<<<
 *     df,       #Dataframe used to plot
 *     seedcmap,       #Cmap for seed heatmap
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_31patientfig(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_30patientfig[] = "\n    Function to save result summary figure without p-values. \n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_31patientfig = {"patientfig", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_31patientfig, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_30patientfig};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_31patientfig(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_df = 0;
  CYTHON_UNUSED PyObject *__pyx_v_seedcmap = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_target_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("patientfig (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_df,&__pyx_n_s_seedcmap,&__pyx_n_s_featurecmap,&__pyx_n_s_prefix,&__pyx_n_s_figure_format,&__pyx_n_s_out_folder,&__pyx_n_s_target_name,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_df)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, 1); __PYX_ERR(0, 1792, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, 2); __PYX_ERR(0, 1792, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, 3); __PYX_ERR(0, 1792, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, 4); __PYX_ERR(0, 1792, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, 5); __PYX_ERR(0, 1792, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, 6); __PYX_ERR(0, 1792, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "patientfig") < 0)) __PYX_ERR(0, 1792, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 7) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
    }
    __pyx_v_df = values[0];
    __pyx_v_seedcmap = values[1];
    __pyx_v_featurecmap = values[2];
    __pyx_v_prefix = values[3];
    __pyx_v_figure_format = values[4];
    __pyx_v_out_folder = values[5];
    __pyx_v_target_name = values[6];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("patientfig", 1, 7, 7, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1792, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.patientfig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_30patientfig(__pyx_self, __pyx_v_df, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_out_folder, __pyx_v_target_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_30patientfig(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, CYTHON_UNUSED PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name) {
  PyObject *__pyx_v_fig = NULL;
  PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("patientfig", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1806
 *     '''
 * 
 *     fig = plt.figure()             # <<<<<<<<<<<<<<
 *     fig.set_figheight(len(df.index)/2+0.5)
 *     fig.set_figwidth(11)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_plt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_figure); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_fig = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1807
 * 
 *     fig = plt.figure()
 *     fig.set_figheight(len(df.index)/2+0.5)             # <<<<<<<<<<<<<<
 *     fig.set_figwidth(11)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figheight); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1807, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyFloat_FromDouble(((((double)__pyx_t_4) / 2.0) + 0.5)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1808
 *     fig = plt.figure()
 *     fig.set_figheight(len(df.index)/2+0.5)
 *     fig.set_figwidth(11)             # <<<<<<<<<<<<<<
 * 
 *     #Target name at left of target heatmap
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figwidth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_int_11) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_int_11);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1811
 * 
 *     #Target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_plt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t((5 * (__pyx_t_4 + 1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_int_110);
  __Pyx_GIVEREF(__pyx_int_110);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_110);
  __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_loc, __pyx_tuple__25) < 0) __PYX_ERR(0, 1811, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 1811, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 1811, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_ax = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1812
 *     #Target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1813
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot heatmap for target
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_target_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Target, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_float_0_9);
  __Pyx_GIVEREF(__pyx_float_0_9);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_float_0_9);
  __Pyx_INCREF(__pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_float_0_5);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 1813, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 1813, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1816
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(df.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=df.iloc[0].mean())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_plt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t((5 * (__pyx_t_4 + 1))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_int_110);
  __Pyx_GIVEREF(__pyx_int_110);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_110);
  __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_loc, __pyx_tuple__26) < 0) __PYX_ERR(0, 1816, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 1816, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 1816, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1817
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(df.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=df.iloc[0].mean())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cmap, __pyx_n_u_bwr) < 0) __PYX_ERR(0, 1817, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 1817, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 1817, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1818
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(df.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=df.iloc[0].mean())             # <<<<<<<<<<<<<<
 * 
 *     #Loop to plot best feature and new seeds.
 */
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 1817, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 1817, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_mean); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_center, __pyx_t_6) < 0) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1817
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(df.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=df.iloc[0].mean())
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1821
 * 
 *     #Loop to plot best feature and new seeds.
 *     for i in range(1,len(df.index)):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
    __pyx_t_5 = __pyx_t_6; __Pyx_INCREF(__pyx_t_5); __pyx_t_4 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1821, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1821, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1821, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_8(__pyx_t_5);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1821, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1824
 * 
 *         #Label name of picked feature in this round
 *         ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(((i))*5, 0),             # <<<<<<<<<<<<<<
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t((5 * (__pyx_t_9 + 1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_INCREF(__pyx_int_110);
    __Pyx_GIVEREF(__pyx_int_110);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_110);
    __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_v_i, __pyx_int_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_0);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_2) < 0) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 1824, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 1824, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1826
 *         ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(((i))*5, 0),
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         ax.text(0.9,0.5,df.index.tolist()[i] + '(' + str(df.iloc[i].tolist().count(1)) + ')', ha='right', va='center')
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1827
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         ax.text(0.9,0.5,df.index.tolist()[i] + '(' + str(df.iloc[i].tolist().count(1)) + ')', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Plot heatmap for best feature
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_6 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__27); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__28); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_float_0_9);
    __Pyx_GIVEREF(__pyx_float_0_9);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_9);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 1827, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 1827, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1830
 * 
 *         #Plot heatmap for best feature
 *         ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(((i))*5, 20),             # <<<<<<<<<<<<<<
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([df.iloc[i].tolist()]).astype(int),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyInt_FromSsize_t((5 * (__pyx_t_9 + 1))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_int_110);
    __Pyx_GIVEREF(__pyx_int_110);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_110);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_2) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Multiply(__pyx_v_i, __pyx_int_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_INCREF(__pyx_int_20);
    __Pyx_GIVEREF(__pyx_int_20);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_20);
    __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_3) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1832
 *         ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(((i))*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([df.iloc[i].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                          cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False, cbar=False)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_iloc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_v_i); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_tolist); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_2 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyList_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_10, 0, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_7 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_10);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_astype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1833
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([df.iloc[i].tolist()]).astype(int),
 *                          cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 * 
 *     #Save figure
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 1833, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 1833, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 1833, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 1833, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 1833, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1832
 *         ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(((i))*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([df.iloc[i].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                          cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False, cbar=False)
 * 
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1821
 * 
 *     #Loop to plot best feature and new seeds.
 *     for i in range(1,len(df.index)):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1836
 * 
 *     #Save figure
 *     plt.savefig(out_folder + prefix+'_tissueType.'+figure_format,format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_savefig); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyNumber_Add(__pyx_t_5, __pyx_kp_u_tissueType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_v_figure_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 1836, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1837
 *     #Save figure
 *     plt.savefig(out_folder + prefix+'_tissueType.'+figure_format,format=figure_format)
 *     plt.close()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1792
 *     return pVals
 * 
 * def patientfig(             # <<<<<<<<<<<<<<
 *     df,       #Dataframe used to plot
 *     seedcmap,       #Cmap for seed heatmap
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.patientfig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fig);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1840
 * 
 * 
 * cpdef prepPvalICInd(             # <<<<<<<<<<<<<<
 *     seedcomb,       #Combined dataframe
 *     target,         #target to be compared
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_33prepPvalICInd(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalICInd(PyObject *__pyx_v_seedcomb, PyObject *__pyx_v_target, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_origtarget = NULL;
  PyObject *__pyx_v_targets = NULL;
  Py_ssize_t __pyx_v_i;
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_memviewslice __pyx_t_15 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_16;
  int __pyx_t_17;
  __pyx_t_5numpy_double_t __pyx_t_18;
  __pyx_t_5numpy_double_t __pyx_t_19;
  __pyx_t_5numpy_double_t __pyx_t_20;
  int __pyx_t_21;
  int __pyx_t_22;
  int __pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepPvalICInd", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1858
 * 
 *     #Get original target
 *     origtarget = target             # <<<<<<<<<<<<<<
 *     targets = []
 *     targets.append(origtarget)
 */
  __Pyx_INCREF(__pyx_v_target);
  __pyx_v_origtarget = __pyx_v_target;

  /* "revealer/REVEALER_runbenchmark.pyx":1859
 *     #Get original target
 *     origtarget = target
 *     targets = []             # <<<<<<<<<<<<<<
 *     targets.append(origtarget)
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1860
 *     origtarget = target
 *     targets = []
 *     targets.append(origtarget)             # <<<<<<<<<<<<<<
 * 
 *     #Create 1000 randomized target
 */
  __pyx_t_2 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_v_origtarget); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1860, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1863
 * 
 *     #Create 1000 randomized target
 *     for i in range(10000):             # <<<<<<<<<<<<<<
 *         targets.append(random.sample(origtarget, len(origtarget)))
 * 
 */
  for (__pyx_t_3 = 0; __pyx_t_3 < 0x2710; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "revealer/REVEALER_runbenchmark.pyx":1864
 *     #Create 1000 randomized target
 *     for i in range(10000):
 *         targets.append(random.sample(origtarget, len(origtarget)))             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t[:] y
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_random); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_sample); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_v_origtarget); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1864, __pyx_L1_error)
    __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_origtarget, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1864, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_origtarget, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1864, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1864, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_v_origtarget);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1864, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_2 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1864, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1867
 * 
 *     cdef np.double_t[:] y
 *     results = []             # <<<<<<<<<<<<<<
 * 
 *     #Make list of results with all the IC calculated with each randomized target
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_results = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1870
 * 
 *     #Make list of results with all the IC calculated with each randomized target
 *     for i in range(len(targets)):             # <<<<<<<<<<<<<<
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 */
  __pyx_t_3 = PyList_GET_SIZE(__pyx_v_targets); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1870, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_3;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_6; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "revealer/REVEALER_runbenchmark.pyx":1871
 *     #Make list of results with all the IC calculated with each randomized target
 *     for i in range(len(targets)):
 *         y = np.ascontiguousarray(np.asarray(targets[i]))             # <<<<<<<<<<<<<<
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(seedcomb.values.astype(int).tolist()),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_targets, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_5 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_11, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 1871, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
    __pyx_v_y = __pyx_t_12;
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;

    /* "revealer/REVEALER_runbenchmark.pyx":1873
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(seedcomb.values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(seedcomb.index)), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_seedcomb, __pyx_n_s_values); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_astype); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_11 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_14, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_7 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_9 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_14, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_15 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_9, PyBUF_WRITABLE); if (unlikely(!__pyx_t_15.memview)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1874
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(seedcomb.values.astype(int).tolist()),
 *                          k, int(len(seedcomb.index)), size, bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)))
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1874, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_seedcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1874, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_16 = PyObject_Length(__pyx_t_9); if (unlikely(__pyx_t_16 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1874, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1874, __pyx_L1_error)
    __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_18 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1874, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1875
 *         results = results + list(np.asarray(rankIC(y, np.array(seedcomb.values.astype(int).tolist()),
 *                          k, int(len(seedcomb.index)), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)))             # <<<<<<<<<<<<<<
 * 
 *     return results
 */
    __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_19 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1875, __pyx_L1_error)
    __pyx_t_20 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_20 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1875, __pyx_L1_error)
    __pyx_t_21 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_21 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1875, __pyx_L1_error)
    __pyx_t_22 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_22 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1875, __pyx_L1_error)
    __pyx_t_23 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_23 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1875, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1873
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(seedcomb.values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(seedcomb.index)), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)))
 */
    __pyx_t_12 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankIC(__pyx_v_y, __pyx_t_15, __pyx_t_8, ((int)__pyx_t_16), __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_20, __pyx_t_21, __pyx_t_22, __pyx_t_23, 0); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __PYX_XDEC_MEMVIEW(&__pyx_t_15, 1);
    __pyx_t_15.memview = NULL;
    __pyx_t_15.data = NULL;
    __pyx_t_9 = __pyx_memoryview_fromslice(__pyx_t_12, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_v_results, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_results, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1877
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)))
 * 
 *     return results             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_results);
  __pyx_r = __pyx_v_results;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1840
 * 
 * 
 * cpdef prepPvalICInd(             # <<<<<<<<<<<<<<
 *     seedcomb,       #Combined dataframe
 *     target,         #target to be compared
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __PYX_XDEC_MEMVIEW(&__pyx_t_15, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalICInd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origtarget);
  __Pyx_XDECREF(__pyx_v_targets);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_33prepPvalICInd(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_32prepPvalICInd[] = "\n    Function to prepare IC values for update\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_33prepPvalICInd(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_seedcomb = 0;
  PyObject *__pyx_v_target = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prepPvalICInd (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_seedcomb,&__pyx_n_s_target,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_k,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 1); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 2); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 3); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 4); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 5); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 6); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 7); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 8); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, 9); __PYX_ERR(0, 1840, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "prepPvalICInd") < 0)) __PYX_ERR(0, 1840, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 10) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
    }
    __pyx_v_seedcomb = values[0];
    __pyx_v_target = values[1];
    __pyx_v_size = values[2];
    __pyx_v_bandwidth = values[3];
    __pyx_v_k = values[4];
    __pyx_v_bandwidth_mult = values[5];
    __pyx_v_bandwidth_adj = values[6];
    __pyx_v_grid = values[7];
    __pyx_v_thread_number = values[8];
    __pyx_v_neighborhood = values[9];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("prepPvalICInd", 1, 10, 10, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1840, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalICInd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_32prepPvalICInd(__pyx_self, __pyx_v_seedcomb, __pyx_v_target, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_32prepPvalICInd(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_seedcomb, PyObject *__pyx_v_target, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_k, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepPvalICInd", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalICInd(__pyx_v_seedcomb, __pyx_v_target, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_k, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalICInd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1880
 * 
 * 
 * cpdef calcPvalCIC(             # <<<<<<<<<<<<<<
 *     results,    #List of IC to be compared
 *     IC,         #IC to be compared
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_35calcPvalCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalCIC(PyObject *__pyx_v_results, PyObject *__pyx_v_IC, PyObject *__pyx_v_direction, CYTHON_UNUSED int __pyx_skip_dispatch) {
  CYTHON_UNUSED long __pyx_v_pval;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcPvalCIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1890
 *     '''
 * 
 *     pval = 0             # <<<<<<<<<<<<<<
 *     count = 0
 *     if direction == 'pos':
 */
  __pyx_v_pval = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1891
 * 
 *     pval = 0
 *     count = 0             # <<<<<<<<<<<<<<
 *     if direction == 'pos':
 *         for i in results:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_count = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":1892
 *     pval = 0
 *     count = 0
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         for i in results:
 *             if i > IC:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_pos, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1892, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":1893
 *     count = 0
 *     if direction == 'pos':
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i > IC:
 *                 count = count + 1
 */
    if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
      __pyx_t_2 = __pyx_v_results; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1893, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1893, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1893, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1893, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1894
 *     if direction == 'pos':
 *         for i in results:
 *             if i > IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     else:
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_i, __pyx_v_IC, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1894, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1894, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":1895
 *         for i in results:
 *             if i > IC:
 *                 count = count + 1             # <<<<<<<<<<<<<<
 *     else:
 *         for i in results:
 */
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1895, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1894
 *     if direction == 'pos':
 *         for i in results:
 *             if i > IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     else:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1893
 *     count = 0
 *     if direction == 'pos':
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i > IC:
 *                 count = count + 1
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1892
 *     pval = 0
 *     count = 0
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         for i in results:
 *             if i > IC:
 */
    goto __pyx_L3;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1897
 *                 count = count + 1
 *     else:
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i < IC:
 *                 count = count + 1
 */
  /*else*/ {
    if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
      __pyx_t_2 = __pyx_v_results; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1897, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1897, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1897, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1897, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1897, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1897, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1898
 *     else:
 *         for i in results:
 *             if i < IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     if count == 0:
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_i, __pyx_v_IC, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1898, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1898, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":1899
 *         for i in results:
 *             if i < IC:
 *                 count = count + 1             # <<<<<<<<<<<<<<
 *     if count == 0:
 *         return len(results)
 */
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1898
 *     else:
 *         for i in results:
 *             if i < IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     if count == 0:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1897
 *                 count = count + 1
 *     else:
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i < IC:
 *                 count = count + 1
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "revealer/REVEALER_runbenchmark.pyx":1900
 *             if i < IC:
 *                 count = count + 1
 *     if count == 0:             # <<<<<<<<<<<<<<
 *         return len(results)
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":1901
 *                 count = count + 1
 *     if count == 0:
 *         return len(results)             # <<<<<<<<<<<<<<
 * 
 *     return count/len(results)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1901, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":1900
 *             if i < IC:
 *                 count = count + 1
 *     if count == 0:             # <<<<<<<<<<<<<<
 *         return len(results)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1903
 *         return len(results)
 * 
 *     return count/len(results)             # <<<<<<<<<<<<<<
 * 
 * cpdef prepPvalCIC(
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1903, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_v_count, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1880
 * 
 * 
 * cpdef calcPvalCIC(             # <<<<<<<<<<<<<<
 *     results,    #List of IC to be compared
 *     IC,         #IC to be compared
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcPvalCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_35calcPvalCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_34calcPvalCIC[] = "\n    Calculate p-value using CIC value and results calculate using prepPvalIC\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_35calcPvalCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_results = 0;
  PyObject *__pyx_v_IC = 0;
  PyObject *__pyx_v_direction = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calcPvalCIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_results,&__pyx_n_s_IC,&__pyx_n_s_direction,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_results)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_IC)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcPvalCIC", 1, 3, 3, 1); __PYX_ERR(0, 1880, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcPvalCIC", 1, 3, 3, 2); __PYX_ERR(0, 1880, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "calcPvalCIC") < 0)) __PYX_ERR(0, 1880, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_results = values[0];
    __pyx_v_IC = values[1];
    __pyx_v_direction = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calcPvalCIC", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1880, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcPvalCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_34calcPvalCIC(__pyx_self, __pyx_v_results, __pyx_v_IC, __pyx_v_direction);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_34calcPvalCIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_results, PyObject *__pyx_v_IC, PyObject *__pyx_v_direction) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcPvalCIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalCIC(__pyx_v_results, __pyx_v_IC, __pyx_v_direction, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcPvalCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1905
 *     return count/len(results)
 * 
 * cpdef prepPvalCIC(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     cythonseed,     #Seed to be used to calculate CIC
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_37prepPvalCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalCIC(PyObject *__pyx_v_comb, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_origtarget = NULL;
  PyObject *__pyx_v_targets = NULL;
  Py_ssize_t __pyx_v_i;
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  __Pyx_memviewslice __pyx_t_16 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  __pyx_t_5numpy_double_t __pyx_t_19;
  __pyx_t_5numpy_double_t __pyx_t_20;
  __pyx_t_5numpy_double_t __pyx_t_21;
  int __pyx_t_22;
  int __pyx_t_23;
  int __pyx_t_24;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepPvalCIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1924
 * 
 *     #Get original target
 *     origtarget = comb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 *     targets = []
 *     targets.append(origtarget)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origtarget = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1925
 *     #Get original target
 *     origtarget = comb.iloc[0].tolist()
 *     targets = []             # <<<<<<<<<<<<<<
 *     targets.append(origtarget)
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1926
 *     origtarget = comb.iloc[0].tolist()
 *     targets = []
 *     targets.append(origtarget)             # <<<<<<<<<<<<<<
 * 
 *     #Create 100 randomized target
 */
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_v_origtarget); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1926, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1929
 * 
 *     #Create 100 randomized target
 *     for i in range(1000):             # <<<<<<<<<<<<<<
 *         targets.append(random.sample(origtarget, len(origtarget)))
 * 
 */
  for (__pyx_t_5 = 0; __pyx_t_5 < 0x3E8; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "revealer/REVEALER_runbenchmark.pyx":1930
 *     #Create 100 randomized target
 *     for i in range(1000):
 *         targets.append(random.sample(origtarget, len(origtarget)))             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t[:] y
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_random); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sample); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_v_origtarget); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1930, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_origtarget, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1930, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_origtarget, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1930, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1930, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_v_origtarget);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1930, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1930, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1933
 * 
 *     cdef np.double_t[:] y
 *     results = []             # <<<<<<<<<<<<<<
 * 
 *     #Make list of results with all the CIC calculated with each randomized target
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_results = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1936
 * 
 *     #Make list of results with all the CIC calculated with each randomized target
 *     for i in range(len(targets)):             # <<<<<<<<<<<<<<
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 */
  __pyx_t_5 = PyList_GET_SIZE(__pyx_v_targets); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1936, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_6; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "revealer/REVEALER_runbenchmark.pyx":1937
 *     #Make list of results with all the CIC calculated with each randomized target
 *     for i in range(len(targets)):
 *         y = np.ascontiguousarray(np.asarray(targets[i]))             # <<<<<<<<<<<<<<
 * 
 *         results = results + list(np.asarray(rankCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_targets, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_11, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
    __pyx_v_y = __pyx_t_12;
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;

    /* "revealer/REVEALER_runbenchmark.pyx":1939
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 *         results = results + list(np.asarray(rankCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_v_cythonseed, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = __Pyx_PyObject_GetSlice(__pyx_t_14, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_values); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_astype); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_11 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_14, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_15, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_tolist); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_7 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_15)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_15);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_9 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_15, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_16 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_9, PyBUF_WRITABLE); if (unlikely(!__pyx_t_16.memview)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1940
 * 
 *         results = results + list(np.asarray(rankCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1940, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_17 = PyObject_Length(__pyx_t_9); if (unlikely(__pyx_t_17 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1940, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1940, __pyx_L1_error)
    __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_19 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1940, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1941
 *         results = results + list(np.asarray(rankCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))             # <<<<<<<<<<<<<<
 * 
 *     return results
 */
    __pyx_t_20 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_20 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1941, __pyx_L1_error)
    __pyx_t_21 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_21 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1941, __pyx_L1_error)
    __pyx_t_22 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_22 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1941, __pyx_L1_error)
    __pyx_t_23 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_23 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1941, __pyx_L1_error)
    __pyx_t_24 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_24 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1941, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":1939
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 *         results = results + list(np.asarray(rankCIC(y, cythonseed, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 */
    __pyx_t_12 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankCIC(__pyx_v_y, __pyx_t_13, __pyx_t_16, __pyx_t_8, ((int)(__pyx_t_17 - 1)), __pyx_t_18, __pyx_t_19, __pyx_t_20, __pyx_t_21, __pyx_t_22, __pyx_t_23, __pyx_t_24, 0); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __PYX_XDEC_MEMVIEW(&__pyx_t_13, 1);
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;
    __PYX_XDEC_MEMVIEW(&__pyx_t_16, 1);
    __pyx_t_16.memview = NULL;
    __pyx_t_16.data = NULL;
    __pyx_t_9 = __pyx_memoryview_fromslice(__pyx_t_12, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_v_results, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_results, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1943
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 * 
 *     return results             # <<<<<<<<<<<<<<
 * 
 * cpdef calcPvalIC(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_results);
  __pyx_r = __pyx_v_results;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1905
 *     return count/len(results)
 * 
 * cpdef prepPvalCIC(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     cythonseed,     #Seed to be used to calculate CIC
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __PYX_XDEC_MEMVIEW(&__pyx_t_16, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origtarget);
  __Pyx_XDECREF(__pyx_v_targets);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_37prepPvalCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_36prepPvalCIC[] = "\n    Function to prepare all CIC calculate with 100 randomized target. \n    Return value can be used as results parameter for calcPvalCIC.\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_37prepPvalCIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_cythonseed = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prepPvalCIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_comb,&__pyx_n_s_cythonseed,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cythonseed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 1); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 2); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 3); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 4); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 5); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 6); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 7); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 8); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, 9); __PYX_ERR(0, 1905, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "prepPvalCIC") < 0)) __PYX_ERR(0, 1905, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 10) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
    }
    __pyx_v_comb = values[0];
    __pyx_v_cythonseed = values[1];
    __pyx_v_k = values[2];
    __pyx_v_size = values[3];
    __pyx_v_bandwidth = values[4];
    __pyx_v_bandwidth_mult = values[5];
    __pyx_v_bandwidth_adj = values[6];
    __pyx_v_grid = values[7];
    __pyx_v_thread_number = values[8];
    __pyx_v_neighborhood = values[9];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("prepPvalCIC", 1, 10, 10, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1905, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_36prepPvalCIC(__pyx_self, __pyx_v_comb, __pyx_v_cythonseed, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_36prepPvalCIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepPvalCIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalCIC(__pyx_v_comb, __pyx_v_cythonseed, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalCIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1945
 *     return results
 * 
 * cpdef calcPvalIC(             # <<<<<<<<<<<<<<
 *     results,    #List of IC to be compared
 *     IC,         #IC to be compared
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_39calcPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalIC(PyObject *__pyx_v_results, PyObject *__pyx_v_IC, PyObject *__pyx_v_direction, CYTHON_UNUSED int __pyx_skip_dispatch) {
  CYTHON_UNUSED long __pyx_v_pval;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcPvalIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1955
 *     '''
 * 
 *     pval = 0             # <<<<<<<<<<<<<<
 *     count = 0
 *     if direction == 'pos':
 */
  __pyx_v_pval = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1956
 * 
 *     pval = 0
 *     count = 0             # <<<<<<<<<<<<<<
 *     if direction == 'pos':
 *         for i in results:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_count = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":1957
 *     pval = 0
 *     count = 0
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         for i in results:
 *             if i > IC:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_pos, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1957, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":1958
 *     count = 0
 *     if direction == 'pos':
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i > IC:
 *                 count = count + 1
 */
    if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
      __pyx_t_2 = __pyx_v_results; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1958, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1958, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1958, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1958, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1958, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1958, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1958, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1959
 *     if direction == 'pos':
 *         for i in results:
 *             if i > IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     else:
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_i, __pyx_v_IC, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1959, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1959, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":1960
 *         for i in results:
 *             if i > IC:
 *                 count = count + 1             # <<<<<<<<<<<<<<
 *     else:
 *         for i in results:
 */
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1960, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1959
 *     if direction == 'pos':
 *         for i in results:
 *             if i > IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     else:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1958
 *     count = 0
 *     if direction == 'pos':
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i > IC:
 *                 count = count + 1
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":1957
 *     pval = 0
 *     count = 0
 *     if direction == 'pos':             # <<<<<<<<<<<<<<
 *         for i in results:
 *             if i > IC:
 */
    goto __pyx_L3;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1962
 *                 count = count + 1
 *     else:
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i < IC:
 *                 count = count + 1
 */
  /*else*/ {
    if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
      __pyx_t_2 = __pyx_v_results; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1962, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1962, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1962, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1962, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 1962, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1962, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1962, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":1963
 *     else:
 *         for i in results:
 *             if i < IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     if count == 0:
 */
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_i, __pyx_v_IC, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1963, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1963, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "revealer/REVEALER_runbenchmark.pyx":1964
 *         for i in results:
 *             if i < IC:
 *                 count = count + 1             # <<<<<<<<<<<<<<
 *     if count == 0:
 *         return len(results)
 */
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1964, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":1963
 *     else:
 *         for i in results:
 *             if i < IC:             # <<<<<<<<<<<<<<
 *                 count = count + 1
 *     if count == 0:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":1962
 *                 count = count + 1
 *     else:
 *         for i in results:             # <<<<<<<<<<<<<<
 *             if i < IC:
 *                 count = count + 1
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "revealer/REVEALER_runbenchmark.pyx":1965
 *             if i < IC:
 *                 count = count + 1
 *     if count == 0:             # <<<<<<<<<<<<<<
 *         return len(results)
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "revealer/REVEALER_runbenchmark.pyx":1966
 *                 count = count + 1
 *     if count == 0:
 *         return len(results)             # <<<<<<<<<<<<<<
 * 
 *     return count/len(results)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1966, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":1965
 *             if i < IC:
 *                 count = count + 1
 *     if count == 0:             # <<<<<<<<<<<<<<
 *         return len(results)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1968
 *         return len(results)
 * 
 *     return count/len(results)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1968, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_v_count, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1945
 *     return results
 * 
 * cpdef calcPvalIC(             # <<<<<<<<<<<<<<
 *     results,    #List of IC to be compared
 *     IC,         #IC to be compared
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_39calcPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_38calcPvalIC[] = "\n    Calculate p-value using IC value and results calculate using prepPvalIC\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_39calcPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_results = 0;
  PyObject *__pyx_v_IC = 0;
  PyObject *__pyx_v_direction = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calcPvalIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_results,&__pyx_n_s_IC,&__pyx_n_s_direction,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_results)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_IC)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcPvalIC", 1, 3, 3, 1); __PYX_ERR(0, 1945, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcPvalIC", 1, 3, 3, 2); __PYX_ERR(0, 1945, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "calcPvalIC") < 0)) __PYX_ERR(0, 1945, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_results = values[0];
    __pyx_v_IC = values[1];
    __pyx_v_direction = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calcPvalIC", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1945, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_38calcPvalIC(__pyx_self, __pyx_v_results, __pyx_v_IC, __pyx_v_direction);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_38calcPvalIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_results, PyObject *__pyx_v_IC, PyObject *__pyx_v_direction) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcPvalIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_calcPvalIC(__pyx_v_results, __pyx_v_IC, __pyx_v_direction, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":1971
 * 
 * 
 * cpdef prepPvalIC(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     k,              #K value for kernel
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_41prepPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalIC(PyObject *__pyx_v_comb, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_origtarget = NULL;
  PyObject *__pyx_v_targets = NULL;
  Py_ssize_t __pyx_v_i;
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_memviewslice __pyx_t_15 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_16;
  int __pyx_t_17;
  __pyx_t_5numpy_double_t __pyx_t_18;
  __pyx_t_5numpy_double_t __pyx_t_19;
  __pyx_t_5numpy_double_t __pyx_t_20;
  int __pyx_t_21;
  int __pyx_t_22;
  int __pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepPvalIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":1989
 * 
 *     #Get original target
 *     origtarget = comb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 *     targets = []
 *     targets.append(origtarget)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origtarget = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1990
 *     #Get original target
 *     origtarget = comb.iloc[0].tolist()
 *     targets = []             # <<<<<<<<<<<<<<
 *     targets.append(origtarget)
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1991
 *     origtarget = comb.iloc[0].tolist()
 *     targets = []
 *     targets.append(origtarget)             # <<<<<<<<<<<<<<
 * 
 *     #Create 100 randomized target
 */
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_v_origtarget); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1991, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1994
 * 
 *     #Create 100 randomized target
 *     for i in range(1000):             # <<<<<<<<<<<<<<
 *         targets.append(random.sample(origtarget, len(origtarget)))
 * 
 */
  for (__pyx_t_5 = 0; __pyx_t_5 < 0x3E8; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "revealer/REVEALER_runbenchmark.pyx":1995
 *     #Create 100 randomized target
 *     for i in range(1000):
 *         targets.append(random.sample(origtarget, len(origtarget)))             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t[:] y
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_random); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sample); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_v_origtarget); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1995, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_origtarget, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_origtarget, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_v_origtarget);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1995, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":1998
 * 
 *     cdef np.double_t[:] y
 *     results = []             # <<<<<<<<<<<<<<
 * 
 *     #Make list of results with all the IC calculated with each randomized target
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_results = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2001
 * 
 *     #Make list of results with all the IC calculated with each randomized target
 *     for i in range(len(targets)):             # <<<<<<<<<<<<<<
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 */
  __pyx_t_5 = PyList_GET_SIZE(__pyx_v_targets); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2001, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_6; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "revealer/REVEALER_runbenchmark.pyx":2002
 *     #Make list of results with all the IC calculated with each randomized target
 *     for i in range(len(targets)):
 *         y = np.ascontiguousarray(np.asarray(targets[i]))             # <<<<<<<<<<<<<<
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_targets, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_11, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
    __pyx_v_y = __pyx_t_12;
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;

    /* "revealer/REVEALER_runbenchmark.pyx":2004
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_14 = __Pyx_PyObject_GetSlice(__pyx_t_13, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_values); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_astype); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_11 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_14, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_7 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_9 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_14, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_15 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_9, PyBUF_WRITABLE); if (unlikely(!__pyx_t_15.memview)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2005
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2005, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_16 = PyObject_Length(__pyx_t_9); if (unlikely(__pyx_t_16 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2005, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2005, __pyx_L1_error)
    __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_18 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2005, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2006
 *         results = results + list(np.asarray(rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))             # <<<<<<<<<<<<<<
 * 
 *     return results
 */
    __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_19 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L1_error)
    __pyx_t_20 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_20 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L1_error)
    __pyx_t_21 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_21 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L1_error)
    __pyx_t_22 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_22 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L1_error)
    __pyx_t_23 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_23 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2006, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2004
 *         y = np.ascontiguousarray(np.asarray(targets[i]))
 * 
 *         results = results + list(np.asarray(rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 */
    __pyx_t_12 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankIC(__pyx_v_y, __pyx_t_15, __pyx_t_8, ((int)(__pyx_t_16 - 1)), __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_20, __pyx_t_21, __pyx_t_22, __pyx_t_23, 0); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __PYX_XDEC_MEMVIEW(&__pyx_t_15, 1);
    __pyx_t_15.memview = NULL;
    __pyx_t_15.data = NULL;
    __pyx_t_9 = __pyx_memoryview_fromslice(__pyx_t_12, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_v_results, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_results, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2008
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)))
 * 
 *     return results             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_results);
  __pyx_r = __pyx_v_results;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":1971
 * 
 * 
 * cpdef prepPvalIC(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     k,              #K value for kernel
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __PYX_XDEC_MEMVIEW(&__pyx_t_15, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origtarget);
  __Pyx_XDECREF(__pyx_v_targets);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_41prepPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_40prepPvalIC[] = "\n    Function to prepare all IC calculate with 100 randomized target. Return value can be used as results parameter\n    for calcPvalIC\n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_41prepPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prepPvalIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_comb,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 1); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 2); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 3); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 4); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 5); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 6); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 7); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, 8); __PYX_ERR(0, 1971, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "prepPvalIC") < 0)) __PYX_ERR(0, 1971, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 9) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
    }
    __pyx_v_comb = values[0];
    __pyx_v_k = values[1];
    __pyx_v_size = values[2];
    __pyx_v_bandwidth = values[3];
    __pyx_v_bandwidth_mult = values[4];
    __pyx_v_bandwidth_adj = values[5];
    __pyx_v_grid = values[6];
    __pyx_v_thread_number = values[7];
    __pyx_v_neighborhood = values[8];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("prepPvalIC", 1, 9, 9, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1971, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_40prepPvalIC(__pyx_self, __pyx_v_comb, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_40prepPvalIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepPvalIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_prepPvalIC(__pyx_v_comb, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.prepPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2011
 * 
 * 
 * def calcIndivisualPvalIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K value for kernel
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_43calcIndivisualPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_42calcIndivisualPvalIC[] = "\n    Calculate individual p-values for IC\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_43calcIndivisualPvalIC = {"calcIndivisualPvalIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_43calcIndivisualPvalIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_42calcIndivisualPvalIC};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_43calcIndivisualPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_subcomb = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  CYTHON_UNUSED PyObject *__pyx_v_IC = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calcIndivisualPvalIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_subcomb,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_IC,&__pyx_n_s_neighborhood,0};
    PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_subcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 1); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 2); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 3); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 4); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 5); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 6); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 7); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_IC)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 8); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, 9); __PYX_ERR(0, 2011, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "calcIndivisualPvalIC") < 0)) __PYX_ERR(0, 2011, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 10) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
    }
    __pyx_v_subcomb = values[0];
    __pyx_v_k = values[1];
    __pyx_v_size = values[2];
    __pyx_v_bandwidth = values[3];
    __pyx_v_bandwidth_mult = values[4];
    __pyx_v_bandwidth_adj = values[5];
    __pyx_v_grid = values[6];
    __pyx_v_thread_number = values[7];
    __pyx_v_IC = values[8];
    __pyx_v_neighborhood = values[9];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calcIndivisualPvalIC", 1, 10, 10, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2011, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcIndivisualPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_42calcIndivisualPvalIC(__pyx_self, __pyx_v_subcomb, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_IC, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_42calcIndivisualPvalIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_subcomb, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, CYTHON_UNUSED PyObject *__pyx_v_IC, PyObject *__pyx_v_neighborhood) {
  PyObject *__pyx_v_origtarget = NULL;
  PyObject *__pyx_v_targets = NULL;
  CYTHON_UNUSED long __pyx_v_i;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_countless = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  long __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_11 = NULL;
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_13;
  __pyx_t_5numpy_double_t __pyx_t_14;
  __pyx_t_5numpy_double_t __pyx_t_15;
  __pyx_t_5numpy_double_t __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  __Pyx_memviewslice __pyx_t_20 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *(*__pyx_t_21)(PyObject *);
  int __pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcIndivisualPvalIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2028
 *     '''
 * 
 *     origtarget = subcomb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 *     targets = []
 *     for i in range(10000):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origtarget = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2029
 * 
 *     origtarget = subcomb.iloc[0].tolist()
 *     targets = []             # <<<<<<<<<<<<<<
 *     for i in range(10000):
 *         targets.append(random.sample(origtarget, len(origtarget)))
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2030
 *     origtarget = subcomb.iloc[0].tolist()
 *     targets = []
 *     for i in range(10000):             # <<<<<<<<<<<<<<
 *         targets.append(random.sample(origtarget, len(origtarget)))
 * 
 */
  for (__pyx_t_4 = 0; __pyx_t_4 < 0x2710; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "revealer/REVEALER_runbenchmark.pyx":2031
 *     targets = []
 *     for i in range(10000):
 *         targets.append(random.sample(origtarget, len(origtarget)))             # <<<<<<<<<<<<<<
 * 
 *     res = runIndividualPvalIC(np.ascontiguousarray(np.asarray(targets)),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_random); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sample); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = PyObject_Length(__pyx_v_origtarget); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2031, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_origtarget, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2031, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_origtarget, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2031, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_INCREF(__pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_v_origtarget);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_origtarget);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2031, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 2031, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2033
 *         targets.append(random.sample(origtarget, len(origtarget)))
 * 
 *     res = runIndividualPvalIC(np.ascontiguousarray(np.asarray(targets)),             # <<<<<<<<<<<<<<
 *                   np.asarray(subcomb.iloc[1].values.astype(int).tolist()),
 *                   k, 10000, size, bandwidth, bandwidth_mult, bandwidth_adj,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_2, __pyx_v_targets) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_targets);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_10 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_10.memview)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2034
 * 
 *     res = runIndividualPvalIC(np.ascontiguousarray(np.asarray(targets)),
 *                   np.asarray(subcomb.iloc[1].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                   k, 10000, size, bandwidth, bandwidth_mult, bandwidth_adj,
 *                   grid,thread_number, neighborhood)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_11 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_values); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_astype); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_6 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_2, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_11, ((PyObject *)(&PyInt_Type)));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_8 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_11, __pyx_t_8) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2035
 *     res = runIndividualPvalIC(np.ascontiguousarray(np.asarray(targets)),
 *                   np.asarray(subcomb.iloc[1].values.astype(int).tolist()),
 *                   k, 10000, size, bandwidth, bandwidth_mult, bandwidth_adj,             # <<<<<<<<<<<<<<
 *                   grid,thread_number, neighborhood)
 * 
 */
  __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2035, __pyx_L1_error)
  __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2035, __pyx_L1_error)
  __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_14 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2035, __pyx_L1_error)
  __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2035, __pyx_L1_error)
  __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2035, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2036
 *                   np.asarray(subcomb.iloc[1].values.astype(int).tolist()),
 *                   k, 10000, size, bandwidth, bandwidth_mult, bandwidth_adj,
 *                   grid,thread_number, neighborhood)             # <<<<<<<<<<<<<<
 * 
 *     countless = 0
 */
  __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2036, __pyx_L1_error)
  __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2036, __pyx_L1_error)
  __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2036, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2033
 *         targets.append(random.sample(origtarget, len(origtarget)))
 * 
 *     res = runIndividualPvalIC(np.ascontiguousarray(np.asarray(targets)),             # <<<<<<<<<<<<<<
 *                   np.asarray(subcomb.iloc[1].values.astype(int).tolist()),
 *                   k, 10000, size, bandwidth, bandwidth_mult, bandwidth_adj,
 */
  __pyx_t_20 = __pyx_f_8revealer_21REVEALER_runbenchmark_runIndividualPvalIC(__pyx_t_10, __pyx_t_12, __pyx_t_7, 0x2710, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, 0); if (unlikely(!__pyx_t_20.memview)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __pyx_t_10.memview = NULL;
  __pyx_t_10.data = NULL;
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __pyx_t_12.memview = NULL;
  __pyx_t_12.data = NULL;
  __pyx_t_1 = __pyx_memoryview_fromslice(__pyx_t_20, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
  __pyx_t_20.memview = NULL;
  __pyx_t_20.data = NULL;
  __pyx_v_res = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2038
 *                   grid,thread_number, neighborhood)
 * 
 *     countless = 0             # <<<<<<<<<<<<<<
 *     for r in res:
 *         if r > res[0]:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_countless = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":2039
 * 
 *     countless = 0
 *     for r in res:             # <<<<<<<<<<<<<<
 *         if r > res[0]:
 *             countless += 1
 */
  if (likely(PyList_CheckExact(__pyx_v_res)) || PyTuple_CheckExact(__pyx_v_res)) {
    __pyx_t_1 = __pyx_v_res; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    __pyx_t_21 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_res); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2039, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_21 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 2039, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_21)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 2039, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2039, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 2039, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2039, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_21(__pyx_t_1);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2039, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_r, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2040
 *     countless = 0
 *     for r in res:
 *         if r > res[0]:             # <<<<<<<<<<<<<<
 *             countless += 1
 *     if countless == 0:
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_res, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyObject_RichCompare(__pyx_v_r, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2040, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_22 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_22 < 0)) __PYX_ERR(0, 2040, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_22) {

      /* "revealer/REVEALER_runbenchmark.pyx":2041
 *     for r in res:
 *         if r > res[0]:
 *             countless += 1             # <<<<<<<<<<<<<<
 *     if countless == 0:
 *         countless = 1
 */
      __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_countless, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF_SET(__pyx_v_countless, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2040
 *     countless = 0
 *     for r in res:
 *         if r > res[0]:             # <<<<<<<<<<<<<<
 *             countless += 1
 *     if countless == 0:
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2039
 * 
 *     countless = 0
 *     for r in res:             # <<<<<<<<<<<<<<
 *         if r > res[0]:
 *             countless += 1
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2042
 *         if r > res[0]:
 *             countless += 1
 *     if countless == 0:             # <<<<<<<<<<<<<<
 *         countless = 1
 *     return (countless / 10000)
 */
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_countless, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_22 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_22 < 0)) __PYX_ERR(0, 2042, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_22) {

    /* "revealer/REVEALER_runbenchmark.pyx":2043
 *             countless += 1
 *     if countless == 0:
 *         countless = 1             # <<<<<<<<<<<<<<
 *     return (countless / 10000)
 * 
 */
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_DECREF_SET(__pyx_v_countless, __pyx_int_1);

    /* "revealer/REVEALER_runbenchmark.pyx":2042
 *         if r > res[0]:
 *             countless += 1
 *     if countless == 0:             # <<<<<<<<<<<<<<
 *         countless = 1
 *     return (countless / 10000)
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2044
 *     if countless == 0:
 *         countless = 1
 *     return (countless / 10000)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_TrueDivideObjC(__pyx_v_countless, __pyx_int_10000, 0x2710, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2011
 * 
 * 
 * def calcIndivisualPvalIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K value for kernel
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __Pyx_XDECREF(__pyx_t_11);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcIndivisualPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origtarget);
  __Pyx_XDECREF(__pyx_v_targets);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_countless);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2051
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] runIndividualPvalIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:,:] ys_in,     #List of targets
 *     np.int_t[:] x_in,           #List of features
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_45runIndividualPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_runIndividualPvalIC(__Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_x_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_v_i;
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __Pyx_memviewslice __pyx_t_11 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runIndividualPvalIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2070
 * 
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:] x = np.asarray(x_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 2070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2071
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:] x = np.asarray(x_in)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_ys_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 2071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2072
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:] x = np.asarray(x_in)             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t miny
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_x_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(0, 2072, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2077
 *     cdef np.double_t deltay
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_8 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_10 = (__pyx_t_8 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_10 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_12) firstprivate(__pyx_t_11, __pyx_t_5)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for lastprivate(__pyx_v_deltay) firstprivate(__pyx_v_i) lastprivate(__pyx_v_i) lastprivate(__pyx_v_miny)
                    #endif /* _OPENMP */
                    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_10; __pyx_t_9++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_9);
                            /* Initialize private variables to invalid values */
                            __pyx_v_deltay = ((__pyx_t_5numpy_double_t)__PYX_NAN());
                            __pyx_v_miny = ((__pyx_t_5numpy_double_t)__PYX_NAN());

                            /* "revealer/REVEALER_runbenchmark.pyx":2078
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         miny = findmin(y[i,:], size)             # <<<<<<<<<<<<<<
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x, k, size, bandwidth, bandwidth_mult,
 */
                            __pyx_t_5.data = __pyx_v_y.data;
                            __pyx_t_5.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_5, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_5.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_5.shape[0] = __pyx_v_y.shape[1];
__pyx_t_5.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_5.suboffsets[0] = -1;

__pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_5, __pyx_v_size);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_5, 0);
                            __pyx_t_5.memview = NULL;
                            __pyx_t_5.data = NULL;

                            /* "revealer/REVEALER_runbenchmark.pyx":2079
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)             # <<<<<<<<<<<<<<
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x, k, size, bandwidth, bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 */
                            __pyx_t_5.data = __pyx_v_y.data;
                            __pyx_t_5.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_5, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_5.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_5.shape[0] = __pyx_v_y.shape[1];
__pyx_t_5.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_5.suboffsets[0] = -1;

__pyx_t_11.data = __pyx_v_y.data;
                            __pyx_t_11.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_11, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_11.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_11.shape[0] = __pyx_v_y.shape[1];
__pyx_t_11.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_11.suboffsets[0] = -1;

__pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_t_5, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_11, __pyx_v_size));
                            __PYX_XDEC_MEMVIEW(&__pyx_t_5, 0);
                            __pyx_t_5.memview = NULL;
                            __pyx_t_5.data = NULL;
                            __PYX_XDEC_MEMVIEW(&__pyx_t_11, 0);
                            __pyx_t_11.memview = NULL;
                            __pyx_t_11.data = NULL;

                            /* "revealer/REVEALER_runbenchmark.pyx":2080
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x, k, size, bandwidth, bandwidth_mult,             # <<<<<<<<<<<<<<
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 *     i = 0
 */
                            __pyx_t_11.data = __pyx_v_y.data;
                            __pyx_t_11.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_11, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_11.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_11.shape[0] = __pyx_v_y.shape[1];
__pyx_t_11.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_11.suboffsets[0] = -1;

__pyx_t_12 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":2081
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x, k, size, bandwidth, bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 *     i = 0
 *     return res
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_12 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_t_11, __pyx_v_x, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_11, 0);
                            __pyx_t_11.memview = NULL;
                            __pyx_t_11.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2077
 *     cdef np.double_t deltay
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2082
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x, k, size, bandwidth, bandwidth_mult,
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 *     i = 0             # <<<<<<<<<<<<<<
 *     return res
 * 
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2083
 *                                                      bandwidth_adj, neighborhood, deltay, miny)
 *     i = 0
 *     return res             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __PYX_INC_MEMVIEW(&__pyx_v_res, 0);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2051
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] runIndividualPvalIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:,:] ys_in,     #List of targets
 *     np.int_t[:] x_in,           #List of features
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_11, 1);
  __pyx_r.data = NULL;
  __pyx_r.memview = NULL;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runIndividualPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  goto __pyx_L2;
  __pyx_L0:;
  if (unlikely(!__pyx_r.memview)) {
    PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
  }
  __pyx_L2:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_45runIndividualPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_44runIndividualPvalIC[] = "\n    Function to run individual IC for p-values \n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_45runIndividualPvalIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_ys_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("runIndividualPvalIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ys_in,&__pyx_n_s_x_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ys_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_x_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 1); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 2); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 3); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 4); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 5); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 6); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 7); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 8); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 9); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, 10); __PYX_ERR(0, 2051, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "runIndividualPvalIC") < 0)) __PYX_ERR(0, 2051, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 11) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
    }
    __pyx_v_ys_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_ys_in.memview)) __PYX_ERR(0, 2052, __pyx_L3_error)
    __pyx_v_x_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_x_in.memview)) __PYX_ERR(0, 2053, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2054, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2055, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2056, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2057, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2058, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2059, __pyx_L3_error)
    __pyx_v_grid = __Pyx_PyInt_As_int(values[8]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2060, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[9]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2061, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2062, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("runIndividualPvalIC", 1, 11, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2051, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runIndividualPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_44runIndividualPvalIC(__pyx_self, __pyx_v_ys_in, __pyx_v_x_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_44runIndividualPvalIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_x_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runIndividualPvalIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_runIndividualPvalIC(__pyx_v_ys_in, __pyx_v_x_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(0, 2051, __pyx_L1_error)
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_t_1, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL;
  __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runIndividualPvalIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_ys_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2087
 * 
 * 
 * def calcBootstrap(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     cythonseed,     #Seed to calculate
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_47calcBootstrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_46calcBootstrap[] = "\n    Calculate variance of CIC by bootstrapping subset of sample\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_47calcBootstrap = {"calcBootstrap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_47calcBootstrap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_46calcBootstrap};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_47calcBootstrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_subcomb = 0;
  PyObject *__pyx_v_cythonseed = 0;
  PyObject *__pyx_v_k = 0;
  CYTHON_UNUSED PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_IC = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calcBootstrap (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_subcomb,&__pyx_n_s_cythonseed,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_IC,&__pyx_n_s_neighborhood,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_subcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cythonseed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 1); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 2); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 3); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 4); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 5); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 6); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 7); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 8); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_IC)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 9); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, 10); __PYX_ERR(0, 2087, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "calcBootstrap") < 0)) __PYX_ERR(0, 2087, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 11) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
    }
    __pyx_v_subcomb = values[0];
    __pyx_v_cythonseed = values[1];
    __pyx_v_k = values[2];
    __pyx_v_size = values[3];
    __pyx_v_bandwidth = values[4];
    __pyx_v_bandwidth_mult = values[5];
    __pyx_v_bandwidth_adj = values[6];
    __pyx_v_grid = values[7];
    __pyx_v_thread_number = values[8];
    __pyx_v_IC = values[9];
    __pyx_v_neighborhood = values[10];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calcBootstrap", 1, 11, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2087, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcBootstrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_46calcBootstrap(__pyx_self, __pyx_v_subcomb, __pyx_v_cythonseed, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_IC, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_46calcBootstrap(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_subcomb, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_k, CYTHON_UNUSED PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_IC, PyObject *__pyx_v_neighborhood) {
  CYTHON_UNUSED PyObject *__pyx_v_origfeature = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_origtarget = NULL;
  PyObject *__pyx_v_features = NULL;
  PyObject *__pyx_v_targets = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_subsubcomb = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_ninety = NULL;
  PyObject *__pyx_v_diff = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_11 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_13;
  int __pyx_t_14;
  __pyx_t_5numpy_double_t __pyx_t_15;
  __pyx_t_5numpy_double_t __pyx_t_16;
  __pyx_t_5numpy_double_t __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  int __pyx_t_20;
  __Pyx_memviewslice __pyx_t_21 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcBootstrap", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2105
 *     '''
 * 
 *     origfeature = subcomb.iloc[1].tolist()             # <<<<<<<<<<<<<<
 *     origtarget = subcomb.iloc[0].tolist()
 *     features = []
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origfeature = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2106
 * 
 *     origfeature = subcomb.iloc[1].tolist()
 *     origtarget = subcomb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 *     features = []
 *     targets = []
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origtarget = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2107
 *     origfeature = subcomb.iloc[1].tolist()
 *     origtarget = subcomb.iloc[0].tolist()
 *     features = []             # <<<<<<<<<<<<<<
 *     targets = []
 *     i = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_features = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2108
 *     origtarget = subcomb.iloc[0].tolist()
 *     features = []
 *     targets = []             # <<<<<<<<<<<<<<
 *     i = 0
 *     while i < 100:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2109
 *     features = []
 *     targets = []
 *     i = 0             # <<<<<<<<<<<<<<
 *     while i < 100:
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_i = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":2110
 *     targets = []
 *     i = 0
 *     while i < 100:             # <<<<<<<<<<<<<<
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:
 */
  while (1) {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_i, __pyx_int_100, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2110, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2110, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_4) break;

    /* "revealer/REVEALER_runbenchmark.pyx":2111
 *     i = 0
 *     while i < 100:
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')             # <<<<<<<<<<<<<<
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_sample); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_math); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_floor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyFloat_FromDouble((__pyx_t_8 * 0.62)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_axis, __pyx_n_u_columns) < 0) __PYX_ERR(0, 2111, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_subsubcomb, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2112
 *     while i < 100:
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:             # <<<<<<<<<<<<<<
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_subsubcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_7, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_values); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_astype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_6, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_int_2, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":2113
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))             # <<<<<<<<<<<<<<
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 *             i += 1
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_subsubcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_astype); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_6 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, ((PyObject *)(&PyFloat_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)(&PyFloat_Type)));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 2113, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2114
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))             # <<<<<<<<<<<<<<
 *             i += 1
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_subsubcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_6, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_values); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_astype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)(&PyInt_Type)));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_features, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2115
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 *             i += 1             # <<<<<<<<<<<<<<
 * 
 *     res = runBootstrap(np.ascontiguousarray(np.asarray(targets)), cythonseed,
 */
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2112
 *     while i < 100:
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:             # <<<<<<<<<<<<<<
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 */
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2117
 *             i += 1
 * 
 *     res = runBootstrap(np.ascontiguousarray(np.asarray(targets)), cythonseed,             # <<<<<<<<<<<<<<
 *                        np.asarray(features), k, 100, math.floor(len(subcomb.columns.tolist())*0.62),
 *                        bandwidth, bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_v_targets) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_targets);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_10 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(__pyx_t_3, PyBUF_WRITABLE); if (unlikely(!__pyx_t_10.memview)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_11 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_v_cythonseed, PyBUF_WRITABLE); if (unlikely(!__pyx_t_11.memview)) __PYX_ERR(0, 2117, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2118
 * 
 *     res = runBootstrap(np.ascontiguousarray(np.asarray(targets)), cythonseed,
 *                        np.asarray(features), k, 100, math.floor(len(subcomb.columns.tolist())*0.62),             # <<<<<<<<<<<<<<
 *                        bandwidth, bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_2, __pyx_v_features) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_features);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_3, PyBUF_WRITABLE); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_math); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_floor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyFloat_FromDouble((__pyx_t_8 * 0.62)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_1, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_14 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_14 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2119
 *     res = runBootstrap(np.ascontiguousarray(np.asarray(targets)), cythonseed,
 *                        np.asarray(features), k, 100, math.floor(len(subcomb.columns.tolist())*0.62),
 *                        bandwidth, bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)             # <<<<<<<<<<<<<<
 * 
 *     ninety = [np.percentile(np.asarray(res), 5), np.percentile(np.asarray(res), 95)]
 */
  __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2119, __pyx_L1_error)
  __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2119, __pyx_L1_error)
  __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_17 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2119, __pyx_L1_error)
  __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2119, __pyx_L1_error)
  __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2119, __pyx_L1_error)
  __pyx_t_20 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_20 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2119, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2117
 *             i += 1
 * 
 *     res = runBootstrap(np.ascontiguousarray(np.asarray(targets)), cythonseed,             # <<<<<<<<<<<<<<
 *                        np.asarray(features), k, 100, math.floor(len(subcomb.columns.tolist())*0.62),
 *                        bandwidth, bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 */
  __pyx_t_21 = __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrap(__pyx_t_10, __pyx_t_11, __pyx_t_12, __pyx_t_13, 0x64, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_20, 0); if (unlikely(!__pyx_t_21.memview)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __pyx_t_10.memview = NULL;
  __pyx_t_10.data = NULL;
  __PYX_XDEC_MEMVIEW(&__pyx_t_11, 1);
  __pyx_t_11.memview = NULL;
  __pyx_t_11.data = NULL;
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __pyx_t_12.memview = NULL;
  __pyx_t_12.data = NULL;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_t_21, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XDEC_MEMVIEW(&__pyx_t_21, 1);
  __pyx_t_21.memview = NULL;
  __pyx_t_21.data = NULL;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2121
 *                        bandwidth, bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 * 
 *     ninety = [np.percentile(np.asarray(res), 5), np.percentile(np.asarray(res), 95)]             # <<<<<<<<<<<<<<
 *     diff = max(IC - ninety[0],ninety[1] - IC)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_percentile); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_v_res) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_res);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_20 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_20 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_2, __pyx_int_5};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_20, 2+__pyx_t_20); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_2, __pyx_int_5};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_20, 2+__pyx_t_20); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_1 = PyTuple_New(2+__pyx_t_20); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_20, __pyx_t_2);
    __Pyx_INCREF(__pyx_int_5);
    __Pyx_GIVEREF(__pyx_int_5);
    PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_20, __pyx_int_5);
    __pyx_t_2 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_percentile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_asarray); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, __pyx_v_res) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_res);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_20 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_20 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_1, __pyx_int_95};
    __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_20, 2+__pyx_t_20); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_1, __pyx_int_95};
    __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_20, 2+__pyx_t_20); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_20); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_20, __pyx_t_1);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_20, __pyx_int_95);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  __pyx_v_ninety = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2122
 * 
 *     ninety = [np.percentile(np.asarray(res), 5), np.percentile(np.asarray(res), 95)]
 *     diff = max(IC - ninety[0],ninety[1] - IC)             # <<<<<<<<<<<<<<
 * 
 *     return diff
 */
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_ninety, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyNumber_Subtract(__pyx_t_2, __pyx_v_IC); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_ninety, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Subtract(__pyx_v_IC, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_4) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_diff = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2124
 *     diff = max(IC - ninety[0],ninety[1] - IC)
 * 
 *     return diff             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_diff);
  __pyx_r = __pyx_v_diff;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2087
 * 
 * 
 * def calcBootstrap(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     cythonseed,     #Seed to calculate
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_11, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_21, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcBootstrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origfeature);
  __Pyx_XDECREF(__pyx_v_origtarget);
  __Pyx_XDECREF(__pyx_v_features);
  __Pyx_XDECREF(__pyx_v_targets);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_subsubcomb);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_ninety);
  __Pyx_XDECREF(__pyx_v_diff);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2131
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] runBootstrap(             # <<<<<<<<<<<<<<
 *     np.double_t[:,:] ys_in,     #List of targets
 *     np.int_t[:] z_in,           #Condition feature to calculate CIC
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_49runBootstrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrap(__Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_v_i;
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_8 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runBootstrap", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2151
 * 
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 2151, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2152
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_ys_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2153
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:] z = np.asarray(z_in)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_xs_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2154
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.int_t[:] z = np.asarray(z_in)             # <<<<<<<<<<<<<<
 * 
 *     cdef np.double_t miny
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_z_in, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_8.memview)) __PYX_ERR(0, 2154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_z = __pyx_t_8;
  __pyx_t_8.memview = NULL;
  __pyx_t_8.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2159
 *     cdef np.double_t deltay
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_9 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_11 = (__pyx_t_9 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_11 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_13) firstprivate(__pyx_t_12, __pyx_t_5, __pyx_t_8)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for lastprivate(__pyx_v_deltay) firstprivate(__pyx_v_i) lastprivate(__pyx_v_i) lastprivate(__pyx_v_miny)
                    #endif /* _OPENMP */
                    for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_11; __pyx_t_10++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_10);
                            /* Initialize private variables to invalid values */
                            __pyx_v_deltay = ((__pyx_t_5numpy_double_t)__PYX_NAN());
                            __pyx_v_miny = ((__pyx_t_5numpy_double_t)__PYX_NAN());

                            /* "revealer/REVEALER_runbenchmark.pyx":2160
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         miny = findmin(y[i,:], size)             # <<<<<<<<<<<<<<
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = ConditionalInformationCoefficient_cython(y[i,:], x[i,:], z, k, size, bandwidth,
 */
                            __pyx_t_5.data = __pyx_v_y.data;
                            __pyx_t_5.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_5, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_5.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_5.shape[0] = __pyx_v_y.shape[1];
__pyx_t_5.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_5.suboffsets[0] = -1;

__pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_5, __pyx_v_size);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_5, 0);
                            __pyx_t_5.memview = NULL;
                            __pyx_t_5.data = NULL;

                            /* "revealer/REVEALER_runbenchmark.pyx":2161
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)             # <<<<<<<<<<<<<<
 *         res[i] = ConditionalInformationCoefficient_cython(y[i,:], x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 */
                            __pyx_t_5.data = __pyx_v_y.data;
                            __pyx_t_5.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_5, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_5.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_5.shape[0] = __pyx_v_y.shape[1];
__pyx_t_5.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_5.suboffsets[0] = -1;

__pyx_t_12.data = __pyx_v_y.data;
                            __pyx_t_12.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_12, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_12.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_12.shape[0] = __pyx_v_y.shape[1];
__pyx_t_12.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_12.suboffsets[0] = -1;

__pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_t_5, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_12, __pyx_v_size));
                            __PYX_XDEC_MEMVIEW(&__pyx_t_5, 0);
                            __pyx_t_5.memview = NULL;
                            __pyx_t_5.data = NULL;
                            __PYX_XDEC_MEMVIEW(&__pyx_t_12, 0);
                            __pyx_t_12.memview = NULL;
                            __pyx_t_12.data = NULL;

                            /* "revealer/REVEALER_runbenchmark.pyx":2162
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = ConditionalInformationCoefficient_cython(y[i,:], x[i,:], z, k, size, bandwidth,             # <<<<<<<<<<<<<<
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)
 */
                            __pyx_t_12.data = __pyx_v_y.data;
                            __pyx_t_12.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_12, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_12.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_12.shape[0] = __pyx_v_y.shape[1];
__pyx_t_12.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_12.suboffsets[0] = -1;

__pyx_t_8.data = __pyx_v_x.data;
                            __pyx_t_8.memview = __pyx_v_x.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_8, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_x.strides[0];
        __pyx_t_8.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_8.shape[0] = __pyx_v_x.shape[1];
__pyx_t_8.strides[0] = __pyx_v_x.strides[1];
    __pyx_t_8.suboffsets[0] = -1;

__pyx_t_13 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":2164
 *         res[i] = ConditionalInformationCoefficient_cython(y[i,:], x[i,:], z, k, size, bandwidth,
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 *     i = 0
 *     return res
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_13 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython(__pyx_t_12, __pyx_t_8, __pyx_v_z, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_12, 0);
                            __pyx_t_12.memview = NULL;
                            __pyx_t_12.data = NULL;
                            __PYX_XDEC_MEMVIEW(&__pyx_t_8, 0);
                            __pyx_t_8.memview = NULL;
                            __pyx_t_8.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2159
 *     cdef np.double_t deltay
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2165
 *                                                           bandwidth_mult, bandwidth_adj,
 *                                                           neighborhood, deltay, miny)
 *     i = 0             # <<<<<<<<<<<<<<
 *     return res
 * 
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2166
 *                                                           neighborhood, deltay, miny)
 *     i = 0
 *     return res             # <<<<<<<<<<<<<<
 * 
 * def calcBootstrapIC(
 */
  __PYX_INC_MEMVIEW(&__pyx_v_res, 0);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2131
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] runBootstrap(             # <<<<<<<<<<<<<<
 *     np.double_t[:,:] ys_in,     #List of targets
 *     np.int_t[:] z_in,           #Condition feature to calculate CIC
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_8, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __pyx_r.data = NULL;
  __pyx_r.memview = NULL;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBootstrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  goto __pyx_L2;
  __pyx_L0:;
  if (unlikely(!__pyx_r.memview)) {
    PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
  }
  __pyx_L2:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_49runBootstrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_48runBootstrap[] = "\n    Function to run bootstrap(CIC) with different pair of target and features \n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_49runBootstrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_ys_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_z_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_xs_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("runBootstrap (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ys_in,&__pyx_n_s_z_in,&__pyx_n_s_xs_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[12] = {0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ys_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_z_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 1); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_xs_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 2); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 3); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 4); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 5); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 6); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 7); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 8); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 9); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 10); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, 11); __PYX_ERR(0, 2131, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "runBootstrap") < 0)) __PYX_ERR(0, 2131, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 12) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
    }
    __pyx_v_ys_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_ys_in.memview)) __PYX_ERR(0, 2132, __pyx_L3_error)
    __pyx_v_z_in = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_z_in.memview)) __PYX_ERR(0, 2133, __pyx_L3_error)
    __pyx_v_xs_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(values[2], PyBUF_WRITABLE); if (unlikely(!__pyx_v_xs_in.memview)) __PYX_ERR(0, 2134, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2135, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2136, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[5]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2137, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2138, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2139, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[8]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2140, __pyx_L3_error)
    __pyx_v_grid = __Pyx_PyInt_As_int(values[9]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2141, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2142, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[11]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2143, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("runBootstrap", 1, 12, 12, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2131, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBootstrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_48runBootstrap(__pyx_self, __pyx_v_ys_in, __pyx_v_z_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_48runBootstrap(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_z_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runBootstrap", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrap(__pyx_v_ys_in, __pyx_v_z_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(0, 2131, __pyx_L1_error)
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_t_1, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL;
  __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBootstrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_ys_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_z_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_xs_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2168
 *     return res
 * 
 * def calcBootstrapIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K for kernel
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_51calcBootstrapIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_50calcBootstrapIC[] = "\n    Calculate variance of IC by bootstrapping subset of sample\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_51calcBootstrapIC = {"calcBootstrapIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_51calcBootstrapIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_50calcBootstrapIC};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_51calcBootstrapIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_subcomb = 0;
  PyObject *__pyx_v_k = 0;
  CYTHON_UNUSED PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_IC = 0;
  PyObject *__pyx_v_neighborhood = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calcBootstrapIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_subcomb,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_IC,&__pyx_n_s_neighborhood,0};
    PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_subcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 1); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 2); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 3); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 4); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 5); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 6); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 7); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_IC)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 8); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, 9); __PYX_ERR(0, 2168, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "calcBootstrapIC") < 0)) __PYX_ERR(0, 2168, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 10) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
    }
    __pyx_v_subcomb = values[0];
    __pyx_v_k = values[1];
    __pyx_v_size = values[2];
    __pyx_v_bandwidth = values[3];
    __pyx_v_bandwidth_mult = values[4];
    __pyx_v_bandwidth_adj = values[5];
    __pyx_v_grid = values[6];
    __pyx_v_thread_number = values[7];
    __pyx_v_IC = values[8];
    __pyx_v_neighborhood = values[9];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calcBootstrapIC", 1, 10, 10, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2168, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcBootstrapIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_50calcBootstrapIC(__pyx_self, __pyx_v_subcomb, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_IC, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_50calcBootstrapIC(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_subcomb, PyObject *__pyx_v_k, CYTHON_UNUSED PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_grid, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_IC, PyObject *__pyx_v_neighborhood) {
  CYTHON_UNUSED PyObject *__pyx_v_origfeature = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_origtarget = NULL;
  PyObject *__pyx_v_features = NULL;
  PyObject *__pyx_v_targets = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_subsubcomb = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_ninety = NULL;
  PyObject *__pyx_v_diff = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_11 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_12;
  int __pyx_t_13;
  __pyx_t_5numpy_double_t __pyx_t_14;
  __pyx_t_5numpy_double_t __pyx_t_15;
  __pyx_t_5numpy_double_t __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  __Pyx_memviewslice __pyx_t_20 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcBootstrapIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2186
 * 
 *     #Save original target and picked feature
 *     origfeature = subcomb.iloc[1].tolist()             # <<<<<<<<<<<<<<
 *     origtarget = subcomb.iloc[0].tolist()
 *     features = []
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origfeature = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2187
 *     #Save original target and picked feature
 *     origfeature = subcomb.iloc[1].tolist()
 *     origtarget = subcomb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 *     features = []
 *     targets = []
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_origtarget = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2188
 *     origfeature = subcomb.iloc[1].tolist()
 *     origtarget = subcomb.iloc[0].tolist()
 *     features = []             # <<<<<<<<<<<<<<
 *     targets = []
 *     i = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_features = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2189
 *     origtarget = subcomb.iloc[0].tolist()
 *     features = []
 *     targets = []             # <<<<<<<<<<<<<<
 *     i = 0
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_targets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2190
 *     features = []
 *     targets = []
 *     i = 0             # <<<<<<<<<<<<<<
 * 
 *     #Make 100 pair of target and feature by subsetting 62% of original one
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_i = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":2193
 * 
 *     #Make 100 pair of target and feature by subsetting 62% of original one
 *     while i < 100:             # <<<<<<<<<<<<<<
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')
 * 
 */
  while (1) {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_i, __pyx_int_100, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2193, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2193, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_4) break;

    /* "revealer/REVEALER_runbenchmark.pyx":2194
 *     #Make 100 pair of target and feature by subsetting 62% of original one
 *     while i < 100:
 *         subsubcomb = subcomb.sample(math.floor(len(subcomb.columns.tolist())*0.62),axis='columns')             # <<<<<<<<<<<<<<
 * 
 *         #Save only if there are more than 3 occurence
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_sample); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_math); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_floor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyFloat_FromDouble((__pyx_t_8 * 0.62)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_axis, __pyx_n_u_columns) < 0) __PYX_ERR(0, 2194, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_subsubcomb, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2197
 * 
 *         #Save only if there are more than 3 occurence
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:             # <<<<<<<<<<<<<<
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_subsubcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_7, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_values); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_astype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_6, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_int_2, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":2198
 *         #Save only if there are more than 3 occurence
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))             # <<<<<<<<<<<<<<
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 *             i += 1
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_subsubcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_astype); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_6 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, ((PyObject *)(&PyFloat_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)(&PyFloat_Type)));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_targets, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 2198, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2199
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))             # <<<<<<<<<<<<<<
 *             i += 1
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_subsubcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_6, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_values); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_astype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)(&PyInt_Type)));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_features, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 2199, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2200
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 *             i += 1             # <<<<<<<<<<<<<<
 * 
 *     #Calculate IC for each pair (can be ran parallelly)
 */
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2197
 * 
 *         #Save only if there are more than 3 occurence
 *         if sum(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist())) > 2:             # <<<<<<<<<<<<<<
 *             targets.append(np.asarray(subsubcomb.iloc[0].values.astype(float).tolist()))
 *             features.append(np.asarray(subsubcomb.iloc[1].values.astype(int).tolist()))
 */
    }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2203
 * 
 *     #Calculate IC for each pair (can be ran parallelly)
 *     res = runBootstrapIC(np.ascontiguousarray(np.asarray(targets)),             # <<<<<<<<<<<<<<
 *                          np.asarray(features).astype(int), k, 100,
 *                          math.floor(len(subcomb.columns.tolist())*0.62), bandwidth,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ascontiguousarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_v_targets) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_targets);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_10 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(__pyx_t_3, PyBUF_WRITABLE); if (unlikely(!__pyx_t_10.memview)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2204
 *     #Calculate IC for each pair (can be ran parallelly)
 *     res = runBootstrapIC(np.ascontiguousarray(np.asarray(targets)),
 *                          np.asarray(features).astype(int), k, 100,             # <<<<<<<<<<<<<<
 *                          math.floor(len(subcomb.columns.tolist())*0.62), bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_v_features) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_features);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_astype); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_2, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)(&PyInt_Type)));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_11 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_3, PyBUF_WRITABLE); if (unlikely(!__pyx_t_11.memview)) __PYX_ERR(0, 2204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2204, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2205
 *     res = runBootstrapIC(np.ascontiguousarray(np.asarray(targets)),
 *                          np.asarray(features).astype(int), k, 100,
 *                          math.floor(len(subcomb.columns.tolist())*0.62), bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_math); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_floor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_subcomb, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyFloat_FromDouble((__pyx_t_8 * 0.62)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_14 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2205, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2206
 *                          np.asarray(features).astype(int), k, 100,
 *                          math.floor(len(subcomb.columns.tolist())*0.62), bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid, thread_number, neighborhood)             # <<<<<<<<<<<<<<
 * 
 *     #get value for 90 percentile and extract larger side
 */
  __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2206, __pyx_L1_error)
  __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2206, __pyx_L1_error)
  __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2206, __pyx_L1_error)
  __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2206, __pyx_L1_error)
  __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2206, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2203
 * 
 *     #Calculate IC for each pair (can be ran parallelly)
 *     res = runBootstrapIC(np.ascontiguousarray(np.asarray(targets)),             # <<<<<<<<<<<<<<
 *                          np.asarray(features).astype(int), k, 100,
 *                          math.floor(len(subcomb.columns.tolist())*0.62), bandwidth,
 */
  __pyx_t_20 = __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrapIC(__pyx_t_10, __pyx_t_11, __pyx_t_12, 0x64, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, 0); if (unlikely(!__pyx_t_20.memview)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __pyx_t_10.memview = NULL;
  __pyx_t_10.data = NULL;
  __PYX_XDEC_MEMVIEW(&__pyx_t_11, 1);
  __pyx_t_11.memview = NULL;
  __pyx_t_11.data = NULL;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_t_20, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
  __pyx_t_20.memview = NULL;
  __pyx_t_20.data = NULL;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2209
 * 
 *     #get value for 90 percentile and extract larger side
 *     ninety = [np.percentile(np.asarray(res), 5), np.percentile(np.asarray(res), 95)]             # <<<<<<<<<<<<<<
 *     diff = max(IC - ninety[0],ninety[1] - IC)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_percentile); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_1, __pyx_v_res) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_res);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_19 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_19 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_2, __pyx_int_5};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_19, 2+__pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_2, __pyx_int_5};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_19, 2+__pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_1 = PyTuple_New(2+__pyx_t_19); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_19, __pyx_t_2);
    __Pyx_INCREF(__pyx_int_5);
    __Pyx_GIVEREF(__pyx_int_5);
    PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_19, __pyx_int_5);
    __pyx_t_2 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_percentile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_asarray); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_v_res) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_res);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_19 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_19 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_1, __pyx_int_95};
    __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_19, 2+__pyx_t_19); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_1, __pyx_int_95};
    __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_19, 2+__pyx_t_19); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_19); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_19, __pyx_t_1);
    __Pyx_INCREF(__pyx_int_95);
    __Pyx_GIVEREF(__pyx_int_95);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_19, __pyx_int_95);
    __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_t_7);
  __pyx_t_3 = 0;
  __pyx_t_7 = 0;
  __pyx_v_ninety = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2210
 *     #get value for 90 percentile and extract larger side
 *     ninety = [np.percentile(np.asarray(res), 5), np.percentile(np.asarray(res), 95)]
 *     diff = max(IC - ninety[0],ninety[1] - IC)             # <<<<<<<<<<<<<<
 * 
 *     return diff
 */
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_ninety, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyNumber_Subtract(__pyx_t_2, __pyx_v_IC); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_ninety, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Subtract(__pyx_v_IC, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_7, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_2 = __pyx_t_7;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_diff = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2212
 *     diff = max(IC - ninety[0],ninety[1] - IC)
 * 
 *     return diff             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_diff);
  __pyx_r = __pyx_v_diff;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2168
 *     return res
 * 
 * def calcBootstrapIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K for kernel
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_11, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.calcBootstrapIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origfeature);
  __Pyx_XDECREF(__pyx_v_origtarget);
  __Pyx_XDECREF(__pyx_v_features);
  __Pyx_XDECREF(__pyx_v_targets);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_subsubcomb);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_ninety);
  __Pyx_XDECREF(__pyx_v_diff);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2219
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] runBootstrapIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:,:] ys_in,     #List of targets
 *     np.int_t[:,:] xs_in,        #List of features
 */

static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_53runBootstrapIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static __Pyx_memviewslice __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrapIC(__Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, CYTHON_UNUSED int __pyx_v_grid, CYTHON_UNUSED int __pyx_v_thread_number, int __pyx_v_neighborhood, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_v_i;
  __Pyx_memviewslice __pyx_v_res = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_y = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_x = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_double_t __pyx_v_miny;
  __pyx_t_5numpy_double_t __pyx_v_deltay;
  __Pyx_memviewslice __pyx_r = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_memviewslice __pyx_t_5 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_6 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __Pyx_memviewslice __pyx_t_11 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runBootstrapIC", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2238
 * 
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)             # <<<<<<<<<<<<<<
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_5.memview)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5.memview = NULL;
  __pyx_t_5.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2239
 *     cdef int i
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)             # <<<<<<<<<<<<<<
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)
 *     cdef np.double_t miny
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_ys_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_6.memview)) __PYX_ERR(0, 2239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_y = __pyx_t_6;
  __pyx_t_6.memview = NULL;
  __pyx_t_6.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2240
 *     cdef np.double_t[:] res = np.zeros(n)
 *     cdef np.double_t[:,:] y = np.asarray(ys_in)
 *     cdef np.int_t[:,:] x = np.asarray(xs_in)             # <<<<<<<<<<<<<<
 *     cdef np.double_t miny
 *     cdef np.double_t deltay
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_xs_in, 2, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(0, 2240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_x = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "revealer/REVEALER_runbenchmark.pyx":2244
 *     cdef np.double_t deltay
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {
        __pyx_t_8 = __pyx_v_n;
        if ((1 == 0)) abort();
        {
            #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
                #undef likely
                #undef unlikely
                #define likely(x)   (x)
                #define unlikely(x) (x)
            #endif
            __pyx_t_10 = (__pyx_t_8 - 0 + 1 - 1/abs(1)) / 1;
            if (__pyx_t_10 > 0)
            {
                #ifdef _OPENMP
                #pragma omp parallel num_threads(__pyx_v_thread_number) private(__pyx_t_13) firstprivate(__pyx_t_11, __pyx_t_12, __pyx_t_5)
                #endif /* _OPENMP */
                {
                    #ifdef _OPENMP
                    #pragma omp for lastprivate(__pyx_v_deltay) firstprivate(__pyx_v_i) lastprivate(__pyx_v_i) lastprivate(__pyx_v_miny)
                    #endif /* _OPENMP */
                    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_10; __pyx_t_9++){
                        {
                            __pyx_v_i = (int)(0 + 1 * __pyx_t_9);
                            /* Initialize private variables to invalid values */
                            __pyx_v_deltay = ((__pyx_t_5numpy_double_t)__PYX_NAN());
                            __pyx_v_miny = ((__pyx_t_5numpy_double_t)__PYX_NAN());

                            /* "revealer/REVEALER_runbenchmark.pyx":2245
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         miny = findmin(y[i,:], size)             # <<<<<<<<<<<<<<
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x[i,:], k, size, bandwidth,
 */
                            __pyx_t_5.data = __pyx_v_y.data;
                            __pyx_t_5.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_5, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_5.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_5.shape[0] = __pyx_v_y.shape[1];
__pyx_t_5.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_5.suboffsets[0] = -1;

__pyx_v_miny = __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_5, __pyx_v_size);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_5, 0);
                            __pyx_t_5.memview = NULL;
                            __pyx_t_5.data = NULL;

                            /* "revealer/REVEALER_runbenchmark.pyx":2246
 *     for i in prange(n, nogil=True,num_threads=thread_number):
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)             # <<<<<<<<<<<<<<
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x[i,:], k, size, bandwidth,
 *                                                      bandwidth_mult, bandwidth_adj,
 */
                            __pyx_t_5.data = __pyx_v_y.data;
                            __pyx_t_5.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_5, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_5.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_5.shape[0] = __pyx_v_y.shape[1];
__pyx_t_5.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_5.suboffsets[0] = -1;

__pyx_t_11.data = __pyx_v_y.data;
                            __pyx_t_11.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_11, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_11.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_11.shape[0] = __pyx_v_y.shape[1];
__pyx_t_11.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_11.suboffsets[0] = -1;

__pyx_v_deltay = (__pyx_f_8revealer_21REVEALER_runbenchmark_findmax(__pyx_t_5, __pyx_v_size) - __pyx_f_8revealer_21REVEALER_runbenchmark_findmin(__pyx_t_11, __pyx_v_size));
                            __PYX_XDEC_MEMVIEW(&__pyx_t_5, 0);
                            __pyx_t_5.memview = NULL;
                            __pyx_t_5.data = NULL;
                            __PYX_XDEC_MEMVIEW(&__pyx_t_11, 0);
                            __pyx_t_11.memview = NULL;
                            __pyx_t_11.data = NULL;

                            /* "revealer/REVEALER_runbenchmark.pyx":2247
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x[i,:], k, size, bandwidth,             # <<<<<<<<<<<<<<
 *                                                      bandwidth_mult, bandwidth_adj,
 *                                                      neighborhood, deltay, miny)
 */
                            __pyx_t_11.data = __pyx_v_y.data;
                            __pyx_t_11.memview = __pyx_v_y.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_11, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_y.strides[0];
        __pyx_t_11.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_11.shape[0] = __pyx_v_y.shape[1];
__pyx_t_11.strides[0] = __pyx_v_y.strides[1];
    __pyx_t_11.suboffsets[0] = -1;

__pyx_t_12.data = __pyx_v_x.data;
                            __pyx_t_12.memview = __pyx_v_x.memview;
                            __PYX_INC_MEMVIEW(&__pyx_t_12, 0);
                            {
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
    Py_ssize_t __pyx_tmp_stride = __pyx_v_x.strides[0];
        __pyx_t_12.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_12.shape[0] = __pyx_v_x.shape[1];
__pyx_t_12.strides[0] = __pyx_v_x.strides[1];
    __pyx_t_12.suboffsets[0] = -1;

__pyx_t_13 = __pyx_v_i;

                            /* "revealer/REVEALER_runbenchmark.pyx":2249
 *         res[i] = binaryInformationCoefficient_cython(y[i,:], x[i,:], k, size, bandwidth,
 *                                                      bandwidth_mult, bandwidth_adj,
 *                                                      neighborhood, deltay, miny)             # <<<<<<<<<<<<<<
 *     i = 0
 * 
 */
                            *((__pyx_t_5numpy_double_t *) ( /* dim=0 */ (__pyx_v_res.data + __pyx_t_13 * __pyx_v_res.strides[0]) )) = __pyx_f_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython(__pyx_t_11, __pyx_t_12, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_neighborhood, __pyx_v_deltay, __pyx_v_miny, 0, NULL);
                            __PYX_XDEC_MEMVIEW(&__pyx_t_11, 0);
                            __pyx_t_11.memview = NULL;
                            __pyx_t_11.data = NULL;
                            __PYX_XDEC_MEMVIEW(&__pyx_t_12, 0);
                            __pyx_t_12.memview = NULL;
                            __pyx_t_12.data = NULL;
                        }
                    }
                }
            }
        }
        #if ((defined(__APPLE__) || defined(__OSX__)) && (defined(__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))))
            #undef likely
            #undef unlikely
            #define likely(x)   __builtin_expect(!!(x), 1)
            #define unlikely(x) __builtin_expect(!!(x), 0)
        #endif
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2244
 *     cdef np.double_t deltay
 * 
 *     for i in prange(n, nogil=True,num_threads=thread_number):             # <<<<<<<<<<<<<<
 *         miny = findmin(y[i,:], size)
 *         deltay = findmax(y[i,:], size) - findmin(y[i,:], size)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2250
 *                                                      bandwidth_mult, bandwidth_adj,
 *                                                      neighborhood, deltay, miny)
 *     i = 0             # <<<<<<<<<<<<<<
 * 
 *     return res
 */
  __pyx_v_i = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2252
 *     i = 0
 * 
 *     return res             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __PYX_INC_MEMVIEW(&__pyx_v_res, 0);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2219
 * @cython.cdivision(True)
 * @cython.initializedcheck(False)
 * cpdef np.double_t[:] runBootstrapIC(             # <<<<<<<<<<<<<<
 *     np.double_t[:,:] ys_in,     #List of targets
 *     np.int_t[:,:] xs_in,        #List of features
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __PYX_XDEC_MEMVIEW(&__pyx_t_5, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_6, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_11, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_12, 1);
  __pyx_r.data = NULL;
  __pyx_r.memview = NULL;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBootstrapIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  goto __pyx_L2;
  __pyx_L0:;
  if (unlikely(!__pyx_r.memview)) {
    PyErr_SetString(PyExc_TypeError, "Memoryview return value is not initialized");
  }
  __pyx_L2:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_res, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_y, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_x, 1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_53runBootstrapIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_52runBootstrapIC[] = "\n    Function to run bootstrap(IC) with different pair of target and features \n    ";
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_53runBootstrapIC(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __Pyx_memviewslice __pyx_v_ys_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_xs_in = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_k;
  int __pyx_v_n;
  int __pyx_v_size;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult;
  __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj;
  int __pyx_v_grid;
  int __pyx_v_thread_number;
  int __pyx_v_neighborhood;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("runBootstrapIC (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ys_in,&__pyx_n_s_xs_in,&__pyx_n_s_k,&__pyx_n_s_n,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_grid,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ys_in)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_xs_in)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 1); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 2); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 3); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 4); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 5); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 6); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 7); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 8); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 9); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, 10); __PYX_ERR(0, 2219, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "runBootstrapIC") < 0)) __PYX_ERR(0, 2219, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 11) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
    }
    __pyx_v_ys_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(values[0], PyBUF_WRITABLE); if (unlikely(!__pyx_v_ys_in.memview)) __PYX_ERR(0, 2220, __pyx_L3_error)
    __pyx_v_xs_in = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(values[1], PyBUF_WRITABLE); if (unlikely(!__pyx_v_xs_in.memview)) __PYX_ERR(0, 2221, __pyx_L3_error)
    __pyx_v_k = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2222, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2223, __pyx_L3_error)
    __pyx_v_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2224, __pyx_L3_error)
    __pyx_v_bandwidth = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_bandwidth == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2225, __pyx_L3_error)
    __pyx_v_bandwidth_mult = __pyx_PyFloat_AsDouble(values[6]); if (unlikely((__pyx_v_bandwidth_mult == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2226, __pyx_L3_error)
    __pyx_v_bandwidth_adj = __pyx_PyFloat_AsDouble(values[7]); if (unlikely((__pyx_v_bandwidth_adj == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2227, __pyx_L3_error)
    __pyx_v_grid = __Pyx_PyInt_As_int(values[8]); if (unlikely((__pyx_v_grid == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2228, __pyx_L3_error)
    __pyx_v_thread_number = __Pyx_PyInt_As_int(values[9]); if (unlikely((__pyx_v_thread_number == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2229, __pyx_L3_error)
    __pyx_v_neighborhood = __Pyx_PyInt_As_int(values[10]); if (unlikely((__pyx_v_neighborhood == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2230, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("runBootstrapIC", 1, 11, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2219, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBootstrapIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_52runBootstrapIC(__pyx_self, __pyx_v_ys_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_52runBootstrapIC(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_ys_in, __Pyx_memviewslice __pyx_v_xs_in, int __pyx_v_k, int __pyx_v_n, int __pyx_v_size, __pyx_t_5numpy_double_t __pyx_v_bandwidth, __pyx_t_5numpy_double_t __pyx_v_bandwidth_mult, __pyx_t_5numpy_double_t __pyx_v_bandwidth_adj, int __pyx_v_grid, int __pyx_v_thread_number, int __pyx_v_neighborhood) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("runBootstrapIC", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_8revealer_21REVEALER_runbenchmark_runBootstrapIC(__pyx_v_ys_in, __pyx_v_xs_in, __pyx_v_k, __pyx_v_n, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_grid, __pyx_v_thread_number, __pyx_v_neighborhood, 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(0, 2219, __pyx_L1_error)
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_t_1, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL;
  __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XDEC_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.runBootstrapIC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XDEC_MEMVIEW(&__pyx_v_ys_in, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_v_xs_in, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2255
 * 
 * 
 * def plotCluster(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_55plotCluster(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_54plotCluster[] = "\n    Function to save intermediate figures with top ranking features in each loop while clustering them into \n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_55plotCluster = {"plotCluster", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_55plotCluster, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_54plotCluster};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_55plotCluster(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_plotcomb = 0;
  PyObject *__pyx_v_CICs = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_cythonseed = 0;
  PyObject *__pyx_v_seedcmap = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_pVals = 0;
  PyObject *__pyx_v_num_top = 0;
  PyObject *__pyx_v_bootstraps = 0;
  PyObject *__pyx_v_nitr = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_locusdic = 0;
  PyObject *__pyx_v_gmt = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotCluster (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_plotcomb,&__pyx_n_s_CICs,&__pyx_n_s_size,&__pyx_n_s_cythonseed,&__pyx_n_s_seedcmap,&__pyx_n_s_featurecmap,&__pyx_n_s_prefix,&__pyx_n_s_figure_format,&__pyx_n_s_pVals,&__pyx_n_s_num_top,&__pyx_n_s_bootstraps,&__pyx_n_s_nitr,&__pyx_n_s_out_folder,&__pyx_n_s_target_name,&__pyx_n_s_seed_name,&__pyx_n_s_locusdic,&__pyx_n_s_gmt,0};
    PyObject* values[17] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_plotcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_CICs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 1); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 2); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cythonseed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 3); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 4); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 5); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 6); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 7); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pVals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 8); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_top)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 9); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bootstraps)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 10); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nitr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 11); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 12); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 13); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (likely((values[14] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 14); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (likely((values[15] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_locusdic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 15); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (likely((values[16] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, 16); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "plotCluster") < 0)) __PYX_ERR(0, 2255, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 17) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
      values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
      values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
      values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
    }
    __pyx_v_plotcomb = values[0];
    __pyx_v_CICs = values[1];
    __pyx_v_size = values[2];
    __pyx_v_cythonseed = values[3];
    __pyx_v_seedcmap = values[4];
    __pyx_v_featurecmap = values[5];
    __pyx_v_prefix = values[6];
    __pyx_v_figure_format = values[7];
    __pyx_v_pVals = values[8];
    __pyx_v_num_top = values[9];
    __pyx_v_bootstraps = values[10];
    __pyx_v_nitr = values[11];
    __pyx_v_out_folder = values[12];
    __pyx_v_target_name = values[13];
    __pyx_v_seed_name = values[14];
    __pyx_v_locusdic = values[15];
    __pyx_v_gmt = values[16];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("plotCluster", 1, 17, 17, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2255, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.plotCluster", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_54plotCluster(__pyx_self, __pyx_v_plotcomb, __pyx_v_CICs, __pyx_v_size, __pyx_v_cythonseed, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_pVals, __pyx_v_num_top, __pyx_v_bootstraps, __pyx_v_nitr, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_11plotCluster_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "revealer/REVEALER_runbenchmark.pyx":2455
 *     plt.close()
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotsubdf.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotsubdf.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_11plotCluster_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2455, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8revealer_21REVEALER_runbenchmark_11plotCluster_2generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_plotCluster_locals_genexpr, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!gen)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.plotCluster.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_11plotCluster_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2455, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_plotsubdf)) { __Pyx_RaiseClosureNameError("plotsubdf"); __PYX_ERR(0, 2455, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_plotsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2455, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 2455, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 2455, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2455, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_elem);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_elem, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt)) { __Pyx_RaiseClosureNameError("gmt"); __PYX_ERR(0, 2455, __pyx_L1_error) }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_elem, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!(__pyx_t_7 != 0)) != 0);
    if (__pyx_t_8) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2255
 * 
 * 
 * def plotCluster(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_54plotCluster(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_CICs, PyObject *__pyx_v_size, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_pVals, PyObject *__pyx_v_num_top, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_gmt) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *__pyx_cur_scope;
  int __pyx_v_plotpval;
  int __pyx_v_if_bootstrap;
  PyObject *__pyx_v_comball = NULL;
  PyObject *__pyx_v_plotcomb2 = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_nmf_results = NULL;
  PyObject *__pyx_v_cophenetic_correlation_coefficients = NULL;
  PyObject *__pyx_v_diff = NULL;
  PyObject *__pyx_v_diffindex = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_group = NULL;
  PyObject *__pyx_v_numgroup = NULL;
  PyObject *__pyx_v_fig = NULL;
  PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_groupindex = NULL;
  PyObject *__pyx_v_g = NULL;
  PyObject *__pyx_v_gsubdf = NULL;
  Py_ssize_t __pyx_v_j;
  PyObject *__pyx_v_pval = NULL;
  PyObject *__pyx_v_pvallist = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  Py_UCS4 __pyx_t_21;
  double __pyx_t_22;
  double __pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotCluster", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2255, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_gmt = __pyx_v_gmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_gmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_gmt);

  /* "revealer/REVEALER_runbenchmark.pyx":2280
 * 
 *     #Check if the bootstrap, clustering, and p-value are calculated
 *     plotpval = False             # <<<<<<<<<<<<<<
 *     if_bootstrap = False
 *     if len(pVals) != 0:
 */
  __pyx_v_plotpval = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2281
 *     #Check if the bootstrap, clustering, and p-value are calculated
 *     plotpval = False
 *     if_bootstrap = False             # <<<<<<<<<<<<<<
 *     if len(pVals) != 0:
 *         plotpval = True
 */
  __pyx_v_if_bootstrap = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2282
 *     plotpval = False
 *     if_bootstrap = False
 *     if len(pVals) != 0:             # <<<<<<<<<<<<<<
 *         plotpval = True
 *     if len(bootstraps) != 0:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_pVals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2282, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2283
 *     if_bootstrap = False
 *     if len(pVals) != 0:
 *         plotpval = True             # <<<<<<<<<<<<<<
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True
 */
    __pyx_v_plotpval = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2282
 *     plotpval = False
 *     if_bootstrap = False
 *     if len(pVals) != 0:             # <<<<<<<<<<<<<<
 *         plotpval = True
 *     if len(bootstraps) != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2284
 *     if len(pVals) != 0:
 *         plotpval = True
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 *     comball = plotcomb.copy()
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2284, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2285
 *         plotpval = True
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True             # <<<<<<<<<<<<<<
 *     comball = plotcomb.copy()
 *     comball['CICs'] = CICs
 */
    __pyx_v_if_bootstrap = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2284
 *     if len(pVals) != 0:
 *         plotpval = True
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 *     comball = plotcomb.copy()
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2286
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True
 *     comball = plotcomb.copy()             # <<<<<<<<<<<<<<
 *     comball['CICs'] = CICs
 *     if plotpval == True:
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_comball = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2287
 *         if_bootstrap = True
 *     comball = plotcomb.copy()
 *     comball['CICs'] = CICs             # <<<<<<<<<<<<<<
 *     if plotpval == True:
 *         comball['pVals'] = list(pVals)
 */
  if (unlikely(PyObject_SetItem(__pyx_v_comball, __pyx_n_u_CICs, __pyx_v_CICs) < 0)) __PYX_ERR(0, 2287, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2288
 *     comball = plotcomb.copy()
 *     comball['CICs'] = CICs
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         comball['pVals'] = list(pVals)
 *     if if_bootstrap == True:
 */
  __pyx_t_2 = ((__pyx_v_plotpval == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2289
 *     comball['CICs'] = CICs
 *     if plotpval == True:
 *         comball['pVals'] = list(pVals)             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         comball['bootstraps'] = list(bootstraps)
 */
    __pyx_t_3 = PySequence_List(__pyx_v_pVals); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(PyObject_SetItem(__pyx_v_comball, __pyx_n_u_pVals, __pyx_t_3) < 0)) __PYX_ERR(0, 2289, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2288
 *     comball = plotcomb.copy()
 *     comball['CICs'] = CICs
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         comball['pVals'] = list(pVals)
 *     if if_bootstrap == True:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2290
 *     if plotpval == True:
 *         comball['pVals'] = list(pVals)
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         comball['bootstraps'] = list(bootstraps)
 * 
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2291
 *         comball['pVals'] = list(pVals)
 *     if if_bootstrap == True:
 *         comball['bootstraps'] = list(bootstraps)             # <<<<<<<<<<<<<<
 * 
 *     #Replace new line otherwise there's error
 */
    __pyx_t_3 = PySequence_List(__pyx_v_bootstraps); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(PyObject_SetItem(__pyx_v_comball, __pyx_n_u_bootstraps, __pyx_t_3) < 0)) __PYX_ERR(0, 2291, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2290
 *     if plotpval == True:
 *         comball['pVals'] = list(pVals)
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         comball['bootstraps'] = list(bootstraps)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2294
 * 
 *     #Replace new line otherwise there's error
 *     plotcomb2 = plotcomb.copy()             # <<<<<<<<<<<<<<
 *     plotcomb2.index = plotcomb2.index.str.replace("\n", ",")
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_plotcomb2 = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2295
 *     #Replace new line otherwise there's error
 *     plotcomb2 = plotcomb.copy()
 *     plotcomb2.index = plotcomb2.index.str.replace("\n", ",")             # <<<<<<<<<<<<<<
 * 
 *     #Run NMF with different k
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb2, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_plotcomb2, __pyx_n_s_index, __pyx_t_4) < 0) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2298
 * 
 *     #Run NMF with different k
 *     res, nmf_results, cophenetic_correlation_coefficients = ccal.explore_components(             # <<<<<<<<<<<<<<
 *                     df = plotcomb2.iloc[1:,].T,
 *                     ks = range(2,12),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ccal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_explore_components); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2299
 *     #Run NMF with different k
 *     res, nmf_results, cophenetic_correlation_coefficients = ccal.explore_components(
 *                     df = plotcomb2.iloc[1:,].T,             # <<<<<<<<<<<<<<
 *                     ks = range(2,12),
 *                     n_clustering = 10,
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb2, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_tuple__31); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_T); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_df, __pyx_t_5) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2300
 *     res, nmf_results, cophenetic_correlation_coefficients = ccal.explore_components(
 *                     df = plotcomb2.iloc[1:,].T,
 *                     ks = range(2,12),             # <<<<<<<<<<<<<<
 *                     n_clustering = 10,
 *                     random_seed = 19981218,
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ks, __pyx_t_5) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_n_clustering, __pyx_int_10) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_random_seed, __pyx_int_19981218) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2303
 *                     n_clustering = 10,
 *                     random_seed = 19981218,
 *                     directory_path = out_folder + prefix + '_NMF/',             # <<<<<<<<<<<<<<
 *                     verbose = 0,
 *                     algorithm = 'ls')
 */
  __pyx_t_5 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_kp_u_NMF); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_directory_path, __pyx_t_6) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_verbose, __pyx_int_0) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_algorithm, __pyx_n_u_ls) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2298
 * 
 *     #Run NMF with different k
 *     res, nmf_results, cophenetic_correlation_coefficients = ccal.explore_components(             # <<<<<<<<<<<<<<
 *                     df = plotcomb2.iloc[1:,].T,
 *                     ks = range(2,12),
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
    PyObject* sequence = __pyx_t_6;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 2298, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_7 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
    index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 1; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 2; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < 0) __PYX_ERR(0, 2298, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L8_unpacking_done;
    __pyx_L7_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 2298, __pyx_L1_error)
    __pyx_L8_unpacking_done:;
  }
  __pyx_v_res = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_nmf_results = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_cophenetic_correlation_coefficients = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2308
 * 
 *     #Pick best k value based on cophenetic correlation coefficients
 *     diff = -1             # <<<<<<<<<<<<<<
 *     diffindex = 0
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):
 */
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_diff = __pyx_int_neg_1;

  /* "revealer/REVEALER_runbenchmark.pyx":2309
 *     #Pick best k value based on cophenetic correlation coefficients
 *     diff = -1
 *     diffindex = 0             # <<<<<<<<<<<<<<
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_diffindex = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":2310
 *     diff = -1
 *     diffindex = 0
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):             # <<<<<<<<<<<<<<
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_cophenetic_correlation_coefficients, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_6, 0, -1L, NULL, NULL, &__pyx_slice__33, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
    __pyx_t_3 = __pyx_t_6; __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2310, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2310, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2310, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2310, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_9(__pyx_t_3);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2310, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2311
 *     diffindex = 0
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:             # <<<<<<<<<<<<<<
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]
 *             diffindex = i
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_cophenetic_correlation_coefficients, __pyx_n_s_iloc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_cophenetic_correlation_coefficients, __pyx_n_s_iloc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Subtract(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_RichCompare(__pyx_t_4, __pyx_v_diff, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2312
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]             # <<<<<<<<<<<<<<
 *             diffindex = i
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_cophenetic_correlation_coefficients, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_cophenetic_correlation_coefficients, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Subtract(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_diff, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2313
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]
 *             diffindex = i             # <<<<<<<<<<<<<<
 * 
 *     #get grouping result with optimal k
 */
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_DECREF_SET(__pyx_v_diffindex, __pyx_v_i);

      /* "revealer/REVEALER_runbenchmark.pyx":2311
 *     diffindex = 0
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:             # <<<<<<<<<<<<<<
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]
 *             diffindex = i
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2310
 *     diff = -1
 *     diffindex = 0
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):             # <<<<<<<<<<<<<<
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2316
 * 
 *     #get grouping result with optimal k
 *     group = nmf_results.loc[cophenetic_correlation_coefficients.index.tolist()[diffindex]].tolist()             # <<<<<<<<<<<<<<
 *     comball['group'] = [0]+group
 *     numgroup = len(set(group))
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_nmf_results, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cophenetic_correlation_coefficients, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_diffindex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_group = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2317
 *     #get grouping result with optimal k
 *     group = nmf_results.loc[cophenetic_correlation_coefficients.index.tolist()[diffindex]].tolist()
 *     comball['group'] = [0]+group             # <<<<<<<<<<<<<<
 *     numgroup = len(set(group))
 * 
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
  __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_v_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(PyObject_SetItem(__pyx_v_comball, __pyx_n_u_group, __pyx_t_7) < 0)) __PYX_ERR(0, 2317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2318
 *     group = nmf_results.loc[cophenetic_correlation_coefficients.index.tolist()[diffindex]].tolist()
 *     comball['group'] = [0]+group
 *     numgroup = len(set(group))             # <<<<<<<<<<<<<<
 * 
 *     #Prepare canvas for result figure
 */
  __pyx_t_7 = PySet_New(__pyx_v_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PySet_GET_SIZE(__pyx_t_7); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_numgroup = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2321
 * 
 *     #Prepare canvas for result figure
 *     fig = plt.figure()             # <<<<<<<<<<<<<<
 *     fig.set_figheight(len(CICs)/2.0+1+numgroup/2.0)
 *     fig.set_figwidth(12)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_figure); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_fig = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2322
 *     #Prepare canvas for result figure
 *     fig = plt.figure()
 *     fig.set_figheight(len(CICs)/2.0+1+numgroup/2.0)             # <<<<<<<<<<<<<<
 *     fig.set_figwidth(12)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figheight); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2322, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(((((double)__pyx_t_1) / 2.0) + 1.0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_numgroup, __pyx_float_2_0, 2.0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2323
 *     fig = plt.figure()
 *     fig.set_figheight(len(CICs)/2.0+1+numgroup/2.0)
 *     fig.set_figwidth(12)             # <<<<<<<<<<<<<<
 * 
 *     #Label target name at left of target heatmap
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figwidth); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_4, __pyx_int_12) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_int_12);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2326
 * 
 *     #Label target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2326, __pyx_L1_error)
  __pyx_t_4 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_v_numgroup); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Multiply(__pyx_int_5, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_132);
  __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_tuple__25) < 0) __PYX_ERR(0, 2326, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2326, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2326, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_ax = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2327
 *     #Label target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2328
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot heatmap for target
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_target_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Target, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_float_0_9);
  __Pyx_GIVEREF(__pyx_float_0_9);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_float_0_9);
  __Pyx_INCREF(__pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_float_0_5);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2328, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2328, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2331
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2331, __pyx_L1_error)
  __pyx_t_7 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyNumber_Add(__pyx_t_7, __pyx_v_numgroup); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_int_5, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_132);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__26) < 0) __PYX_ERR(0, 2331, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2331, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2331, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2332
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_7, 0, __pyx_int_0);
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cmap, __pyx_n_u_bwr) < 0) __PYX_ERR(0, 2332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2332, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2333
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())             # <<<<<<<<<<<<<<
 * 
 *     #Label for IC or CIC and p-values on right of target heatmap.
 */
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2332, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_mean); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_center, __pyx_t_3) < 0) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2332
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2336
 * 
 *     #Label for IC or CIC and p-values on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2336, __pyx_L1_error)
  __pyx_t_7 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = PyNumber_Add(__pyx_t_7, __pyx_v_numgroup); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_int_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_132);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__34) < 0) __PYX_ERR(0, 2336, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2336, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2336, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2337
 *     #Label for IC or CIC and p-values on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2338
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2339
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2339, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2339, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2339, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__35, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2338
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')
 *     else:
 */
    goto __pyx_L12;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2341
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2341, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2341, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2341, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__36, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L12:;

  /* "revealer/REVEALER_runbenchmark.pyx":2342
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if plotpval == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2342, __pyx_L1_error)
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyNumber_Add(__pyx_t_5, __pyx_v_numgroup); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Multiply(__pyx_int_5, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_132);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__37) < 0) __PYX_ERR(0, 2342, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2342, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2342, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2343
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if plotpval == True:
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2344
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')
 * 
 */
  __pyx_t_2 = ((__pyx_v_plotpval == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2345
 *     ax.set_axis_off()
 *     if plotpval == True:
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Label seed name at left of seed heatmap
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2345, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2345, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__38, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2344
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2348
 * 
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if seed_name != None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2348, __pyx_L1_error)
  __pyx_t_7 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyNumber_Add(__pyx_t_7, __pyx_v_numgroup); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_int_5, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_132);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__39) < 0) __PYX_ERR(0, 2348, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2348, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2348, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2349
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2350
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2350, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2350, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2351
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_seed_name); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2351, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_1 > 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2352
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_3, __pyx_kp_u__40); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2352, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2352, __pyx_L1_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2351
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
      goto __pyx_L15;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2354
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')
 */
    /*else*/ {
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2354, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2354, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_L15:;

    /* "revealer/REVEALER_runbenchmark.pyx":2350
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
    goto __pyx_L14;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2356
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot seed heatmap
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2356, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2356, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__41, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L14:;

  /* "revealer/REVEALER_runbenchmark.pyx":2359
 * 
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2359, __pyx_L1_error)
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyNumber_Add(__pyx_t_5, __pyx_v_numgroup); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Multiply(__pyx_int_5, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_132);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__42) < 0) __PYX_ERR(0, 2359, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2359, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2359, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2360
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_sns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_cythonseed);
  __Pyx_GIVEREF(__pyx_v_cythonseed);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_cythonseed);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 2360, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2360, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2360, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2361
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 * 
 *     #Blanks
 */
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2360, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2360, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2360
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2364
 * 
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2364, __pyx_L1_error)
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_1 + 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyNumber_Add(__pyx_t_5, __pyx_v_numgroup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Multiply(__pyx_int_5, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_132);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__43) < 0) __PYX_ERR(0, 2364, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2364, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2364, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2365
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 * 
 *     #Subset dataframe to plot portion
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2368
 * 
 *     #Subset dataframe to plot portion
 *     plotsubdf = comball.iloc[1:]             # <<<<<<<<<<<<<<
 *     plotsubdf.sort_values(by='group', ascending=False, inplace=True)
 *     pos = 2
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_comball, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_3, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_plotsubdf = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2369
 *     #Subset dataframe to plot portion
 *     plotsubdf = comball.iloc[1:]
 *     plotsubdf.sort_values(by='group', ascending=False, inplace=True)             # <<<<<<<<<<<<<<
 *     pos = 2
 *     groupindex = 1
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotsubdf, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_by, __pyx_n_u_group) < 0) __PYX_ERR(0, 2369, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 2369, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 2369, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2370
 *     plotsubdf = comball.iloc[1:]
 *     plotsubdf.sort_values(by='group', ascending=False, inplace=True)
 *     pos = 2             # <<<<<<<<<<<<<<
 *     groupindex = 1
 * 
 */
  __Pyx_INCREF(__pyx_int_2);
  __pyx_v_pos = __pyx_int_2;

  /* "revealer/REVEALER_runbenchmark.pyx":2371
 *     plotsubdf.sort_values(by='group', ascending=False, inplace=True)
 *     pos = 2
 *     groupindex = 1             # <<<<<<<<<<<<<<
 * 
 *     #Loop for plot features by group
 */
  __Pyx_INCREF(__pyx_int_1);
  __pyx_v_groupindex = __pyx_int_1;

  /* "revealer/REVEALER_runbenchmark.pyx":2374
 * 
 *     #Loop for plot features by group
 *     for g in plotsubdf['group'].unique():             # <<<<<<<<<<<<<<
 * 
 *         #Put group id
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_plotsubdf, __pyx_n_u_group); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_unique); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
    __pyx_t_4 = __pyx_t_7; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2374, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2374, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2374, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2374, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2374, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_9(__pyx_t_4);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2374, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_g, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2377
 * 
 *         #Put group id
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 20),             # <<<<<<<<<<<<<<
 *                               colspan=90,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_11 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2377, __pyx_L1_error)
    __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_11 + 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_v_numgroup); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Multiply(__pyx_int_5, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
    __Pyx_INCREF(__pyx_int_132);
    __Pyx_GIVEREF(__pyx_int_132);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_132);
    __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Multiply(__pyx_v_pos, __pyx_int_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_int_20);
    __Pyx_GIVEREF(__pyx_int_20);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_20);
    __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_t_5) < 0) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2377, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2377, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2379
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"Group"+str(groupindex),ha='center', va='center')
 * 
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2380
 *                               colspan=90,rowspan=5)
 *         ax.set_axis_off()
 *         ax.text(0.5,0.5,"Group"+str(groupindex),ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Subset df with group id and sort by CIC value
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_groupindex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_n_u_Group, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_float_0_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2380, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2380, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2383
 * 
 *         #Subset df with group id and sort by CIC value
 *         gsubdf = plotsubdf[plotsubdf['group'] == g]             # <<<<<<<<<<<<<<
 *         pos += 1
 *         groupindex += 1
 */
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_plotsubdf, __pyx_n_u_group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_6, __pyx_v_g, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2383, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_plotsubdf, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_gsubdf, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2384
 *         #Subset df with group id and sort by CIC value
 *         gsubdf = plotsubdf[plotsubdf['group'] == g]
 *         pos += 1             # <<<<<<<<<<<<<<
 *         groupindex += 1
 *         gsubdf.sort_values(by='CICs', ascending=False, inplace=True)
 */
    __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_pos, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF_SET(__pyx_v_pos, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2385
 *         gsubdf = plotsubdf[plotsubdf['group'] == g]
 *         pos += 1
 *         groupindex += 1             # <<<<<<<<<<<<<<
 *         gsubdf.sort_values(by='CICs', ascending=False, inplace=True)
 * 
 */
    __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_groupindex, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF_SET(__pyx_v_groupindex, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2386
 *         pos += 1
 *         groupindex += 1
 *         gsubdf.sort_values(by='CICs', ascending=False, inplace=True)             # <<<<<<<<<<<<<<
 * 
 *         #Loop for plot features in specific group
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_by, __pyx_n_u_CICs) < 0) __PYX_ERR(0, 2386, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 2386, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_inplace, Py_True) < 0) __PYX_ERR(0, 2386, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2389
 * 
 *         #Loop for plot features in specific group
 *         for j in range(len(gsubdf.index.tolist())):             # <<<<<<<<<<<<<<
 * 
 *             #Label name of picked feature in this round
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2389, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_12 = __pyx_t_11;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_j = __pyx_t_13;

      /* "revealer/REVEALER_runbenchmark.pyx":2392
 * 
 *             #Label name of picked feature in this round
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 0),             # <<<<<<<<<<<<<<
 *                                   colspan=20,rowspan=5)
 *             ax.set_axis_off()
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_14 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2392, __pyx_L1_error)
      __pyx_t_3 = PyInt_FromSsize_t((__pyx_t_14 + 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_v_numgroup); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Multiply(__pyx_int_5, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
      __Pyx_INCREF(__pyx_int_132);
      __Pyx_GIVEREF(__pyx_int_132);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_132);
      __pyx_t_3 = 0;
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Multiply(__pyx_v_pos, __pyx_int_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
      __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_t_3) < 0) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2392, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2392, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2394
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 0),
 *                                   colspan=20,rowspan=5)
 *             ax.set_axis_off()             # <<<<<<<<<<<<<<
 * 
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2396
 *             ax.set_axis_off()
 * 
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 */
      __pyx_t_15 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
      __pyx_t_16 = (__pyx_t_15 != 0);
      if (__pyx_t_16) {
      } else {
        __pyx_t_2 = __pyx_t_16;
        goto __pyx_L21_bool_binop_done;
      }
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_t_6, __pyx_t_3, Py_EQ)); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 2396, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_15 = (__pyx_t_16 != 0);
      __pyx_t_2 = __pyx_t_15;
      __pyx_L21_bool_binop_done:;
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2397
 * 
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 */
        __pyx_t_3 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2397, __pyx_L1_error)
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2397, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":2398
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_6, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__44); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_7, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyNumber_Add(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyNumber_Add(__pyx_t_10, __pyx_kp_u__27); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2399
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_tolist); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_18))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_18);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_18, function);
            }
          }
          __pyx_t_5 = (__pyx_t_17) ? __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_t_17) : __Pyx_PyObject_CallNoArg(__pyx_t_18);
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = __Pyx_GetItemInt(__pyx_t_5, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_18); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_notna); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_18))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_18);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_18, function);
            }
          }
          __pyx_t_10 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_18);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_10); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_18); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = PyNumber_Add(__pyx_t_7, __pyx_t_10); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyNumber_Add(__pyx_t_18, __pyx_kp_u__29); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2400
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *                 else:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_tolist); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_19);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_19, function);
            }
          }
          __pyx_t_6 = (__pyx_t_17) ? __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_17) : __Pyx_PyObject_CallNoArg(__pyx_t_19);
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = __Pyx_GetItemInt(__pyx_t_6, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_19); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_19);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_19, function);
            }
          }
          __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_19);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_count); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_19);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_19, function);
            }
          }
          __pyx_t_18 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_19, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_int_1);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_18); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2399
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_18 = PyNumber_Add(__pyx_t_10, __pyx_t_19); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2400
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *                 else:
 */
          __pyx_t_19 = PyNumber_Add(__pyx_t_18, __pyx_kp_u__28); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2398
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',
 */
          __pyx_t_18 = PyTuple_New(3); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_18, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_19);
          PyTuple_SET_ITEM(__pyx_t_18, 2, __pyx_t_19);
          __pyx_t_19 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2401
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',
 *                         ha='right', va='center')             # <<<<<<<<<<<<<<
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+
 */
          __pyx_t_19 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2401, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2401, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2401, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2398
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[j]].tolist().count(1)) + ')',
 */
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_18, __pyx_t_19); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2397
 * 
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[j]].notna())) + ',' +
 */
          goto __pyx_L23;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":2403
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_18)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_18);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_19 = (__pyx_t_18) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_18) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_19, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__27); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2404
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_v_i)) { __Pyx_RaiseUnboundLocalError("i"); __PYX_ERR(0, 2404, __pyx_L1_error) }
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_18, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_notna); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = PyNumber_Add(__pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__29); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2405
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *             else:
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          __pyx_t_18 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_17);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_v_i)) { __Pyx_RaiseUnboundLocalError("i"); __PYX_ERR(0, 2405, __pyx_L1_error) }
          __pyx_t_17 = __Pyx_PyObject_GetItem(__pyx_t_18, __pyx_v_i); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_17); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_tolist); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_18)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_18);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          __pyx_t_19 = (__pyx_t_18) ? __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_18) : __Pyx_PyObject_CallNoArg(__pyx_t_17);
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_count); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_19)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_19);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          __pyx_t_5 = (__pyx_t_19) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_19, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_int_1);
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2404
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_17); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2404, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2405
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *             else:
 */
          __pyx_t_17 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__28); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2405, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2403
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_17);
          PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_17);
          __pyx_t_17 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2406
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 if locusdic != None:
 */
          __pyx_t_17 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2406, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2406, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2406, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2403
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[gsubdf.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[gsubdf.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_5, __pyx_t_17); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_L23:;

        /* "revealer/REVEALER_runbenchmark.pyx":2396
 *             ax.set_axis_off()
 * 
 *             if (gmt is not None) and (gsubdf.index.tolist()[j] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[j] +' '+ locusdic[gsubdf.index.tolist()[j]]+
 */
        goto __pyx_L20;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2408
 *                         ha='right', va='center')
 *             else:
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i] +' '+ locusdic[gsubdf.index.tolist()[i]],
 *                             ha='right', va='center')
 */
      /*else*/ {
        __pyx_t_3 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2408, __pyx_L1_error)
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2408, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":2409
 *             else:
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i] +' '+ locusdic[gsubdf.index.tolist()[i]],             # <<<<<<<<<<<<<<
 *                             ha='right', va='center')
 *                 else:
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          __pyx_t_17 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_v_i)) { __Pyx_RaiseUnboundLocalError("i"); __PYX_ERR(0, 2409, __pyx_L1_error) }
          __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_17, __pyx_v_i); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = PyNumber_Add(__pyx_t_10, __pyx_kp_u__44); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_19);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_19, function);
            }
          }
          __pyx_t_10 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_19);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          if (unlikely(!__pyx_v_i)) { __Pyx_RaiseUnboundLocalError("i"); __PYX_ERR(0, 2409, __pyx_L1_error) }
          __pyx_t_19 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_v_i); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_19); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = PyNumber_Add(__pyx_t_17, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_19);
          PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_19);
          __pyx_t_19 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2410
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i] +' '+ locusdic[gsubdf.index.tolist()[i]],
 *                             ha='right', va='center')             # <<<<<<<<<<<<<<
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i], ha='right', va='center')
 */
          __pyx_t_19 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2410, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2410, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2410, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2409
 *             else:
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i] +' '+ locusdic[gsubdf.index.tolist()[i]],             # <<<<<<<<<<<<<<
 *                             ha='right', va='center')
 *                 else:
 */
          __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, __pyx_t_19); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2409, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2408
 *                         ha='right', va='center')
 *             else:
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i] +' '+ locusdic[gsubdf.index.tolist()[i]],
 *                             ha='right', va='center')
 */
          goto __pyx_L24;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":2412
 *                             ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,gsubdf.index.tolist()[i], ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *             #Plot heatmap for picked feature
 */
        /*else*/ {
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_19 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_v_i)) { __Pyx_RaiseUnboundLocalError("i"); __PYX_ERR(0, 2412, __pyx_L1_error) }
          __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_19, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = PyTuple_New(3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_19, 2, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2412, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2412, __pyx_L1_error)
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_L24:;
      }
      __pyx_L20:;

      /* "revealer/REVEALER_runbenchmark.pyx":2415
 * 
 *             #Plot heatmap for picked feature
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 20),             # <<<<<<<<<<<<<<
 *                                   colspan=90,rowspan=5)
 *             ax = sns.heatmap(np.asarray([gsubdf.iloc[j,:size].tolist()]).astype(int),
 */
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_plt); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_14 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2415, __pyx_L1_error)
      __pyx_t_19 = PyInt_FromSsize_t((__pyx_t_14 + 2)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __pyx_t_17 = PyNumber_Add(__pyx_t_19, __pyx_v_numgroup); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      __pyx_t_19 = PyNumber_Multiply(__pyx_int_5, __pyx_t_17); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = PyTuple_New(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_GIVEREF(__pyx_t_19);
      PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_19);
      __Pyx_INCREF(__pyx_int_132);
      __Pyx_GIVEREF(__pyx_int_132);
      PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_int_132);
      __pyx_t_19 = 0;
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_shape, __pyx_t_17) < 0) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = PyNumber_Multiply(__pyx_v_pos, __pyx_int_5); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_19 = PyTuple_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_GIVEREF(__pyx_t_17);
      PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_17);
      __Pyx_INCREF(__pyx_int_20);
      __Pyx_GIVEREF(__pyx_int_20);
      PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_int_20);
      __pyx_t_17 = 0;
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_loc, __pyx_t_19) < 0) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2415, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2415, __pyx_L1_error)
      __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_19);
      __pyx_t_19 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2417
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 20),
 *                                   colspan=90,rowspan=5)
 *             ax = sns.heatmap(np.asarray([gsubdf.iloc[j,:size].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                              cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False,
 *                              cbar=False)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_sns); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_np); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_asarray); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_gsubdf, __pyx_n_s_iloc); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_18);
      __pyx_t_7 = PyInt_FromSsize_t(__pyx_v_j); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = PySlice_New(Py_None, __pyx_v_size, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_20 = PyTuple_New(2); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_20);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_20, 0, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_20, 1, __pyx_t_6);
      __pyx_t_7 = 0;
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_18, __pyx_t_20); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_20);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_20);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_20, function);
        }
      }
      __pyx_t_17 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_20, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_20);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      __pyx_t_20 = PyList_New(1); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_20);
      __Pyx_GIVEREF(__pyx_t_17);
      PyList_SET_ITEM(__pyx_t_20, 0, __pyx_t_17);
      __pyx_t_17 = 0;
      __pyx_t_17 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_3 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_17, __pyx_t_20) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_20);
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_astype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_19 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_3, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_5, ((PyObject *)(&PyInt_Type)));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_19);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_19);
      __pyx_t_19 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2418
 *                                   colspan=90,rowspan=5)
 *             ax = sns.heatmap(np.asarray([gsubdf.iloc[j,:size].tolist()]).astype(int),
 *                              cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False,             # <<<<<<<<<<<<<<
 *                              cbar=False)
 * 
 */
      __pyx_t_19 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 2418, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2418, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2418, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2418, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2419
 *             ax = sns.heatmap(np.asarray([gsubdf.iloc[j,:size].tolist()]).astype(int),
 *                              cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False,
 *                              cbar=False)             # <<<<<<<<<<<<<<
 * 
 *             #Label CIC or IC for this feature
 */
      if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2418, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2417
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 20),
 *                                   colspan=90,rowspan=5)
 *             ax = sns.heatmap(np.asarray([gsubdf.iloc[j,:size].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                              cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False,
 *                              cbar=False)
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_5, __pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2422
 * 
 *             #Label CIC or IC for this feature
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 110),             # <<<<<<<<<<<<<<
 *                                   colspan=12,rowspan=5)
 *             ax.set_axis_off()
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_14 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2422, __pyx_L1_error)
      __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_14 + 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = PyNumber_Add(__pyx_t_5, __pyx_v_numgroup); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Multiply(__pyx_int_5, __pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_int_132);
      __Pyx_GIVEREF(__pyx_int_132);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_int_132);
      __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_10) < 0) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyNumber_Multiply(__pyx_v_pos, __pyx_int_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_10);
      __Pyx_INCREF(__pyx_int_110);
      __Pyx_GIVEREF(__pyx_int_110);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_110);
      __pyx_t_10 = 0;
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_t_5) < 0) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2422, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2422, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2424
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 110),
 *                                   colspan=12,rowspan=5)
 *             ax.set_axis_off()             # <<<<<<<<<<<<<<
 *             if if_bootstrap == True:
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_19 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_19)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_19);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_5 = (__pyx_t_19) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_19) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2425
 *                                   colspan=12,rowspan=5)
 *             ax.set_axis_off()
 *             if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),
 */
      __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2426
 *             ax.set_axis_off()
 *             if if_bootstrap == True:
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],             # <<<<<<<<<<<<<<
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),
 *                         ha='center', va='center', color = 'blue')
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = 0;
        __pyx_t_21 = 127;
        __pyx_t_19 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gsubdf, __pyx_n_u_CICs); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_iloc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_19 = __Pyx_GetItemInt(__pyx_t_10, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_PyObject_Format(__pyx_t_19, __pyx_kp_u_3f); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_21 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) > __pyx_t_21) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) : __pyx_t_21;
        __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_INCREF(__pyx_kp_u__27);
        __pyx_t_14 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__27);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_kp_u__27);

        /* "revealer/REVEALER_runbenchmark.pyx":2427
 *             if if_bootstrap == True:
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),             # <<<<<<<<<<<<<<
 *                         ha='center', va='center', color = 'blue')
 *             else:
 */
        __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gsubdf, __pyx_n_u_bootstraps); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2427, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_iloc); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2427, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_19, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2427, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_19 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2427, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_PyNumber_Int(__pyx_t_19); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2427, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_19 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_10), __pyx_empty_unicode); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2427, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_21 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_19) > __pyx_t_21) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_19) : __pyx_t_21;
        __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_19);
        __Pyx_GIVEREF(__pyx_t_19);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_19);
        __pyx_t_19 = 0;
        __Pyx_INCREF(__pyx_kp_u__28);
        __pyx_t_14 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__28);
        PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_kp_u__28);

        /* "revealer/REVEALER_runbenchmark.pyx":2426
 *             ax.set_axis_off()
 *             if if_bootstrap == True:
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],             # <<<<<<<<<<<<<<
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),
 *                         ha='center', va='center', color = 'blue')
 */
        __pyx_t_19 = __Pyx_PyUnicode_Join(__pyx_t_3, 4, __pyx_t_14, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_5);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_19);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_19);
        __pyx_t_19 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2428
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),
 *                         ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 *             else:
 *                 ax.text(0.5,0.5,"%.3f"%(gsubdf['CICs'].iloc[j]),
 */
        __pyx_t_19 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2428, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2428, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2428, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2428, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2426
 *             ax.set_axis_off()
 *             if if_bootstrap == True:
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],             # <<<<<<<<<<<<<<
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),
 *                         ha='center', va='center', color = 'blue')
 */
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_19); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2426, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2425
 *                                   colspan=12,rowspan=5)
 *             ax.set_axis_off()
 *             if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *                 ax.text(0.5,0.5,"%.3f(%s)"%(gsubdf['CICs'].iloc[j],
 *                         int(1000*gsubdf['bootstraps'].iloc[j])),
 */
        goto __pyx_L25;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2430
 *                         ha='center', va='center', color = 'blue')
 *             else:
 *                 ax.text(0.5,0.5,"%.3f"%(gsubdf['CICs'].iloc[j]),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center', color = 'blue')
 * 
 */
      /*else*/ {
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_19 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gsubdf, __pyx_n_u_CICs); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_iloc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_19 = __Pyx_GetItemInt(__pyx_t_3, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_19 = PyTuple_New(3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_float_0_5);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_19, 2, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2431
 *             else:
 *                 ax.text(0.5,0.5,"%.3f"%(gsubdf['CICs'].iloc[j]),
 *                     ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 * 
 *             #Label p-values if plotpval is True
 */
        __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2431, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2431, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2431, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2431, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2430
 *                         ha='center', va='center', color = 'blue')
 *             else:
 *                 ax.text(0.5,0.5,"%.3f"%(gsubdf['CICs'].iloc[j]),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center', color = 'blue')
 * 
 */
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_L25:;

      /* "revealer/REVEALER_runbenchmark.pyx":2434
 * 
 *             #Label p-values if plotpval is True
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 122),             # <<<<<<<<<<<<<<
 *                                   colspan=10, rowspan=5)
 *             ax.set_axis_off()
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2434, __pyx_L1_error)
      __pyx_t_19 = PyInt_FromSsize_t((__pyx_t_14 + 2)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __pyx_t_10 = PyNumber_Add(__pyx_t_19, __pyx_v_numgroup); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      __pyx_t_19 = PyNumber_Multiply(__pyx_int_5, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_19);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_19);
      __Pyx_INCREF(__pyx_int_132);
      __Pyx_GIVEREF(__pyx_int_132);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_int_132);
      __pyx_t_19 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_10) < 0) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyNumber_Multiply(__pyx_v_pos, __pyx_int_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_19 = PyTuple_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_10);
      __Pyx_INCREF(__pyx_int_122);
      __Pyx_GIVEREF(__pyx_int_122);
      PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_int_122);
      __pyx_t_10 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_t_19) < 0) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2434, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2434, __pyx_L1_error)
      __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_19);
      __pyx_t_19 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2436
 *             ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(pos*5, 122),
 *                                   colspan=10, rowspan=5)
 *             ax.set_axis_off()             # <<<<<<<<<<<<<<
 *             if plotpval == True:
 *                 pval = gsubdf['pVals'].iloc[j]
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_19 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2437
 *                                   colspan=10, rowspan=5)
 *             ax.set_axis_off()
 *             if plotpval == True:             # <<<<<<<<<<<<<<
 *                 pval = gsubdf['pVals'].iloc[j]
 *                 if pval > 1:
 */
      __pyx_t_2 = ((__pyx_v_plotpval == 1) != 0);
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2438
 *             ax.set_axis_off()
 *             if plotpval == True:
 *                 pval = gsubdf['pVals'].iloc[j]             # <<<<<<<<<<<<<<
 *                 if pval > 1:
 *                     pval = float(1)/float(pval)
 */
        __pyx_t_19 = __Pyx_PyObject_Dict_GetItem(__pyx_v_gsubdf, __pyx_n_u_pVals); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2438, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2438, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_19 = __Pyx_GetItemInt(__pyx_t_5, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2438, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF_SET(__pyx_v_pval, __pyx_t_19);
        __pyx_t_19 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2439
 *             if plotpval == True:
 *                 pval = gsubdf['pVals'].iloc[j]
 *                 if pval > 1:             # <<<<<<<<<<<<<<
 *                     pval = float(1)/float(pval)
 *                     pvallist = ("%e"%pval).split('e')
 */
        __pyx_t_19 = PyObject_RichCompare(__pyx_v_pval, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_19); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2439, __pyx_L1_error)
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_19); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2439, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":2440
 *                 pval = gsubdf['pVals'].iloc[j]
 *                 if pval > 1:
 *                     pval = float(1)/float(pval)             # <<<<<<<<<<<<<<
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 */
          __pyx_t_22 = __Pyx_PyObject_AsDouble(__pyx_int_1); if (unlikely(__pyx_t_22 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2440, __pyx_L1_error)
          __pyx_t_23 = __Pyx_PyObject_AsDouble(__pyx_v_pval); if (unlikely(__pyx_t_23 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2440, __pyx_L1_error)
          if (unlikely(__pyx_t_23 == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "float division");
            __PYX_ERR(0, 2440, __pyx_L1_error)
          }
          __pyx_t_19 = PyFloat_FromDouble((__pyx_t_22 / __pyx_t_23)); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2440, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF_SET(__pyx_v_pval, __pyx_t_19);
          __pyx_t_19 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2441
 *                 if pval > 1:
 *                     pval = float(1)/float(pval)
 *                     pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *                     ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                             ha='center', va='center')
 */
          __pyx_t_19 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2441, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __pyx_t_5 = PyUnicode_Split(((PyObject*)__pyx_t_19), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2441, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_XDECREF_SET(__pyx_v_pvallist, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2442
 *                     pval = float(1)/float(pval)
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                             ha='center', va='center')
 *                 else:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_19 = PyTuple_New(5); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __pyx_t_14 = 0;
          __pyx_t_21 = 127;
          __Pyx_INCREF(__pyx_kp_u__45);
          __pyx_t_14 += 1;
          __Pyx_GIVEREF(__pyx_kp_u__45);
          PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_kp_u__45);
          __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_10 = __Pyx_PyNumber_Float(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_Format(__pyx_t_10, __pyx_kp_u_1f); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_21 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_21) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_21;
          __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_t_3);
          __pyx_t_3 = 0;
          __Pyx_INCREF(__pyx_kp_u_x_10);
          __pyx_t_14 += 7;
          __Pyx_GIVEREF(__pyx_kp_u_x_10);
          PyTuple_SET_ITEM(__pyx_t_19, 2, __pyx_kp_u_x_10);
          __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_10 = __Pyx_PyNumber_Int(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_10), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_21 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_21) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_21;
          __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_19, 3, __pyx_t_3);
          __pyx_t_3 = 0;
          __Pyx_INCREF(__pyx_kp_u__46);
          __pyx_t_14 += 3;
          __Pyx_GIVEREF(__pyx_kp_u__46);
          PyTuple_SET_ITEM(__pyx_t_19, 4, __pyx_kp_u__46);
          __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_19, 5, __pyx_t_14, __pyx_t_21); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = PyTuple_New(3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_float_0_5);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_19, 2, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2443
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                             ha='center', va='center')             # <<<<<<<<<<<<<<
 *                 else:
 *                     pvallist = ("%e"%pval).split('e')
 */
          __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2443, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2443, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2443, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2442
 *                     pval = float(1)/float(pval)
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                             ha='center', va='center')
 *                 else:
 */
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_19, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2439
 *             if plotpval == True:
 *                 pval = gsubdf['pVals'].iloc[j]
 *                 if pval > 1:             # <<<<<<<<<<<<<<
 *                     pval = float(1)/float(pval)
 *                     pvallist = ("%e"%pval).split('e')
 */
          goto __pyx_L27;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":2445
 *                             ha='center', va='center')
 *                 else:
 *                     pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *                     ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                             ha='center', va='center')
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2445, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_3 = PyUnicode_Split(((PyObject*)__pyx_t_10), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2445, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF_SET(__pyx_v_pvallist, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2446
 *                 else:
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                             ha='center', va='center')
 *             pos += 1
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_10 = PyTuple_New(4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_14 = 0;
          __pyx_t_21 = 127;
          __pyx_t_19 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __pyx_t_5 = __Pyx_PyNumber_Float(__pyx_t_19); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = __Pyx_PyObject_Format(__pyx_t_5, __pyx_kp_u_1f); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_21 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_19) > __pyx_t_21) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_19) : __pyx_t_21;
          __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_19);
          __Pyx_GIVEREF(__pyx_t_19);
          PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_19);
          __pyx_t_19 = 0;
          __Pyx_INCREF(__pyx_kp_u_x_10);
          __pyx_t_14 += 7;
          __Pyx_GIVEREF(__pyx_kp_u_x_10);
          PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_kp_u_x_10);
          __pyx_t_19 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_19); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __pyx_t_19 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_21 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_19) > __pyx_t_21) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_19) : __pyx_t_21;
          __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_19);
          __Pyx_GIVEREF(__pyx_t_19);
          PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_19);
          __pyx_t_19 = 0;
          __Pyx_INCREF(__pyx_kp_u__46);
          __pyx_t_14 += 3;
          __Pyx_GIVEREF(__pyx_kp_u__46);
          PyTuple_SET_ITEM(__pyx_t_10, 3, __pyx_kp_u__46);
          __pyx_t_19 = __Pyx_PyUnicode_Join(__pyx_t_10, 4, __pyx_t_14, __pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_float_0_5);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_19);
          PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_19);
          __pyx_t_19 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2447
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                             ha='center', va='center')             # <<<<<<<<<<<<<<
 *             pos += 1
 * 
 */
          __pyx_t_19 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2447, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2447, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2447, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2446
 *                 else:
 *                     pvallist = ("%e"%pval).split('e')
 *                     ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                             ha='center', va='center')
 *             pos += 1
 */
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, __pyx_t_19); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2446, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_L27:;

        /* "revealer/REVEALER_runbenchmark.pyx":2437
 *                                   colspan=10, rowspan=5)
 *             ax.set_axis_off()
 *             if plotpval == True:             # <<<<<<<<<<<<<<
 *                 pval = gsubdf['pVals'].iloc[j]
 *                 if pval > 1:
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2448
 *                     ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                             ha='center', va='center')
 *             pos += 1             # <<<<<<<<<<<<<<
 * 
 *     #Save Plot
 */
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_pos, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_pos, __pyx_t_5);
      __pyx_t_5 = 0;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2374
 * 
 *     #Loop for plot features by group
 *     for g in plotsubdf['group'].unique():             # <<<<<<<<<<<<<<
 * 
 *         #Put group id
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2451
 * 
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'itr'+str(nitr)+'_Top'+str(num_top)+'ResultClustered.'+             # <<<<<<<<<<<<<<
 *                 figure_format, format=figure_format)
 *     plt.close()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_savefig); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_19 = PyNumber_Add(__pyx_t_4, __pyx_n_u_itr); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyNumber_Add(__pyx_t_19, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_10, __pyx_n_u_Top); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_19 = PyNumber_Add(__pyx_t_4, __pyx_t_10); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyNumber_Add(__pyx_t_19, __pyx_kp_u_ResultClustered); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2452
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'itr'+str(nitr)+'_Top'+str(num_top)+'ResultClustered.'+
 *                 figure_format, format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __pyx_t_19 = PyNumber_Add(__pyx_t_10, __pyx_v_figure_format); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2451
 * 
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'itr'+str(nitr)+'_Top'+str(num_top)+'ResultClustered.'+             # <<<<<<<<<<<<<<
 *                 figure_format, format=figure_format)
 *     plt.close()
 */
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_19);
  PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_19);
  __pyx_t_19 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2452
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'itr'+str(nitr)+'_Top'+str(num_top)+'ResultClustered.'+
 *                 figure_format, format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __pyx_t_19 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 2452, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2451
 * 
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'itr'+str(nitr)+'_Top'+str(num_top)+'ResultClustered.'+             # <<<<<<<<<<<<<<
 *                 figure_format, format=figure_format)
 *     plt.close()
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_10, __pyx_t_19); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2453
 *     plt.savefig(out_folder + prefix+'itr'+str(nitr)+'_Top'+str(num_top)+'ResultClustered.'+
 *                 figure_format, format=figure_format)
 *     plt.close()             # <<<<<<<<<<<<<<
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotsubdf.index.tolist()) == True):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_plt); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_close); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_4 = (__pyx_t_19) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_19) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2455
 *     plt.close()
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotsubdf.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotsubdf.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */
  __pyx_t_15 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
  __pyx_t_16 = (__pyx_t_15 != 0);
  if (__pyx_t_16) {
  } else {
    __pyx_t_2 = __pyx_t_16;
    goto __pyx_L29_bool_binop_done;
  }
  __pyx_t_4 = __pyx_pf_8revealer_21REVEALER_runbenchmark_11plotCluster_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_Generator_Next(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_10, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_16;
  __pyx_L29_bool_binop_done:;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2456
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotsubdf.index.tolist()) == True):
 *         gmt.loc[plotsubdf.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)             # <<<<<<<<<<<<<<
 * 
 *     #Save report
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotsubdf, __pyx_n_s_index); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_19)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_19);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_10 = (__pyx_t_19) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_19) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_n_u_itr_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_19 = PyNumber_Add(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_19, __pyx_n_u_Top); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_t_19); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __pyx_t_19 = PyNumber_Add(__pyx_t_4, __pyx_kp_u_gmt_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_19);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_19);
    __pyx_t_19 = 0;
    __pyx_t_19 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_19);
    if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 2456, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_header, Py_False) < 0) __PYX_ERR(0, 2456, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_4, __pyx_t_19); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2455
 *     plt.close()
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotsubdf.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotsubdf.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2459
 * 
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+             # <<<<<<<<<<<<<<
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comball, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_19 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_by, __pyx_n_u_group) < 0) __PYX_ERR(0, 2459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_19, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 2459, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_19); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_n_u_itr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyNumber_Add(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_10, __pyx_n_u_Top); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2460
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "revealer/REVEALER_runbenchmark.pyx":2459
 * 
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+             # <<<<<<<<<<<<<<
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')
 * 
 */
  __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2460
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_10 = PyNumber_Add(__pyx_t_5, __pyx_kp_u_ResultClustered_txt); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2459
 * 
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+             # <<<<<<<<<<<<<<
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')
 * 
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_10);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_10);
  __pyx_t_10 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2460
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 2460, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2459
 * 
 *     #Save report
 *     comball.sort_values(by='group', ascending=False).to_csv(out_folder + prefix+'itr'+str(nitr)+'_Top'+             # <<<<<<<<<<<<<<
 *                                                             str(num_top)+'ResultClustered.txt',sep='\t')
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_t_5, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2255
 * 
 * 
 * def plotCluster(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.plotCluster", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_comball);
  __Pyx_XDECREF(__pyx_v_plotcomb2);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_nmf_results);
  __Pyx_XDECREF(__pyx_v_cophenetic_correlation_coefficients);
  __Pyx_XDECREF(__pyx_v_diff);
  __Pyx_XDECREF(__pyx_v_diffindex);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_group);
  __Pyx_XDECREF(__pyx_v_numgroup);
  __Pyx_XDECREF(__pyx_v_fig);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_groupindex);
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XDECREF(__pyx_v_gsubdf);
  __Pyx_XDECREF(__pyx_v_pval);
  __Pyx_XDECREF(__pyx_v_pvallist);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2463
 * 
 * 
 * def pileRank(             # <<<<<<<<<<<<<<
 *     rank,       #Rank for features
 *     num_top,    #Number of top feature
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_57pileRank(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_57pileRank = {"pileRank", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_57pileRank, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_57pileRank(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_rank = 0;
  PyObject *__pyx_v_num_top = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_nitr = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pileRank (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_rank,&__pyx_n_s_num_top,&__pyx_n_s_prefix,&__pyx_n_s_out_folder,&__pyx_n_s_nitr,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_rank)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_top)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pileRank", 1, 5, 5, 1); __PYX_ERR(0, 2463, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pileRank", 1, 5, 5, 2); __PYX_ERR(0, 2463, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pileRank", 1, 5, 5, 3); __PYX_ERR(0, 2463, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nitr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pileRank", 1, 5, 5, 4); __PYX_ERR(0, 2463, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pileRank") < 0)) __PYX_ERR(0, 2463, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 5) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
    }
    __pyx_v_rank = values[0];
    __pyx_v_num_top = values[1];
    __pyx_v_prefix = values[2];
    __pyx_v_out_folder = values[3];
    __pyx_v_nitr = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pileRank", 1, 5, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2463, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.pileRank", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_56pileRank(__pyx_self, __pyx_v_rank, __pyx_v_num_top, __pyx_v_prefix, __pyx_v_out_folder, __pyx_v_nitr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_56pileRank(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_rank, PyObject *__pyx_v_num_top, PyObject *__pyx_v_prefix, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_nitr) {
  PyObject *__pyx_v_sub = NULL;
  PyObject *__pyx_v_ICs = NULL;
  double __pyx_v_old;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_total = NULL;
  PyObject *__pyx_v_i = NULL;
  double __pyx_v_new;
  PyObject *__pyx_v_pileres = NULL;
  PyObject *__pyx_v_pile = NULL;
  PyObject *__pyx_v_gene = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  double __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pileRank", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":2471
 *     ):
 * 
 *     sub = []             # <<<<<<<<<<<<<<
 *     ICs = []
 *     old = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sub = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2472
 * 
 *     sub = []
 *     ICs = []             # <<<<<<<<<<<<<<
 *     old = 0
 *     n = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ICs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2473
 *     sub = []
 *     ICs = []
 *     old = 0             # <<<<<<<<<<<<<<
 *     n = 0
 *     total = []
 */
  __pyx_v_old = 0.0;

  /* "revealer/REVEALER_runbenchmark.pyx":2474
 *     ICs = []
 *     old = 0
 *     n = 0             # <<<<<<<<<<<<<<
 *     total = []
 *     for i in rank:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_n = __pyx_int_0;

  /* "revealer/REVEALER_runbenchmark.pyx":2475
 *     old = 0
 *     n = 0
 *     total = []             # <<<<<<<<<<<<<<
 *     for i in rank:
 *         new = float(i[1])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_total = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2476
 *     n = 0
 *     total = []
 *     for i in rank:             # <<<<<<<<<<<<<<
 *         new = float(i[1])
 *         if new == old:
 */
  if (likely(PyList_CheckExact(__pyx_v_rank)) || PyTuple_CheckExact(__pyx_v_rank)) {
    __pyx_t_1 = __pyx_v_rank; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_rank); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2476, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2476, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2476, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2476, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2476, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2476, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2477
 *     total = []
 *     for i in rank:
 *         new = float(i[1])             # <<<<<<<<<<<<<<
 *         if new == old:
 *             sub.append(i)
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_i, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_AsDouble(__pyx_t_4); if (unlikely(__pyx_t_5 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_new = __pyx_t_5;

    /* "revealer/REVEALER_runbenchmark.pyx":2478
 *     for i in rank:
 *         new = float(i[1])
 *         if new == old:             # <<<<<<<<<<<<<<
 *             sub.append(i)
 *             continue
 */
    __pyx_t_6 = ((__pyx_v_new == __pyx_v_old) != 0);
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":2479
 *         new = float(i[1])
 *         if new == old:
 *             sub.append(i)             # <<<<<<<<<<<<<<
 *             continue
 *         else:
 */
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_sub, __pyx_v_i); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2479, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2480
 *         if new == old:
 *             sub.append(i)
 *             continue             # <<<<<<<<<<<<<<
 *         else:
 *             if n != 0:
 */
      goto __pyx_L3_continue;

      /* "revealer/REVEALER_runbenchmark.pyx":2478
 *     for i in rank:
 *         new = float(i[1])
 *         if new == old:             # <<<<<<<<<<<<<<
 *             sub.append(i)
 *             continue
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2482
 *             continue
 *         else:
 *             if n != 0:             # <<<<<<<<<<<<<<
 *                 total.append(sub)
 *                 old = new
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyInt_NeObjC(__pyx_v_n, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "revealer/REVEALER_runbenchmark.pyx":2483
 *         else:
 *             if n != 0:
 *                 total.append(sub)             # <<<<<<<<<<<<<<
 *                 old = new
 *                 n = n + 1
 */
        __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_total, __pyx_v_sub); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2483, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2484
 *             if n != 0:
 *                 total.append(sub)
 *                 old = new             # <<<<<<<<<<<<<<
 *                 n = n + 1
 *                 sub = []
 */
        __pyx_v_old = __pyx_v_new;

        /* "revealer/REVEALER_runbenchmark.pyx":2485
 *                 total.append(sub)
 *                 old = new
 *                 n = n + 1             # <<<<<<<<<<<<<<
 *                 sub = []
 *                 sub.append(i)
 */
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2485, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2486
 *                 old = new
 *                 n = n + 1
 *                 sub = []             # <<<<<<<<<<<<<<
 *                 sub.append(i)
 *             else:
 */
        __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2486, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_sub, ((PyObject*)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2487
 *                 n = n + 1
 *                 sub = []
 *                 sub.append(i)             # <<<<<<<<<<<<<<
 *             else:
 *                 sub = []
 */
        __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_sub, __pyx_v_i); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2487, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2482
 *             continue
 *         else:
 *             if n != 0:             # <<<<<<<<<<<<<<
 *                 total.append(sub)
 *                 old = new
 */
        goto __pyx_L6;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2489
 *                 sub.append(i)
 *             else:
 *                 sub = []             # <<<<<<<<<<<<<<
 *                 sub.append(i)
 *                 old = new
 */
      /*else*/ {
        __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2489, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_sub, ((PyObject*)__pyx_t_4));
        __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2490
 *             else:
 *                 sub = []
 *                 sub.append(i)             # <<<<<<<<<<<<<<
 *                 old = new
 *                 n = n + 1
 */
        __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_sub, __pyx_v_i); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2490, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2491
 *                 sub = []
 *                 sub.append(i)
 *                 old = new             # <<<<<<<<<<<<<<
 *                 n = n + 1
 *             ICs.append(old)
 */
        __pyx_v_old = __pyx_v_new;

        /* "revealer/REVEALER_runbenchmark.pyx":2492
 *                 sub.append(i)
 *                 old = new
 *                 n = n + 1             # <<<<<<<<<<<<<<
 *             ICs.append(old)
 *         if n == num_top:
 */
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_4);
        __pyx_t_4 = 0;
      }
      __pyx_L6:;

      /* "revealer/REVEALER_runbenchmark.pyx":2493
 *                 old = new
 *                 n = n + 1
 *             ICs.append(old)             # <<<<<<<<<<<<<<
 *         if n == num_top:
 *             break
 */
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_old); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_ICs, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2493, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2494
 *                 n = n + 1
 *             ICs.append(old)
 *         if n == num_top:             # <<<<<<<<<<<<<<
 *             break
 * 
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_n, __pyx_v_num_top, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2494, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2494, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {

      /* "revealer/REVEALER_runbenchmark.pyx":2495
 *             ICs.append(old)
 *         if n == num_top:
 *             break             # <<<<<<<<<<<<<<
 * 
 *     total.append(sub)
 */
      goto __pyx_L4_break;

      /* "revealer/REVEALER_runbenchmark.pyx":2494
 *                 n = n + 1
 *             ICs.append(old)
 *         if n == num_top:             # <<<<<<<<<<<<<<
 *             break
 * 
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2476
 *     n = 0
 *     total = []
 *     for i in rank:             # <<<<<<<<<<<<<<
 *         new = float(i[1])
 *         if new == old:
 */
    __pyx_L3_continue:;
  }
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2497
 *             break
 * 
 *     total.append(sub)             # <<<<<<<<<<<<<<
 *     pileres = 'CIC\tGeneNames\n'
 *     for pile in total:
 */
  __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_total, __pyx_v_sub); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2497, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2498
 * 
 *     total.append(sub)
 *     pileres = 'CIC\tGeneNames\n'             # <<<<<<<<<<<<<<
 *     for pile in total:
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 */
  __Pyx_INCREF(__pyx_kp_u_CIC_GeneNames);
  __pyx_v_pileres = __pyx_kp_u_CIC_GeneNames;

  /* "revealer/REVEALER_runbenchmark.pyx":2499
 *     total.append(sub)
 *     pileres = 'CIC\tGeneNames\n'
 *     for pile in total:             # <<<<<<<<<<<<<<
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 *         for gene in pile:
 */
  __pyx_t_1 = __pyx_v_total; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2499, __pyx_L1_error)
    #else
    __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_pile, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2500
 *     pileres = 'CIC\tGeneNames\n'
 *     for pile in total:
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'             # <<<<<<<<<<<<<<
 *         for gene in pile:
 *             if '\n' in gene[0]:
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_pile, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyNumber_Float(__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_pileres, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_pileres, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2501
 *     for pile in total:
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 *         for gene in pile:             # <<<<<<<<<<<<<<
 *             if '\n' in gene[0]:
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'
 */
    if (likely(PyList_CheckExact(__pyx_v_pile)) || PyTuple_CheckExact(__pyx_v_pile)) {
      __pyx_t_8 = __pyx_v_pile; __Pyx_INCREF(__pyx_t_8); __pyx_t_9 = 0;
      __pyx_t_3 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_v_pile); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_3 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2501, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_3)) {
        if (likely(PyList_CheckExact(__pyx_t_8))) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 2501, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_8, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2501, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 2501, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_8, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2501, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_3(__pyx_t_8);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2501, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_gene, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2502
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 *         for gene in pile:
 *             if '\n' in gene[0]:             # <<<<<<<<<<<<<<
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'
 *             else:
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_gene, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__9, __pyx_t_4, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2502, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = (__pyx_t_6 != 0);
      if (__pyx_t_10) {

        /* "revealer/REVEALER_runbenchmark.pyx":2503
 *         for gene in pile:
 *             if '\n' in gene[0]:
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'             # <<<<<<<<<<<<<<
 *             else:
 *                 pileres = pileres + gene[0] + '\t'
 */
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_gene, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_replace); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyNumber_Add(__pyx_v_pileres, __pyx_t_4); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_11, __pyx_kp_u__28); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_pileres, __pyx_t_11);
        __pyx_t_11 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2502
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 *         for gene in pile:
 *             if '\n' in gene[0]:             # <<<<<<<<<<<<<<
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'
 *             else:
 */
        goto __pyx_L12;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2505
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'
 *             else:
 *                 pileres = pileres + gene[0] + '\t'             # <<<<<<<<<<<<<<
 *         pileres = pileres[:-1]+'\n'
 *     f = open(out_folder + prefix+'_'+str(nitr)+'_top'+str(num_top)+".txt", "w")
 */
      /*else*/ {
        __pyx_t_11 = __Pyx_GetItemInt(__pyx_v_gene, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2505, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = PyNumber_Add(__pyx_v_pileres, __pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2505, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2505, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_pileres, __pyx_t_11);
        __pyx_t_11 = 0;
      }
      __pyx_L12:;

      /* "revealer/REVEALER_runbenchmark.pyx":2501
 *     for pile in total:
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 *         for gene in pile:             # <<<<<<<<<<<<<<
 *             if '\n' in gene[0]:
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'
 */
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2506
 *             else:
 *                 pileres = pileres + gene[0] + '\t'
 *         pileres = pileres[:-1]+'\n'             # <<<<<<<<<<<<<<
 *     f = open(out_folder + prefix+'_'+str(nitr)+'_top'+str(num_top)+".txt", "w")
 *     f.write(pileres[:-1])
 */
    __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_pileres, 0, -1L, NULL, NULL, &__pyx_slice__33, 0, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_11 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF_SET(__pyx_v_pileres, __pyx_t_11);
    __pyx_t_11 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2499
 *     total.append(sub)
 *     pileres = 'CIC\tGeneNames\n'
 *     for pile in total:             # <<<<<<<<<<<<<<
 *         pileres = pileres + "%.3f"%(float(pile[0][1]))+'\t'
 *         for gene in pile:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2507
 *                 pileres = pileres + gene[0] + '\t'
 *         pileres = pileres[:-1]+'\n'
 *     f = open(out_folder + prefix+'_'+str(nitr)+'_top'+str(num_top)+".txt", "w")             # <<<<<<<<<<<<<<
 *     f.write(pileres[:-1])
 *     f.close()
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = PyNumber_Add(__pyx_t_1, __pyx_n_u__8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = PyNumber_Add(__pyx_t_11, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_8, __pyx_n_u_top); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_11 = PyNumber_Add(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_11, __pyx_kp_u_txt); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8);
  __Pyx_INCREF(__pyx_n_u_w);
  __Pyx_GIVEREF(__pyx_n_u_w);
  PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_n_u_w);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_11, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_v_f = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2508
 *         pileres = pileres[:-1]+'\n'
 *     f = open(out_folder + prefix+'_'+str(nitr)+'_top'+str(num_top)+".txt", "w")
 *     f.write(pileres[:-1])             # <<<<<<<<<<<<<<
 *     f.close()
 * 
 */
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_write); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_pileres, 0, -1L, NULL, NULL, &__pyx_slice__33, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_8 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2509
 *     f = open(out_folder + prefix+'_'+str(nitr)+'_top'+str(num_top)+".txt", "w")
 *     f.write(pileres[:-1])
 *     f.close()             # <<<<<<<<<<<<<<
 * 
 *     return total, ICs
 */
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_close); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_8 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2511
 *     f.close()
 * 
 *     return total, ICs             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_v_total);
  __Pyx_GIVEREF(__pyx_v_total);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_total);
  __Pyx_INCREF(__pyx_v_ICs);
  __Pyx_GIVEREF(__pyx_v_ICs);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_ICs);
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":2463
 * 
 * 
 * def pileRank(             # <<<<<<<<<<<<<<
 *     rank,       #Rank for features
 *     num_top,    #Number of top feature
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.pileRank", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sub);
  __Pyx_XDECREF(__pyx_v_ICs);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_total);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_pileres);
  __Pyx_XDECREF(__pyx_v_pile);
  __Pyx_XDECREF(__pyx_v_gene);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2514
 * 
 * 
 * def savetopfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_59savetopfig(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_58savetopfig[] = "\n    Function to save intermediate figures with top ranking features in each loop\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_59savetopfig = {"savetopfig", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_59savetopfig, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_58savetopfig};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_59savetopfig(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_plotcomb = 0;
  PyObject *__pyx_v_CICs = 0;
  PyObject *__pyx_v_cythonseed = 0;
  PyObject *__pyx_v_seedcmap = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_pVals = 0;
  PyObject *__pyx_v_num_top = 0;
  PyObject *__pyx_v_bootstraps = 0;
  PyObject *__pyx_v_pilesize = 0;
  PyObject *__pyx_v_nitr = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_gmt = 0;
  PyObject *__pyx_v_locusdic = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("savetopfig (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_plotcomb,&__pyx_n_s_CICs,&__pyx_n_s_cythonseed,&__pyx_n_s_seedcmap,&__pyx_n_s_featurecmap,&__pyx_n_s_prefix,&__pyx_n_s_figure_format,&__pyx_n_s_pVals,&__pyx_n_s_num_top,&__pyx_n_s_bootstraps,&__pyx_n_s_pilesize,&__pyx_n_s_nitr,&__pyx_n_s_out_folder,&__pyx_n_s_target_name,&__pyx_n_s_seed_name,&__pyx_n_s_gmt,&__pyx_n_s_locusdic,0};
    PyObject* values[17] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_plotcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_CICs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 1); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cythonseed)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 2); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 3); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 4); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 5); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 6); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pVals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 7); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_top)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 8); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bootstraps)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 9); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pilesize)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 10); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nitr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 11); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 12); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 13); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (likely((values[14] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 14); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (likely((values[15] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 15); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (likely((values[16] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_locusdic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, 16); __PYX_ERR(0, 2514, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "savetopfig") < 0)) __PYX_ERR(0, 2514, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 17) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
      values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
      values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
      values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
    }
    __pyx_v_plotcomb = values[0];
    __pyx_v_CICs = values[1];
    __pyx_v_cythonseed = values[2];
    __pyx_v_seedcmap = values[3];
    __pyx_v_featurecmap = values[4];
    __pyx_v_prefix = values[5];
    __pyx_v_figure_format = values[6];
    __pyx_v_pVals = values[7];
    __pyx_v_num_top = values[8];
    __pyx_v_bootstraps = values[9];
    __pyx_v_pilesize = values[10];
    __pyx_v_nitr = values[11];
    __pyx_v_out_folder = values[12];
    __pyx_v_target_name = values[13];
    __pyx_v_seed_name = values[14];
    __pyx_v_gmt = values[15];
    __pyx_v_locusdic = values[16];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("savetopfig", 1, 17, 17, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2514, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.savetopfig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_58savetopfig(__pyx_self, __pyx_v_plotcomb, __pyx_v_CICs, __pyx_v_cythonseed, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_pVals, __pyx_v_num_top, __pyx_v_bootstraps, __pyx_v_pilesize, __pyx_v_nitr, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_gmt, __pyx_v_locusdic);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_10savetopfig_2generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "revealer/REVEALER_runbenchmark.pyx":2680
 *         plotcomb['pVals'] = pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotcomb.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotcomb.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_10savetopfig_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2680, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8revealer_21REVEALER_runbenchmark_10savetopfig_2generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_savetopfig_locals_genexpr, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!gen)) __PYX_ERR(0, 2680, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.savetopfig.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_10savetopfig_2generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *__pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2680, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_plotcomb)) { __Pyx_RaiseClosureNameError("plotcomb"); __PYX_ERR(0, 2680, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2680, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 2680, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2680, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 2680, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2680, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2680, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_elem);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_elem, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt)) { __Pyx_RaiseClosureNameError("gmt"); __PYX_ERR(0, 2680, __pyx_L1_error) }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_elem, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2680, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!(__pyx_t_7 != 0)) != 0);
    if (__pyx_t_8) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2514
 * 
 * 
 * def savetopfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_58savetopfig(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_CICs, PyObject *__pyx_v_cythonseed, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_pVals, PyObject *__pyx_v_num_top, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_pilesize, PyObject *__pyx_v_nitr, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_gmt, PyObject *__pyx_v_locusdic) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *__pyx_cur_scope;
  int __pyx_v_plotpval;
  int __pyx_v_piled;
  int __pyx_v_if_bootstrap;
  PyObject *__pyx_v_fig = NULL;
  PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_v_i = NULL;
  double __pyx_v_pval;
  PyObject *__pyx_v_pvallist = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  Py_UCS4 __pyx_t_16;
  double __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("savetopfig", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2514, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_plotcomb = __pyx_v_plotcomb;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_plotcomb);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_plotcomb);
  __pyx_cur_scope->__pyx_v_gmt = __pyx_v_gmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_gmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_gmt);

  /* "revealer/REVEALER_runbenchmark.pyx":2539
 * 
 *     #Check if the bootstrap, clustering, and p-value are calculated
 *     plotpval = False             # <<<<<<<<<<<<<<
 *     piled = False
 *     if_bootstrap = False
 */
  __pyx_v_plotpval = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2540
 *     #Check if the bootstrap, clustering, and p-value are calculated
 *     plotpval = False
 *     piled = False             # <<<<<<<<<<<<<<
 *     if_bootstrap = False
 *     if len(pilesize) != 0:
 */
  __pyx_v_piled = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2541
 *     plotpval = False
 *     piled = False
 *     if_bootstrap = False             # <<<<<<<<<<<<<<
 *     if len(pilesize) != 0:
 *         piled = True
 */
  __pyx_v_if_bootstrap = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2542
 *     piled = False
 *     if_bootstrap = False
 *     if len(pilesize) != 0:             # <<<<<<<<<<<<<<
 *         piled = True
 *     if len(pVals) != 0:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_pilesize); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2542, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2543
 *     if_bootstrap = False
 *     if len(pilesize) != 0:
 *         piled = True             # <<<<<<<<<<<<<<
 *     if len(pVals) != 0:
 *         plotpval = True
 */
    __pyx_v_piled = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2542
 *     piled = False
 *     if_bootstrap = False
 *     if len(pilesize) != 0:             # <<<<<<<<<<<<<<
 *         piled = True
 *     if len(pVals) != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2544
 *     if len(pilesize) != 0:
 *         piled = True
 *     if len(pVals) != 0:             # <<<<<<<<<<<<<<
 *         plotpval = True
 *     if len(bootstraps) != 0:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_pVals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2544, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2545
 *         piled = True
 *     if len(pVals) != 0:
 *         plotpval = True             # <<<<<<<<<<<<<<
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True
 */
    __pyx_v_plotpval = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2544
 *     if len(pilesize) != 0:
 *         piled = True
 *     if len(pVals) != 0:             # <<<<<<<<<<<<<<
 *         plotpval = True
 *     if len(bootstraps) != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2546
 *     if len(pVals) != 0:
 *         plotpval = True
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 * 
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2546, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2547
 *         plotpval = True
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True             # <<<<<<<<<<<<<<
 * 
 *     #Prepare canvas for result figure
 */
    __pyx_v_if_bootstrap = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2546
 *     if len(pVals) != 0:
 *         plotpval = True
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2550
 * 
 *     #Prepare canvas for result figure
 *     fig = plt.figure()             # <<<<<<<<<<<<<<
 *     fig.set_figheight(len(CICs)/2.0+1)
 *     fig.set_figwidth(14.2)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_figure); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_fig = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2551
 *     #Prepare canvas for result figure
 *     fig = plt.figure()
 *     fig.set_figheight(len(CICs)/2.0+1)             # <<<<<<<<<<<<<<
 *     fig.set_figwidth(14.2)
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figheight); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2551, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(((((double)__pyx_t_1) / 2.0) + 1.0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2552
 *     fig = plt.figure()
 *     fig.set_figheight(len(CICs)/2.0+1)
 *     fig.set_figwidth(14.2)             # <<<<<<<<<<<<<<
 * 
 *     #Label target name at left of target heatmap
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figwidth); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_float_14_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_float_14_2);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2555
 * 
 *     #Label target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 0), colspan=30,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2555, __pyx_L1_error)
  __pyx_t_4 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_142);
  __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__25) < 0) __PYX_ERR(0, 2555, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_30) < 0) __PYX_ERR(0, 2555, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2555, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ax = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2556
 *     #Label target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 0), colspan=30,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2557
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 0), colspan=30,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot heatmap for target
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_target_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Target, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_float_0_9);
  __Pyx_GIVEREF(__pyx_float_0_9);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_9);
  __Pyx_INCREF(__pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_float_0_5);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2560
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 30), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2560, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_142);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__48) < 0) __PYX_ERR(0, 2560, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2560, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2560, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2561
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 30), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_sns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
  __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_cmap, __pyx_n_u_bwr) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2562
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 30), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())             # <<<<<<<<<<<<<<
 * 
 *     #Label for IC or CIC and p-values on right of target heatmap.
 */
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_mean); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_center, __pyx_t_7) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2561
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 30), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2565
 * 
 *     #Label for IC or CIC and p-values on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 120), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2565, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_142);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_tuple__49) < 0) __PYX_ERR(0, 2565, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2565, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2565, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2566
 *     #Label for IC or CIC and p-values on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 120), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color='blue')
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2567
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 120), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color='blue')
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2568
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color='blue')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color='blue')
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2568, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2568, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2568, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__35, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2567
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 120), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color='blue')
 *     else:
 */
    goto __pyx_L6;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2570
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color='blue')
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color='blue')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 132), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2570, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2570, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2570, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__36, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L6:;

  /* "revealer/REVEALER_runbenchmark.pyx":2571
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color='blue')
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 132), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if plotpval == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2571, __pyx_L1_error)
  __pyx_t_6 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_142);
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__50) < 0) __PYX_ERR(0, 2571, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2571, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2571, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2572
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color='blue')
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 132), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if plotpval == True:
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2573
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 132), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')
 * 
 */
  __pyx_t_2 = ((__pyx_v_plotpval == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2574
 *     ax.set_axis_off()
 *     if plotpval == True:
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Label seed name at left of seed heatmap
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2574, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2574, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__38, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2573
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 132), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2577
 * 
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 0), colspan=30,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if seed_name != None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2577, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_142);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_tuple__39) < 0) __PYX_ERR(0, 2577, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_30) < 0) __PYX_ERR(0, 2577, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2577, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2578
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 0), colspan=30,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2579
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 0), colspan=30,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
  __pyx_t_6 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2579, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2580
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_seed_name); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2580, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_1 > 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2581
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_t_7, __pyx_kp_u__40); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2581, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2581, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2580
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
      goto __pyx_L9;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2583
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2583, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2583, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L9:;

    /* "revealer/REVEALER_runbenchmark.pyx":2579
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 0), colspan=30,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
    goto __pyx_L8;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2585
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot seed heatmap
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2585, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2585, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__41, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L8:;

  /* "revealer/REVEALER_runbenchmark.pyx":2588
 * 
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 30), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2588, __pyx_L1_error)
  __pyx_t_6 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_142);
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_tuple__51) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2589
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 30), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_array); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_cythonseed);
  __Pyx_GIVEREF(__pyx_v_cythonseed);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_cythonseed);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 2589, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2589, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2589, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2590
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 30), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 * 
 *     #Blanks
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2589, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2589, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2589
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 30), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2593
 * 
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 120), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 132), colspan=10,rowspan=5)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2593, __pyx_L1_error)
  __pyx_t_6 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_142);
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__52) < 0) __PYX_ERR(0, 2593, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2593, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2593, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2594
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 120), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 132), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2595
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 120), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 132), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2595, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t((5 * (__pyx_t_1 + 2))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_142);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_tuple__53) < 0) __PYX_ERR(0, 2595, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2595, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2595, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2596
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 132), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 * 
 *     #Loop to plot top features one by one
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2599
 * 
 *     #Loop to plot top features one by one
 *     for i in range(1,len(CICs)):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2599, __pyx_L1_error)
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
    __pyx_t_7 = __pyx_t_6; __Pyx_INCREF(__pyx_t_7); __pyx_t_1 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2599, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_7))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_7)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2599, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_7, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2599, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2599, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_7, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2599, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_9(__pyx_t_7);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2599, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2602
 * 
 *         #Label name of picked feature in this round
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 0), colspan=30,rowspan=5)             # <<<<<<<<<<<<<<
 *         ax.set_axis_off()
 *         if piled == True and pilesize[i-1] > 1:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2602, __pyx_L1_error)
    __pyx_t_3 = PyInt_FromSsize_t((5 * (__pyx_t_10 + 2))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_int_142);
    __Pyx_GIVEREF(__pyx_int_142);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_142);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_5, __pyx_int_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_0);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_5) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_30) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2603
 *         #Label name of picked feature in this round
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 0), colspan=30,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if piled == True and pilesize[i-1] > 1:
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2603, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2603, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2604
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 0), colspan=30,rowspan=5)
 *         ax.set_axis_off()
 *         if piled == True and pilesize[i-1] > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 *                     '(' + str(pilesize[i-1]) + ',' +
 */
    __pyx_t_11 = ((__pyx_v_piled == 1) != 0);
    if (__pyx_t_11) {
    } else {
      __pyx_t_2 = __pyx_t_11;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pilesize, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_6, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 2604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_2 = __pyx_t_11;
    __pyx_L13_bool_binop_done:;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2605
 *         ax.set_axis_off()
 *         if piled == True and pilesize[i-1] > 1:
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(pilesize[i-1]) + ',' +
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__44); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__27); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2606
 *         if piled == True and pilesize[i-1] > 1:
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 *                     '(' + str(pilesize[i-1]) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +
 *                     ')', ha='right', va='center')
 */
      __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pilesize, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_Add(__pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_Add(__pyx_t_6, __pyx_kp_u__29); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2607
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 *                     '(' + str(pilesize[i-1]) + ',' +
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +             # <<<<<<<<<<<<<<
 *                     ')', ha='right', va='center')
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
        }
      }
      __pyx_t_12 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_t_12, __pyx_v_i); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_14); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
        }
      }
      __pyx_t_3 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_count); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
        }
      }
      __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_3, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_6); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2606
 *         if piled == True and pilesize[i-1] > 1:
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 *                     '(' + str(pilesize[i-1]) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +
 *                     ')', ha='right', va='center')
 */
      __pyx_t_6 = PyNumber_Add(__pyx_t_8, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2607
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 *                     '(' + str(pilesize[i-1]) + ',' +
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +             # <<<<<<<<<<<<<<
 *                     ')', ha='right', va='center')
 *         else:
 */
      __pyx_t_14 = PyNumber_Add(__pyx_t_6, __pyx_kp_u__28); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2607, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2605
 *         ax.set_axis_off()
 *         if piled == True and pilesize[i-1] > 1:
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(pilesize[i-1]) + ',' +
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +
 */
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2608
 *                     '(' + str(pilesize[i-1]) + ',' +
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +
 *                     ')', ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):
 */
      __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2608, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2608, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2608, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2605
 *         ax.set_axis_off()
 *         if piled == True and pilesize[i-1] > 1:
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(pilesize[i-1]) + ',' +
 *                     str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) +
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2604
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 0), colspan=30,rowspan=5)
 *         ax.set_axis_off()
 *         if piled == True and pilesize[i-1] > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]] +
 *                     '(' + str(pilesize[i-1]) + ',' +
 */
      goto __pyx_L12;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2610
 *                     ')', ha='right', va='center')
 *         else:
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 */
    /*else*/ {
      __pyx_t_11 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
      __pyx_t_15 = (__pyx_t_11 != 0);
      if (__pyx_t_15) {
      } else {
        __pyx_t_2 = __pyx_t_15;
        goto __pyx_L16_bool_binop_done;
      }
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_8 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_8 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_15 = (__Pyx_PySequence_ContainsTF(__pyx_t_6, __pyx_t_8, Py_EQ)); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 2610, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_11 = (__pyx_t_15 != 0);
      __pyx_t_2 = __pyx_t_11;
      __pyx_L16_bool_binop_done:;
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2611
 *         else:
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 */
        __pyx_t_8 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2611, __pyx_L1_error)
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2611, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":2612
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__44); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_14 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_14, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyNumber_Add(__pyx_t_6, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__27); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2613
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          __pyx_t_5 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_notna); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyNumber_Add(__pyx_t_14, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__29); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2614
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *                 else:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          __pyx_t_6 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_13);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          __pyx_t_14 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_13);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_count); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          __pyx_t_4 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_int_1);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2613
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_13); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2614
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *                 else:
 */
          __pyx_t_13 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__28); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2614, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2612
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_13);
          __pyx_t_13 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2615
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')             # <<<<<<<<<<<<<<
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+
 */
          __pyx_t_13 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2615, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2615, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2615, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2612
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_4, __pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2612, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2611
 *         else:
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 */
          goto __pyx_L18;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":2617
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
        /*else*/ {
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          __pyx_t_13 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_13, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__27); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2618
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_14 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_14, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_notna); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_8 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = PyNumber_Add(__pyx_t_13, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__29); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2619
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *             else:
 */
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_14, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          __pyx_t_13 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_count); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          __pyx_t_5 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_13, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_int_1);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2618
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_5 = PyNumber_Add(__pyx_t_8, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2619
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *             else:
 */
          __pyx_t_12 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__28); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2617
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_12);
          PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2620
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 if locusdic != None:
 */
          __pyx_t_12 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2620, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2620, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2620, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2617
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i]+             # <<<<<<<<<<<<<<
 *                         '(' + str(sum(gmt.loc[plotcomb.index.tolist()[i]].notna())) + ',' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_L18:;

        /* "revealer/REVEALER_runbenchmark.pyx":2610
 *                     ')', ha='right', va='center')
 *         else:
 *             if (gmt is not None) and (plotcomb.index.tolist()[i] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+ locusdic[plotcomb.index.tolist()[i]]+
 */
        goto __pyx_L15;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2622
 *                         ha='right', va='center')
 *             else:
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 */
      /*else*/ {
        __pyx_t_8 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2622, __pyx_L1_error)
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2622, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_2) {

          /* "revealer/REVEALER_runbenchmark.pyx":2623
 *             else:
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+             # <<<<<<<<<<<<<<
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_12 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_12, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__44); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2624
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_13);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_i); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2623
 *             else:
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+             # <<<<<<<<<<<<<<
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_13 = PyNumber_Add(__pyx_t_12, __pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2624
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_3 = PyNumber_Add(__pyx_t_13, __pyx_kp_u__27); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2625
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *                 else:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          __pyx_t_4 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_count); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          __pyx_t_13 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_12, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_int_1);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2624
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_13 = PyNumber_Add(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2624, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2625
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 *                 else:
 */
          __pyx_t_6 = PyNumber_Add(__pyx_t_13, __pyx_kp_u__28); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2625, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2623
 *             else:
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+             # <<<<<<<<<<<<<<
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_13 = PyTuple_New(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_13, 2, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2626
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')             # <<<<<<<<<<<<<<
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +
 */
          __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2626, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2626, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2626, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2623
 *             else:
 *                 if locusdic != None:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+             # <<<<<<<<<<<<<<
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 */
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_13, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2623, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2622
 *                         ha='right', va='center')
 *             else:
 *                 if locusdic != None:             # <<<<<<<<<<<<<<
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] +' '+
 *                         locusdic[plotcomb.index.tolist()[i]] + '(' +
 */
          goto __pyx_L19;
        }

        /* "revealer/REVEALER_runbenchmark.pyx":2628
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
        /*else*/ {
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          __pyx_t_6 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__27); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2629
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 * 
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_i); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_12, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          __pyx_t_13 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_count); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          __pyx_t_8 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_int_1);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2628
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_8 = PyNumber_Add(__pyx_t_6, __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2629
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                         ha='right', va='center')
 * 
 */
          __pyx_t_14 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__28); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2629, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2628
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_float_0_9);
          __Pyx_GIVEREF(__pyx_float_0_9);
          PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_float_0_9);
          __Pyx_INCREF(__pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_float_0_5);
          PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_float_0_5);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_14);
          __pyx_t_14 = 0;

          /* "revealer/REVEALER_runbenchmark.pyx":2630
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Plot heatmap for picked feature
 */
          __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2630, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2630, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2630, __pyx_L1_error)

          /* "revealer/REVEALER_runbenchmark.pyx":2628
 *                         ha='right', va='center')
 *                 else:
 *                     ax.text(0.9,0.5,plotcomb.index.tolist()[i] + '(' +             # <<<<<<<<<<<<<<
 *                         str(plotcomb.loc[plotcomb.index.tolist()[i]].tolist().count(1)) + ')',
 *                         ha='right', va='center')
 */
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_L19:;
      }
      __pyx_L15:;
    }
    __pyx_L12:;

    /* "revealer/REVEALER_runbenchmark.pyx":2633
 * 
 *         #Plot heatmap for picked feature
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 30), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *         ax = sns.heatmap(np.asarray([plotcomb.iloc[i].tolist()]).astype(int), cmap=featurecmap,
 *                          annot=False, yticklabels=False, xticklabels=False, cbar=False)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2633, __pyx_L1_error)
    __pyx_t_8 = PyInt_FromSsize_t((5 * (__pyx_t_10 + 2))); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
    __Pyx_INCREF(__pyx_int_142);
    __Pyx_GIVEREF(__pyx_int_142);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_142);
    __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyNumber_Multiply(__pyx_t_3, __pyx_int_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
    __Pyx_INCREF(__pyx_int_30);
    __Pyx_GIVEREF(__pyx_int_30);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_30);
    __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_3) < 0) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2633, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2633, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2634
 *         #Plot heatmap for picked feature
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 30), colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.iloc[i].tolist()]).astype(int), cmap=featurecmap,             # <<<<<<<<<<<<<<
 *                          annot=False, yticklabels=False, xticklabels=False, cbar=False)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_asarray); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_8 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_13);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_13, function);
      }
    }
    __pyx_t_14 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_8, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_astype); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_13, function);
      }
    }
    __pyx_t_3 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_13, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 2634, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2635
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 30), colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.iloc[i].tolist()]).astype(int), cmap=featurecmap,
 *                          annot=False, yticklabels=False, xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 * 
 *         #Label CIC or IC for this feature
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2634, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2634, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2634, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2634, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2634
 *         #Plot heatmap for picked feature
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 30), colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.iloc[i].tolist()]).astype(int), cmap=featurecmap,             # <<<<<<<<<<<<<<
 *                          annot=False, yticklabels=False, xticklabels=False, cbar=False)
 * 
 */
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_14);
    __pyx_t_14 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2638
 * 
 *         #Label CIC or IC for this feature
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 120), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_plt); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_10 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2638, __pyx_L1_error)
    __pyx_t_13 = PyInt_FromSsize_t((5 * (__pyx_t_10 + 2))); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_13);
    __Pyx_INCREF(__pyx_int_142);
    __Pyx_GIVEREF(__pyx_int_142);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_142);
    __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_13 = PyNumber_Multiply(__pyx_t_6, __pyx_int_5); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_13);
    __Pyx_INCREF(__pyx_int_120);
    __Pyx_GIVEREF(__pyx_int_120);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_120);
    __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_loc, __pyx_t_6) < 0) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2638, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2638, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2639
 *         #Label CIC or IC for this feature
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 120), colspan=12,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[i],int(float(bootstraps[i]*1000))), ha='center',
 */
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2640
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 120), colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[i],int(float(bootstraps[i]*1000))), ha='center',
 *                     va='center',color='blue')
 */
    __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2641
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[i],int(float(bootstraps[i]*1000))), ha='center',             # <<<<<<<<<<<<<<
 *                     va='center',color='blue')
 *         else:
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_14 = PyTuple_New(4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_10 = 0;
      __pyx_t_16 = 127;
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_13 = __Pyx_PyObject_Format(__pyx_t_3, __pyx_kp_u_3f); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) : __pyx_t_16;
      __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13);
      __pyx_t_13 = 0;
      __Pyx_INCREF(__pyx_kp_u__27);
      __pyx_t_10 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__27);
      PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_kp_u__27);
      __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_3 = PyNumber_Multiply(__pyx_t_13, __pyx_int_1000); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyNumber_Float(__pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) : __pyx_t_16;
      __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_13);
      __pyx_t_13 = 0;
      __Pyx_INCREF(__pyx_kp_u__28);
      __pyx_t_10 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__28);
      PyTuple_SET_ITEM(__pyx_t_14, 3, __pyx_kp_u__28);
      __pyx_t_13 = __Pyx_PyUnicode_Join(__pyx_t_14, 4, __pyx_t_10, __pyx_t_16); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2641, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2641, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2641, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_14, __pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2640
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 120), colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[i],int(float(bootstraps[i]*1000))), ha='center',
 *                     va='center',color='blue')
 */
      goto __pyx_L20;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2644
 *                     va='center',color='blue')
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[i]), ha='center', va='center',color='blue')             # <<<<<<<<<<<<<<
 * 
 *         #Label p-values if plotpval is True
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_v_i); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyTuple_New(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_13, 2, __pyx_t_14);
      __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2644, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2644, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2644, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L20:;

    /* "revealer/REVEALER_runbenchmark.pyx":2647
 * 
 *         #Label p-values if plotpval is True
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 132), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *         ax.set_axis_off()
 *         if plotpval == True:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = PyObject_Length(__pyx_v_CICs); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2647, __pyx_L1_error)
    __pyx_t_13 = PyInt_FromSsize_t((5 * (__pyx_t_10 + 2))); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_13);
    __Pyx_INCREF(__pyx_int_142);
    __Pyx_GIVEREF(__pyx_int_142);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_142);
    __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_13 = PyNumber_Multiply(__pyx_t_3, __pyx_int_5); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_13);
    __Pyx_INCREF(__pyx_int_132);
    __Pyx_GIVEREF(__pyx_int_132);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_132);
    __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_3) < 0) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2647, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2647, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2648
 *         #Label p-values if plotpval is True
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 132), colspan=10,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if plotpval == True:
 *             if pval > 1:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_3 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2649
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 132), colspan=10,rowspan=5)
 *         ax.set_axis_off()
 *         if plotpval == True:             # <<<<<<<<<<<<<<
 *             if pval > 1:
 *                 pval = float(1)/float(pval)
 */
    __pyx_t_2 = ((__pyx_v_plotpval == 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2650
 *         ax.set_axis_off()
 *         if plotpval == True:
 *             if pval > 1:             # <<<<<<<<<<<<<<
 *                 pval = float(1)/float(pval)
 *                 pvallist = ("%e"%pval).split('e')
 */
      __pyx_t_2 = ((__pyx_v_pval > 1.0) != 0);
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2651
 *         if plotpval == True:
 *             if pval > 1:
 *                 pval = float(1)/float(pval)             # <<<<<<<<<<<<<<
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 */
        __pyx_t_17 = __Pyx_PyObject_AsDouble(__pyx_int_1); if (unlikely(__pyx_t_17 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2651, __pyx_L1_error)
        if (unlikely(__pyx_v_pval == 0)) {
          PyErr_SetString(PyExc_ZeroDivisionError, "float division");
          __PYX_ERR(0, 2651, __pyx_L1_error)
        }
        __pyx_v_pval = (__pyx_t_17 / __pyx_v_pval);

        /* "revealer/REVEALER_runbenchmark.pyx":2652
 *             if pval > 1:
 *                 pval = float(1)/float(pval)
 *                 pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *                 ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                         ha='center', va='center')
 */
        __pyx_t_3 = PyFloat_FromDouble(__pyx_v_pval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2652, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_e, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2652, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyUnicode_Split(((PyObject*)__pyx_t_6), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2652, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF_SET(__pyx_v_pvallist, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2653
 *                 pval = float(1)/float(pval)
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                         ha='center', va='center')
 *             else:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = PyTuple_New(5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = 0;
        __pyx_t_16 = 127;
        __Pyx_INCREF(__pyx_kp_u__45);
        __pyx_t_10 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__45);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u__45);
        __pyx_t_14 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_13 = __Pyx_PyNumber_Float(__pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_Format(__pyx_t_13, __pyx_kp_u_1f); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_16;
        __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_14);
        __pyx_t_14 = 0;
        __Pyx_INCREF(__pyx_kp_u_x_10);
        __pyx_t_10 += 7;
        __Pyx_GIVEREF(__pyx_kp_u_x_10);
        PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_kp_u_x_10);
        __pyx_t_14 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_13 = __Pyx_PyNumber_Int(__pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_13), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_16;
        __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_14);
        __pyx_t_14 = 0;
        __Pyx_INCREF(__pyx_kp_u__46);
        __pyx_t_10 += 3;
        __Pyx_GIVEREF(__pyx_kp_u__46);
        PyTuple_SET_ITEM(__pyx_t_6, 4, __pyx_kp_u__46);
        __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_6, 5, __pyx_t_10, __pyx_t_16); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_float_0_5);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_14);
        __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2654
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                         ha='center', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 pvallist = ("%e"%pval).split('e')
 */
        __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2654, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2654, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2654, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2653
 *                 pval = float(1)/float(pval)
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                         ha='center', va='center')
 *             else:
 */
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2650
 *         ax.set_axis_off()
 *         if plotpval == True:
 *             if pval > 1:             # <<<<<<<<<<<<<<
 *                 pval = float(1)/float(pval)
 *                 pvallist = ("%e"%pval).split('e')
 */
        goto __pyx_L22;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2656
 *                         ha='center', va='center')
 *             else:
 *                 pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *                 ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                         ha='center', va='center')
 */
      /*else*/ {
        __pyx_t_13 = PyFloat_FromDouble(__pyx_v_pval); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2656, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = PyUnicode_Format(__pyx_kp_u_e, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2656, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = PyUnicode_Split(((PyObject*)__pyx_t_14), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2656, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF_SET(__pyx_v_pvallist, __pyx_t_13);
        __pyx_t_13 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2657
 *             else:
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                         ha='center', va='center')
 * 
 */
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = PyTuple_New(4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_10 = 0;
        __pyx_t_16 = 127;
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = __Pyx_PyNumber_Float(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_Format(__pyx_t_3, __pyx_kp_u_1f); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_16;
        __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_INCREF(__pyx_kp_u_x_10);
        __pyx_t_10 += 7;
        __Pyx_GIVEREF(__pyx_kp_u_x_10);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_kp_u_x_10);
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_16;
        __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_INCREF(__pyx_kp_u__46);
        __pyx_t_10 += 3;
        __Pyx_GIVEREF(__pyx_kp_u__46);
        PyTuple_SET_ITEM(__pyx_t_14, 3, __pyx_kp_u__46);
        __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_14, 4, __pyx_t_10, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_float_0_5);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2658
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                         ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Save Plot
 */
        __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2658, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2658, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2658, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2657
 *             else:
 *                 pvallist = ("%e"%pval).split('e')
 *                 ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                         ha='center', va='center')
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_14, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_L22:;

      /* "revealer/REVEALER_runbenchmark.pyx":2649
 *         ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=((i+1)*5, 132), colspan=10,rowspan=5)
 *         ax.set_axis_off()
 *         if plotpval == True:             # <<<<<<<<<<<<<<
 *             if pval > 1:
 *                 pval = float(1)/float(pval)
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2599
 * 
 *     #Loop to plot top features one by one
 *     for i in range(1,len(CICs)):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2661
 * 
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'_Result.'+figure_format,             # <<<<<<<<<<<<<<
 *                 format=figure_format)
 *     plt.close()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_savefig); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_n_u_itr_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_14 = PyNumber_Add(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_14, __pyx_n_u_Top); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_6, __pyx_kp_u_Result); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_14, __pyx_v_figure_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2662
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'_Result.'+figure_format,
 *                 format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 2662, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2661
 * 
 *     #Save Plot
 *     plt.savefig(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'_Result.'+figure_format,             # <<<<<<<<<<<<<<
 *                 format=figure_format)
 *     plt.close()
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_14, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2663
 *     plt.savefig(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'_Result.'+figure_format,
 *                 format=figure_format)
 *     plt.close()             # <<<<<<<<<<<<<<
 * 
 *     #Set new line of gene locus  to ,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_close); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2669
 * 
 *     #Adjust length of CIC/IC
 *     plotcomb['CICs'] = CICs             # <<<<<<<<<<<<<<
 * 
 *     #Put bootstrap and p-values to report
 */
  if (unlikely(PyObject_SetItem(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_u_CICs, __pyx_v_CICs) < 0)) __PYX_ERR(0, 2669, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2672
 * 
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2673
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):             # <<<<<<<<<<<<<<
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2673, __pyx_L1_error)
    __pyx_t_7 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (likely(PyList_CheckExact(__pyx_t_14)) || PyTuple_CheckExact(__pyx_t_14)) {
      __pyx_t_7 = __pyx_t_14; __Pyx_INCREF(__pyx_t_7); __pyx_t_1 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_1 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2673, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2673, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_7)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_14 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_1); __Pyx_INCREF(__pyx_t_14); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2673, __pyx_L1_error)
          #else
          __pyx_t_14 = PySequence_ITEM(__pyx_t_7, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2673, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          #endif
        } else {
          if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_14 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_1); __Pyx_INCREF(__pyx_t_14); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2673, __pyx_L1_error)
          #else
          __pyx_t_14 = PySequence_ITEM(__pyx_t_7, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2673, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          #endif
        }
      } else {
        __pyx_t_14 = __pyx_t_9(__pyx_t_7);
        if (unlikely(!__pyx_t_14)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2673, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_14);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2674
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':             # <<<<<<<<<<<<<<
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         plotcomb['bootstrap'] = bootstraps
 */
      __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_14, __pyx_kp_u__2, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2674, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2675
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]             # <<<<<<<<<<<<<<
 *         plotcomb['bootstrap'] = bootstraps
 *     if plotpval == True:
 */
        __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2675, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_6 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2675, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_bootstraps, __pyx_v_i, __pyx_t_6) < 0)) __PYX_ERR(0, 2675, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2674
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':             # <<<<<<<<<<<<<<
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         plotcomb['bootstrap'] = bootstraps
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2673
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):             # <<<<<<<<<<<<<<
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 */
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2676
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         plotcomb['bootstrap'] = bootstraps             # <<<<<<<<<<<<<<
 *     if plotpval == True:
 *         plotcomb['pVals'] = pVals
 */
    if (unlikely(PyObject_SetItem(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_u_bootstrap, __pyx_v_bootstraps) < 0)) __PYX_ERR(0, 2676, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2672
 * 
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2677
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         plotcomb['bootstrap'] = bootstraps
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         plotcomb['pVals'] = pVals
 * 
 */
  __pyx_t_2 = ((__pyx_v_plotpval == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2678
 *         plotcomb['bootstrap'] = bootstraps
 *     if plotpval == True:
 *         plotcomb['pVals'] = pVals             # <<<<<<<<<<<<<<
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotcomb.index.tolist()) == True):
 */
    if (unlikely(PyObject_SetItem(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_u_pVals, __pyx_v_pVals) < 0)) __PYX_ERR(0, 2678, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2677
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         plotcomb['bootstrap'] = bootstraps
 *     if plotpval == True:             # <<<<<<<<<<<<<<
 *         plotcomb['pVals'] = pVals
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2680
 *         plotcomb['pVals'] = pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotcomb.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotcomb.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */
  __pyx_t_11 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
  __pyx_t_15 = (__pyx_t_11 != 0);
  if (__pyx_t_15) {
  } else {
    __pyx_t_2 = __pyx_t_15;
    goto __pyx_L29_bool_binop_done;
  }
  __pyx_t_7 = __pyx_pf_8revealer_21REVEALER_runbenchmark_10savetopfig_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_Generator_Next(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_6, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_2 = __pyx_t_15;
  __pyx_L29_bool_binop_done:;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2681
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotcomb.index.tolist()) == True):
 *         gmt.loc[plotcomb.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)             # <<<<<<<<<<<<<<
 * 
 *     #Save report
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_index); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_6 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_n_u_itr_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_14 = PyNumber_Add(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_14, __pyx_n_u_Top); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyNumber_Add(__pyx_t_7, __pyx_kp_u_gmt_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_14);
    __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 2681, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_header, Py_False) < 0) __PYX_ERR(0, 2681, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2680
 *         plotcomb['pVals'] = pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in plotcomb.index.tolist()) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[plotcomb.index.tolist()].to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'.gmt',sep='\t',header=False)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2684
 * 
 *     #Save report
 *     plotcomb.to_csv(out_folder + prefix+'_itr'+str(nitr)+'_Top'+str(num_top)+'_Result.txt',sep='\t')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_plotcomb, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_7 = PyNumber_Add(__pyx_t_14, __pyx_n_u_itr_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_nitr); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyNumber_Add(__pyx_t_6, __pyx_n_u_Top); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_num_top); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Add(__pyx_t_14, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_kp_u_Result_txt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 2684, __pyx_L1_error)
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2514
 * 
 * 
 * def savetopfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.savetopfig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fig);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_pvallist);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2687
 * 
 * 
 * def saveresfigWithPval(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_61saveresfigWithPval(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_60saveresfigWithPval[] = "\n    Function to save result summary figure with p-values. \n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_61saveresfigWithPval = {"saveresfigWithPval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_61saveresfigWithPval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_60saveresfigWithPval};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_61saveresfigWithPval(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_plotcomb = 0;
  PyObject *__pyx_v_seedids = 0;
  PyObject *__pyx_v_CICs = 0;
  PyObject *__pyx_v_seedlists = 0;
  PyObject *__pyx_v_seedcmap = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_pVals = 0;
  PyObject *__pyx_v_bootstraps = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_locusdic = 0;
  PyObject *__pyx_v_gmt = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("saveresfigWithPval (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_plotcomb,&__pyx_n_s_seedids,&__pyx_n_s_CICs,&__pyx_n_s_seedlists,&__pyx_n_s_seedcmap,&__pyx_n_s_featurecmap,&__pyx_n_s_prefix,&__pyx_n_s_figure_format,&__pyx_n_s_pVals,&__pyx_n_s_bootstraps,&__pyx_n_s_out_folder,&__pyx_n_s_target_name,&__pyx_n_s_seed_name,&__pyx_n_s_locusdic,&__pyx_n_s_gmt,0};
    PyObject* values[15] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_plotcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedids)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 1); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_CICs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 2); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedlists)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 3); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 4); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 5); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 6); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 7); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pVals)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 8); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bootstraps)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 9); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 10); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 11); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 12); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_locusdic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 13); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (likely((values[14] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, 14); __PYX_ERR(0, 2687, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "saveresfigWithPval") < 0)) __PYX_ERR(0, 2687, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 15) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
      values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
    }
    __pyx_v_plotcomb = values[0];
    __pyx_v_seedids = values[1];
    __pyx_v_CICs = values[2];
    __pyx_v_seedlists = values[3];
    __pyx_v_seedcmap = values[4];
    __pyx_v_featurecmap = values[5];
    __pyx_v_prefix = values[6];
    __pyx_v_figure_format = values[7];
    __pyx_v_pVals = values[8];
    __pyx_v_bootstraps = values[9];
    __pyx_v_out_folder = values[10];
    __pyx_v_target_name = values[11];
    __pyx_v_seed_name = values[12];
    __pyx_v_locusdic = values[13];
    __pyx_v_gmt = values[14];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("saveresfigWithPval", 1, 15, 15, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2687, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.saveresfigWithPval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_60saveresfigWithPval(__pyx_self, __pyx_v_plotcomb, __pyx_v_seedids, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_pVals, __pyx_v_bootstraps, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_18saveresfigWithPval_2generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "revealer/REVEALER_runbenchmark.pyx":2915
 *     reportdf['pVals'] = [''] + pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_18saveresfigWithPval_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2915, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8revealer_21REVEALER_runbenchmark_18saveresfigWithPval_2generator2, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_saveresfigWithPval_locals_genexp, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!gen)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.saveresfigWithPval.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_18saveresfigWithPval_2generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *__pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2915, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids)) { __Pyx_RaiseClosureNameError("seedids"); __PYX_ERR(0, 2915, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2915, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2915, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2915, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2915, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2915, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2915, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_elem);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_elem, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt)) { __Pyx_RaiseClosureNameError("gmt"); __PYX_ERR(0, 2915, __pyx_L1_error) }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_elem, __pyx_t_4, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = ((!(__pyx_t_7 != 0)) != 0);
    if (__pyx_t_8) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2687
 * 
 * 
 * def saveresfigWithPval(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_60saveresfigWithPval(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_seedids, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_pVals, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_gmt) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *__pyx_cur_scope;
  int __pyx_v_if_bootstrap;
  PyObject *__pyx_v_reportdf = NULL;
  PyObject *__pyx_v_fig = NULL;
  PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_v_pval = NULL;
  PyObject *__pyx_v_pvallist = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_UCS4 __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  Py_ssize_t __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  double __pyx_t_17;
  double __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("saveresfigWithPval", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2687, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_seedids = __pyx_v_seedids;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_seedids);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_seedids);
  __pyx_cur_scope->__pyx_v_gmt = __pyx_v_gmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_gmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_gmt);

  /* "revealer/REVEALER_runbenchmark.pyx":2710
 * 
 *     #Check if bootstrap value is calculated
 *     if_bootstrap = False             # <<<<<<<<<<<<<<
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True
 */
  __pyx_v_if_bootstrap = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2711
 *     #Check if bootstrap value is calculated
 *     if_bootstrap = False
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 * 
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2711, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2712
 *     if_bootstrap = False
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True             # <<<<<<<<<<<<<<
 * 
 *     #Create dataframe to write down report
 */
    __pyx_v_if_bootstrap = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2711
 *     #Check if bootstrap value is calculated
 *     if_bootstrap = False
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2715
 * 
 *     #Create dataframe to write down report
 *     reportdf = pd.DataFrame(columns=plotcomb.columns.tolist())             # <<<<<<<<<<<<<<
 * 
 *     #Prepare canvas for result figure
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_reportdf = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2718
 * 
 *     #Prepare canvas for result figure
 *     fig = plt.figure()             # <<<<<<<<<<<<<<
 *     fig.set_figheight(len(seedids)+1)
 *     fig.set_figwidth(15.4)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_figure); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_fig = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2719
 *     #Prepare canvas for result figure
 *     fig = plt.figure()
 *     fig.set_figheight(len(seedids)+1)             # <<<<<<<<<<<<<<
 *     fig.set_figwidth(15.4)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figheight); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t((__pyx_t_1 + 1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2720
 *     fig = plt.figure()
 *     fig.set_figheight(len(seedids)+1)
 *     fig.set_figwidth(15.4)             # <<<<<<<<<<<<<<
 * 
 *     #Add Target row for report
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figwidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, __pyx_float_15_4) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_float_15_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2723
 * 
 *     #Add Target row for report
 *     reportdf.loc['Target'] = plotcomb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 * 
 *     #Label target name at left of target heatmap
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(PyObject_SetItem(__pyx_t_4, __pyx_n_u_Target_2, __pyx_t_5) < 0)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2726
 * 
 *     #Label target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_154);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_tuple__25) < 0) __PYX_ERR(0, 2726, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2726, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2726, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_ax = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2727
 *     #Label target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2728
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot heatmap for target
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_target_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Target, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_float_0_9);
  __Pyx_GIVEREF(__pyx_float_0_9);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
  __Pyx_INCREF(__pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_float_0_5);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2728, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2728, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2731
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_154);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__26) < 0) __PYX_ERR(0, 2731, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2731, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2731, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2732
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_sns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_int_0);
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cmap, __pyx_n_u_bwr) < 0) __PYX_ERR(0, 2732, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2732, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2732, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2733
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())             # <<<<<<<<<<<<<<
 * 
 *     #Label for IC, p-value for IC, CIC, p-value for CIC on right of target heatmap.
 */
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2732, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2732, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_mean); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_center, __pyx_t_6) < 0) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2732
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2736
 * 
 *     #Label for IC, p-value for IC, CIC, p-value for CIC on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_154);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__34) < 0) __PYX_ERR(0, 2736, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2736, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2736, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2737
 *     #Label for IC, p-value for IC, CIC, p-value for CIC on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2738
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2739
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2739, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2739, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__54, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2738
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 */
    goto __pyx_L4;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2741
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2741, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2741, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__55, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "revealer/REVEALER_runbenchmark.pyx":2742
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 122), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_154);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__37) < 0) __PYX_ERR(0, 2742, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2742, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2742, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2743
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 132), colspan=12,rowspan=5)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2744
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2744, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2744, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__38, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2745
 *     ax.set_axis_off()
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 132), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_154);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__50) < 0) __PYX_ERR(0, 2745, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2745, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2745, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2746
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2747
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2748
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2748, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2748, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2748, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__35, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2747
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 *     else:
 */
    goto __pyx_L5;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2750
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 144), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2750, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2750, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2750, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__36, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L5:;

  /* "revealer/REVEALER_runbenchmark.pyx":2751
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 144), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center',color = 'blue')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_154);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_tuple__56) < 0) __PYX_ERR(0, 2751, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2751, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2751, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2752
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 144), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center',color = 'blue')
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2753
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 144), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 * 
 *     #Add seed row for report
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2753, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2753, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2753, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__38, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2756
 * 
 *     #Add seed row for report
 *     reportdf.loc['Seed'] = seedlists[0]             # <<<<<<<<<<<<<<
 * 
 *     #Label seed name at left of seed heatmap
 */
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_seedlists, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (unlikely(PyObject_SetItem(__pyx_t_7, __pyx_n_u_Seed_2, __pyx_t_6) < 0)) __PYX_ERR(0, 2756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2759
 * 
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if seed_name != None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_154);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__39) < 0) __PYX_ERR(0, 2759, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2759, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2759, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2760
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2761
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2761, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2762
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_seed_name); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2762, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_1 > 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2763
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_t_6, __pyx_kp_u__40); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2763, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2763, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2762
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
      goto __pyx_L7;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2765
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.9,0.5, 'Null Seed', ha='right', va='center')
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2765, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2765, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L7:;

    /* "revealer/REVEALER_runbenchmark.pyx":2761
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
    goto __pyx_L6;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2767
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 *     else:
 *         ax.text(0.9,0.5, 'Null Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot seed heatmap
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2767, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2767, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__57, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L6:;

  /* "revealer/REVEALER_runbenchmark.pyx":2770
 * 
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,
 *                      xticklabels=False,cbar=False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_154);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__42) < 0) __PYX_ERR(0, 2770, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2770, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2770, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2771
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False,cbar=False)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_seedlists, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 2771, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2771, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2771, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2772
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,
 *                      xticklabels=False,cbar=False)             # <<<<<<<<<<<<<<
 * 
 *     #CIC for seed if seed exists
 */
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2771, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2771, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2771
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False,cbar=False)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2775
 * 
 *     #CIC for seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_154);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__43) < 0) __PYX_ERR(0, 2775, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2775, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2775, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2776
 *     #CIC for seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2777
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:
 */
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = PyFloat_Check(__pyx_t_6); 
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_10 = ((__pyx_t_9 == 1) != 0);
  if (__pyx_t_10) {
  } else {
    __pyx_t_2 = __pyx_t_10;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_10 = ((__pyx_v_if_bootstrap == 1) != 0);
  __pyx_t_2 = __pyx_t_10;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2778
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')             # <<<<<<<<<<<<<<
 *     elif isinstance(CICs[0],float) == True:
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = 0;
    __pyx_t_11 = 127;
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_Format(__pyx_t_5, __pyx_kp_u_3f); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_11;
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u__27);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__27);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u__27);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_bootstraps, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Multiply(__pyx_t_3, __pyx_int_1000); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_3), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_11;
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u__28);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__28);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__28);
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_1, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2778, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2778, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2777
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:
 */
    goto __pyx_L8;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2779
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 * 
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyFloat_Check(__pyx_t_3); 
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_10 = ((__pyx_t_2 == 1) != 0);
  if (__pyx_t_10) {

    /* "revealer/REVEALER_runbenchmark.pyx":2780
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #p-value for this seed if seed exists
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2780, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2780, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2779
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 * 
 */
  }
  __pyx_L8:;

  /* "revealer/REVEALER_runbenchmark.pyx":2783
 * 
 *     #p-value for this seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 122), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if isinstance(pVals[0],float) == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_154);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__58) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2784
 *     #p-value for this seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if isinstance(pVals[0],float) == True:
 *         pval = pVals[0]
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2785
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     if isinstance(pVals[0],float) == True:             # <<<<<<<<<<<<<<
 *         pval = pVals[0]
 *         pvallist = ("%e"%pval).split('e')
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_pVals, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = PyFloat_Check(__pyx_t_3); 
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = ((__pyx_t_10 == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2786
 *     ax.set_axis_off()
 *     if isinstance(pVals[0],float) == True:
 *         pval = pVals[0]             # <<<<<<<<<<<<<<
 *         pvallist = ("%e"%pval).split('e')
 *         ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_pVals, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2786, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_pval = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2787
 *     if isinstance(pVals[0],float) == True:
 *         pval = pVals[0]
 *         pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                 ha='center', va='center')
 */
    __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyUnicode_Split(((PyObject*)__pyx_t_3), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_pvallist = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2788
 *         pval = pVals[0]
 *         pvallist = ("%e"%pval).split('e')
 *         ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                 ha='center', va='center')
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = 0;
    __pyx_t_11 = 127;
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Format(__pyx_t_5, __pyx_kp_u_1f); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_11;
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_kp_u_x_10);
    __pyx_t_1 += 7;
    __Pyx_GIVEREF(__pyx_kp_u_x_10);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_kp_u_x_10);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_11;
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_kp_u__46);
    __pyx_t_1 += 3;
    __Pyx_GIVEREF(__pyx_kp_u__46);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_kp_u__46);
    __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_3, 4, __pyx_t_1, __pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2789
 *         pvallist = ("%e"%pval).split('e')
 *         ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                 ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Blanks
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2789, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2789, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2788
 *         pval = pVals[0]
 *         pvallist = ("%e"%pval).split('e')
 *         ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                 ha='center', va='center')
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2785
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 *     if isinstance(pVals[0],float) == True:             # <<<<<<<<<<<<<<
 *         pval = pVals[0]
 *         pvallist = ("%e"%pval).split('e')
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2792
 * 
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 132), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 144), colspan=10,rowspan=5)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_154);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_tuple__53) < 0) __PYX_ERR(0, 2792, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2792, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2792, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2793
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 144), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2794
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 144), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_int_154);
  __Pyx_GIVEREF(__pyx_int_154);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_154);
  __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__59) < 0) __PYX_ERR(0, 2794, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2794, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2794, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2795
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 144), colspan=10,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 * 
 *     #Loop to plot best feature and new seeds.
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2798
 * 
 *     #Loop to plot best feature and new seeds.
 *     for i in range(1,len(seedids)+1):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2798, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t((__pyx_t_1 + 1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_6 = __pyx_t_3; __Pyx_INCREF(__pyx_t_6); __pyx_t_1 = 0;
    __pyx_t_12 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2798, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_12)) {
      if (likely(PyList_CheckExact(__pyx_t_6))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_1); __Pyx_INCREF(__pyx_t_3); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2798, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_6, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_1); __Pyx_INCREF(__pyx_t_3); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2798, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_6, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_12(__pyx_t_6);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2798, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2801
 * 
 *         #Label name of picked feature in this round
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 0),             # <<<<<<<<<<<<<<
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_13 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_154);
    __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_7, __pyx_int_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_0);
    __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_t_7) < 0) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2801, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2801, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2803
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 0),
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2804
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 */
    __pyx_t_10 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
    __pyx_t_9 = (__pyx_t_10 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_2 = __pyx_t_9;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_t_7, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 2804, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_10 = (__pyx_t_9 != 0);
    __pyx_t_2 = __pyx_t_10;
    __pyx_L15_bool_binop_done:;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2805
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 */
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2805, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2805, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2806
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__44); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__27); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2807
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_notna); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_14);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_14, function);
          }
        }
        __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = PyNumber_Add(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__29); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2808
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *             else:
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_15); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_count); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_4, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2807
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_14 = PyNumber_Add(__pyx_t_5, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2807, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2808
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *             else:
 */
        __pyx_t_15 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__28); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2806
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_15);
        __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2809
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 */
        __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2809, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2809, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2809, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2806
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_14, __pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2805
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 */
        goto __pyx_L17;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2811
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
      /*else*/ {
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_15 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__27); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2812
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_notna); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyNumber_Add(__pyx_t_15, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__29); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2813
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *         else:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        __pyx_t_15 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_count); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        __pyx_t_3 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_15, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2812
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_3 = PyNumber_Add(__pyx_t_14, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2813
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *         else:
 */
        __pyx_t_8 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__28); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2811
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2814
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             if locusdic != None:
 */
        __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2814, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2814, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2814, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2811
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __pyx_L17:;

      /* "revealer/REVEALER_runbenchmark.pyx":2804
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 */
      goto __pyx_L14;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2816
 *                     ha='right', va='center')
 *         else:
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
    /*else*/ {
      __pyx_t_14 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2816, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2816, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2817
 *         else:
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__44); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Add(__pyx_t_8, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__27); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2818
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *             else:
 */
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_15, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_count); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__28); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2817
 *         else:
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2819
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 */
        __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2819, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2819, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2819, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2817
 *         else:
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2816
 *                     ha='right', va='center')
 *         else:
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        goto __pyx_L18;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2821
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__27); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2822
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 * 
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_15); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_14 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_count); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_5 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_14, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2821
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2822
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 * 
 */
        __pyx_t_15 = PyNumber_Add(__pyx_t_5, __pyx_kp_u__28); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2821
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_15);
        __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2823
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Plot heatmap for best feature
 */
        __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2823, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":2821
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L18:;
    }
    __pyx_L14:;

    /* "revealer/REVEALER_runbenchmark.pyx":2826
 * 
 *         #Plot heatmap for best feature
 *         reportdf.loc[seedids[i-1]] = plotcomb.loc[seedids[i-1]].tolist()             # <<<<<<<<<<<<<<
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 20),
 *                               colspan=90,rowspan=5)
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_15, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(PyObject_SetItem(__pyx_t_3, __pyx_t_15, __pyx_t_4) < 0)) __PYX_ERR(0, 2826, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2827
 *         #Plot heatmap for best feature
 *         reportdf.loc[seedids[i-1]] = plotcomb.loc[seedids[i-1]].tolist()
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 20),             # <<<<<<<<<<<<<<
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_13 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_154);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_5, __pyx_int_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_int_20);
    __Pyx_GIVEREF(__pyx_int_20);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_20);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_t_5) < 0) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2827, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2827, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2829
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                          cmap=featurecmap,annot=False,yticklabels=False, xticklabels=False,cbar=False)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_8); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_tolist); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_16);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_16, function);
      }
    }
    __pyx_t_3 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyList_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_3);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_15 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_3, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_astype); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_15)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_15);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_5 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_15, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_14, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2830
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),
 *                          cmap=featurecmap,annot=False,yticklabels=False, xticklabels=False,cbar=False)             # <<<<<<<<<<<<<<
 * 
 *         #Label CIC for this feature
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 2830, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2830, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2830, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2830, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2830, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2829
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                          cmap=featurecmap,annot=False,yticklabels=False, xticklabels=False,cbar=False)
 * 
 */
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_14, __pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2833
 * 
 *         #Label CIC for this feature
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 132),             # <<<<<<<<<<<<<<
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_plt); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_14);
    __pyx_t_13 = PyObject_Length(__pyx_t_14); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_154);
    __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = PyNumber_Multiply(__pyx_t_4, __pyx_int_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_int_132);
    __Pyx_GIVEREF(__pyx_int_132);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_132);
    __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_loc, __pyx_t_4) < 0) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2833, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2833, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2833, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2835
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 132),
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1], int(1000*bootstraps[(i-1)*2+1])),
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2836
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1], int(1000*bootstraps[(i-1)*2+1])),
 *                     ha = 'center', va = 'center', color = 'blue')
 */
    __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2837
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1], int(1000*bootstraps[(i-1)*2+1])),             # <<<<<<<<<<<<<<
 *                     ha = 'center', va = 'center', color = 'blue')
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_15 = PyTuple_New(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = PyNumber_Multiply(__pyx_t_5, __pyx_int_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_14, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Format(__pyx_t_14, __pyx_kp_u_3f); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u__27);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__27);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_kp_u__27);
      __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = PyNumber_Multiply(__pyx_t_5, __pyx_int_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_14, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_14), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u__28);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__28);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_kp_u__28);
      __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_15, 4, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2838
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1], int(1000*bootstraps[(i-1)*2+1])),
 *                     ha = 'center', va = 'center', color = 'blue')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+1]), ha='center', va='center',color = 'blue')
 */
      __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2838, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2838, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2838, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2837
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1], int(1000*bootstraps[(i-1)*2+1])),             # <<<<<<<<<<<<<<
 *                     ha = 'center', va = 'center', color = 'blue')
 *         else:
 */
      __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_15, __pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2836
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1], int(1000*bootstraps[(i-1)*2+1])),
 *                     ha = 'center', va = 'center', color = 'blue')
 */
      goto __pyx_L19;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2840
 *                     ha = 'center', va = 'center', color = 'blue')
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+1]), ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 * 
 *         #Label p-value for picked feature
 */
    /*else*/ {
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_15 = PyNumber_Multiply(__pyx_t_5, __pyx_int_2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_15, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2840, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2840, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2840, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_15, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2840, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L19:;

    /* "revealer/REVEALER_runbenchmark.pyx":2843
 * 
 *         #Label p-value for picked feature
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 144),             # <<<<<<<<<<<<<<
 *                               colspan=10,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_15);
    __pyx_t_13 = PyObject_Length(__pyx_t_15); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_int_154);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_14) < 0) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = PyNumber_Multiply(__pyx_t_14, __pyx_int_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_144);
    __Pyx_GIVEREF(__pyx_int_144);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_int_144);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_t_14) < 0) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2843, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2843, __pyx_L1_error)
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_14);
    __pyx_t_14 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2845
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2)*5, 144),
 *                               colspan=10,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         pval = pVals[(i-1)*2+1]
 *         if pval > 1:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_14 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2846
 *                               colspan=10,rowspan=5)
 *         ax.set_axis_off()
 *         pval = pVals[(i-1)*2+1]             # <<<<<<<<<<<<<<
 *         if pval > 1:
 *             pval = float(1)/float(pval)
 */
    __pyx_t_14 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_14, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pVals, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pval, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2847
 *         ax.set_axis_off()
 *         pval = pVals[(i-1)*2+1]
 *         if pval > 1:             # <<<<<<<<<<<<<<
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_pval, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2847, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2847, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2848
 *         pval = pVals[(i-1)*2+1]
 *         if pval > 1:
 *             pval = float(1)/float(pval)             # <<<<<<<<<<<<<<
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),ha = 'center',
 */
      __pyx_t_17 = __Pyx_PyObject_AsDouble(__pyx_int_1); if (unlikely(__pyx_t_17 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2848, __pyx_L1_error)
      __pyx_t_18 = __Pyx_PyObject_AsDouble(__pyx_v_pval); if (unlikely(__pyx_t_18 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2848, __pyx_L1_error)
      if (unlikely(__pyx_t_18 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 2848, __pyx_L1_error)
      }
      __pyx_t_4 = PyFloat_FromDouble((__pyx_t_17 / __pyx_t_18)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2848, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_pval, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2849
 *         if pval > 1:
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),ha = 'center',
 *                     va = 'center',color = 'blue')
 */
      __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = PyUnicode_Split(((PyObject*)__pyx_t_4), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_pvallist, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2850
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),ha = 'center',             # <<<<<<<<<<<<<<
 *                     va = 'center',color = 'blue')
 *         else:
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __Pyx_INCREF(__pyx_kp_u__45);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__45);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u__45);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_15 = __Pyx_PyNumber_Float(__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Format(__pyx_t_15, __pyx_kp_u_1f); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u_x_10);
      __pyx_t_13 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_x_10);
      PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u_x_10);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_15 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_15), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u__46);
      __pyx_t_13 += 3;
      __Pyx_GIVEREF(__pyx_kp_u__46);
      PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_kp_u__46);
      __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_4, 5, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2850, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2850, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2850, __pyx_L1_error)
      __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2847
 *         ax.set_axis_off()
 *         pval = pVals[(i-1)*2+1]
 *         if pval > 1:             # <<<<<<<<<<<<<<
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 */
      goto __pyx_L20;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2853
 *                     va = 'center',color = 'blue')
 *         else:
 *             pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),ha = 'center',
 *                     va = 'center',color = 'blue')
 */
    /*else*/ {
      __pyx_t_15 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_5 = PyUnicode_Split(((PyObject*)__pyx_t_15), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF_SET(__pyx_v_pvallist, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2854
 *         else:
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),ha = 'center',             # <<<<<<<<<<<<<<
 *                     va = 'center',color = 'blue')
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_15 = PyTuple_New(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Format(__pyx_t_14, __pyx_kp_u_1f); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_kp_u_x_10);
      __pyx_t_13 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_x_10);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_kp_u_x_10);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_14), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_kp_u__46);
      __pyx_t_13 += 3;
      __Pyx_GIVEREF(__pyx_kp_u__46);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_kp_u__46);
      __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_15, 4, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2854, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2854, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2854, __pyx_L1_error)
      __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_15, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    }
    __pyx_L20:;

    /* "revealer/REVEALER_runbenchmark.pyx":2858
 * 
 *         #Label for new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 0),             # <<<<<<<<<<<<<<
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_plt); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_15);
    __pyx_t_13 = PyObject_Length(__pyx_t_15); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_154);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_15 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Multiply(__pyx_t_15, __pyx_int_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_5);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_int_0);
    __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_loc, __pyx_t_15) < 0) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2858, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2858, __pyx_L1_error)
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2860
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 0),
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         ax.text(0.9,0.5,'New Seed', ha='right', va='center')
 * 
 */
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_15 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2860, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2861
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         ax.text(0.9,0.5,'New Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Put new seed to report
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2861, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2861, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_tuple__60, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2864
 * 
 *         #Put new seed to report
 *         reportdf.loc['New Seed'+str(i)] = seedlists[i]             # <<<<<<<<<<<<<<
 * 
 *         #Plot heatmap for new seed
 */
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_seedlists, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_i); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_kp_u_New_Seed, __pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(PyObject_SetItem(__pyx_t_14, __pyx_t_5, __pyx_t_4) < 0)) __PYX_ERR(0, 2864, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2867
 * 
 *         #Plot heatmap for new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 20),             # <<<<<<<<<<<<<<
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_14);
    __pyx_t_13 = PyObject_Length(__pyx_t_14); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_int_154);
    __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_15) < 0) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_t_15, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyNumber_Multiply(__pyx_t_14, __pyx_int_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_20);
    __Pyx_GIVEREF(__pyx_int_20);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_int_20);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_t_14) < 0) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2867, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2867, __pyx_L1_error)
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_14);
    __pyx_t_14 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2869
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                          xticklabels=False,cbar=False)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_sns); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_array); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_seedlists, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_16 = PyList_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_5);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_14 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_5, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyTuple_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14);
    __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 2869, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2869, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2869, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2870
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,
 *                          xticklabels=False,cbar=False)             # <<<<<<<<<<<<<<
 * 
 *         #Label IC for new seed
 */
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2869, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2869, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":2869
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                          xticklabels=False,cbar=False)
 * 
 */
    __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_15, __pyx_t_14); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_16);
    __pyx_t_16 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2873
 * 
 *         #Label IC for new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 110),             # <<<<<<<<<<<<<<
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_plt); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_15 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_15);
    __pyx_t_13 = PyObject_Length(__pyx_t_15); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_154);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_15, __pyx_int_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_int_110);
    __Pyx_GIVEREF(__pyx_int_110);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_int_110);
    __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_loc, __pyx_t_15) < 0) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2873, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2873, __pyx_L1_error)
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_empty_tuple, __pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2875
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 110),
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 */
    __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_16);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_16, function);
      }
    }
    __pyx_t_15 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2876
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 *                     ha='center', va='center')
 */
    __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2877
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 *         else:
 */
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = PyTuple_New(4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __pyx_t_14 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = PyNumber_Multiply(__pyx_t_14, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_Format(__pyx_t_4, __pyx_kp_u_3f); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u__27);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__27);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_kp_u__27);
      __pyx_t_14 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = PyNumber_Multiply(__pyx_t_14, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u__28);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__28);
      PyTuple_SET_ITEM(__pyx_t_16, 3, __pyx_kp_u__28);
      __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_16, 4, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2878
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 *                     ha='center', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+2]), ha='center', va='center')
 */
      __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2878, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2878, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2878, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2877
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_16, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2876
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 *                     ha='center', va='center')
 */
      goto __pyx_L21;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2880
 *                     ha='center', va='center')
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+2]), ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Label p-value for new seed
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_16 = PyNumber_Multiply(__pyx_t_14, __pyx_int_2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_t_16, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_14); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_16); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_14);
      __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2880, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2880, __pyx_L1_error)
      __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_16, __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    }
    __pyx_L21:;

    /* "revealer/REVEALER_runbenchmark.pyx":2883
 * 
 *         #Label p-value for new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 122),             # <<<<<<<<<<<<<<
 *                               colspan=10,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_plt); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_16 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_16);
    __pyx_t_13 = PyObject_Length(__pyx_t_16); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_16);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_16);
    __Pyx_INCREF(__pyx_int_154);
    __Pyx_GIVEREF(__pyx_int_154);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_154);
    __pyx_t_16 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_16 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_16, __pyx_int_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyTuple_New(2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_int_122);
    __Pyx_GIVEREF(__pyx_int_122);
    PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_int_122);
    __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_loc, __pyx_t_16) < 0) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_colspan, __pyx_int_10) < 0) __PYX_ERR(0, 2883, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2883, __pyx_L1_error)
    __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_empty_tuple, __pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_16);
    __pyx_t_16 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2885
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(((i)*2+1)*5, 122),
 *                               colspan=10,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         pval = pVals[(i-1)*2+2]
 *         if pval > 1:
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_16 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2886
 *                               colspan=10,rowspan=5)
 *         ax.set_axis_off()
 *         pval = pVals[(i-1)*2+2]             # <<<<<<<<<<<<<<
 *         if pval > 1:
 *             pval = float(1)/float(pval)
 */
    __pyx_t_16 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_15 = PyNumber_Multiply(__pyx_t_16, __pyx_int_2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = __Pyx_PyInt_AddObjC(__pyx_t_15, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_v_pVals, __pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF_SET(__pyx_v_pval, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2887
 *         ax.set_axis_off()
 *         pval = pVals[(i-1)*2+2]
 *         if pval > 1:             # <<<<<<<<<<<<<<
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 */
    __pyx_t_15 = PyObject_RichCompare(__pyx_v_pval, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_15); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_15); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2888
 *         pval = pVals[(i-1)*2+2]
 *         if pval > 1:
 *             pval = float(1)/float(pval)             # <<<<<<<<<<<<<<
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 */
      __pyx_t_18 = __Pyx_PyObject_AsDouble(__pyx_int_1); if (unlikely(__pyx_t_18 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2888, __pyx_L1_error)
      __pyx_t_17 = __Pyx_PyObject_AsDouble(__pyx_v_pval); if (unlikely(__pyx_t_17 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2888, __pyx_L1_error)
      if (unlikely(__pyx_t_17 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 2888, __pyx_L1_error)
      }
      __pyx_t_15 = PyFloat_FromDouble((__pyx_t_18 / __pyx_t_17)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF_SET(__pyx_v_pval, __pyx_t_15);
      __pyx_t_15 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2889
 *         if pval > 1:
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                     ha='center', va='center')
 */
      __pyx_t_15 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = PyUnicode_Split(((PyObject*)__pyx_t_15), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF_SET(__pyx_v_pvallist, __pyx_t_16);
      __pyx_t_16 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2890
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 *         else:
 */
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_15 = PyTuple_New(5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __Pyx_INCREF(__pyx_kp_u__45);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__45);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u__45);
      __pyx_t_14 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = __Pyx_PyNumber_Float(__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_Format(__pyx_t_4, __pyx_kp_u_1f); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_x_10);
      __pyx_t_13 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_x_10);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_kp_u_x_10);
      __pyx_t_14 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u__46);
      __pyx_t_13 += 3;
      __Pyx_GIVEREF(__pyx_kp_u__46);
      PyTuple_SET_ITEM(__pyx_t_15, 4, __pyx_kp_u__46);
      __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_15, 5, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2891
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                     ha='center', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             pvallist = ("%e"%pval).split('e')
 */
      __pyx_t_14 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2891, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2891, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2890
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"<%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_15, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2887
 *         ax.set_axis_off()
 *         pval = pVals[(i-1)*2+2]
 *         if pval > 1:             # <<<<<<<<<<<<<<
 *             pval = float(1)/float(pval)
 *             pvallist = ("%e"%pval).split('e')
 */
      goto __pyx_L22;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2893
 *                     ha='center', va='center')
 *         else:
 *             pvallist = ("%e"%pval).split('e')             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                     ha='center', va='center')
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_e, __pyx_v_pval); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = PyUnicode_Split(((PyObject*)__pyx_t_4), __pyx_n_u_e_2, -1L); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_pvallist, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2894
 *         else:
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 * 
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __pyx_t_15 = __Pyx_GetItemInt(__pyx_v_pvallist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = __Pyx_PyNumber_Float(__pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_Format(__pyx_t_16, __pyx_kp_u_1f); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_15);
      __Pyx_GIVEREF(__pyx_t_15);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_15);
      __pyx_t_15 = 0;
      __Pyx_INCREF(__pyx_kp_u_x_10);
      __pyx_t_13 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_x_10);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u_x_10);
      __pyx_t_15 = __Pyx_GetItemInt(__pyx_v_pvallist, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = __Pyx_PyNumber_Int(__pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_16), __pyx_empty_unicode); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_15);
      __Pyx_GIVEREF(__pyx_t_15);
      PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_15);
      __pyx_t_15 = 0;
      __Pyx_INCREF(__pyx_kp_u__46);
      __pyx_t_13 += 3;
      __Pyx_GIVEREF(__pyx_kp_u__46);
      PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__46);
      __pyx_t_15 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_15);
      PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_15);
      __pyx_t_15 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2895
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),
 *                     ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Save plot
 */
      __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2895, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2895, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2895, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":2894
 *         else:
 *             pvallist = ("%e"%pval).split('e')
 *             ax.text(0.5,0.5,"%.1fx${10^{%s}}$"%(float(pvallist[0]),int(pvallist[1])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 * 
 */
      __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_4, __pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    }
    __pyx_L22:;

    /* "revealer/REVEALER_runbenchmark.pyx":2798
 * 
 *     #Loop to plot best feature and new seeds.
 *     for i in range(1,len(seedids)+1):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2898
 * 
 *     #Save plot
 *     plt.savefig(out_folder + prefix+'_Result.'+figure_format,format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_savefig); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_15 = PyNumber_Add(__pyx_t_6, __pyx_kp_u_Result); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_15, __pyx_v_figure_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = PyTuple_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 2898, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_15, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2899
 *     #Save plot
 *     plt.savefig(out_folder + prefix+'_Result.'+figure_format,format=figure_format)
 *     plt.close()             # <<<<<<<<<<<<<<
 * 
 *     #Set new line of gene locus  to ,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_close); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2902
 * 
 *     #Set new line of gene locus  to ,
 *     reportdf.index = reportdf.index.str.replace("\n", ",")             # <<<<<<<<<<<<<<
 * 
 *     #Adjust length of CIC/IC
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_replace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_reportdf, __pyx_n_s_index, __pyx_t_15) < 0) __PYX_ERR(0, 2902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2905
 * 
 *     #Adjust length of CIC/IC
 *     reportdf['CICs'] = [''] + CICs             # <<<<<<<<<<<<<<
 * 
 *     #Put bootstrap and p-values to report
 */
  __pyx_t_15 = PyList_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_INCREF(__pyx_kp_u__2);
  __Pyx_GIVEREF(__pyx_kp_u__2);
  PyList_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u__2);
  __pyx_t_4 = PyNumber_Add(__pyx_t_15, __pyx_v_CICs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(PyObject_SetItem(__pyx_v_reportdf, __pyx_n_u_CICs, __pyx_t_4) < 0)) __PYX_ERR(0, 2905, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2908
 * 
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2909
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):             # <<<<<<<<<<<<<<
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2909, __pyx_L1_error)
    __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_15)) || PyTuple_CheckExact(__pyx_t_15)) {
      __pyx_t_4 = __pyx_t_15; __Pyx_INCREF(__pyx_t_4); __pyx_t_1 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_1 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_12 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2909, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_15 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_15); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2909, __pyx_L1_error)
          #else
          __pyx_t_15 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2909, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_15);
          #endif
        } else {
          if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_15 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_15); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 2909, __pyx_L1_error)
          #else
          __pyx_t_15 = PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2909, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_15);
          #endif
        }
      } else {
        __pyx_t_15 = __pyx_t_12(__pyx_t_4);
        if (unlikely(!__pyx_t_15)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2909, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_15);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_15);
      __pyx_t_15 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2910
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':             # <<<<<<<<<<<<<<
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps
 */
      __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2910, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_kp_u__2, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2910, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      if (__pyx_t_2) {

        /* "revealer/REVEALER_runbenchmark.pyx":2911
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]             # <<<<<<<<<<<<<<
 *         reportdf['bootstrap'] = [''] + bootstraps
 *     reportdf['pVals'] = [''] + pVals
 */
        __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2911, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_6 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_15); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2911, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_bootstraps, __pyx_v_i, __pyx_t_6) < 0)) __PYX_ERR(0, 2911, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":2910
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':             # <<<<<<<<<<<<<<
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":2909
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):             # <<<<<<<<<<<<<<
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2912
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps             # <<<<<<<<<<<<<<
 *     reportdf['pVals'] = [''] + pVals
 * 
 */
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_kp_u__2);
    __Pyx_GIVEREF(__pyx_kp_u__2);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u__2);
    __pyx_t_6 = PyNumber_Add(__pyx_t_4, __pyx_v_bootstraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(PyObject_SetItem(__pyx_v_reportdf, __pyx_n_u_bootstrap, __pyx_t_6) < 0)) __PYX_ERR(0, 2912, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2908
 * 
 *     #Put bootstrap and p-values to report
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2913
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps
 *     reportdf['pVals'] = [''] + pVals             # <<<<<<<<<<<<<<
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):
 */
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_kp_u__2);
  __Pyx_GIVEREF(__pyx_kp_u__2);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u__2);
  __pyx_t_4 = PyNumber_Add(__pyx_t_6, __pyx_v_pVals); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(PyObject_SetItem(__pyx_v_reportdf, __pyx_n_u_pVals, __pyx_t_4) < 0)) __PYX_ERR(0, 2913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2915
 *     reportdf['pVals'] = [''] + pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */
  __pyx_t_10 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
  __pyx_t_9 = (__pyx_t_10 != 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_2 = __pyx_t_9;
    goto __pyx_L28_bool_binop_done;
  }
  __pyx_t_4 = __pyx_pf_8revealer_21REVEALER_runbenchmark_18saveresfigWithPval_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_Generator_Next(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_6, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_9;
  __pyx_L28_bool_binop_done:;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2916
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)             # <<<<<<<<<<<<<<
 * 
 *     #Save report
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_cur_scope->__pyx_v_seedids); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_15 = PyNumber_Add(__pyx_t_6, __pyx_kp_u_Result_gmt); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_15);
    __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 2916, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_header, Py_False) < 0) __PYX_ERR(0, 2916, __pyx_L1_error)
    __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, __pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2915
 *     reportdf['pVals'] = [''] + pVals
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2919
 * 
 *     #Save report
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')             # <<<<<<<<<<<<<<
 * 
 * def saveresfig(
 */
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_15 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_6 = PyNumber_Add(__pyx_t_15, __pyx_kp_u_Result_txt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = PyTuple_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 2919, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_15, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2687
 * 
 * 
 * def saveresfigWithPval(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.saveresfigWithPval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_reportdf);
  __Pyx_XDECREF(__pyx_v_fig);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XDECREF(__pyx_v_pval);
  __Pyx_XDECREF(__pyx_v_pvallist);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2921
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def saveresfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_63saveresfig(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_62saveresfig[] = "\n    Function to save result summary figure without p-values. \n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_63saveresfig = {"saveresfig", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_63saveresfig, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_62saveresfig};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_63saveresfig(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_plotcomb = 0;
  PyObject *__pyx_v_seedids = 0;
  PyObject *__pyx_v_CICs = 0;
  PyObject *__pyx_v_seedlists = 0;
  PyObject *__pyx_v_seedcmap = 0;
  PyObject *__pyx_v_featurecmap = 0;
  PyObject *__pyx_v_prefix = 0;
  PyObject *__pyx_v_figure_format = 0;
  PyObject *__pyx_v_bootstraps = 0;
  PyObject *__pyx_v_out_folder = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_locusdic = 0;
  PyObject *__pyx_v_gmt = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("saveresfig (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_plotcomb,&__pyx_n_s_seedids,&__pyx_n_s_CICs,&__pyx_n_s_seedlists,&__pyx_n_s_seedcmap,&__pyx_n_s_featurecmap,&__pyx_n_s_prefix,&__pyx_n_s_figure_format,&__pyx_n_s_bootstraps,&__pyx_n_s_out_folder,&__pyx_n_s_target_name,&__pyx_n_s_seed_name,&__pyx_n_s_locusdic,&__pyx_n_s_gmt,0};
    PyObject* values[14] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_plotcomb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedids)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 1); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_CICs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 2); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedlists)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 3); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seedcmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 4); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_featurecmap)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 5); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_prefix)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 6); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_figure_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 7); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bootstraps)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 8); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_out_folder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 9); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 10); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 11); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_locusdic)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 12); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gmt)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, 13); __PYX_ERR(0, 2921, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "saveresfig") < 0)) __PYX_ERR(0, 2921, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 14) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
    }
    __pyx_v_plotcomb = values[0];
    __pyx_v_seedids = values[1];
    __pyx_v_CICs = values[2];
    __pyx_v_seedlists = values[3];
    __pyx_v_seedcmap = values[4];
    __pyx_v_featurecmap = values[5];
    __pyx_v_prefix = values[6];
    __pyx_v_figure_format = values[7];
    __pyx_v_bootstraps = values[8];
    __pyx_v_out_folder = values[9];
    __pyx_v_target_name = values[10];
    __pyx_v_seed_name = values[11];
    __pyx_v_locusdic = values[12];
    __pyx_v_gmt = values[13];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("saveresfig", 1, 14, 14, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2921, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.saveresfig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_62saveresfig(__pyx_self, __pyx_v_plotcomb, __pyx_v_seedids, __pyx_v_CICs, __pyx_v_seedlists, __pyx_v_seedcmap, __pyx_v_featurecmap, __pyx_v_prefix, __pyx_v_figure_format, __pyx_v_bootstraps, __pyx_v_out_folder, __pyx_v_target_name, __pyx_v_seed_name, __pyx_v_locusdic, __pyx_v_gmt);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_10saveresfig_2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "revealer/REVEALER_runbenchmark.pyx":3100
 *         reportdf['bootstrap'] = [''] + bootstraps
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_10saveresfig_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3100, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8revealer_21REVEALER_runbenchmark_10saveresfig_2generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_saveresfig_locals_genexpr, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!gen)) __PYX_ERR(0, 3100, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.saveresfig.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8revealer_21REVEALER_runbenchmark_10saveresfig_2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *__pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3100, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids)) { __Pyx_RaiseClosureNameError("seedids"); __PYX_ERR(0, 3100, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_seedids); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3100, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 3100, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3100, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 3100, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3100, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3100, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_elem);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_elem, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt)) { __Pyx_RaiseClosureNameError("gmt"); __PYX_ERR(0, 3100, __pyx_L1_error) }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_elem, __pyx_t_4, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3100, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = ((!(__pyx_t_7 != 0)) != 0);
    if (__pyx_t_8) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":2921
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def saveresfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_62saveresfig(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_plotcomb, PyObject *__pyx_v_seedids, PyObject *__pyx_v_CICs, PyObject *__pyx_v_seedlists, PyObject *__pyx_v_seedcmap, PyObject *__pyx_v_featurecmap, PyObject *__pyx_v_prefix, PyObject *__pyx_v_figure_format, PyObject *__pyx_v_bootstraps, PyObject *__pyx_v_out_folder, PyObject *__pyx_v_target_name, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_locusdic, PyObject *__pyx_v_gmt) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *__pyx_cur_scope;
  int __pyx_v_if_bootstrap;
  PyObject *__pyx_v_reportdf = NULL;
  PyObject *__pyx_v_fig = NULL;
  PyObject *__pyx_v_ax = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_UCS4 __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  Py_ssize_t __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("saveresfig", 0);
  __pyx_cur_scope = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *)__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig(__pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2921, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_seedids = __pyx_v_seedids;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_seedids);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_seedids);
  __pyx_cur_scope->__pyx_v_gmt = __pyx_v_gmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_gmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_gmt);

  /* "revealer/REVEALER_runbenchmark.pyx":2943
 * 
 *     #Check if bootstrap value is calculated
 *     if_bootstrap = False             # <<<<<<<<<<<<<<
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True
 */
  __pyx_v_if_bootstrap = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2944
 *     #Check if bootstrap value is calculated
 *     if_bootstrap = False
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 * 
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2944, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2945
 *     if_bootstrap = False
 *     if len(bootstraps) != 0:
 *         if_bootstrap = True             # <<<<<<<<<<<<<<
 * 
 *     #Create dataframe to write down report
 */
    __pyx_v_if_bootstrap = 1;

    /* "revealer/REVEALER_runbenchmark.pyx":2944
 *     #Check if bootstrap value is calculated
 *     if_bootstrap = False
 *     if len(bootstraps) != 0:             # <<<<<<<<<<<<<<
 *         if_bootstrap = True
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2948
 * 
 *     #Create dataframe to write down report
 *     reportdf = pd.DataFrame(columns=plotcomb.columns.tolist())             # <<<<<<<<<<<<<<
 * 
 *     #Prepare canvas for result figure
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_reportdf = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2951
 * 
 *     #Prepare canvas for result figure
 *     fig = plt.figure()             # <<<<<<<<<<<<<<
 *     fig.set_figheight(len(seedids)+1)
 *     fig.set_figwidth(13.4)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_figure); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_fig = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2952
 *     #Prepare canvas for result figure
 *     fig = plt.figure()
 *     fig.set_figheight(len(seedids)+1)             # <<<<<<<<<<<<<<
 *     fig.set_figwidth(13.4)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figheight); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t((__pyx_t_1 + 1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2953
 *     fig = plt.figure()
 *     fig.set_figheight(len(seedids)+1)
 *     fig.set_figwidth(13.4)             # <<<<<<<<<<<<<<
 * 
 *     #Add Target row for report
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fig, __pyx_n_s_set_figwidth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, __pyx_float_13_4) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_float_13_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2956
 * 
 *     #Add Target row for report
 *     reportdf.loc['Target'] = plotcomb.iloc[0].tolist()             # <<<<<<<<<<<<<<
 * 
 *     #Target name at left of target heatmap
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(PyObject_SetItem(__pyx_t_4, __pyx_n_u_Target_2, __pyx_t_5) < 0)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2959
 * 
 *     #Target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_134);
  __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_tuple__25) < 0) __PYX_ERR(0, 2959, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2959, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2959, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_ax = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2960
 *     #Target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2961
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot heatmap for target
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_target_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Target, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_float_0_9);
  __Pyx_GIVEREF(__pyx_float_0_9);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
  __Pyx_INCREF(__pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_float_0_5);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2961, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2961, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2964
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_134);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__26) < 0) __PYX_ERR(0, 2964, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2964, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2964, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2965
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_sns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_int_0);
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_numpy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cmap, __pyx_n_u_bwr) < 0) __PYX_ERR(0, 2965, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2965, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2965, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2966
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())             # <<<<<<<<<<<<<<
 * 
 *     #Label for IC and CIC on right of target heatmap.
 */
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2965, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2965, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_mean); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_center, __pyx_t_6) < 0) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2965
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2969
 * 
 *     #Label for IC and CIC on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_134);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_tuple__34) < 0) __PYX_ERR(0, 2969, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2969, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2969, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2970
 *     #Label for IC and CIC on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2971
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2972
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2972, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2972, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__54, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2971
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 */
    goto __pyx_L4;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2974
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 122), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2974, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2974, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__55, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "revealer/REVEALER_runbenchmark.pyx":2975
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 122), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_plt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_134);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loc, __pyx_tuple__37) < 0) __PYX_ERR(0, 2975, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 2975, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2975, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2976
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 122), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2977
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 122), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2978
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2978, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2978, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2978, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__35, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":2977
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(0, 122), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 *     else:
 */
    goto __pyx_L5;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2980
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center',color = 'blue')
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 * 
 *     #Add seed row for report
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 2980, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2980, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 2980, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__36, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L5:;

  /* "revealer/REVEALER_runbenchmark.pyx":2983
 * 
 *     #Add seed row for report
 *     reportdf.loc['Seed'] = seedlists[0]             # <<<<<<<<<<<<<<
 * 
 *     #Label Seed name at left of seed heatmap
 */
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_seedlists, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(PyObject_SetItem(__pyx_t_3, __pyx_n_u_Seed_2, __pyx_t_5) < 0)) __PYX_ERR(0, 2983, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2986
 * 
 *     #Label Seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if seed_name != None:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_1 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_134);
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_tuple__39) < 0) __PYX_ERR(0, 2986, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 2986, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2986, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2987
 *     #Label Seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2988
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
  __pyx_t_7 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2988, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":2989
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_seed_name); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2989, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_1 > 1) != 0);
    if (__pyx_t_2) {

      /* "revealer/REVEALER_runbenchmark.pyx":2990
 *     if seed_name != None:
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_5, __pyx_kp_u__40); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2990, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2990, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":2989
 *     ax.set_axis_off()
 *     if seed_name != None:
 *         if len(seed_name) > 1:             # <<<<<<<<<<<<<<
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 */
      goto __pyx_L7;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":2992
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 *         else:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')
 */
    /*else*/ {
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Seed, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_float_0_9);
      __Pyx_GIVEREF(__pyx_float_0_9);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_float_0_9);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2992, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2992, __pyx_L1_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_L7:;

    /* "revealer/REVEALER_runbenchmark.pyx":2988
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 0), colspan=20,rowspan=5)
 *     ax.set_axis_off()
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         if len(seed_name) > 1:
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0])+',...', ha='right', va='center')
 */
    goto __pyx_L6;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":2994
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot seed heatmap
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 2994, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 2994, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__41, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L6:;

  /* "revealer/REVEALER_runbenchmark.pyx":2997
 * 
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,
 *                      xticklabels=False,cbar=False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_134);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_tuple__42) < 0) __PYX_ERR(0, 2997, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 2997, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 2997, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2998
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False,cbar=False)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_sns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_seedlists, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 2998, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 2998, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 2998, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2999
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,
 *                      xticklabels=False,cbar=False)             # <<<<<<<<<<<<<<
 * 
 *     #CIC for seed if seed exists
 */
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 2998, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 2998, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2998
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 20), colspan=90,rowspan=5)
 *     ax = sns.heatmap(np.array([seedlists[0]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                      xticklabels=False,cbar=False)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3002
 * 
 *     #CIC for seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_134);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_5) < 0) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_tuple__43) < 0) __PYX_ERR(0, 3002, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 3002, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3002, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3003
 *     #CIC for seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3004
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:
 */
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_9 = PyFloat_Check(__pyx_t_5); 
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_10 = ((__pyx_t_9 == 1) != 0);
  if (__pyx_t_10) {
  } else {
    __pyx_t_2 = __pyx_t_10;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_10 = ((__pyx_v_if_bootstrap == 1) != 0);
  __pyx_t_2 = __pyx_t_10;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_2) {

    /* "revealer/REVEALER_runbenchmark.pyx":3005
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')             # <<<<<<<<<<<<<<
 *     elif isinstance(CICs[0],float) == True:
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = 0;
    __pyx_t_11 = 127;
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_Format(__pyx_t_6, __pyx_kp_u_3f); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_11;
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u__27);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__27);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u__27);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_bootstraps, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyNumber_Multiply(__pyx_t_7, __pyx_int_1000); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_11;
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u__28);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__28);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__28);
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_1, __pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 3005, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3005, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3004
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 110), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:
 */
    goto __pyx_L8;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3006
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 122), colspan=12,rowspan=5)
 */
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyFloat_Check(__pyx_t_7); 
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_10 = ((__pyx_t_2 == 1) != 0);
  if (__pyx_t_10) {

    /* "revealer/REVEALER_runbenchmark.pyx":3007
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 122), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_CICs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_float_0_5);
    __Pyx_INCREF(__pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_float_0_5);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_float_0_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 3007, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3007, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3006
 *     if isinstance(CICs[0],float) == True and if_bootstrap == True:
 *         ax.text(0.5,0.5,"%.3f(%s)"%(CICs[0], int(bootstraps[0]*1000)), ha='center', va='center')
 *     elif isinstance(CICs[0],float) == True:             # <<<<<<<<<<<<<<
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 122), colspan=12,rowspan=5)
 */
  }
  __pyx_L8:;

  /* "revealer/REVEALER_runbenchmark.pyx":3008
 *     elif isinstance(CICs[0],float) == True:
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 122), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_1 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyInt_FromSsize_t(((5 * (__pyx_t_1 + 1)) * 2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __Pyx_INCREF(__pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_int_134);
  __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shape, __pyx_t_7) < 0) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loc, __pyx_tuple__58) < 0) __PYX_ERR(0, 3008, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 3008, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3008, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3009
 *         ax.text(0.5,0.5,"%.3f"%(CICs[0]), ha='center', va='center')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(5, 122), colspan=12,rowspan=5)
 *     ax.set_axis_off()             # <<<<<<<<<<<<<<
 * 
 *     #Loop to plot best feature and new seeds.
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3012
 * 
 *     #Loop to plot best feature and new seeds.
 *     for i in range(1,len(seedids)+1):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  __pyx_t_7 = __pyx_cur_scope->__pyx_v_seedids;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_1 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3012, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyInt_FromSsize_t((__pyx_t_1 + 1)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
    __pyx_t_5 = __pyx_t_7; __Pyx_INCREF(__pyx_t_5); __pyx_t_1 = 0;
    __pyx_t_12 = NULL;
  } else {
    __pyx_t_1 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_12 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3012, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  for (;;) {
    if (likely(!__pyx_t_12)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 3012, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_5, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3012, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_1); __Pyx_INCREF(__pyx_t_7); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 3012, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_5, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3012, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_12(__pyx_t_5);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3012, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3015
 * 
 *         #Label name of picked feature in this round
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 0),             # <<<<<<<<<<<<<<
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_plt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_13 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_int_134);
    __Pyx_GIVEREF(__pyx_int_134);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_134);
    __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_shape, __pyx_t_3) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_int_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
    __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_loc, __pyx_t_3) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3017
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 0),
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3018
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 */
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
    __pyx_t_9 = (__pyx_t_2 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_10 = __pyx_t_9;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_t_7, __pyx_t_3, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = (__pyx_t_9 != 0);
    __pyx_t_10 = __pyx_t_2;
    __pyx_L14_bool_binop_done:;
    if (__pyx_t_10) {

      /* "revealer/REVEALER_runbenchmark.pyx":3019
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 */
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3019, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 3019, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_10) {

        /* "revealer/REVEALER_runbenchmark.pyx":3020
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_kp_u__44); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__27); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3021
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_notna); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_14);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_14, function);
          }
        }
        __pyx_t_4 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = PyNumber_Add(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__29); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3022
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *             else:
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_15); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_count); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_14 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3021
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_14 = PyNumber_Add(__pyx_t_4, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3022
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *             else:
 */
        __pyx_t_15 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__28); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3022, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3020
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_15);
        __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3023
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 */
        __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3023, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 3023, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3023, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":3020
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_14, __pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3020, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3019
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 */
        goto __pyx_L16;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":3025
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
      /*else*/ {
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_15 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = PyNumber_Add(__pyx_t_14, __pyx_kp_u__27); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3026
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_notna); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        __pyx_t_14 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_Add(__pyx_t_15, __pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__29); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3027
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *         else:
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        __pyx_t_15 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_count); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        __pyx_t_7 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_15, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3026
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_7 = PyNumber_Add(__pyx_t_14, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3027
 *                 ax.text(0.9,0.5,seedids[(i-1)] +
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *         else:
 */
        __pyx_t_8 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__28); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3027, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3025
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3028
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             if locusdic != None:
 */
        __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3028, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 3028, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3028, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":3025
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +             # <<<<<<<<<<<<<<
 *                     '(' + str(sum(gmt.loc[seedids[(i-1)]].notna())) + ',' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3025, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __pyx_L16:;

      /* "revealer/REVEALER_runbenchmark.pyx":3018
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         if (gmt is not None) and (seedids[(i-1)] in gmt.index.tolist()):             # <<<<<<<<<<<<<<
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 */
      goto __pyx_L13;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3030
 *                     ha='right', va='center')
 *         else:
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
    /*else*/ {
      __pyx_t_14 = PyObject_RichCompare(__pyx_v_locusdic, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3030, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 3030, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (__pyx_t_10) {

        /* "revealer/REVEALER_runbenchmark.pyx":3031
 *         else:
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__44); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_locusdic, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__27); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3032
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 *             else:
 */
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_15, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_8 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_count); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_4 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__28); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3032, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3031
 *         else:
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3033
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 */
        __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3033, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 3033, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3033, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":3031
 *         else:
 *             if locusdic != None:
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +             # <<<<<<<<<<<<<<
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3031, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3030
 *                     ha='right', va='center')
 *         else:
 *             if locusdic != None:             # <<<<<<<<<<<<<<
 *                 ax.text(0.9,0.5,seedids[(i-1)] +' '+ locusdic[seedids[(i-1)]] +
 *                     '(' +str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 */
        goto __pyx_L17;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":3035
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
      /*else*/ {
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__27); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3036
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 * 
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_t_15); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tolist); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_14 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_count); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_4 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_14, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3035
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_4 = PyNumber_Add(__pyx_t_6, __pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3036
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',             # <<<<<<<<<<<<<<
 *                     ha='right', va='center')
 * 
 */
        __pyx_t_15 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__28); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3036, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3035
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_float_0_9);
        __Pyx_GIVEREF(__pyx_float_0_9);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_float_0_9);
        __Pyx_INCREF(__pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_float_0_5);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_float_0_5);
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_15);
        __pyx_t_15 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3037
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Add best feature row in report
 */
        __pyx_t_15 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3037, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 3037, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3037, __pyx_L1_error)

        /* "revealer/REVEALER_runbenchmark.pyx":3035
 *                     ha='right', va='center')
 *             else:
 *                 ax.text(0.9,0.5,seedids[(i-1)] + '(' +             # <<<<<<<<<<<<<<
 *                     str(plotcomb.loc[seedids[(i-1)]].tolist().count(1)) + ')',
 *                     ha='right', va='center')
 */
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, __pyx_t_15); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3035, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_L17:;
    }
    __pyx_L13:;

    /* "revealer/REVEALER_runbenchmark.pyx":3040
 * 
 *         #Add best feature row in report
 *         reportdf.loc[seedids[i-1]] = plotcomb.loc[seedids[i-1]].tolist()             # <<<<<<<<<<<<<<
 * 
 *         #Plot heatmap for best feature
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_15, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(PyObject_SetItem(__pyx_t_7, __pyx_t_15, __pyx_t_6) < 0)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3043
 * 
 *         #Plot heatmap for best feature
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 20),             # <<<<<<<<<<<<<<
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_13 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
    __Pyx_INCREF(__pyx_int_134);
    __Pyx_GIVEREF(__pyx_int_134);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_134);
    __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyNumber_Multiply(__pyx_t_4, __pyx_int_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
    __Pyx_INCREF(__pyx_int_20);
    __Pyx_GIVEREF(__pyx_int_20);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_20);
    __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_4) < 0) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 3043, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3043, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3045
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                          cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False, cbar=False)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_sns); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_asarray); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_plotcomb, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_seedids, __pyx_t_8); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_tolist); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_16);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_16, function);
      }
    }
    __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyList_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_7);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_15 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_7, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_astype); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_15)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_15);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
      }
    }
    __pyx_t_4 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_15, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_14, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3046
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),
 *                          cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False, cbar=False)             # <<<<<<<<<<<<<<
 * 
 *         #Label CIC for this feature
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_cmap, __pyx_v_featurecmap) < 0) __PYX_ERR(0, 3046, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 3046, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 3046, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 3046, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 3046, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3045
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.asarray([plotcomb.loc[seedids[i-1]].tolist()]).astype(int),             # <<<<<<<<<<<<<<
 *                          cmap=featurecmap, annot=False, yticklabels=False, xticklabels=False, cbar=False)
 * 
 */
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_14, __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3049
 * 
 *         #Label CIC for this feature
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 122),             # <<<<<<<<<<<<<<
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_plt); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_14);
    __pyx_t_13 = PyObject_Length(__pyx_t_14); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_int_134);
    __Pyx_GIVEREF(__pyx_int_134);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_134);
    __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_shape, __pyx_t_6) < 0) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_14 = PyNumber_Multiply(__pyx_t_6, __pyx_int_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_int_122);
    __Pyx_GIVEREF(__pyx_int_122);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_122);
    __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_loc, __pyx_t_6) < 0) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 3049, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3049, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_15); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3051
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2)*5, 122),
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1],int(1000*bootstraps[(i-1)*2+1])),
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3052
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1],int(1000*bootstraps[(i-1)*2+1])),
 *                     ha='center', va='center', color = 'blue')
 */
    __pyx_t_10 = ((__pyx_v_if_bootstrap == 1) != 0);
    if (__pyx_t_10) {

      /* "revealer/REVEALER_runbenchmark.pyx":3053
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1],int(1000*bootstraps[(i-1)*2+1])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center', color = 'blue')
 *         else:
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_15 = PyTuple_New(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = PyNumber_Multiply(__pyx_t_4, __pyx_int_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_14, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Format(__pyx_t_14, __pyx_kp_u_3f); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_kp_u__27);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__27);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_kp_u__27);
      __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_14 = PyNumber_Multiply(__pyx_t_4, __pyx_int_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_14, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_14), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_kp_u__28);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__28);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_kp_u__28);
      __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_15, 4, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3054
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1],int(1000*bootstraps[(i-1)*2+1])),
 *                     ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+1]), ha='center', va='center',color = 'blue')
 */
      __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3054, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 3054, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3054, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 3054, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":3053
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1],int(1000*bootstraps[(i-1)*2+1])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center', color = 'blue')
 *         else:
 */
      __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_15, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3053, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3052
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+1],int(1000*bootstraps[(i-1)*2+1])),
 *                     ha='center', va='center', color = 'blue')
 */
      goto __pyx_L18;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3056
 *                     ha='center', va='center', color = 'blue')
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+1]), ha='center', va='center',color = 'blue')             # <<<<<<<<<<<<<<
 * 
 *         # Label new seed
 */
    /*else*/ {
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_15 = PyNumber_Multiply(__pyx_t_4, __pyx_int_2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_15, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 3056, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3056, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_color, __pyx_n_u_blue) < 0) __PYX_ERR(0, 3056, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_15, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L18:;

    /* "revealer/REVEALER_runbenchmark.pyx":3059
 * 
 *         # Label new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 0),             # <<<<<<<<<<<<<<
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_plt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_15 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_15);
    __pyx_t_13 = PyObject_Length(__pyx_t_15); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_134);
    __Pyx_GIVEREF(__pyx_int_134);
    PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_int_134);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shape, __pyx_t_14) < 0) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = __Pyx_PyInt_AddObjC(__pyx_t_14, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = PyNumber_Multiply(__pyx_t_15, __pyx_int_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_14);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_int_0);
    __pyx_t_14 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_loc, __pyx_t_15) < 0) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_colspan, __pyx_int_20) < 0) __PYX_ERR(0, 3059, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3059, __pyx_L1_error)
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3061
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 0),
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         ax.text(0.9,0.5,'New Seed', ha='right', va='center')
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_15 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3062
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         ax.text(0.9,0.5,'New Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Put new seed into
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_right) < 0) __PYX_ERR(0, 3062, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3062, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_tuple__60, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3065
 * 
 *         #Put new seed into
 *         reportdf.loc['New Seed'+str(i)] = seedlists[i]             # <<<<<<<<<<<<<<
 * 
 *         #Plot heatmap for new seed
 */
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_seedlists, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_15 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_i); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __Pyx_PyUnicode_Concat(__pyx_kp_u_New_Seed, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(PyObject_SetItem(__pyx_t_6, __pyx_t_14, __pyx_t_4) < 0)) __PYX_ERR(0, 3065, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3068
 * 
 *         #Plot heatmap for new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 20),             # <<<<<<<<<<<<<<
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_plt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_13 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_int_134);
    __Pyx_GIVEREF(__pyx_int_134);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_int_134);
    __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_shape, __pyx_t_15) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_t_15, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyNumber_Multiply(__pyx_t_6, __pyx_int_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_20);
    __Pyx_GIVEREF(__pyx_int_20);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_20);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loc, __pyx_t_6) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_colspan, __pyx_int_90) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3070
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                          xticklabels=False,cbar=False)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_sns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_heatmap); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_np); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_array); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_seedlists, __pyx_v_i); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_16 = PyList_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_14);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_t_14);
    __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    __pyx_t_6 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_14, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyTuple_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_cmap, __pyx_v_seedcmap) < 0) __PYX_ERR(0, 3070, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_annot, Py_False) < 0) __PYX_ERR(0, 3070, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_yticklabels, Py_False) < 0) __PYX_ERR(0, 3070, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3071
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,
 *                          xticklabels=False,cbar=False)             # <<<<<<<<<<<<<<
 * 
 *         #Label IC for new seed
 */
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_xticklabels, Py_False) < 0) __PYX_ERR(0, 3070, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_cbar, Py_False) < 0) __PYX_ERR(0, 3070, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3070
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 20),
 *                               colspan=90,rowspan=5)
 *         ax = sns.heatmap(np.array([seedlists[i]]),cmap=seedcmap,annot=False,yticklabels=False,             # <<<<<<<<<<<<<<
 *                          xticklabels=False,cbar=False)
 * 
 */
    __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_15, __pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_16);
    __pyx_t_16 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3074
 * 
 *         #Label IC for new seed
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 110),             # <<<<<<<<<<<<<<
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_plt); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_subplot2grid); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_15 = __pyx_cur_scope->__pyx_v_seedids;
    __Pyx_INCREF(__pyx_t_15);
    __pyx_t_13 = PyObject_Length(__pyx_t_15); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyInt_FromSsize_t(((5 * (__pyx_t_13 + 1)) * 2)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_15);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_15);
    __Pyx_INCREF(__pyx_int_134);
    __Pyx_GIVEREF(__pyx_int_134);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_134);
    __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_shape, __pyx_t_4) < 0) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_i, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_15, __pyx_int_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_int_110);
    __Pyx_GIVEREF(__pyx_int_110);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_int_110);
    __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_loc, __pyx_t_15) < 0) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_colspan, __pyx_int_12) < 0) __PYX_ERR(0, 3074, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_rowspan, __pyx_int_5) < 0) __PYX_ERR(0, 3074, __pyx_L1_error)
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF_SET(__pyx_v_ax, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3076
 *         ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,134), loc=(((i)*2+1)*5, 110),
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()             # <<<<<<<<<<<<<<
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 */
    __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_set_axis_off); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3076, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_16, function);
      }
    }
    __pyx_t_15 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3076, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3077
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 *                     ha='center', va='center')
 */
    __pyx_t_10 = ((__pyx_v_if_bootstrap == 1) != 0);
    if (__pyx_t_10) {

      /* "revealer/REVEALER_runbenchmark.pyx":3078
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 *         else:
 */
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = PyTuple_New(4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_13 = 0;
      __pyx_t_11 = 127;
      __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Format(__pyx_t_4, __pyx_kp_u_3f); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__27);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__27);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_kp_u__27);
      __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_int_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_11) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_11;
      __pyx_t_13 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__28);
      __pyx_t_13 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__28);
      PyTuple_SET_ITEM(__pyx_t_16, 3, __pyx_kp_u__28);
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_16, 4, __pyx_t_13, __pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3079
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 *                     ha='center', va='center')             # <<<<<<<<<<<<<<
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+2]), ha='center', va='center')
 */
      __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 3079, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3079, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":3078
 *         ax.set_axis_off()
 *         if if_bootstrap == True:
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),             # <<<<<<<<<<<<<<
 *                     ha='center', va='center')
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_16, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3077
 *                               colspan=12,rowspan=5)
 *         ax.set_axis_off()
 *         if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *             ax.text(0.5,0.5,"%.3f(%s)"%(CICs[(i-1)*2+2],int(1000*bootstraps[(i-1)*2+2])),
 *                     ha='center', va='center')
 */
      goto __pyx_L19;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3081
 *                     ha='center', va='center')
 *         else:
 *             ax.text(0.5,0.5,"%.3f"%(CICs[(i-1)*2+2]), ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Save figure
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ax, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_16 = PyNumber_Multiply(__pyx_t_6, __pyx_int_2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_t_16, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_v_CICs, __pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_3f_2, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_float_0_5);
      __Pyx_INCREF(__pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_float_0_5);
      PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_float_0_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ha, __pyx_n_u_center) < 0) __PYX_ERR(0, 3081, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_va, __pyx_n_u_center) < 0) __PYX_ERR(0, 3081, __pyx_L1_error)
      __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_16, __pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    }
    __pyx_L19:;

    /* "revealer/REVEALER_runbenchmark.pyx":3012
 * 
 *     #Loop to plot best feature and new seeds.
 *     for i in range(1,len(seedids)+1):             # <<<<<<<<<<<<<<
 * 
 *         #Label name of picked feature in this round
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3084
 * 
 *     #Save figure
 *     plt.savefig(out_folder + prefix+'_Result.'+figure_format,format=figure_format)             # <<<<<<<<<<<<<<
 *     plt.close()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_savefig); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_kp_u_Result); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_t_6, __pyx_v_figure_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_format, __pyx_v_figure_format) < 0) __PYX_ERR(0, 3084, __pyx_L1_error)
  __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3085
 *     #Save figure
 *     plt.savefig(out_folder + prefix+'_Result.'+figure_format,format=figure_format)
 *     plt.close()             # <<<<<<<<<<<<<<
 * 
 *     #Set new line of gene locus  to ,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_plt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_close); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_16 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3088
 * 
 *     #Set new line of gene locus  to ,
 *     reportdf.index = reportdf.index.str.replace("\n", ",")             # <<<<<<<<<<<<<<
 * 
 *     #Adjust length of CIC/IC
 */
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_index); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_replace); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_reportdf, __pyx_n_s_index, __pyx_t_6) < 0) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3091
 * 
 *     #Adjust length of CIC/IC
 *     reportdf['CICs'] = [''] + CICs             # <<<<<<<<<<<<<<
 * 
 *     #Put bootstrap to report
 */
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_kp_u__2);
  __Pyx_GIVEREF(__pyx_kp_u__2);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u__2);
  __pyx_t_16 = PyNumber_Add(__pyx_t_6, __pyx_v_CICs); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(PyObject_SetItem(__pyx_v_reportdf, __pyx_n_u_CICs, __pyx_t_16) < 0)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3094
 * 
 *     #Put bootstrap to report
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 */
  __pyx_t_10 = ((__pyx_v_if_bootstrap == 1) != 0);
  if (__pyx_t_10) {

    /* "revealer/REVEALER_runbenchmark.pyx":3095
 *     #Put bootstrap to report
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):             # <<<<<<<<<<<<<<
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_bootstraps); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3095, __pyx_L1_error)
    __pyx_t_16 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
      __pyx_t_16 = __pyx_t_6; __Pyx_INCREF(__pyx_t_16); __pyx_t_1 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_1 = -1; __pyx_t_16 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3095, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_12 = Py_TYPE(__pyx_t_16)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3095, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_16))) {
          if (__pyx_t_1 >= PyList_GET_SIZE(__pyx_t_16)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 3095, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_16, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3095, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_16)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_1); __Pyx_INCREF(__pyx_t_6); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(0, 3095, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_16, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3095, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_12(__pyx_t_16);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3095, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3096
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':             # <<<<<<<<<<<<<<
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3096, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_kp_u__2, Py_NE)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 3096, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_10) {

        /* "revealer/REVEALER_runbenchmark.pyx":3097
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]             # <<<<<<<<<<<<<<
 *         reportdf['bootstrap'] = [''] + bootstraps
 * 
 */
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_bootstraps, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3097, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PyNumber_Multiply(__pyx_int_1000, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3097, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_bootstraps, __pyx_v_i, __pyx_t_5) < 0)) __PYX_ERR(0, 3097, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3096
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':             # <<<<<<<<<<<<<<
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps
 */
      }

      /* "revealer/REVEALER_runbenchmark.pyx":3095
 *     #Put bootstrap to report
 *     if if_bootstrap == True:
 *         for i in range(len(bootstraps)):             # <<<<<<<<<<<<<<
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 */
    }
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3098
 *             if bootstraps[i] != '':
 *                 bootstraps[i] = 1000*bootstraps[i]
 *         reportdf['bootstrap'] = [''] + bootstraps             # <<<<<<<<<<<<<<
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):
 */
    __pyx_t_16 = PyList_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(__pyx_kp_u__2);
    __Pyx_GIVEREF(__pyx_kp_u__2);
    PyList_SET_ITEM(__pyx_t_16, 0, __pyx_kp_u__2);
    __pyx_t_5 = PyNumber_Add(__pyx_t_16, __pyx_v_bootstraps); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(PyObject_SetItem(__pyx_v_reportdf, __pyx_n_u_bootstrap, __pyx_t_5) < 0)) __PYX_ERR(0, 3098, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3094
 * 
 *     #Put bootstrap to report
 *     if if_bootstrap == True:             # <<<<<<<<<<<<<<
 *         for i in range(len(bootstraps)):
 *             if bootstraps[i] != '':
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3100
 *         reportdf['bootstrap'] = [''] + bootstraps
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_gmt != Py_None);
  __pyx_t_9 = (__pyx_t_2 != 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_10 = __pyx_t_9;
    goto __pyx_L25_bool_binop_done;
  }
  __pyx_t_5 = __pyx_pf_8revealer_21REVEALER_runbenchmark_10saveresfig_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_16 = __Pyx_Generator_Next(__pyx_t_5); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_16, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_10 = __pyx_t_9;
  __pyx_L25_bool_binop_done:;
  if (__pyx_t_10) {

    /* "revealer/REVEALER_runbenchmark.pyx":3101
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)             # <<<<<<<<<<<<<<
 * 
 *     #Save report
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_gmt, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_16 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_cur_scope->__pyx_v_seedids); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_6 = PyNumber_Add(__pyx_t_16, __pyx_kp_u_Result_gmt); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyTuple_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3101, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_header, Py_False) < 0) __PYX_ERR(0, 3101, __pyx_L1_error)
    __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_16, __pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3100
 *         reportdf['bootstrap'] = [''] + bootstraps
 * 
 *     if (gmt is not None) and (all(elem in gmt.index.tolist() for elem in seedids) == True):             # <<<<<<<<<<<<<<
 *         gmt.loc[seedids].to_csv(out_folder + prefix+'_Result.gmt',sep='\t',header=False)
 * 
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3104
 * 
 *     #Save report
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')             # <<<<<<<<<<<<<<
 * 
 * def topMatches(
 */
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_reportdf, __pyx_n_s_to_csv); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_6 = PyNumber_Add(__pyx_v_out_folder, __pyx_v_prefix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_16 = PyNumber_Add(__pyx_t_6, __pyx_kp_u_Result_txt); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_16);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_16);
  __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3104, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_6, __pyx_t_16); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2921
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def saveresfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.saveresfig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_reportdf);
  __Pyx_XDECREF(__pyx_v_fig);
  __Pyx_XDECREF(__pyx_v_ax);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":3106
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def topMatches(             # <<<<<<<<<<<<<<
 *     comb,           #Dataframe contain target and features
 *     y,              #Target
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_65topMatches(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_64topMatches[] = "\n    Functionn to make rank for IC/CIC values. \n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_65topMatches = {"topMatches", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_65topMatches, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_64topMatches};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_65topMatches(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_y = 0;
  PyObject *__pyx_v_grid = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_v_bandwidth = 0;
  PyObject *__pyx_v_bandwidth_mult = 0;
  PyObject *__pyx_v_bandwidth_adj = 0;
  PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_neighborhood = 0;
  PyObject *__pyx_v_seed = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("topMatches (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_comb,&__pyx_n_s_y,&__pyx_n_s_grid,&__pyx_n_s_k,&__pyx_n_s_size,&__pyx_n_s_bandwidth,&__pyx_n_s_bandwidth_mult,&__pyx_n_s_bandwidth_adj,&__pyx_n_s_thread_number,&__pyx_n_s_neighborhood,&__pyx_n_s_seed,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    values[10] = ((PyObject *)__pyx_int_1);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_y)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 1); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_grid)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 2); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 3); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 4); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 5); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_mult)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 6); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bandwidth_adj)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 7); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 8); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_neighborhood)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, 9); __PYX_ERR(0, 3106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed);
          if (value) { values[10] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "topMatches") < 0)) __PYX_ERR(0, 3106, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_comb = values[0];
    __pyx_v_y = values[1];
    __pyx_v_grid = values[2];
    __pyx_v_k = values[3];
    __pyx_v_size = values[4];
    __pyx_v_bandwidth = values[5];
    __pyx_v_bandwidth_mult = values[6];
    __pyx_v_bandwidth_adj = values[7];
    __pyx_v_thread_number = values[8];
    __pyx_v_neighborhood = values[9];
    __pyx_v_seed = values[10];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("topMatches", 0, 10, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3106, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.topMatches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_64topMatches(__pyx_self, __pyx_v_comb, __pyx_v_y, __pyx_v_grid, __pyx_v_k, __pyx_v_size, __pyx_v_bandwidth, __pyx_v_bandwidth_mult, __pyx_v_bandwidth_adj, __pyx_v_thread_number, __pyx_v_neighborhood, __pyx_v_seed);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_64topMatches(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_y, PyObject *__pyx_v_grid, PyObject *__pyx_v_k, PyObject *__pyx_v_size, PyObject *__pyx_v_bandwidth, PyObject *__pyx_v_bandwidth_mult, PyObject *__pyx_v_bandwidth_adj, PyObject *__pyx_v_thread_number, PyObject *__pyx_v_neighborhood, PyObject *__pyx_v_seed) {
  PyObject *__pyx_v_rank = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_memviewslice __pyx_t_4 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_memviewslice __pyx_t_10 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  __pyx_t_5numpy_double_t __pyx_t_14;
  __pyx_t_5numpy_double_t __pyx_t_15;
  __pyx_t_5numpy_double_t __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  __Pyx_memviewslice __pyx_t_20 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *(*__pyx_t_21)(PyObject *);
  int __pyx_t_22;
  __Pyx_memviewslice __pyx_t_23 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("topMatches", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":3124
 *     '''
 * 
 *     rank = []             # <<<<<<<<<<<<<<
 *     if isinstance(seed, int):
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rank = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3125
 * 
 *     rank = []
 *     if isinstance(seed, int):             # <<<<<<<<<<<<<<
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_seed); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "revealer/REVEALER_runbenchmark.pyx":3126
 *     rank = []
 *     if isinstance(seed, int):
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 */
    __pyx_t_4 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_v_y, PyBUF_WRITABLE); if (unlikely(!__pyx_t_4.memview)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_array); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_t_8, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_values); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_astype); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_8, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_9, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tolist); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_10 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_10.memview)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3127
 *     if isinstance(seed, int):
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []
 */
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3127, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3127, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3127, __pyx_L1_error)
    __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_14 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3127, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3128
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)             # <<<<<<<<<<<<<<
 *         rank = []
 *         for i in range(len(results)):
 */
    __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3128, __pyx_L1_error)
    __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3128, __pyx_L1_error)
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3128, __pyx_L1_error)
    __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3128, __pyx_L1_error)
    __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3128, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3126
 *     rank = []
 *     if isinstance(seed, int):
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 */
    __pyx_t_20 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankIC(__pyx_t_4, __pyx_t_10, __pyx_t_11, ((int)(__pyx_t_12 - 1)), __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, 0); if (unlikely(!__pyx_t_20.memview)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __PYX_XDEC_MEMVIEW(&__pyx_t_4, 1);
    __pyx_t_4.memview = NULL;
    __pyx_t_4.data = NULL;
    __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
    __pyx_t_10.memview = NULL;
    __pyx_t_10.data = NULL;
    __pyx_t_1 = __pyx_memoryview_fromslice(__pyx_t_20, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
    __pyx_t_20.memview = NULL;
    __pyx_t_20.data = NULL;
    __pyx_v_results = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3129
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []             # <<<<<<<<<<<<<<
 *         for i in range(len(results)):
 *             rank.append([comb.index[i+1],results[i]])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_rank, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3130
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []
 *         for i in range(len(results)):             # <<<<<<<<<<<<<<
 *             rank.append([comb.index[i+1],results[i]])
 *         return rank
 */
    __pyx_t_12 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3130, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
      __pyx_t_1 = __pyx_t_6; __Pyx_INCREF(__pyx_t_1); __pyx_t_12 = 0;
      __pyx_t_21 = NULL;
    } else {
      __pyx_t_12 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_21 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 3130, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      if (likely(!__pyx_t_21)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_6); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 3130, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3130, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_6); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 3130, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3130, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_21(__pyx_t_1);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3130, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3131
 *         rank = []
 *         for i in range(len(results)):
 *             rank.append([comb.index[i+1],results[i]])             # <<<<<<<<<<<<<<
 *         return rank
 *     else:
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_results, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_9);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_5);
      PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_5);
      __pyx_t_9 = 0;
      __pyx_t_5 = 0;
      __pyx_t_22 = __Pyx_PyList_Append(__pyx_v_rank, __pyx_t_6); if (unlikely(__pyx_t_22 == ((int)-1))) __PYX_ERR(0, 3131, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3130
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []
 *         for i in range(len(results)):             # <<<<<<<<<<<<<<
 *             rank.append([comb.index[i+1],results[i]])
 *         return rank
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3132
 *         for i in range(len(results)):
 *             rank.append([comb.index[i+1],results[i]])
 *         return rank             # <<<<<<<<<<<<<<
 *     else:
 *         results = rankCIC(y, seed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_rank);
    __pyx_r = __pyx_v_rank;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":3125
 * 
 *     rank = []
 *     if isinstance(seed, int):             # <<<<<<<<<<<<<<
 *         results = rankIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3134
 *         return rank
 *     else:
 *         results = rankCIC(y, seed, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 */
  /*else*/ {
    __pyx_t_20 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(__pyx_v_y, PyBUF_WRITABLE); if (unlikely(!__pyx_t_20.memview)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __pyx_t_23 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(__pyx_v_seed, PyBUF_WRITABLE); if (unlikely(!__pyx_t_23.memview)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_t_7, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_values); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_astype); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_9 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, ((PyObject *)(&PyInt_Type))) : __Pyx_PyObject_CallOneArg(__pyx_t_8, ((PyObject *)(&PyInt_Type)));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_6 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_10 = __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_10.memview)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3135
 *     else:
 *         results = rankCIC(y, seed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,             # <<<<<<<<<<<<<<
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []
 */
    __pyx_t_19 = __Pyx_PyInt_As_int(__pyx_v_k); if (unlikely((__pyx_t_19 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3135, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3135, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3135, __pyx_L1_error)
    __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth); if (unlikely((__pyx_t_16 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3135, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3136
 *         results = rankCIC(y, seed, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)             # <<<<<<<<<<<<<<
 *         rank = []
 *         for i in range(len(results)):
 */
    __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_mult); if (unlikely((__pyx_t_15 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3136, __pyx_L1_error)
    __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_bandwidth_adj); if (unlikely((__pyx_t_14 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3136, __pyx_L1_error)
    __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_v_grid); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3136, __pyx_L1_error)
    __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_v_thread_number); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3136, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_neighborhood); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3136, __pyx_L1_error)

    /* "revealer/REVEALER_runbenchmark.pyx":3134
 *         return rank
 *     else:
 *         results = rankCIC(y, seed, np.array(comb.iloc[1:].values.astype(int).tolist()),             # <<<<<<<<<<<<<<
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 */
    __pyx_t_4 = __pyx_f_8revealer_21REVEALER_runbenchmark_rankCIC(__pyx_t_20, __pyx_t_23, __pyx_t_10, __pyx_t_19, ((int)(__pyx_t_12 - 1)), __pyx_t_18, __pyx_t_16, __pyx_t_15, __pyx_t_14, __pyx_t_17, __pyx_t_13, __pyx_t_11, 0); if (unlikely(!__pyx_t_4.memview)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
    __pyx_t_20.memview = NULL;
    __pyx_t_20.data = NULL;
    __PYX_XDEC_MEMVIEW(&__pyx_t_23, 1);
    __pyx_t_23.memview = NULL;
    __pyx_t_23.data = NULL;
    __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
    __pyx_t_10.memview = NULL;
    __pyx_t_10.data = NULL;
    __pyx_t_1 = __pyx_memoryview_fromslice(__pyx_t_4, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_double_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_double_t, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XDEC_MEMVIEW(&__pyx_t_4, 1);
    __pyx_t_4.memview = NULL;
    __pyx_t_4.data = NULL;
    __pyx_v_results = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3137
 *                          k, int(len(comb.index)-1), size, bandwidth,
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []             # <<<<<<<<<<<<<<
 *         for i in range(len(results)):
 *             rank.append([comb.index[i+1],results[i]])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_rank, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3138
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []
 *         for i in range(len(results)):             # <<<<<<<<<<<<<<
 *             rank.append([comb.index[i+1],results[i]])
 *         return rank
 */
    __pyx_t_12 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3138, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_1 = __pyx_t_5; __Pyx_INCREF(__pyx_t_1); __pyx_t_12 = 0;
      __pyx_t_21 = NULL;
    } else {
      __pyx_t_12 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_21 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 3138, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_21)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_5); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 3138, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_5); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 3138, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_21(__pyx_t_1);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3138, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3139
 *         rank = []
 *         for i in range(len(results)):
 *             rank.append([comb.index[i+1],results[i]])             # <<<<<<<<<<<<<<
 *         return rank
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_results, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_8);
      PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_6);
      PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
      __pyx_t_8 = 0;
      __pyx_t_6 = 0;
      __pyx_t_22 = __Pyx_PyList_Append(__pyx_v_rank, __pyx_t_5); if (unlikely(__pyx_t_22 == ((int)-1))) __PYX_ERR(0, 3139, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3138
 *                          bandwidth_mult, bandwidth_adj, grid,thread_number, neighborhood)
 *         rank = []
 *         for i in range(len(results)):             # <<<<<<<<<<<<<<
 *             rank.append([comb.index[i+1],results[i]])
 *         return rank
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3140
 *         for i in range(len(results)):
 *             rank.append([comb.index[i+1],results[i]])
 *         return rank             # <<<<<<<<<<<<<<
 * 
 * def seedcomball(
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_rank);
    __pyx_r = __pyx_v_rank;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3106
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def topMatches(             # <<<<<<<<<<<<<<
 *     comb,           #Dataframe contain target and features
 *     y,              #Target
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_4, 1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __PYX_XDEC_MEMVIEW(&__pyx_t_10, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_20, 1);
  __PYX_XDEC_MEMVIEW(&__pyx_t_23, 1);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.topMatches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_rank);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":3142
 *         return rank
 * 
 * def seedcomball(             # <<<<<<<<<<<<<<
 *     comb,       #Dataframe
 *     seed_name   #List of seed name
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_67seedcomball(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_8revealer_21REVEALER_runbenchmark_66seedcomball[] = "\n    combine all seed with given seed names\n    ";
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_67seedcomball = {"seedcomball", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_67seedcomball, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_66seedcomball};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_67seedcomball(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_comb = 0;
  PyObject *__pyx_v_seed_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seedcomball (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_comb,&__pyx_n_s_seed_name,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_comb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("seedcomball", 1, 2, 2, 1); __PYX_ERR(0, 3142, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "seedcomball") < 0)) __PYX_ERR(0, 3142, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_comb = values[0];
    __pyx_v_seed_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("seedcomball", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3142, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.seedcomball", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_66seedcomball(__pyx_self, __pyx_v_comb, __pyx_v_seed_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_66seedcomball(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_comb, PyObject *__pyx_v_seed_name) {
  PyObject *__pyx_v_currentseed = NULL;
  PyObject *__pyx_v_subseed = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seedcomball", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":3151
 *     '''
 * 
 *     currentseed = comb.loc[seed_name[0]].tolist()             # <<<<<<<<<<<<<<
 *     if len(seed_name) == 1:
 *         return currentseed
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_seed_name, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_tolist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_currentseed = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3152
 * 
 *     currentseed = comb.loc[seed_name[0]].tolist()
 *     if len(seed_name) == 1:             # <<<<<<<<<<<<<<
 *         return currentseed
 *     for subseed in seed_name[1:]:
 */
  __pyx_t_5 = PyObject_Length(__pyx_v_seed_name); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3152, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_5 == 1) != 0);
  if (__pyx_t_6) {

    /* "revealer/REVEALER_runbenchmark.pyx":3153
 *     currentseed = comb.loc[seed_name[0]].tolist()
 *     if len(seed_name) == 1:
 *         return currentseed             # <<<<<<<<<<<<<<
 *     for subseed in seed_name[1:]:
 *         currentseed = seedCombine(currentseed,comb.loc[subseed].tolist())
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_currentseed);
    __pyx_r = __pyx_v_currentseed;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":3152
 * 
 *     currentseed = comb.loc[seed_name[0]].tolist()
 *     if len(seed_name) == 1:             # <<<<<<<<<<<<<<
 *         return currentseed
 *     for subseed in seed_name[1:]:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3154
 *     if len(seed_name) == 1:
 *         return currentseed
 *     for subseed in seed_name[1:]:             # <<<<<<<<<<<<<<
 *         currentseed = seedCombine(currentseed,comb.loc[subseed].tolist())
 *     return currentseed
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_seed_name, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_5 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3154, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3154, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3154, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3154, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_subseed, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3155
 *         return currentseed
 *     for subseed in seed_name[1:]:
 *         currentseed = seedCombine(currentseed,comb.loc[subseed].tolist())             # <<<<<<<<<<<<<<
 *     return currentseed
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_seedCombine); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_t_8, __pyx_v_subseed); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_2 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    __pyx_t_10 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_10 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_currentseed, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3155, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_currentseed, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3155, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_INCREF(__pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_v_currentseed);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_10, __pyx_v_currentseed);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_10, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_currentseed, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3154
 *     if len(seed_name) == 1:
 *         return currentseed
 *     for subseed in seed_name[1:]:             # <<<<<<<<<<<<<<
 *         currentseed = seedCombine(currentseed,comb.loc[subseed].tolist())
 *     return currentseed
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3156
 *     for subseed in seed_name[1:]:
 *         currentseed = seedCombine(currentseed,comb.loc[subseed].tolist())
 *     return currentseed             # <<<<<<<<<<<<<<
 * 
 * def readInput(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_currentseed);
  __pyx_r = __pyx_v_currentseed;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":3142
 *         return rank
 * 
 * def seedcomball(             # <<<<<<<<<<<<<<
 *     comb,       #Dataframe
 *     seed_name   #List of seed name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.seedcomball", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_currentseed);
  __Pyx_XDECREF(__pyx_v_subseed);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":3158
 *     return currentseed
 * 
 * def readInput(             # <<<<<<<<<<<<<<
 *     target_file,    #Name of target file
 *     feature_file,   #Name of feature file
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_69readInput(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_69readInput = {"readInput", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_69readInput, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_69readInput(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_target_file = 0;
  PyObject *__pyx_v_feature_file = 0;
  PyObject *__pyx_v_seed_file = 0;
  PyObject *__pyx_v_seed_name = 0;
  PyObject *__pyx_v_target_name = 0;
  PyObject *__pyx_v_direction = 0;
  PyObject *__pyx_v_gene_locus = 0;
  PyObject *__pyx_v_low_threshold = 0;
  PyObject *__pyx_v_high_threshold = 0;
  PyObject *__pyx_v_subset = 0;
  PyObject *__pyx_v_gene_set = 0;
  PyObject *__pyx_v_gene_separator = 0;
  CYTHON_UNUSED PyObject *__pyx_v_thread_number = 0;
  PyObject *__pyx_v_tissue_file = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("readInput (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_target_file,&__pyx_n_s_feature_file,&__pyx_n_s_seed_file,&__pyx_n_s_seed_name,&__pyx_n_s_target_name,&__pyx_n_s_direction,&__pyx_n_s_gene_locus,&__pyx_n_s_low_threshold,&__pyx_n_s_high_threshold,&__pyx_n_s_subset,&__pyx_n_s_gene_set,&__pyx_n_s_gene_separator,&__pyx_n_s_thread_number,&__pyx_n_s_tissue_file,0};
    PyObject* values[14] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_file)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_feature_file)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 1); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_file)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 2); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_seed_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 3); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_target_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 4); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_direction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 5); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_locus)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 6); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_low_threshold)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 7); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_high_threshold)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 8); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (likely((values[9] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_subset)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 9); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (likely((values[10] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_set)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 10); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (likely((values[11] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_separator)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 11); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (likely((values[12] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_thread_number)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 12); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (likely((values[13] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tissue_file)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, 13); __PYX_ERR(0, 3158, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "readInput") < 0)) __PYX_ERR(0, 3158, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 14) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
      values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
      values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
      values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
      values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
      values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
    }
    __pyx_v_target_file = values[0];
    __pyx_v_feature_file = values[1];
    __pyx_v_seed_file = values[2];
    __pyx_v_seed_name = values[3];
    __pyx_v_target_name = values[4];
    __pyx_v_direction = values[5];
    __pyx_v_gene_locus = values[6];
    __pyx_v_low_threshold = values[7];
    __pyx_v_high_threshold = values[8];
    __pyx_v_subset = values[9];
    __pyx_v_gene_set = values[10];
    __pyx_v_gene_separator = values[11];
    __pyx_v_thread_number = values[12];
    __pyx_v_tissue_file = values[13];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("readInput", 1, 14, 14, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3158, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.readInput", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_68readInput(__pyx_self, __pyx_v_target_file, __pyx_v_feature_file, __pyx_v_seed_file, __pyx_v_seed_name, __pyx_v_target_name, __pyx_v_direction, __pyx_v_gene_locus, __pyx_v_low_threshold, __pyx_v_high_threshold, __pyx_v_subset, __pyx_v_gene_set, __pyx_v_gene_separator, __pyx_v_thread_number, __pyx_v_tissue_file);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_68readInput(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_target_file, PyObject *__pyx_v_feature_file, PyObject *__pyx_v_seed_file, PyObject *__pyx_v_seed_name, PyObject *__pyx_v_target_name, PyObject *__pyx_v_direction, PyObject *__pyx_v_gene_locus, PyObject *__pyx_v_low_threshold, PyObject *__pyx_v_high_threshold, PyObject *__pyx_v_subset, PyObject *__pyx_v_gene_set, PyObject *__pyx_v_gene_separator, CYTHON_UNUSED PyObject *__pyx_v_thread_number, PyObject *__pyx_v_tissue_file) {
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_v_feature = NULL;
  PyObject *__pyx_v_patient = NULL;
  PyObject *__pyx_v_commoncol = NULL;
  PyObject *__pyx_v_comb = NULL;
  PyObject *__pyx_v_seed_df = NULL;
  PyObject *__pyx_v_rmrow = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_seedIndex = NULL;
  PyObject *__pyx_v_locus = NULL;
  PyObject *__pyx_v_locusdic = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_genename = NULL;
  PyObject *__pyx_v_newseed_names = NULL;
  PyObject *__pyx_v_currentseed = NULL;
  PyObject *__pyx_v_inset_list = NULL;
  PyObject *__pyx_v_feature_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("readInput", 0);
  __Pyx_INCREF(__pyx_v_low_threshold);
  __Pyx_INCREF(__pyx_v_high_threshold);

  /* "revealer/REVEALER_runbenchmark.pyx":3175
 *     ):
 * 
 *     print('seed_file is' + seed_file)             # <<<<<<<<<<<<<<
 * 
 *     '''
 */
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_seed_file_is, __pyx_v_seed_file); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3181
 *     '''
 * 
 *     print('Start reading input files...')             # <<<<<<<<<<<<<<
 * 
 *     #Read target file with given target name or index, replace - with _ in column name
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3184
 * 
 *     #Read target file with given target name or index, replace - with _ in column name
 *     if isinstance(target_name,int) == True:             # <<<<<<<<<<<<<<
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 *         target = target.drop(columns=target.columns[0]).iloc[[target_name]]
 */
  __pyx_t_3 = PyInt_Check(__pyx_v_target_name); 
  __pyx_t_4 = ((__pyx_t_3 == 1) != 0);
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3185
 *     #Read target file with given target name or index, replace - with _ in column name
 *     if isinstance(target_name,int) == True:
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *         target = target.drop(columns=target.columns[0]).iloc[[target_name]]
 *         target.columns = target.columns.str.replace("-", "_")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_target_file);
    __Pyx_GIVEREF(__pyx_v_target_file);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_target_file);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    PyList_SET_ITEM(__pyx_t_6, 1, __pyx_int_1);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_skiprows, __pyx_t_6) < 0) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3185, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3185, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_target = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3186
 *     if isinstance(target_name,int) == True:
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 *         target = target.drop(columns=target.columns[0]).iloc[[target_name]]             # <<<<<<<<<<<<<<
 *         target.columns = target.columns.str.replace("-", "_")
 *     else:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_drop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_target_name);
    __Pyx_GIVEREF(__pyx_v_target_name);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_target_name);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3187
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 *         target = target.drop(columns=target.columns[0]).iloc[[target_name]]
 *         target.columns = target.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *     else:
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_target, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3184
 * 
 *     #Read target file with given target name or index, replace - with _ in column name
 *     if isinstance(target_name,int) == True:             # <<<<<<<<<<<<<<
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 *         target = target.drop(columns=target.columns[0]).iloc[[target_name]]
 */
    goto __pyx_L3;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3189
 *         target.columns = target.columns.str.replace("-", "_")
 *     else:
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *         target = target.drop(columns=target.columns[0]).loc[[target_name]]
 *         target.columns = target.columns.str.replace("-", "_")
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_target_file);
    __Pyx_GIVEREF(__pyx_v_target_file);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_target_file);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    PyList_SET_ITEM(__pyx_t_2, 1, __pyx_int_1);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_skiprows, __pyx_t_2) < 0) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3189, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3189, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_target = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3190
 *     else:
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 *         target = target.drop(columns=target.columns[0]).loc[[target_name]]             # <<<<<<<<<<<<<<
 *         target.columns = target.columns.str.replace("-", "_")
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_drop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_columns, __pyx_t_6) < 0) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_target_name);
    __Pyx_GIVEREF(__pyx_v_target_name);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_target_name);
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3191
 *         target = pd.read_csv(target_file,skiprows=[0,1],sep='\t',index_col=0)
 *         target = target.drop(columns=target.columns[0]).loc[[target_name]]
 *         target.columns = target.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_target, __pyx_n_s_columns, __pyx_t_6) < 0) __PYX_ERR(0, 3191, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "revealer/REVEALER_runbenchmark.pyx":3195
 * 
 *     #Read seed file and feature file and extract seed. If same, read only one
 *     if tissue_file:             # <<<<<<<<<<<<<<
 *         if seed_file == feature_file:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_tissue_file); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3195, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3196
 *     #Read seed file and feature file and extract seed. If same, read only one
 *     if tissue_file:
 *         if seed_file == feature_file:             # <<<<<<<<<<<<<<
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 */
    __pyx_t_6 = PyObject_RichCompare(__pyx_v_seed_file, __pyx_v_feature_file, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3196, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3196, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":3197
 *     if tissue_file:
 *         if seed_file == feature_file:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             feature = feature.drop(columns=feature.columns[0])
 *             feature.columns = feature.columns.str.replace("-", "_")
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pd); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_feature_file);
      __Pyx_GIVEREF(__pyx_v_feature_file);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_feature_file);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_1, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_skiprows, __pyx_t_1) < 0) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3197, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3197, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_feature = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3198
 *         if seed_file == feature_file:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])             # <<<<<<<<<<<<<<
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_drop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 3198, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_feature, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3199
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 *             feature.columns = feature.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *             patient = patient.drop(columns=patient.columns[0])
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_feature, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 3199, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3200
 *             feature = feature.drop(columns=feature.columns[0])
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             patient = patient.drop(columns=patient.columns[0])
 *             patient.columns = patient.columns.str.replace("-", "_")
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_tissue_file);
      __Pyx_GIVEREF(__pyx_v_tissue_file);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tissue_file);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_6, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_skiprows, __pyx_t_6) < 0) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3200, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3200, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_patient = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3201
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *             patient = patient.drop(columns=patient.columns[0])             # <<<<<<<<<<<<<<
 *             patient.columns = patient.columns.str.replace("-", "_")
 *             commoncol = list(set(target.columns)&set(feature.columns)&set(patient.columns))
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_drop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_patient, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3202
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *             patient = patient.drop(columns=patient.columns[0])
 *             patient.columns = patient.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             commoncol = list(set(target.columns)&set(feature.columns)&set(patient.columns))
 *             comb = pd.concat([target,feature],  join='inner')
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_patient, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 3202, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3203
 *             patient = patient.drop(columns=patient.columns[0])
 *             patient.columns = patient.columns.str.replace("-", "_")
 *             commoncol = list(set(target.columns)&set(feature.columns)&set(patient.columns))             # <<<<<<<<<<<<<<
 *             comb = pd.concat([target,feature],  join='inner')
 *             comb = comb[commoncol]
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PySet_New(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PySet_New(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_And(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = PySet_New(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_And(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PySequence_List(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_commoncol = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3204
 *             patient.columns = patient.columns.str.replace("-", "_")
 *             commoncol = list(set(target.columns)&set(feature.columns)&set(patient.columns))
 *             comb = pd.concat([target,feature],  join='inner')             # <<<<<<<<<<<<<<
 *             comb = comb[commoncol]
 *         else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_concat); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_target);
      __Pyx_GIVEREF(__pyx_v_target);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_target);
      __Pyx_INCREF(__pyx_v_feature);
      __Pyx_GIVEREF(__pyx_v_feature);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_feature);
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_join, __pyx_n_u_inner) < 0) __PYX_ERR(0, 3204, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_comb = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3205
 *             commoncol = list(set(target.columns)&set(feature.columns)&set(patient.columns))
 *             comb = pd.concat([target,feature],  join='inner')
 *             comb = comb[commoncol]             # <<<<<<<<<<<<<<
 *         else:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 */
      __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_comb, __pyx_v_commoncol); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3196
 *     #Read seed file and feature file and extract seed. If same, read only one
 *     if tissue_file:
 *         if seed_file == feature_file:             # <<<<<<<<<<<<<<
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 */
      goto __pyx_L5;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3207
 *             comb = comb[commoncol]
 *         else:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             feature = feature.drop(columns=feature.columns[0])
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_feature_file);
      __Pyx_GIVEREF(__pyx_v_feature_file);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_feature_file);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_6, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_skiprows, __pyx_t_6) < 0) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3207, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3207, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_feature = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3208
 *         else:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])             # <<<<<<<<<<<<<<
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_drop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 3208, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_feature, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3209
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_seed_file);
      __Pyx_GIVEREF(__pyx_v_seed_file);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_seed_file);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_5, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_5, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_skiprows, __pyx_t_5) < 0) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3209, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3209, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_seed_df = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3210
 *             feature = feature.drop(columns=feature.columns[0])
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]             # <<<<<<<<<<<<<<
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *             patient = patient.drop(columns=patient.columns[0])
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_drop); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_seed_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_seed_df, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3211
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             patient = patient.drop(columns=patient.columns[0])
 *             patient.columns = patient.columns.str.replace("-", "_")
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_tissue_file);
      __Pyx_GIVEREF(__pyx_v_tissue_file);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tissue_file);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_skiprows, __pyx_t_2) < 0) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3211, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3211, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_patient = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3212
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *             patient = patient.drop(columns=patient.columns[0])             # <<<<<<<<<<<<<<
 *             patient.columns = patient.columns.str.replace("-", "_")
 *             feature.columns = feature.columns.str.replace("-", "_")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_drop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_columns, __pyx_t_6) < 0) __PYX_ERR(0, 3212, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_patient, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3213
 *             patient = pd.read_csv(tissue_file,skiprows=[0,1],sep='\t',index_col=0)
 *             patient = patient.drop(columns=patient.columns[0])
 *             patient.columns = patient.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_patient, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 3213, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3214
 *             patient = patient.drop(columns=patient.columns[0])
 *             patient.columns = patient.columns.str.replace("-", "_")
 *             feature.columns = feature.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 *             seed_df = seed_df.dropna(axis=1)
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_feature, __pyx_n_s_columns, __pyx_t_6) < 0) __PYX_ERR(0, 3214, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3215
 *             patient.columns = patient.columns.str.replace("-", "_")
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             seed_df = seed_df.dropna(axis=1)
 *             commoncol = list(set(target.columns)&set(seed_df.columns)&set(feature.columns)&set(patient.columns))
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 3215, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3216
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 *             seed_df = seed_df.dropna(axis=1)             # <<<<<<<<<<<<<<
 *             commoncol = list(set(target.columns)&set(seed_df.columns)&set(feature.columns)&set(patient.columns))
 *             comb = pd.concat([target,seed_df,feature],  join='inner')
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_dropna); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_axis, __pyx_int_1) < 0) __PYX_ERR(0, 3216, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_seed_df, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3217
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 *             seed_df = seed_df.dropna(axis=1)
 *             commoncol = list(set(target.columns)&set(seed_df.columns)&set(feature.columns)&set(patient.columns))             # <<<<<<<<<<<<<<
 *             comb = pd.concat([target,seed_df,feature],  join='inner')
 *             comb = comb[commoncol]
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = PySet_New(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = PySet_New(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_And(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySet_New(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_And(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_patient, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = PySet_New(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_And(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PySequence_List(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_commoncol = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3218
 *             seed_df = seed_df.dropna(axis=1)
 *             commoncol = list(set(target.columns)&set(seed_df.columns)&set(feature.columns)&set(patient.columns))
 *             comb = pd.concat([target,seed_df,feature],  join='inner')             # <<<<<<<<<<<<<<
 *             comb = comb[commoncol]
 *     else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_concat); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_target);
      __Pyx_GIVEREF(__pyx_v_target);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_target);
      __Pyx_INCREF(__pyx_v_seed_df);
      __Pyx_GIVEREF(__pyx_v_seed_df);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_seed_df);
      __Pyx_INCREF(__pyx_v_feature);
      __Pyx_GIVEREF(__pyx_v_feature);
      PyList_SET_ITEM(__pyx_t_2, 2, __pyx_v_feature);
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_join, __pyx_n_u_inner) < 0) __PYX_ERR(0, 3218, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_comb = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3219
 *             commoncol = list(set(target.columns)&set(seed_df.columns)&set(feature.columns)&set(patient.columns))
 *             comb = pd.concat([target,seed_df,feature],  join='inner')
 *             comb = comb[commoncol]             # <<<<<<<<<<<<<<
 *     else:
 *         if seed_file == feature_file:
 */
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_comb, __pyx_v_commoncol); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "revealer/REVEALER_runbenchmark.pyx":3195
 * 
 *     #Read seed file and feature file and extract seed. If same, read only one
 *     if tissue_file:             # <<<<<<<<<<<<<<
 *         if seed_file == feature_file:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 */
    goto __pyx_L4;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3221
 *             comb = comb[commoncol]
 *     else:
 *         if seed_file == feature_file:             # <<<<<<<<<<<<<<
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 */
  /*else*/ {
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_seed_file, __pyx_v_feature_file, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3221, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3221, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":3222
 *     else:
 *         if seed_file == feature_file:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             feature = feature.drop(columns=feature.columns[0])
 *             feature.columns = feature.columns.str.replace("-", "_")
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_feature_file);
      __Pyx_GIVEREF(__pyx_v_feature_file);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_feature_file);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_6, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_skiprows, __pyx_t_6) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_feature = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3223
 *         if seed_file == feature_file:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])             # <<<<<<<<<<<<<<
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             comb = pd.concat([target,feature],  join='inner')
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_drop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 3223, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_feature, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3224
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 *             feature.columns = feature.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             comb = pd.concat([target,feature],  join='inner')
 *         else:
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_feature, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 3224, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3225
 *             feature = feature.drop(columns=feature.columns[0])
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             comb = pd.concat([target,feature],  join='inner')             # <<<<<<<<<<<<<<
 *         else:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_target);
      __Pyx_GIVEREF(__pyx_v_target);
      PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_target);
      __Pyx_INCREF(__pyx_v_feature);
      __Pyx_GIVEREF(__pyx_v_feature);
      PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_feature);
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_join, __pyx_n_u_inner) < 0) __PYX_ERR(0, 3225, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_comb = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3221
 *             comb = comb[commoncol]
 *     else:
 *         if seed_file == feature_file:             # <<<<<<<<<<<<<<
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 */
      goto __pyx_L6;
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3227
 *             comb = pd.concat([target,feature],  join='inner')
 *         else:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             feature = feature.drop(columns=feature.columns[0])
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_feature_file);
      __Pyx_GIVEREF(__pyx_v_feature_file);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_feature_file);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_skiprows, __pyx_t_2) < 0) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3227, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3227, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_feature = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3228
 *         else:
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])             # <<<<<<<<<<<<<<
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_drop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_columns, __pyx_t_5) < 0) __PYX_ERR(0, 3228, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_feature, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3229
 *             feature = pd.read_csv(feature_file,skiprows=[0,1],sep='\t',index_col=0)
 *             feature = feature.drop(columns=feature.columns[0])
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)             # <<<<<<<<<<<<<<
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 *             seed_df = seed_df.dropna(axis=1)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_seed_file);
      __Pyx_GIVEREF(__pyx_v_seed_file);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_seed_file);
      __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyList_SET_ITEM(__pyx_t_1, 1, __pyx_int_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_skiprows, __pyx_t_1) < 0) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3229, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_index_col, __pyx_int_0) < 0) __PYX_ERR(0, 3229, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_seed_df = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3230
 *             feature = feature.drop(columns=feature.columns[0])
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]             # <<<<<<<<<<<<<<
 *             seed_df = seed_df.dropna(axis=1)
 *             feature.columns = feature.columns.str.replace("-", "_")
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_drop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_columns, __pyx_t_6) < 0) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_seed_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_seed_df, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3231
 *             seed_df = pd.read_csv(seed_file,skiprows=[0,1],sep='\t',index_col=0)
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 *             seed_df = seed_df.dropna(axis=1)             # <<<<<<<<<<<<<<
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_dropna); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_axis, __pyx_int_1) < 0) __PYX_ERR(0, 3231, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_seed_df, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3232
 *             seed_df = seed_df.drop(columns=seed_df.columns[0]).loc[seed_name]
 *             seed_df = seed_df.dropna(axis=1)
 *             feature.columns = feature.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 *             comb = pd.concat([target,seed_df,feature],  join='inner')
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_feature, __pyx_n_s_columns, __pyx_t_2) < 0) __PYX_ERR(0, 3232, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3233
 *             seed_df = seed_df.dropna(axis=1)
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *             comb = pd.concat([target,seed_df,feature],  join='inner')
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_seed_df, __pyx_n_s_columns, __pyx_t_1) < 0) __PYX_ERR(0, 3233, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3234
 *             feature.columns = feature.columns.str.replace("-", "_")
 *             seed_df.columns = seed_df.columns.str.replace("-", "_")
 *             comb = pd.concat([target,seed_df,feature],  join='inner')             # <<<<<<<<<<<<<<
 * 
 *     #If subset list is passed, extract subset only
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_target);
      __Pyx_GIVEREF(__pyx_v_target);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_target);
      __Pyx_INCREF(__pyx_v_seed_df);
      __Pyx_GIVEREF(__pyx_v_seed_df);
      PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_seed_df);
      __Pyx_INCREF(__pyx_v_feature);
      __Pyx_GIVEREF(__pyx_v_feature);
      PyList_SET_ITEM(__pyx_t_1, 2, __pyx_v_feature);
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_join, __pyx_n_u_inner) < 0) __PYX_ERR(0, 3234, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_comb = __pyx_t_5;
      __pyx_t_5 = 0;
    }
    __pyx_L6:;
  }
  __pyx_L4:;

  /* "revealer/REVEALER_runbenchmark.pyx":3237
 * 
 *     #If subset list is passed, extract subset only
 *     if subset != 'no':             # <<<<<<<<<<<<<<
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:
 *             print('subset not exist! Please check your subset list.')
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_subset, __pyx_n_u_no, Py_NE)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3237, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3238
 *     #If subset list is passed, extract subset only
 *     if subset != 'no':
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:             # <<<<<<<<<<<<<<
 *             print('subset not exist! Please check your subset list.')
 *             sys.exit(1)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PySet_New(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PySet_New(__pyx_v_subset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyNumber_And(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = PyList_GET_SIZE(__pyx_t_5); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3238, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = ((__pyx_t_7 == 0) != 0);
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":3239
 *     if subset != 'no':
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:
 *             print('subset not exist! Please check your subset list.')             # <<<<<<<<<<<<<<
 *             sys.exit(1)
 *         comb = comb[list(set(comb.columns.tolist())&set(subset))]
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3240
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:
 *             print('subset not exist! Please check your subset list.')
 *             sys.exit(1)             # <<<<<<<<<<<<<<
 *         comb = comb[list(set(comb.columns.tolist())&set(subset))]
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_exit_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_5 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_1, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3238
 *     #If subset list is passed, extract subset only
 *     if subset != 'no':
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:             # <<<<<<<<<<<<<<
 *             print('subset not exist! Please check your subset list.')
 *             sys.exit(1)
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3241
 *             print('subset not exist! Please check your subset list.')
 *             sys.exit(1)
 *         comb = comb[list(set(comb.columns.tolist())&set(subset))]             # <<<<<<<<<<<<<<
 * 
 *     #Sort whole dataframe by target by direction
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_columns); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PySet_New(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PySet_New(__pyx_v_subset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyNumber_And(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PySequence_List(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_comb, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3237
 * 
 *     #If subset list is passed, extract subset only
 *     if subset != 'no':             # <<<<<<<<<<<<<<
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:
 *             print('subset not exist! Please check your subset list.')
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3244
 * 
 *     #Sort whole dataframe by target by direction
 *     if direction == 'neg':             # <<<<<<<<<<<<<<
 *         comb = comb.sort_values(by = comb.index[0], axis = 1)
 *     else:
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_direction, __pyx_n_u_neg, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3244, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3245
 *     #Sort whole dataframe by target by direction
 *     if direction == 'neg':
 *         comb = comb.sort_values(by = comb.index[0], axis = 1)             # <<<<<<<<<<<<<<
 *     else:
 *         comb = comb.sort_values(by = comb.index[0], axis = 1,ascending=False)
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_by, __pyx_t_2) < 0) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_axis, __pyx_int_1) < 0) __PYX_ERR(0, 3245, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3244
 * 
 *     #Sort whole dataframe by target by direction
 *     if direction == 'neg':             # <<<<<<<<<<<<<<
 *         comb = comb.sort_values(by = comb.index[0], axis = 1)
 *     else:
 */
    goto __pyx_L9;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3247
 *         comb = comb.sort_values(by = comb.index[0], axis = 1)
 *     else:
 *         comb = comb.sort_values(by = comb.index[0], axis = 1,ascending=False)             # <<<<<<<<<<<<<<
 * 
 *     comb = comb.dropna(axis=1, how='all')
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_sort_values); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_by, __pyx_t_1) < 0) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_axis, __pyx_int_1) < 0) __PYX_ERR(0, 3247, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ascending, Py_False) < 0) __PYX_ERR(0, 3247, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L9:;

  /* "revealer/REVEALER_runbenchmark.pyx":3249
 *         comb = comb.sort_values(by = comb.index[0], axis = 1,ascending=False)
 * 
 *     comb = comb.dropna(axis=1, how='all')             # <<<<<<<<<<<<<<
 *     comb = comb.dropna(axis=0, how='all')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_dropna); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_axis, __pyx_int_1) < 0) __PYX_ERR(0, 3249, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_how, __pyx_n_u_all) < 0) __PYX_ERR(0, 3249, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3250
 * 
 *     comb = comb.dropna(axis=1, how='all')
 *     comb = comb.dropna(axis=0, how='all')             # <<<<<<<<<<<<<<
 * 
 *     comb = comb.dropna(axis=1)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_dropna); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_axis, __pyx_int_0) < 0) __PYX_ERR(0, 3250, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_how, __pyx_n_u_all) < 0) __PYX_ERR(0, 3250, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3252
 *     comb = comb.dropna(axis=0, how='all')
 * 
 *     comb = comb.dropna(axis=1)             # <<<<<<<<<<<<<<
 *     comb = comb.dropna(axis=0)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_dropna); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_axis, __pyx_int_1) < 0) __PYX_ERR(0, 3252, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3253
 * 
 *     comb = comb.dropna(axis=1)
 *     comb = comb.dropna(axis=0)             # <<<<<<<<<<<<<<
 * 
 *     #remove row by low and high threshold
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_dropna); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_axis, __pyx_int_0) < 0) __PYX_ERR(0, 3253, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3256
 * 
 *     #remove row by low and high threshold
 *     if low_threshold < 1 and low_threshold != 0:             # <<<<<<<<<<<<<<
 *         low_threshold = len(comb.iloc[0].tolist()) * low_threshold
 *     if high_threshold < 1 and high_threshold != 0:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_low_threshold, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3256, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyInt_NeObjC(__pyx_v_low_threshold, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3257
 *     #remove row by low and high threshold
 *     if low_threshold < 1 and low_threshold != 0:
 *         low_threshold = len(comb.iloc[0].tolist()) * low_threshold             # <<<<<<<<<<<<<<
 *     if high_threshold < 1 and high_threshold != 0:
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyNumber_Multiply(__pyx_t_1, __pyx_v_low_threshold); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_low_threshold, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3256
 * 
 *     #remove row by low and high threshold
 *     if low_threshold < 1 and low_threshold != 0:             # <<<<<<<<<<<<<<
 *         low_threshold = len(comb.iloc[0].tolist()) * low_threshold
 *     if high_threshold < 1 and high_threshold != 0:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3258
 *     if low_threshold < 1 and low_threshold != 0:
 *         low_threshold = len(comb.iloc[0].tolist()) * low_threshold
 *     if high_threshold < 1 and high_threshold != 0:             # <<<<<<<<<<<<<<
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold
 *     rmrow = []
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_high_threshold, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3258, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3258, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyInt_NeObjC(__pyx_v_high_threshold, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3258, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3259
 *         low_threshold = len(comb.iloc[0].tolist()) * low_threshold
 *     if high_threshold < 1 and high_threshold != 0:
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold             # <<<<<<<<<<<<<<
 *     rmrow = []
 *     for i in comb.index.tolist()[1:]:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_5 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyNumber_Multiply(__pyx_t_5, __pyx_v_high_threshold); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_high_threshold, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3258
 *     if low_threshold < 1 and low_threshold != 0:
 *         low_threshold = len(comb.iloc[0].tolist()) * low_threshold
 *     if high_threshold < 1 and high_threshold != 0:             # <<<<<<<<<<<<<<
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold
 *     rmrow = []
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3260
 *     if high_threshold < 1 and high_threshold != 0:
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold
 *     rmrow = []             # <<<<<<<<<<<<<<
 *     for i in comb.index.tolist()[1:]:
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rmrow = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3261
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold
 *     rmrow = []
 *     for i in comb.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):
 *             rmrow.append(i)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3261, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3261, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3261, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3261, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3261, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_8(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3261, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3262
 *     rmrow = []
 *     for i in comb.index.tolist()[1:]:
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):             # <<<<<<<<<<<<<<
 *             rmrow.append(i)
 *     comb = comb.drop(index=rmrow)
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_5, __pyx_v_low_threshold, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_3) {
    } else {
      goto __pyx_L20_next_and;
    }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_2 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_5, __pyx_v_high_threshold, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_L20_next_and:;
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_i, __pyx_v_seed_name, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __pyx_t_9 = (__pyx_t_3 != 0);
    __pyx_t_4 = __pyx_t_9;
    __pyx_L19_bool_binop_done:;
    if (__pyx_t_4) {

      /* "revealer/REVEALER_runbenchmark.pyx":3263
 *     for i in comb.index.tolist()[1:]:
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):
 *             rmrow.append(i)             # <<<<<<<<<<<<<<
 *     comb = comb.drop(index=rmrow)
 *     seedIndex = []
 */
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_rmrow, __pyx_v_i); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3263, __pyx_L1_error)

      /* "revealer/REVEALER_runbenchmark.pyx":3262
 *     rmrow = []
 *     for i in comb.index.tolist()[1:]:
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):             # <<<<<<<<<<<<<<
 *             rmrow.append(i)
 *     comb = comb.drop(index=rmrow)
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3261
 *         high_threshold = len(comb.iloc[0].tolist()) * high_threshold
 *     rmrow = []
 *     for i in comb.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):
 *             rmrow.append(i)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3264
 *         if (sum(comb.loc[i].tolist()) <= low_threshold or sum(comb.loc[i].tolist()) >= high_threshold) and ((seed_name == None) or ((seed_name != None) and (i not in seed_name))):
 *             rmrow.append(i)
 *     comb = comb.drop(index=rmrow)             # <<<<<<<<<<<<<<
 *     seedIndex = []
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_drop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_index, __pyx_v_rmrow) < 0) __PYX_ERR(0, 3264, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3265
 *             rmrow.append(i)
 *     comb = comb.drop(index=rmrow)
 *     seedIndex = []             # <<<<<<<<<<<<<<
 * 
 *     #Save index of seed
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_seedIndex = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3268
 * 
 *     #Save index of seed
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         for i in seed_name:
 *             seedIndex.append(comb.index.tolist().index(i))
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3268, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3268, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3269
 *     #Save index of seed
 *     if seed_name != None:
 *         for i in seed_name:             # <<<<<<<<<<<<<<
 *             seedIndex.append(comb.index.tolist().index(i))
 * 
 */
    if (likely(PyList_CheckExact(__pyx_v_seed_name)) || PyTuple_CheckExact(__pyx_v_seed_name)) {
      __pyx_t_5 = __pyx_v_seed_name; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_seed_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3269, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3269, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3269, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3269, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3269, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3269, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_8(__pyx_t_5);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3269, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3270
 *     if seed_name != None:
 *         for i in seed_name:
 *             seedIndex.append(comb.index.tolist().index(i))             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tolist); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_index); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_1, __pyx_v_i) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_i);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_seedIndex, __pyx_t_2); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3270, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3269
 *     #Save index of seed
 *     if seed_name != None:
 *         for i in seed_name:             # <<<<<<<<<<<<<<
 *             seedIndex.append(comb.index.tolist().index(i))
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3268
 * 
 *     #Save index of seed
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         for i in seed_name:
 *             seedIndex.append(comb.index.tolist().index(i))
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3273
 * 
 * 
 *     if gene_locus != 'None':             # <<<<<<<<<<<<<<
 *         locus = pd.read_csv(gene_locus,sep='\t')
 *         locus = locus.dropna(axis=0)
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_gene_locus, __pyx_n_u_None, Py_NE)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3273, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "revealer/REVEALER_runbenchmark.pyx":3274
 * 
 *     if gene_locus != 'None':
 *         locus = pd.read_csv(gene_locus,sep='\t')             # <<<<<<<<<<<<<<
 *         locus = locus.dropna(axis=0)
 *         locusdic = {}
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_gene_locus);
    __Pyx_GIVEREF(__pyx_v_gene_locus);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_gene_locus);
    __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_sep, __pyx_kp_u__14) < 0) __PYX_ERR(0, 3274, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_v_locus = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3275
 *     if gene_locus != 'None':
 *         locus = pd.read_csv(gene_locus,sep='\t')
 *         locus = locus.dropna(axis=0)             # <<<<<<<<<<<<<<
 *         locusdic = {}
 *         for name in comb.index.tolist()[1:]:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_locus, __pyx_n_s_dropna); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_axis, __pyx_int_0) < 0) __PYX_ERR(0, 3275, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF_SET(__pyx_v_locus, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3276
 *         locus = pd.read_csv(gene_locus,sep='\t')
 *         locus = locus.dropna(axis=0)
 *         locusdic = {}             # <<<<<<<<<<<<<<
 *         for name in comb.index.tolist()[1:]:
 *             genename = name.split(gene_separator)[0]
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_locusdic = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3277
 *         locus = locus.dropna(axis=0)
 *         locusdic = {}
 *         for name in comb.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *             genename = name.split(gene_separator)[0]
 *             if genename in locus['Name'].tolist():
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_5 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_5, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3277, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3277, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3277, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3277, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3277, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_8(__pyx_t_5);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3277, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3278
 *         locusdic = {}
 *         for name in comb.index.tolist()[1:]:
 *             genename = name.split(gene_separator)[0]             # <<<<<<<<<<<<<<
 *             if genename in locus['Name'].tolist():
 *                 locusdic[name] = locus[locus['Name']==genename]['Location'].tolist()[0]
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_split); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_2, __pyx_v_gene_separator) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_gene_separator);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_genename, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3279
 *         for name in comb.index.tolist()[1:]:
 *             genename = name.split(gene_separator)[0]
 *             if genename in locus['Name'].tolist():             # <<<<<<<<<<<<<<
 *                 locusdic[name] = locus[locus['Name']==genename]['Location'].tolist()[0]
 *             else:
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_locus, __pyx_n_u_Name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_11 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_genename, __pyx_t_11, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3279, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_9 = (__pyx_t_4 != 0);
      if (__pyx_t_9) {

        /* "revealer/REVEALER_runbenchmark.pyx":3280
 *             genename = name.split(gene_separator)[0]
 *             if genename in locus['Name'].tolist():
 *                 locusdic[name] = locus[locus['Name']==genename]['Location'].tolist()[0]             # <<<<<<<<<<<<<<
 *             else:
 *                 locusdic[name] = ''
 */
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_locus, __pyx_n_u_Name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_v_genename, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_locus, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_u_Location); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        __pyx_t_11 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_11, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(PyDict_SetItem(__pyx_v_locusdic, __pyx_v_name, __pyx_t_2) < 0)) __PYX_ERR(0, 3280, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3279
 *         for name in comb.index.tolist()[1:]:
 *             genename = name.split(gene_separator)[0]
 *             if genename in locus['Name'].tolist():             # <<<<<<<<<<<<<<
 *                 locusdic[name] = locus[locus['Name']==genename]['Location'].tolist()[0]
 *             else:
 */
        goto __pyx_L30;
      }

      /* "revealer/REVEALER_runbenchmark.pyx":3282
 *                 locusdic[name] = locus[locus['Name']==genename]['Location'].tolist()[0]
 *             else:
 *                 locusdic[name] = ''             # <<<<<<<<<<<<<<
 *     else:
 *         locusdic = None
 */
      /*else*/ {
        if (unlikely(PyDict_SetItem(__pyx_v_locusdic, __pyx_v_name, __pyx_kp_u__2) < 0)) __PYX_ERR(0, 3282, __pyx_L1_error)
      }
      __pyx_L30:;

      /* "revealer/REVEALER_runbenchmark.pyx":3277
 *         locus = locus.dropna(axis=0)
 *         locusdic = {}
 *         for name in comb.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *             genename = name.split(gene_separator)[0]
 *             if genename in locus['Name'].tolist():
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3273
 * 
 * 
 *     if gene_locus != 'None':             # <<<<<<<<<<<<<<
 *         locus = pd.read_csv(gene_locus,sep='\t')
 *         locus = locus.dropna(axis=0)
 */
    goto __pyx_L27;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3284
 *                 locusdic[name] = ''
 *     else:
 *         locusdic = None             # <<<<<<<<<<<<<<
 * 
 *     #Set first seed by extracting specific index part
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_locusdic = ((PyObject*)Py_None);
  }
  __pyx_L27:;

  /* "revealer/REVEALER_runbenchmark.pyx":3287
 * 
 *     #Set first seed by extracting specific index part
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         newseed_names = []
 *         for i in seedIndex:
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_seed_name, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3287, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_9) {

    /* "revealer/REVEALER_runbenchmark.pyx":3288
 *     #Set first seed by extracting specific index part
 *     if seed_name != None:
 *         newseed_names = []             # <<<<<<<<<<<<<<
 *         for i in seedIndex:
 *             newseed_names.append(comb.index.tolist()[i])
 */
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_newseed_names = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3289
 *     if seed_name != None:
 *         newseed_names = []
 *         for i in seedIndex:             # <<<<<<<<<<<<<<
 *             newseed_names.append(comb.index.tolist()[i])
 *         currentseed = seedcomball(comb,newseed_names)
 */
    __pyx_t_5 = __pyx_v_seedIndex; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
    for (;;) {
      if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3289, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3290
 *         newseed_names = []
 *         for i in seedIndex:
 *             newseed_names.append(comb.index.tolist()[i])             # <<<<<<<<<<<<<<
 *         currentseed = seedcomball(comb,newseed_names)
 *         comb = comb.drop(index=newseed_names)
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_2 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_newseed_names, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3290, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3289
 *     if seed_name != None:
 *         newseed_names = []
 *         for i in seedIndex:             # <<<<<<<<<<<<<<
 *             newseed_names.append(comb.index.tolist()[i])
 *         currentseed = seedcomball(comb,newseed_names)
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3291
 *         for i in seedIndex:
 *             newseed_names.append(comb.index.tolist()[i])
 *         currentseed = seedcomball(comb,newseed_names)             # <<<<<<<<<<<<<<
 *         comb = comb.drop(index=newseed_names)
 *         comb.loc['firstseed'] = currentseed
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_seedcomball); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    __pyx_t_12 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_12 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_comb, __pyx_v_newseed_names};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3291, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_comb, __pyx_v_newseed_names};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3291, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3291, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_INCREF(__pyx_v_comb);
      __Pyx_GIVEREF(__pyx_v_comb);
      PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_12, __pyx_v_comb);
      __Pyx_INCREF(__pyx_v_newseed_names);
      __Pyx_GIVEREF(__pyx_v_newseed_names);
      PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_12, __pyx_v_newseed_names);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_11, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3291, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_currentseed = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3292
 *             newseed_names.append(comb.index.tolist()[i])
 *         currentseed = seedcomball(comb,newseed_names)
 *         comb = comb.drop(index=newseed_names)             # <<<<<<<<<<<<<<
 *         comb.loc['firstseed'] = currentseed
 *         if gene_set != None:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_drop); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_index, __pyx_v_newseed_names) < 0) __PYX_ERR(0, 3292, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_11);
    __pyx_t_11 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3293
 *         currentseed = seedcomball(comb,newseed_names)
 *         comb = comb.drop(index=newseed_names)
 *         comb.loc['firstseed'] = currentseed             # <<<<<<<<<<<<<<
 *         if gene_set != None:
 *             inset_list = []
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_loc); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (unlikely(PyObject_SetItem(__pyx_t_11, __pyx_n_u_firstseed, __pyx_v_currentseed) < 0)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "revealer/REVEALER_runbenchmark.pyx":3294
 *         comb = comb.drop(index=newseed_names)
 *         comb.loc['firstseed'] = currentseed
 *         if gene_set != None:             # <<<<<<<<<<<<<<
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[2:]:
 */
    __pyx_t_11 = PyObject_RichCompare(__pyx_v_gene_set, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3294, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3294, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":3295
 *         comb.loc['firstseed'] = currentseed
 *         if gene_set != None:
 *             inset_list = []             # <<<<<<<<<<<<<<
 *             for feature_name in comb.index.tolist()[2:]:
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 */
      __pyx_t_11 = PyList_New(0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3295, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_v_inset_list = ((PyObject*)__pyx_t_11);
      __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3296
 *         if gene_set != None:
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[2:]:             # <<<<<<<<<<<<<<
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True,True]+inset_list
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_tolist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_11 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_t_11, 2, 0, NULL, NULL, &__pyx_slice__13, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
        __pyx_t_11 = __pyx_t_5; __Pyx_INCREF(__pyx_t_11); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_11 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3296, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_8 = Py_TYPE(__pyx_t_11)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3296, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      for (;;) {
        if (likely(!__pyx_t_8)) {
          if (likely(PyList_CheckExact(__pyx_t_11))) {
            if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_11)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3296, __pyx_L1_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_11, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3296, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_11)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_11, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3296, __pyx_L1_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_11, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3296, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_8(__pyx_t_11);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3296, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_XDECREF_SET(__pyx_v_feature_name, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3297
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[2:]:
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))             # <<<<<<<<<<<<<<
 *             inset_list = [True,True]+inset_list
 *             comb = comb.iloc[inset_list]
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_check_inset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3297, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_12 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_v_gene_set, __pyx_v_feature_name, __pyx_v_gene_separator};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3297, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_v_gene_set, __pyx_v_feature_name, __pyx_v_gene_separator};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3297, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3297, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_2) {
            __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
          }
          __Pyx_INCREF(__pyx_v_gene_set);
          __Pyx_GIVEREF(__pyx_v_gene_set);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_12, __pyx_v_gene_set);
          __Pyx_INCREF(__pyx_v_feature_name);
          __Pyx_GIVEREF(__pyx_v_feature_name);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_12, __pyx_v_feature_name);
          __Pyx_INCREF(__pyx_v_gene_separator);
          __Pyx_GIVEREF(__pyx_v_gene_separator);
          PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_12, __pyx_v_gene_separator);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3297, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_inset_list, __pyx_t_5); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3297, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3296
 *         if gene_set != None:
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[2:]:             # <<<<<<<<<<<<<<
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True,True]+inset_list
 */
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3298
 *             for feature_name in comb.index.tolist()[2:]:
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True,True]+inset_list             # <<<<<<<<<<<<<<
 *             comb = comb.iloc[inset_list]
 *     else:
 */
      __pyx_t_11 = PyList_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(Py_True);
      __Pyx_GIVEREF(Py_True);
      PyList_SET_ITEM(__pyx_t_11, 0, Py_True);
      __Pyx_INCREF(Py_True);
      __Pyx_GIVEREF(Py_True);
      PyList_SET_ITEM(__pyx_t_11, 1, Py_True);
      __pyx_t_5 = PyNumber_Add(__pyx_t_11, __pyx_v_inset_list); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF_SET(__pyx_v_inset_list, ((PyObject*)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3299
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True,True]+inset_list
 *             comb = comb.iloc[inset_list]             # <<<<<<<<<<<<<<
 *     else:
 *         if gene_set != None:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_inset_list); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3294
 *         comb = comb.drop(index=newseed_names)
 *         comb.loc['firstseed'] = currentseed
 *         if gene_set != None:             # <<<<<<<<<<<<<<
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[2:]:
 */
    }

    /* "revealer/REVEALER_runbenchmark.pyx":3287
 * 
 *     #Set first seed by extracting specific index part
 *     if seed_name != None:             # <<<<<<<<<<<<<<
 *         newseed_names = []
 *         for i in seedIndex:
 */
    goto __pyx_L31;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3301
 *             comb = comb.iloc[inset_list]
 *     else:
 *         if gene_set != None:             # <<<<<<<<<<<<<<
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[1:]:
 */
  /*else*/ {
    __pyx_t_11 = PyObject_RichCompare(__pyx_v_gene_set, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3301, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3301, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_9) {

      /* "revealer/REVEALER_runbenchmark.pyx":3302
 *     else:
 *         if gene_set != None:
 *             inset_list = []             # <<<<<<<<<<<<<<
 *             for feature_name in comb.index.tolist()[1:]:
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 */
      __pyx_t_11 = PyList_New(0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_v_inset_list = ((PyObject*)__pyx_t_11);
      __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3303
 *         if gene_set != None:
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True]+inset_list
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tolist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_11 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_11, 1, 0, NULL, NULL, &__pyx_slice__20, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_11 = __pyx_t_1; __Pyx_INCREF(__pyx_t_11); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_11 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3303, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_8 = Py_TYPE(__pyx_t_11)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3303, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_8)) {
          if (likely(PyList_CheckExact(__pyx_t_11))) {
            if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_11)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3303, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_11, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3303, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_11)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_11, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3303, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_11, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3303, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_8(__pyx_t_11);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3303, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_feature_name, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3304
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[1:]:
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))             # <<<<<<<<<<<<<<
 *             inset_list = [True]+inset_list
 *             comb = comb.iloc[inset_list]
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_check_inset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3304, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_12 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_gene_set, __pyx_v_feature_name, __pyx_v_gene_separator};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3304, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_gene_set, __pyx_v_feature_name, __pyx_v_gene_separator};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3304, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_2 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3304, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (__pyx_t_6) {
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
          }
          __Pyx_INCREF(__pyx_v_gene_set);
          __Pyx_GIVEREF(__pyx_v_gene_set);
          PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_12, __pyx_v_gene_set);
          __Pyx_INCREF(__pyx_v_feature_name);
          __Pyx_GIVEREF(__pyx_v_feature_name);
          PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_12, __pyx_v_feature_name);
          __Pyx_INCREF(__pyx_v_gene_separator);
          __Pyx_GIVEREF(__pyx_v_gene_separator);
          PyTuple_SET_ITEM(__pyx_t_2, 2+__pyx_t_12, __pyx_v_gene_separator);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3304, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_inset_list, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3304, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "revealer/REVEALER_runbenchmark.pyx":3303
 *         if gene_set != None:
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True]+inset_list
 */
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3305
 *             for feature_name in comb.index.tolist()[1:]:
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True]+inset_list             # <<<<<<<<<<<<<<
 *             comb = comb.iloc[inset_list]
 * 
 */
      __pyx_t_11 = PyList_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(Py_True);
      __Pyx_GIVEREF(Py_True);
      PyList_SET_ITEM(__pyx_t_11, 0, Py_True);
      __pyx_t_1 = PyNumber_Add(__pyx_t_11, __pyx_v_inset_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF_SET(__pyx_v_inset_list, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3306
 *                 inset_list.append(check_inset(gene_set,feature_name,gene_separator))
 *             inset_list = [True]+inset_list
 *             comb = comb.iloc[inset_list]             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_comb, __pyx_n_s_iloc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_inset_list); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_comb, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "revealer/REVEALER_runbenchmark.pyx":3301
 *             comb = comb.iloc[inset_list]
 *     else:
 *         if gene_set != None:             # <<<<<<<<<<<<<<
 *             inset_list = []
 *             for feature_name in comb.index.tolist()[1:]:
 */
    }
  }
  __pyx_L31:;

  /* "revealer/REVEALER_runbenchmark.pyx":3309
 * 
 * 
 *     print('Done reading input files')             # <<<<<<<<<<<<<<
 * 
 *     return comb,locusdic
 */
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3311
 *     print('Done reading input files')
 * 
 *     return comb,locusdic             # <<<<<<<<<<<<<<
 * 
 * def check_inset(gene_set,feature_name,gene_separator):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_INCREF(__pyx_v_comb);
  __Pyx_GIVEREF(__pyx_v_comb);
  PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_v_comb);
  __Pyx_INCREF(__pyx_v_locusdic);
  __Pyx_GIVEREF(__pyx_v_locusdic);
  PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_v_locusdic);
  __pyx_r = __pyx_t_11;
  __pyx_t_11 = 0;
  goto __pyx_L0;

  /* "revealer/REVEALER_runbenchmark.pyx":3158
 *     return currentseed
 * 
 * def readInput(             # <<<<<<<<<<<<<<
 *     target_file,    #Name of target file
 *     feature_file,   #Name of feature file
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.readInput", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF(__pyx_v_feature);
  __Pyx_XDECREF(__pyx_v_patient);
  __Pyx_XDECREF(__pyx_v_commoncol);
  __Pyx_XDECREF(__pyx_v_comb);
  __Pyx_XDECREF(__pyx_v_seed_df);
  __Pyx_XDECREF(__pyx_v_rmrow);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_seedIndex);
  __Pyx_XDECREF(__pyx_v_locus);
  __Pyx_XDECREF(__pyx_v_locusdic);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_genename);
  __Pyx_XDECREF(__pyx_v_newseed_names);
  __Pyx_XDECREF(__pyx_v_currentseed);
  __Pyx_XDECREF(__pyx_v_inset_list);
  __Pyx_XDECREF(__pyx_v_feature_name);
  __Pyx_XDECREF(__pyx_v_low_threshold);
  __Pyx_XDECREF(__pyx_v_high_threshold);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "revealer/REVEALER_runbenchmark.pyx":3313
 *     return comb,locusdic
 * 
 * def check_inset(gene_set,feature_name,gene_separator):             # <<<<<<<<<<<<<<
 *     if feature_name.split(gene_separator)[0] in gene_set:
 *         return True
 */

/* Python wrapper */
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_71check_inset(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_8revealer_21REVEALER_runbenchmark_71check_inset = {"check_inset", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_71check_inset, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_8revealer_21REVEALER_runbenchmark_71check_inset(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_gene_set = 0;
  PyObject *__pyx_v_feature_name = 0;
  PyObject *__pyx_v_gene_separator = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_inset (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_gene_set,&__pyx_n_s_feature_name,&__pyx_n_s_gene_separator,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_set)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_feature_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("check_inset", 1, 3, 3, 1); __PYX_ERR(0, 3313, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_gene_separator)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("check_inset", 1, 3, 3, 2); __PYX_ERR(0, 3313, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "check_inset") < 0)) __PYX_ERR(0, 3313, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_gene_set = values[0];
    __pyx_v_feature_name = values[1];
    __pyx_v_gene_separator = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("check_inset", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3313, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.check_inset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8revealer_21REVEALER_runbenchmark_70check_inset(__pyx_self, __pyx_v_gene_set, __pyx_v_feature_name, __pyx_v_gene_separator);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8revealer_21REVEALER_runbenchmark_70check_inset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_gene_set, PyObject *__pyx_v_feature_name, PyObject *__pyx_v_gene_separator) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_inset", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":3314
 * 
 * def check_inset(gene_set,feature_name,gene_separator):
 *     if feature_name.split(gene_separator)[0] in gene_set:             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_feature_name, __pyx_n_s_split); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_gene_separator) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_gene_separator);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_v_gene_set, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "revealer/REVEALER_runbenchmark.pyx":3315
 * def check_inset(gene_set,feature_name,gene_separator):
 *     if feature_name.split(gene_separator)[0] in gene_set:
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "revealer/REVEALER_runbenchmark.pyx":3314
 * 
 * def check_inset(gene_set,feature_name,gene_separator):
 *     if feature_name.split(gene_separator)[0] in gene_set:             # <<<<<<<<<<<<<<
 *         return True
 *     else:
 */
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3317
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }

  /* "revealer/REVEALER_runbenchmark.pyx":3313
 *     return comb,locusdic
 * 
 * def check_inset(gene_set,feature_name,gene_separator):             # <<<<<<<<<<<<<<
 *     if feature_name.split(gene_separator)[0] in gene_set:
 *         return True
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark.check_inset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":735
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":736
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":735
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":738
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":739
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":738
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":741
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":742
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":741
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":744
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":745
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":744
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":747
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":748
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":747
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":750
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":751
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = (PyDataType_HASSUBARRAY(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":752
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":751
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":754
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":750
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":929
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":930
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":931
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  (void)(PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base));

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":929
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":933
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":934
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":935
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = ((__pyx_v_base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":936
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":935
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":937
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":933
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":941
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":942
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":943
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 943, __pyx_L3_error)

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":942
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":944
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 944, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":945
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 945, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 945, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":942
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":941
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":947
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":948
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":949
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 949, __pyx_L3_error)

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":948
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":950
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 950, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":951
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 951, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 951, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":948
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":947
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":953
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":954
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":955
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 955, __pyx_L3_error)

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":954
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":956
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 956, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":957
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef extern from *:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 957, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 957, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":954
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":953
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":967
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_timedelta64_object", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":979
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":967
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":982
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_datetime64_object", 0);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":994
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":982
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":997
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1004
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":997
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1007
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1011
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1007
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1014
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1018
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":1014
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":122
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

/* Python wrapper */
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_shape = 0;
  Py_ssize_t __pyx_v_itemsize;
  PyObject *__pyx_v_format = 0;
  PyObject *__pyx_v_mode = 0;
  int __pyx_v_allocate_buffer;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_shape,&__pyx_n_s_itemsize,&__pyx_n_s_format,&__pyx_n_s_mode,&__pyx_n_s_allocate_buffer,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[3] = ((PyObject *)__pyx_n_s_c);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_shape)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_itemsize)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 1); __PYX_ERR(2, 122, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_format)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 2); __PYX_ERR(2, 122, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mode);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_allocate_buffer);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(2, 122, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_shape = ((PyObject*)values[0]);
    __pyx_v_itemsize = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_itemsize == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 122, __pyx_L3_error)
    __pyx_v_format = values[2];
    __pyx_v_mode = values[3];
    if (values[4]) {
      __pyx_v_allocate_buffer = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_allocate_buffer == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 123, __pyx_L3_error)
    } else {

      /* "View.MemoryView":123
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,
 *                   mode="c", bint allocate_buffer=True):             # <<<<<<<<<<<<<<
 * 
 *         cdef int idx
 */
      __pyx_v_allocate_buffer = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 122, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_shape), (&PyTuple_Type), 1, "shape", 1))) __PYX_ERR(2, 122, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_format) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "format"); __PYX_ERR(2, 122, __pyx_L1_error)
  }
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v_shape, __pyx_v_itemsize, __pyx_v_format, __pyx_v_mode, __pyx_v_allocate_buffer);

  /* "View.MemoryView":122
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_dim;
  PyObject **__pyx_v_p;
  char __pyx_v_order;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_INCREF(__pyx_v_format);

  /* "View.MemoryView":129
 *         cdef PyObject **p
 * 
 *         self.ndim = <int> len(shape)             # <<<<<<<<<<<<<<
 *         self.itemsize = itemsize
 * 
 */
  if (unlikely(__pyx_v_shape == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(2, 129, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_GET_SIZE(__pyx_v_shape); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 129, __pyx_L1_error)
  __pyx_v_self->ndim = ((int)__pyx_t_1);

  /* "View.MemoryView":130
 * 
 *         self.ndim = <int> len(shape)
 *         self.itemsize = itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not self.ndim:
 */
  __pyx_v_self->itemsize = __pyx_v_itemsize;

  /* "View.MemoryView":132
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError("Empty shape tuple for cython.array")
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_self->ndim != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":133
 * 
 *         if not self.ndim:
 *             raise ValueError("Empty shape tuple for cython.array")             # <<<<<<<<<<<<<<
 * 
 *         if itemsize <= 0:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 133, __pyx_L1_error)

    /* "View.MemoryView":132
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError("Empty shape tuple for cython.array")
 * 
 */
  }

  /* "View.MemoryView":135
 *             raise ValueError("Empty shape tuple for cython.array")
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("itemsize <= 0 for cython.array")
 * 
 */
  __pyx_t_2 = ((__pyx_v_itemsize <= 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":136
 * 
 *         if itemsize <= 0:
 *             raise ValueError("itemsize <= 0 for cython.array")             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(format, bytes):
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 136, __pyx_L1_error)

    /* "View.MemoryView":135
 *             raise ValueError("Empty shape tuple for cython.array")
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("itemsize <= 0 for cython.array")
 * 
 */
  }

  /* "View.MemoryView":138
 *             raise ValueError("itemsize <= 0 for cython.array")
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_format); 
  __pyx_t_4 = ((!(__pyx_t_2 != 0)) != 0);
  if (__pyx_t_4) {

    /* "View.MemoryView":139
 * 
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')             # <<<<<<<<<<<<<<
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_format, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_n_s_ASCII) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_s_ASCII);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_format, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":138
 *             raise ValueError("itemsize <= 0 for cython.array")
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  }

  /* "View.MemoryView":140
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string             # <<<<<<<<<<<<<<
 *         self.format = self._format
 * 
 */
  if (!(likely(PyBytes_CheckExact(__pyx_v_format))||((__pyx_v_format) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_v_format)->tp_name), 0))) __PYX_ERR(2, 140, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_format;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->_format);
  __Pyx_DECREF(__pyx_v_self->_format);
  __pyx_v_self->_format = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "View.MemoryView":141
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_self->_format == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(2, 141, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyBytes_AsWritableString(__pyx_v_self->_format); if (unlikely((!__pyx_t_7) && PyErr_Occurred())) __PYX_ERR(2, 141, __pyx_L1_error)
  __pyx_v_self->format = __pyx_t_7;

  /* "View.MemoryView":144
 * 
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)             # <<<<<<<<<<<<<<
 *         self._strides = self._shape + self.ndim
 * 
 */
  __pyx_v_self->_shape = ((Py_ssize_t *)PyObject_Malloc((((sizeof(Py_ssize_t)) * __pyx_v_self->ndim) * 2)));

  /* "View.MemoryView":145
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)
 *         self._strides = self._shape + self.ndim             # <<<<<<<<<<<<<<
 * 
 *         if not self._shape:
 */
  __pyx_v_self->_strides = (__pyx_v_self->_shape + __pyx_v_self->ndim);

  /* "View.MemoryView":147
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError("unable to allocate shape and strides.")
 * 
 */
  __pyx_t_4 = ((!(__pyx_v_self->_shape != 0)) != 0);
  if (unlikely(__pyx_t_4)) {

    /* "View.MemoryView":148
 * 
 *         if not self._shape:
 *             raise MemoryError("unable to allocate shape and strides.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 148, __pyx_L1_error)

    /* "View.MemoryView":147
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError("unable to allocate shape and strides.")
 * 
 */
  }

  /* "View.MemoryView":151
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError("Invalid shape in axis %d: %d." % (idx, dim))
 */
  __pyx_t_8 = 0;
  __pyx_t_3 = __pyx_v_shape; __Pyx_INCREF(__pyx_t_3); __pyx_t_1 = 0;
  for (;;) {
    if (__pyx_t_1 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely(0 < 0)) __PYX_ERR(2, 151, __pyx_L1_error)
    #else
    __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 151, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_9;
    __pyx_v_idx = __pyx_t_8;
    __pyx_t_8 = (__pyx_t_8 + 1);

    /* "View.MemoryView":152
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Invalid shape in axis %d: %d." % (idx, dim))
 *             self._shape[idx] = dim
 */
    __pyx_t_4 = ((__pyx_v_dim <= 0) != 0);
    if (unlikely(__pyx_t_4)) {

      /* "View.MemoryView":153
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:
 *                 raise ValueError("Invalid shape in axis %d: %d." % (idx, dim))             # <<<<<<<<<<<<<<
 *             self._shape[idx] = dim
 * 
 */
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_idx); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_dim); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_6);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyString_Format(__pyx_kp_s_Invalid_shape_in_axis_d_d, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(2, 153, __pyx_L1_error)

      /* "View.MemoryView":152
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Invalid shape in axis %d: %d." % (idx, dim))
 *             self._shape[idx] = dim
 */
    }

    /* "View.MemoryView":154
 *             if dim <= 0:
 *                 raise ValueError("Invalid shape in axis %d: %d." % (idx, dim))
 *             self._shape[idx] = dim             # <<<<<<<<<<<<<<
 * 
 *         cdef char order
 */
    (__pyx_v_self->_shape[__pyx_v_idx]) = __pyx_v_dim;

    /* "View.MemoryView":151
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError("Invalid shape in axis %d: %d." % (idx, dim))
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "View.MemoryView":157
 * 
 *         cdef char order
 *         if mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_fortran, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 157, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "View.MemoryView":158
 *         cdef char order
 *         if mode == 'fortran':
 *             order = b'F'             # <<<<<<<<<<<<<<
 *             self.mode = u'fortran'
 *         elif mode == 'c':
 */
    __pyx_v_order = 'F';

    /* "View.MemoryView":159
 *         if mode == 'fortran':
 *             order = b'F'
 *             self.mode = u'fortran'             # <<<<<<<<<<<<<<
 *         elif mode == 'c':
 *             order = b'C'
 */
    __Pyx_INCREF(__pyx_n_u_fortran);
    __Pyx_GIVEREF(__pyx_n_u_fortran);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_fortran;

    /* "View.MemoryView":157
 * 
 *         cdef char order
 *         if mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
    goto __pyx_L10;
  }

  /* "View.MemoryView":160
 *             order = b'F'
 *             self.mode = u'fortran'
 *         elif mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_c, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 160, __pyx_L1_error)
  if (likely(__pyx_t_4)) {

    /* "View.MemoryView":161
 *             self.mode = u'fortran'
 *         elif mode == 'c':
 *             order = b'C'             # <<<<<<<<<<<<<<
 *             self.mode = u'c'
 *         else:
 */
    __pyx_v_order = 'C';

    /* "View.MemoryView":162
 *         elif mode == 'c':
 *             order = b'C'
 *             self.mode = u'c'             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("Invalid mode, expected 'c' or 'fortran', got %s" % mode)
 */
    __Pyx_INCREF(__pyx_n_u_c);
    __Pyx_GIVEREF(__pyx_n_u_c);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_c;

    /* "View.MemoryView":160
 *             order = b'F'
 *             self.mode = u'fortran'
 *         elif mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
    goto __pyx_L10;
  }

  /* "View.MemoryView":164
 *             self.mode = u'c'
 *         else:
 *             raise ValueError("Invalid mode, expected 'c' or 'fortran', got %s" % mode)             # <<<<<<<<<<<<<<
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides,
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyString_FormatSafe(__pyx_kp_s_Invalid_mode_expected_c_or_fortr, __pyx_v_mode); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_10, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __PYX_ERR(2, 164, __pyx_L1_error)
  }
  __pyx_L10:;

  /* "View.MemoryView":166
 *             raise ValueError("Invalid mode, expected 'c' or 'fortran', got %s" % mode)
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides,             # <<<<<<<<<<<<<<
 *                                              itemsize, self.ndim, order)
 * 
 */
  __pyx_v_self->len = __pyx_fill_contig_strides_array(__pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_itemsize, __pyx_v_self->ndim, __pyx_v_order);

  /* "View.MemoryView":169
 *                                              itemsize, self.ndim, order)
 * 
 *         self.free_data = allocate_buffer             # <<<<<<<<<<<<<<
 *         self.dtype_is_object = format == b'O'
 *         if allocate_buffer:
 */
  __pyx_v_self->free_data = __pyx_v_allocate_buffer;

  /* "View.MemoryView":170
 * 
 *         self.free_data = allocate_buffer
 *         self.dtype_is_object = format == b'O'             # <<<<<<<<<<<<<<
 *         if allocate_buffer:
 * 
 */
  __pyx_t_10 = PyObject_RichCompare(__pyx_v_format, __pyx_n_b_O, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 170, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_v_self->dtype_is_object = __pyx_t_4;

  /* "View.MemoryView":171
 *         self.free_data = allocate_buffer
 *         self.dtype_is_object = format == b'O'
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = (__pyx_v_allocate_buffer != 0);
  if (__pyx_t_4) {

    /* "View.MemoryView":174
 * 
 * 
 *             self.data = <char *>malloc(self.len)             # <<<<<<<<<<<<<<
 *             if not self.data:
 *                 raise MemoryError("unable to allocate array data.")
 */
    __pyx_v_self->data = ((char *)malloc(__pyx_v_self->len));

    /* "View.MemoryView":175
 * 
 *             self.data = <char *>malloc(self.len)
 *             if not self.data:             # <<<<<<<<<<<<<<
 *                 raise MemoryError("unable to allocate array data.")
 * 
 */
    __pyx_t_4 = ((!(__pyx_v_self->data != 0)) != 0);
    if (unlikely(__pyx_t_4)) {

      /* "View.MemoryView":176
 *             self.data = <char *>malloc(self.len)
 *             if not self.data:
 *                 raise MemoryError("unable to allocate array data.")             # <<<<<<<<<<<<<<
 * 
 *             if self.dtype_is_object:
 */
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_MemoryError, __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(2, 176, __pyx_L1_error)

      /* "View.MemoryView":175
 * 
 *             self.data = <char *>malloc(self.len)
 *             if not self.data:             # <<<<<<<<<<<<<<
 *                 raise MemoryError("unable to allocate array data.")
 * 
 */
    }

    /* "View.MemoryView":178
 *                 raise MemoryError("unable to allocate array data.")
 * 
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 p = <PyObject **> self.data
 *                 for i in range(self.len / itemsize):
 */
    __pyx_t_4 = (__pyx_v_self->dtype_is_object != 0);
    if (__pyx_t_4) {

      /* "View.MemoryView":179
 * 
 *             if self.dtype_is_object:
 *                 p = <PyObject **> self.data             # <<<<<<<<<<<<<<
 *                 for i in range(self.len / itemsize):
 *                     p[i] = Py_None
 */
      __pyx_v_p = ((PyObject **)__pyx_v_self->data);

      /* "View.MemoryView":180
 *             if self.dtype_is_object:
 *                 p = <PyObject **> self.data
 *                 for i in range(self.len / itemsize):             # <<<<<<<<<<<<<<
 *                     p[i] = Py_None
 *                     Py_INCREF(Py_None)
 */
      if (unlikely(__pyx_v_itemsize == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
        __PYX_ERR(2, 180, __pyx_L1_error)
      }
      else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_itemsize == (Py_ssize_t)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->len))) {
        PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
        __PYX_ERR(2, 180, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_div_Py_ssize_t(__pyx_v_self->len, __pyx_v_itemsize);
      __pyx_t_9 = __pyx_t_1;
      for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_9; __pyx_t_11+=1) {
        __pyx_v_i = __pyx_t_11;

        /* "View.MemoryView":181
 *                 p = <PyObject **> self.data
 *                 for i in range(self.len / itemsize):
 *                     p[i] = Py_None             # <<<<<<<<<<<<<<
 *                     Py_INCREF(Py_None)
 * 
 */
        (__pyx_v_p[__pyx_v_i]) = Py_None;

        /* "View.MemoryView":182
 *                 for i in range(self.len / itemsize):
 *                     p[i] = Py_None
 *                     Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
        Py_INCREF(Py_None);
      }

      /* "View.MemoryView":178
 *                 raise MemoryError("unable to allocate array data.")
 * 
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 p = <PyObject **> self.data
 *                 for i in range(self.len / itemsize):
 */
    }

    /* "View.MemoryView":171
 *         self.free_data = allocate_buffer
 *         self.dtype_is_object = format == b'O'
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":122
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_format);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":185
 * 
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):             # <<<<<<<<<<<<<<
 *         cdef int bufmode = -1
 *         if self.mode == u"c":
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(((struct __pyx_array_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_bufmode;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  char *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (__pyx_v_info == NULL) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":186
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1             # <<<<<<<<<<<<<<
 *         if self.mode == u"c":
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  __pyx_v_bufmode = -1;

  /* "View.MemoryView":187
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if self.mode == u"c":             # <<<<<<<<<<<<<<
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         elif self.mode == u"fortran":
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_c, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 187, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":188
 *         cdef int bufmode = -1
 *         if self.mode == u"c":
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *         elif self.mode == u"fortran":
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
    __pyx_v_bufmode = (PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

    /* "View.MemoryView":187
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if self.mode == u"c":             # <<<<<<<<<<<<<<
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         elif self.mode == u"fortran":
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":189
 *         if self.mode == u"c":
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         if not (flags & bufmode):
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_fortran, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 189, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":190
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         elif self.mode == u"fortran":
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *         if not (flags & bufmode):
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")
 */
    __pyx_v_bufmode = (PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

    /* "View.MemoryView":189
 *         if self.mode == u"c":
 *             bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         if not (flags & bufmode):
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":191
 *         elif self.mode == u"fortran":
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")
 *         info.buf = self.data
 */
  __pyx_t_1 = ((!((__pyx_v_flags & __pyx_v_bufmode) != 0)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":192
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         if not (flags & bufmode):
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")             # <<<<<<<<<<<<<<
 *         info.buf = self.data
 *         info.len = self.len
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 192, __pyx_L1_error)

    /* "View.MemoryView":191
 *         elif self.mode == u"fortran":
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")
 *         info.buf = self.data
 */
  }

  /* "View.MemoryView":193
 *         if not (flags & bufmode):
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")
 *         info.buf = self.data             # <<<<<<<<<<<<<<
 *         info.len = self.len
 *         info.ndim = self.ndim
 */
  __pyx_t_4 = __pyx_v_self->data;
  __pyx_v_info->buf = __pyx_t_4;

  /* "View.MemoryView":194
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")
 *         info.buf = self.data
 *         info.len = self.len             # <<<<<<<<<<<<<<
 *         info.ndim = self.ndim
 *         info.shape = self._shape
 */
  __pyx_t_5 = __pyx_v_self->len;
  __pyx_v_info->len = __pyx_t_5;

  /* "View.MemoryView":195
 *         info.buf = self.data
 *         info.len = self.len
 *         info.ndim = self.ndim             # <<<<<<<<<<<<<<
 *         info.shape = self._shape
 *         info.strides = self._strides
 */
  __pyx_t_6 = __pyx_v_self->ndim;
  __pyx_v_info->ndim = __pyx_t_6;

  /* "View.MemoryView":196
 *         info.len = self.len
 *         info.ndim = self.ndim
 *         info.shape = self._shape             # <<<<<<<<<<<<<<
 *         info.strides = self._strides
 *         info.suboffsets = NULL
 */
  __pyx_t_7 = __pyx_v_self->_shape;
  __pyx_v_info->shape = __pyx_t_7;

  /* "View.MemoryView":197
 *         info.ndim = self.ndim
 *         info.shape = self._shape
 *         info.strides = self._strides             # <<<<<<<<<<<<<<
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize
 */
  __pyx_t_7 = __pyx_v_self->_strides;
  __pyx_v_info->strides = __pyx_t_7;

  /* "View.MemoryView":198
 *         info.shape = self._shape
 *         info.strides = self._strides
 *         info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 */
  __pyx_v_info->suboffsets = NULL;

  /* "View.MemoryView":199
 *         info.strides = self._strides
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize             # <<<<<<<<<<<<<<
 *         info.readonly = 0
 * 
 */
  __pyx_t_5 = __pyx_v_self->itemsize;
  __pyx_v_info->itemsize = __pyx_t_5;

  /* "View.MemoryView":200
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize
 *         info.readonly = 0             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
  __pyx_v_info->readonly = 0;

  /* "View.MemoryView":202
 *         info.readonly = 0
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.format
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":203
 * 
 *         if flags & PyBUF_FORMAT:
 *             info.format = self.format             # <<<<<<<<<<<<<<
 *         else:
 *             info.format = NULL
 */
    __pyx_t_4 = __pyx_v_self->format;
    __pyx_v_info->format = __pyx_t_4;

    /* "View.MemoryView":202
 *         info.readonly = 0
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.format
 *         else:
 */
    goto __pyx_L5;
  }

  /* "View.MemoryView":205
 *             info.format = self.format
 *         else:
 *             info.format = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.obj = self
 */
  /*else*/ {
    __pyx_v_info->format = NULL;
  }
  __pyx_L5:;

  /* "View.MemoryView":207
 *             info.format = NULL
 * 
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 *     __pyx_getbuffer = capsule(<void *> &__pyx_array_getbuffer, "getbuffer(obj, view, flags)")
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":185
 * 
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):             # <<<<<<<<<<<<<<
 *         cdef int bufmode = -1
 *         if self.mode == u"c":
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":211
 *     __pyx_getbuffer = capsule(<void *> &__pyx_array_getbuffer, "getbuffer(obj, view, flags)")
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

/* Python wrapper */
static void __pyx_array___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_array___dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "View.MemoryView":212
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data:
 */
  __pyx_t_1 = ((__pyx_v_self->callback_free_data != NULL) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":213
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)             # <<<<<<<<<<<<<<
 *         elif self.free_data:
 *             if self.dtype_is_object:
 */
    __pyx_v_self->callback_free_data(__pyx_v_self->data);

    /* "View.MemoryView":212
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":214
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape,
 */
  __pyx_t_1 = (__pyx_v_self->free_data != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":215
 *             self.callback_free_data(self.data)
 *         elif self.free_data:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape,
 *                                           self._strides, self.ndim, False)
 */
    __pyx_t_1 = (__pyx_v_self->dtype_is_object != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":216
 *         elif self.free_data:
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape,             # <<<<<<<<<<<<<<
 *                                           self._strides, self.ndim, False)
 *             free(self.data)
 */
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_self->data, __pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_self->ndim, 0);

      /* "View.MemoryView":215
 *             self.callback_free_data(self.data)
 *         elif self.free_data:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape,
 *                                           self._strides, self.ndim, False)
 */
    }

    /* "View.MemoryView":218
 *                 refcount_objects_in_slice(self.data, self._shape,
 *                                           self._strides, self.ndim, False)
 *             free(self.data)             # <<<<<<<<<<<<<<
 *         PyObject_Free(self._shape)
 * 
 */
    free(__pyx_v_self->data);

    /* "View.MemoryView":214
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape,
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":219
 *                                           self._strides, self.ndim, False)
 *             free(self.data)
 *         PyObject_Free(self._shape)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  PyObject_Free(__pyx_v_self->_shape);

  /* "View.MemoryView":211
 *     __pyx_getbuffer = capsule(<void *> &__pyx_array_getbuffer, "getbuffer(obj, view, flags)")
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":222
 * 
 *     @property
 *     def memview(self):             # <<<<<<<<<<<<<<
 *         return self.get_memview()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_5array_7memview___get__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":223
 *     @property
 *     def memview(self):
 *         return self.get_memview()             # <<<<<<<<<<<<<<
 * 
 *     @cname('get_memview')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_array *)__pyx_v_self->__pyx_vtab)->get_memview(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":222
 * 
 *     @property
 *     def memview(self):             # <<<<<<<<<<<<<<
 *         return self.get_memview()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.memview.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":226
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self) {
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_memview", 0);

  /* "View.MemoryView":227
 *     @cname('get_memview')
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE             # <<<<<<<<<<<<<<
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 */
  __pyx_v_flags = ((PyBUF_ANY_CONTIGUOUS | PyBUF_FORMAT) | PyBUF_WRITABLE);

  /* "View.MemoryView":228
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":226
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.array.get_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":230
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "View.MemoryView":231
 * 
 *     def __len__(self):
 *         return self._shape[0]             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, attr):
 */
  __pyx_r = (__pyx_v_self->_shape[0]);
  goto __pyx_L0;

  /* "View.MemoryView":230
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":233
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr); /*proto*/
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_attr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "View.MemoryView":234
 * 
 *     def __getattr__(self, attr):
 *         return getattr(self.memview, attr)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, item):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":233
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":236
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "View.MemoryView":237
 * 
 *     def __getitem__(self, item):
 *         return self.memview[item]             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, item, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_item); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":236
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":239
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

/* Python wrapper */
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /*proto*/
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "View.MemoryView":240
 * 
 *     def __setitem__(self, item, value):
 *         self.memview[item] = value             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(PyObject_SetItem(__pyx_t_1, __pyx_v_item, __pyx_v_value) < 0)) __PYX_ERR(2, 240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":239
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_array___reduce_cython__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_array_2__setstate_cython__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":244
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format,             # <<<<<<<<<<<<<<
 *                           char *mode, char *buf):
 *     cdef array result
 */

static struct __pyx_array_obj *__pyx_array_new(PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, char *__pyx_v_format, char *__pyx_v_mode, char *__pyx_v_buf) {
  struct __pyx_array_obj *__pyx_v_result = 0;
  struct __pyx_array_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("array_cwrapper", 0);

  /* "View.MemoryView":248
 *     cdef array result
 * 
 *     if buf == NULL:             # <<<<<<<<<<<<<<
 *         result = array(shape, itemsize, format, mode.decode('ASCII'))
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_buf == NULL) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":249
 * 
 *     if buf == NULL:
 *         result = array(shape, itemsize, format, mode.decode('ASCII'))             # <<<<<<<<<<<<<<
 *     else:
 *         result = array(shape, itemsize, format, mode.decode('ASCII'),
 */
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_decode_c_string(__pyx_v_mode, 0, strlen(__pyx_v_mode), NULL, NULL, PyUnicode_DecodeASCII); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_array_type), __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "View.MemoryView":248
 *     cdef array result
 * 
 *     if buf == NULL:             # <<<<<<<<<<<<<<
 *         result = array(shape, itemsize, format, mode.decode('ASCII'))
 *     else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":251
 *         result = array(shape, itemsize, format, mode.decode('ASCII'))
 *     else:
 *         result = array(shape, itemsize, format, mode.decode('ASCII'),             # <<<<<<<<<<<<<<
 *                        allocate_buffer=False)
 *         result.data = buf
 */
  /*else*/ {
    __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_decode_c_string(__pyx_v_mode, 0, strlen(__pyx_v_mode), NULL, NULL, PyUnicode_DecodeASCII); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_shape);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_3 = 0;

    /* "View.MemoryView":252
 *     else:
 *         result = array(shape, itemsize, format, mode.decode('ASCII'),
 *                        allocate_buffer=False)             # <<<<<<<<<<<<<<
 *         result.data = buf
 * 
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_allocate_buffer, Py_False) < 0) __PYX_ERR(2, 252, __pyx_L1_error)

    /* "View.MemoryView":251
 *         result = array(shape, itemsize, format, mode.decode('ASCII'))
 *     else:
 *         result = array(shape, itemsize, format, mode.decode('ASCII'),             # <<<<<<<<<<<<<<
 *                        allocate_buffer=False)
 *         result.data = buf
 */
    __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_array_type), __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "View.MemoryView":253
 *         result = array(shape, itemsize, format, mode.decode('ASCII'),
 *                        allocate_buffer=False)
 *         result.data = buf             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __pyx_v_result->data = __pyx_v_buf;
  }
  __pyx_L3:;

  /* "View.MemoryView":255
 *         result.data = buf
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":244
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format,             # <<<<<<<<<<<<<<
 *                           char *mode, char *buf):
 *     cdef array result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.array_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":281
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

/* Python wrapper */
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(2, 281, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_name = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 281, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.Enum.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "View.MemoryView":282
 *     cdef object name
 *     def __init__(self, name):
 *         self.name = name             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return self.name
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_name;

  /* "View.MemoryView":281
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":283
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "View.MemoryView":284
 *         self.name = name
 *     def __repr__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* "View.MemoryView":283
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_MemviewEnum___reduce_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.name,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->name);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, None), state
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->name != Py_None);
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_184977713);
    __Pyx_GIVEREF(__pyx_int_184977713);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_184977713);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, None), state
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_184977713);
    __Pyx_GIVEREF(__pyx_int_184977713);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_184977713);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.Enum.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_MemviewEnum_2__setstate_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(2, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle_Enum__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0xb068931, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":298
 * 
 * @cname('__pyx_align_pointer')
 * cdef void *align_pointer(void *memory, size_t alignment) nogil:             # <<<<<<<<<<<<<<
 *     "Align pointer memory on a given boundary"
 *     cdef Py_intptr_t aligned_p = <Py_intptr_t> memory
 */

static void *__pyx_align_pointer(void *__pyx_v_memory, size_t __pyx_v_alignment) {
  Py_intptr_t __pyx_v_aligned_p;
  size_t __pyx_v_offset;
  void *__pyx_r;
  int __pyx_t_1;

  /* "View.MemoryView":300
 * cdef void *align_pointer(void *memory, size_t alignment) nogil:
 *     "Align pointer memory on a given boundary"
 *     cdef Py_intptr_t aligned_p = <Py_intptr_t> memory             # <<<<<<<<<<<<<<
 *     cdef size_t offset
 * 
 */
  __pyx_v_aligned_p = ((Py_intptr_t)__pyx_v_memory);

  /* "View.MemoryView":304
 * 
 *     with cython.cdivision(True):
 *         offset = aligned_p % alignment             # <<<<<<<<<<<<<<
 * 
 *     if offset > 0:
 */
  __pyx_v_offset = (__pyx_v_aligned_p % __pyx_v_alignment);

  /* "View.MemoryView":306
 *         offset = aligned_p % alignment
 * 
 *     if offset > 0:             # <<<<<<<<<<<<<<
 *         aligned_p += alignment - offset
 * 
 */
  __pyx_t_1 = ((__pyx_v_offset > 0) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":307
 * 
 *     if offset > 0:
 *         aligned_p += alignment - offset             # <<<<<<<<<<<<<<
 * 
 *     return <void *> aligned_p
 */
    __pyx_v_aligned_p = (__pyx_v_aligned_p + (__pyx_v_alignment - __pyx_v_offset));

    /* "View.MemoryView":306
 *         offset = aligned_p % alignment
 * 
 *     if offset > 0:             # <<<<<<<<<<<<<<
 *         aligned_p += alignment - offset
 * 
 */
  }

  /* "View.MemoryView":309
 *         aligned_p += alignment - offset
 * 
 *     return <void *> aligned_p             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((void *)__pyx_v_aligned_p);
  goto __pyx_L0;

  /* "View.MemoryView":298
 * 
 * @cname('__pyx_align_pointer')
 * cdef void *align_pointer(void *memory, size_t alignment) nogil:             # <<<<<<<<<<<<<<
 *     "Align pointer memory on a given boundary"
 *     cdef Py_intptr_t aligned_p = <Py_intptr_t> memory
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":345
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

/* Python wrapper */
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_obj = 0;
  int __pyx_v_flags;
  int __pyx_v_dtype_is_object;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,&__pyx_n_s_flags,&__pyx_n_s_dtype_is_object,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_obj)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_flags)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(2, 345, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dtype_is_object);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(2, 345, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_obj = values[0];
    __pyx_v_flags = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 345, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_dtype_is_object = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_dtype_is_object == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 345, __pyx_L3_error)
    } else {
      __pyx_v_dtype_is_object = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 345, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_obj, __pyx_v_flags, __pyx_v_dtype_is_object);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "View.MemoryView":346
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj             # <<<<<<<<<<<<<<
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 */
  __Pyx_INCREF(__pyx_v_obj);
  __Pyx_GIVEREF(__pyx_v_obj);
  __Pyx_GOTREF(__pyx_v_self->obj);
  __Pyx_DECREF(__pyx_v_self->obj);
  __pyx_v_self->obj = __pyx_v_obj;

  /* "View.MemoryView":347
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj
 *         self.flags = flags             # <<<<<<<<<<<<<<
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 */
  __pyx_v_self->flags = __pyx_v_flags;

  /* "View.MemoryView":348
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  __pyx_t_2 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_memoryview_type));
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_obj != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":349
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)             # <<<<<<<<<<<<<<
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 */
    __pyx_t_4 = __Pyx_GetBuffer(__pyx_v_obj, (&__pyx_v_self->view), __pyx_v_flags); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 349, __pyx_L1_error)

    /* "View.MemoryView":350
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    __pyx_t_1 = ((((PyObject *)__pyx_v_self->view.obj) == NULL) != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":351
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None             # <<<<<<<<<<<<<<
 *                 Py_INCREF(Py_None)
 * 
 */
      ((Py_buffer *)(&__pyx_v_self->view))->obj = Py_None;

      /* "View.MemoryView":352
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         global __pyx_memoryview_thread_locks_used
 */
      Py_INCREF(Py_None);

      /* "View.MemoryView":350
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    }

    /* "View.MemoryView":348
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  }

  /* "View.MemoryView":355
 * 
 *         global __pyx_memoryview_thread_locks_used
 *         if __pyx_memoryview_thread_locks_used < THREAD_LOCKS_PREALLOCATED:             # <<<<<<<<<<<<<<
 *             self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *             __pyx_memoryview_thread_locks_used += 1
 */
  __pyx_t_1 = ((__pyx_memoryview_thread_locks_used < 8) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":356
 *         global __pyx_memoryview_thread_locks_used
 *         if __pyx_memoryview_thread_locks_used < THREAD_LOCKS_PREALLOCATED:
 *             self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]             # <<<<<<<<<<<<<<
 *             __pyx_memoryview_thread_locks_used += 1
 *         if self.lock is NULL:
 */
    __pyx_v_self->lock = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);

    /* "View.MemoryView":357
 *         if __pyx_memoryview_thread_locks_used < THREAD_LOCKS_PREALLOCATED:
 *             self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *             __pyx_memoryview_thread_locks_used += 1             # <<<<<<<<<<<<<<
 *         if self.lock is NULL:
 *             self.lock = PyThread_allocate_lock()
 */
    __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used + 1);

    /* "View.MemoryView":355
 * 
 *         global __pyx_memoryview_thread_locks_used
 *         if __pyx_memoryview_thread_locks_used < THREAD_LOCKS_PREALLOCATED:             # <<<<<<<<<<<<<<
 *             self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *             __pyx_memoryview_thread_locks_used += 1
 */
  }

  /* "View.MemoryView":358
 *             self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *             __pyx_memoryview_thread_locks_used += 1
 *         if self.lock is NULL:             # <<<<<<<<<<<<<<
 *             self.lock = PyThread_allocate_lock()
 *             if self.lock is NULL:
 */
  __pyx_t_1 = ((__pyx_v_self->lock == NULL) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":359
 *             __pyx_memoryview_thread_locks_used += 1
 *         if self.lock is NULL:
 *             self.lock = PyThread_allocate_lock()             # <<<<<<<<<<<<<<
 *             if self.lock is NULL:
 *                 raise MemoryError
 */
    __pyx_v_self->lock = PyThread_allocate_lock();

    /* "View.MemoryView":360
 *         if self.lock is NULL:
 *             self.lock = PyThread_allocate_lock()
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 * 
 */
    __pyx_t_1 = ((__pyx_v_self->lock == NULL) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "View.MemoryView":361
 *             self.lock = PyThread_allocate_lock()
 *             if self.lock is NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
      PyErr_NoMemory(); __PYX_ERR(2, 361, __pyx_L1_error)

      /* "View.MemoryView":360
 *         if self.lock is NULL:
 *             self.lock = PyThread_allocate_lock()
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 * 
 */
    }

    /* "View.MemoryView":358
 *             self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *             __pyx_memoryview_thread_locks_used += 1
 *         if self.lock is NULL:             # <<<<<<<<<<<<<<
 *             self.lock = PyThread_allocate_lock()
 *             if self.lock is NULL:
 */
  }

  /* "View.MemoryView":363
 *                 raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":364
 * 
 *         if flags & PyBUF_FORMAT:
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')             # <<<<<<<<<<<<<<
 *         else:
 *             self.dtype_is_object = dtype_is_object
 */
    __pyx_t_2 = (((__pyx_v_self->view.format[0]) == 'O') != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_2 = (((__pyx_v_self->view.format[1]) == '\x00') != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L11_bool_binop_done:;
    __pyx_v_self->dtype_is_object = __pyx_t_1;

    /* "View.MemoryView":363
 *                 raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
    goto __pyx_L10;
  }

  /* "View.MemoryView":366
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 *             self.dtype_is_object = dtype_is_object             # <<<<<<<<<<<<<<
 * 
 *         self.acquisition_count_aligned_p = <__pyx_atomic_int *> align_pointer(
 */
  /*else*/ {
    __pyx_v_self->dtype_is_object = __pyx_v_dtype_is_object;
  }
  __pyx_L10:;

  /* "View.MemoryView":368
 *             self.dtype_is_object = dtype_is_object
 * 
 *         self.acquisition_count_aligned_p = <__pyx_atomic_int *> align_pointer(             # <<<<<<<<<<<<<<
 *                   <void *> &self.acquisition_count[0], sizeof(__pyx_atomic_int))
 *         self.typeinfo = NULL
 */
  __pyx_v_self->acquisition_count_aligned_p = ((__pyx_atomic_int *)__pyx_align_pointer(((void *)(&(__pyx_v_self->acquisition_count[0]))), (sizeof(__pyx_atomic_int))));

  /* "View.MemoryView":370
 *         self.acquisition_count_aligned_p = <__pyx_atomic_int *> align_pointer(
 *                   <void *> &self.acquisition_count[0], sizeof(__pyx_atomic_int))
 *         self.typeinfo = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(memoryview self):
 */
  __pyx_v_self->typeinfo = NULL;

  /* "View.MemoryView":345
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":372
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

/* Python wrapper */
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self) {
  int __pyx_v_i;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyThread_type_lock __pyx_t_6;
  PyThread_type_lock __pyx_t_7;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "View.MemoryView":373
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
  __pyx_t_1 = (__pyx_v_self->obj != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":374
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)             # <<<<<<<<<<<<<<
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 */
    __Pyx_ReleaseBuffer((&__pyx_v_self->view));

    /* "View.MemoryView":373
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":375
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  __pyx_t_2 = ((((Py_buffer *)(&__pyx_v_self->view))->obj == Py_None) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":377
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL             # <<<<<<<<<<<<<<
 *             Py_DECREF(Py_None)
 * 
 */
    ((Py_buffer *)(&__pyx_v_self->view))->obj = NULL;

    /* "View.MemoryView":378
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 *             Py_DECREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         cdef int i
 */
    Py_DECREF(Py_None);

    /* "View.MemoryView":375
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":382
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  __pyx_t_2 = ((__pyx_v_self->lock != NULL) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":383
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):             # <<<<<<<<<<<<<<
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 */
    __pyx_t_3 = __pyx_memoryview_thread_locks_used;
    __pyx_t_4 = __pyx_t_3;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "View.MemoryView":384
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      __pyx_t_2 = (((__pyx_memoryview_thread_locks[__pyx_v_i]) == __pyx_v_self->lock) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":385
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1             # <<<<<<<<<<<<<<
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 */
        __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used - 1);

        /* "View.MemoryView":386
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        __pyx_t_2 = ((__pyx_v_i != __pyx_memoryview_thread_locks_used) != 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":388
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])             # <<<<<<<<<<<<<<
 *                     break
 *             else:
 */
          __pyx_t_6 = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);
          __pyx_t_7 = (__pyx_memoryview_thread_locks[__pyx_v_i]);

          /* "View.MemoryView":387
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (             # <<<<<<<<<<<<<<
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break
 */
          (__pyx_memoryview_thread_locks[__pyx_v_i]) = __pyx_t_6;
          (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]) = __pyx_t_7;

          /* "View.MemoryView":386
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        }

        /* "View.MemoryView":389
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 PyThread_free_lock(self.lock)
 */
        goto __pyx_L6_break;

        /* "View.MemoryView":384
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      }
    }
    /*else*/ {

      /* "View.MemoryView":391
 *                     break
 *             else:
 *                 PyThread_free_lock(self.lock)             # <<<<<<<<<<<<<<
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 */
      PyThread_free_lock(__pyx_v_self->lock);
    }
    __pyx_L6_break:;

    /* "View.MemoryView":382
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  }

  /* "View.MemoryView":372
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":393
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  Py_ssize_t __pyx_v_dim;
  char *__pyx_v_itemp;
  PyObject *__pyx_v_idx = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item_pointer", 0);

  /* "View.MemoryView":395
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf             # <<<<<<<<<<<<<<
 * 
 *         for dim, idx in enumerate(index):
 */
  __pyx_v_itemp = ((char *)__pyx_v_self->view.buf);

  /* "View.MemoryView":397
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_v_index)) || PyTuple_CheckExact(__pyx_v_index)) {
    __pyx_t_2 = __pyx_v_index; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 397, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(2, 397, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(2, 397, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(2, 397, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_idx, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_1;
    __pyx_t_1 = (__pyx_t_1 + 1);

    /* "View.MemoryView":398
 * 
 *         for dim, idx in enumerate(index):
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)             # <<<<<<<<<<<<<<
 * 
 *         return itemp
 */
    __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_v_idx); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 398, __pyx_L1_error)
    __pyx_t_7 = __pyx_pybuffer_index((&__pyx_v_self->view), __pyx_v_itemp, __pyx_t_6, __pyx_v_dim); if (unlikely(__pyx_t_7 == ((char *)NULL))) __PYX_ERR(2, 398, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_7;

    /* "View.MemoryView":397
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":400
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 *         return itemp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_itemp;
  goto __pyx_L0;

  /* "View.MemoryView":393
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.get_item_pointer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":403
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_indices = NULL;
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  char *__pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "View.MemoryView":404
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  __pyx_t_1 = (__pyx_v_index == __pyx_builtin_Ellipsis);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":405
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:
 *             return self             # <<<<<<<<<<<<<<
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __pyx_r = ((PyObject *)__pyx_v_self);
    goto __pyx_L0;

    /* "View.MemoryView":404
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  }

  /* "View.MemoryView":407
 *             return self
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *itemp
 */
  __pyx_t_3 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(__pyx_t_3 != Py_None)) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 407, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(2, 407, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_indices = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "View.MemoryView":410
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 410, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "View.MemoryView":411
 *         cdef char *itemp
 *         if have_slices:
 *             return memview_slice(self, indices)             # <<<<<<<<<<<<<<
 *         else:
 *             itemp = self.get_item_pointer(indices)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((PyObject *)__pyx_memview_slice(__pyx_v_self, __pyx_v_indices)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":410
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  }

  /* "View.MemoryView":413
 *             return memview_slice(self, indices)
 *         else:
 *             itemp = self.get_item_pointer(indices)             # <<<<<<<<<<<<<<
 *             return self.convert_item_to_object(itemp)
 * 
 */
  /*else*/ {
    __pyx_t_6 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_indices); if (unlikely(__pyx_t_6 == ((char *)NULL))) __PYX_ERR(2, 413, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_6;

    /* "View.MemoryView":414
 *         else:
 *             itemp = self.get_item_pointer(indices)
 *             return self.convert_item_to_object(itemp)             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(memoryview self, object index, object value):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->convert_item_to_object(__pyx_v_self, __pyx_v_itemp); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":403
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_indices);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":416
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError("Cannot assign to read-only memoryview")
 */

/* Python wrapper */
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /*proto*/
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_obj = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);
  __Pyx_INCREF(__pyx_v_index);

  /* "View.MemoryView":417
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError("Cannot assign to read-only memoryview")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.readonly != 0);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":418
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:
 *             raise TypeError("Cannot assign to read-only memoryview")             # <<<<<<<<<<<<<<
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__73, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 418, __pyx_L1_error)

    /* "View.MemoryView":417
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError("Cannot assign to read-only memoryview")
 * 
 */
  }

  /* "View.MemoryView":420
 *             raise TypeError("Cannot assign to read-only memoryview")
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         if have_slices:
 */
  __pyx_t_2 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(__pyx_t_2 != Py_None)) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 420, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(2, 420, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_3;
  __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "View.MemoryView":422
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 422, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "View.MemoryView":423
 * 
 *         if have_slices:
 *             obj = self.is_slice(value)             # <<<<<<<<<<<<<<
 *             if obj:
 *                 self.setitem_slice_assignment(self[index], obj)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->is_slice(__pyx_v_self, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_obj = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "View.MemoryView":424
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_obj); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 424, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":425
 *             obj = self.is_slice(value)
 *             if obj:
 *                 self.setitem_slice_assignment(self[index], obj)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)
 */
      __pyx_t_2 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assignment(__pyx_v_self, __pyx_t_2, __pyx_v_obj); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "View.MemoryView":424
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":427
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)             # <<<<<<<<<<<<<<
 *         else:
 *             self.setitem_indexed(index, value)
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 427, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_memoryview_type))))) __PYX_ERR(2, 427, __pyx_L1_error)
      __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assign_scalar(__pyx_v_self, ((struct __pyx_memoryview_obj *)__pyx_t_4), __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 427, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L5:;

    /* "View.MemoryView":422
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":429
 *                 self.setitem_slice_assign_scalar(self[index], value)
 *         else:
 *             self.setitem_indexed(index, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef is_slice(self, obj):
 */
  /*else*/ {
    __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_indexed(__pyx_v_self, __pyx_v_index, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L4:;

  /* "View.MemoryView":416
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError("Cannot assign to read-only memoryview")
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":431
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_slice", 0);
  __Pyx_INCREF(__pyx_v_obj);

  /* "View.MemoryView":432
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_memoryview_type); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":433
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "View.MemoryView":434
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_6 = __Pyx_PyInt_From_int(((__pyx_v_self->flags & (~PyBUF_WRITABLE)) | PyBUF_ANY_CONTIGUOUS)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 434, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "View.MemoryView":435
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 return None
 */
        __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 435, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "View.MemoryView":434
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 434, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_obj);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7);
        __pyx_t_6 = 0;
        __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 434, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "View.MemoryView":433
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "View.MemoryView":436
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 return None
 * 
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(2, 436, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_6);

        /* "View.MemoryView":437
 *                                  self.dtype_is_object)
 *             except TypeError:
 *                 return None             # <<<<<<<<<<<<<<
 * 
 *         return obj
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "View.MemoryView":433
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L0;
      __pyx_L9_try_end:;
    }

    /* "View.MemoryView":432
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  }

  /* "View.MemoryView":439
 *                 return None
 * 
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assignment(self, dst, src):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "View.MemoryView":431
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":441
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src) {
  __Pyx_memviewslice __pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_src_slice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  __Pyx_memviewslice *__pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assignment", 0);

  /* "View.MemoryView":445
 *         cdef __Pyx_memviewslice src_slice
 * 
 *         memoryview_copy_contents(get_slice_from_memview(src, &src_slice)[0],             # <<<<<<<<<<<<<<
 *                                  get_slice_from_memview(dst, &dst_slice)[0],
 *                                  src.ndim, dst.ndim, self.dtype_is_object)
 */
  if (!(likely(((__pyx_v_src) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_src, __pyx_memoryview_type))))) __PYX_ERR(2, 445, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_src), (&__pyx_v_src_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(2, 445, __pyx_L1_error)

  /* "View.MemoryView":446
 * 
 *         memoryview_copy_contents(get_slice_from_memview(src, &src_slice)[0],
 *                                  get_slice_from_memview(dst, &dst_slice)[0],             # <<<<<<<<<<<<<<
 *                                  src.ndim, dst.ndim, self.dtype_is_object)
 * 
 */
  if (!(likely(((__pyx_v_dst) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dst, __pyx_memoryview_type))))) __PYX_ERR(2, 446, __pyx_L1_error)
  __pyx_t_2 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_dst), (&__pyx_v_dst_slice)); if (unlikely(__pyx_t_2 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(2, 446, __pyx_L1_error)

  /* "View.MemoryView":447
 *         memoryview_copy_contents(get_slice_from_memview(src, &src_slice)[0],
 *                                  get_slice_from_memview(dst, &dst_slice)[0],
 *                                  src.ndim, dst.ndim, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_src, __pyx_n_s_ndim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dst, __pyx_n_s_ndim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "View.MemoryView":445
 *         cdef __Pyx_memviewslice src_slice
 * 
 *         memoryview_copy_contents(get_slice_from_memview(src, &src_slice)[0],             # <<<<<<<<<<<<<<
 *                                  get_slice_from_memview(dst, &dst_slice)[0],
 *                                  src.ndim, dst.ndim, self.dtype_is_object)
 */
  __pyx_t_6 = __pyx_memoryview_copy_contents((__pyx_t_1[0]), (__pyx_t_2[0]), __pyx_t_4, __pyx_t_5, __pyx_v_self->dtype_is_object); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(2, 445, __pyx_L1_error)

  /* "View.MemoryView":441
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":449
 *                                  src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value) {
  int __pyx_v_array[0x80];
  void *__pyx_v_tmp;
  void *__pyx_v_item;
  __Pyx_memviewslice *__pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_tmp_slice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assign_scalar", 0);

  /* "View.MemoryView":451
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 *         cdef int array[128]
 *         cdef void *tmp = NULL             # <<<<<<<<<<<<<<
 *         cdef void *item
 * 
 */
  __pyx_v_tmp = NULL;

  /* "View.MemoryView":456
 *         cdef __Pyx_memviewslice *dst_slice
 *         cdef __Pyx_memviewslice tmp_slice
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)             # <<<<<<<<<<<<<<
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_dst, (&__pyx_v_tmp_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(2, 456, __pyx_L1_error)
  __pyx_v_dst_slice = __pyx_t_1;

  /* "View.MemoryView":458
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
  __pyx_t_2 = ((((size_t)__pyx_v_self->view.itemsize) > (sizeof(__pyx_v_array))) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":459
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)             # <<<<<<<<<<<<<<
 *             if tmp == NULL:
 *                 raise MemoryError
 */
    __pyx_v_tmp = PyMem_Malloc(__pyx_v_self->view.itemsize);

    /* "View.MemoryView":460
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    __pyx_t_2 = ((__pyx_v_tmp == NULL) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":461
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             item = tmp
 *         else:
 */
      PyErr_NoMemory(); __PYX_ERR(2, 461, __pyx_L1_error)

      /* "View.MemoryView":460
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    }

    /* "View.MemoryView":462
 *             if tmp == NULL:
 *                 raise MemoryError
 *             item = tmp             # <<<<<<<<<<<<<<
 *         else:
 *             item = <void *> array
 */
    __pyx_v_item = __pyx_v_tmp;

    /* "View.MemoryView":458
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":464
 *             item = tmp
 *         else:
 *             item = <void *> array             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __pyx_v_item = ((void *)__pyx_v_array);
  }
  __pyx_L3:;

  /* "View.MemoryView":466
 *             item = <void *> array
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value
 */
  /*try:*/ {

    /* "View.MemoryView":467
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
    __pyx_t_2 = (__pyx_v_self->dtype_is_object != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":468
 *         try:
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value             # <<<<<<<<<<<<<<
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)
 */
      (((PyObject **)__pyx_v_item)[0]) = ((PyObject *)__pyx_v_value);

      /* "View.MemoryView":467
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":470
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, ((char *)__pyx_v_item), __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 470, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "View.MemoryView":474
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    __pyx_t_2 = ((__pyx_v_self->view.suboffsets != NULL) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":475
 * 
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)             # <<<<<<<<<<<<<<
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 *                                 item, self.dtype_is_object)
 */
      __pyx_t_3 = assert_direct_dimensions(__pyx_v_self->view.suboffsets, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 475, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "View.MemoryView":474
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    }

    /* "View.MemoryView":476
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,             # <<<<<<<<<<<<<<
 *                                 item, self.dtype_is_object)
 *         finally:
 */
    __pyx_memoryview_slice_assign_scalar(__pyx_v_dst_slice, __pyx_v_dst->view.ndim, __pyx_v_self->view.itemsize, __pyx_v_item, __pyx_v_self->dtype_is_object);
  }

  /* "View.MemoryView":479
 *                                 item, self.dtype_is_object)
 *         finally:
 *             PyMem_Free(tmp)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_indexed(self, index, value):
 */
  /*finally:*/ {
    /*normal exit:*/{
      PyMem_Free(__pyx_v_tmp);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {
        PyMem_Free(__pyx_v_tmp);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "View.MemoryView":449
 *                                  src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assign_scalar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":481
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_indexed", 0);

  /* "View.MemoryView":482
 * 
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)             # <<<<<<<<<<<<<<
 *         self.assign_item_from_object(itemp, value)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_index); if (unlikely(__pyx_t_1 == ((char *)NULL))) __PYX_ERR(2, 482, __pyx_L1_error)
  __pyx_v_itemp = __pyx_t_1;

  /* "View.MemoryView":483
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":481
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_indexed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":485
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_v_struct = NULL;
  PyObject *__pyx_v_bytesitem = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 0);

  /* "View.MemoryView":488
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef bytes bytesitem
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_struct, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":491
 *         cdef bytes bytesitem
 * 
 *         bytesitem = itemp[:self.view.itemsize]             # <<<<<<<<<<<<<<
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 */
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_itemp + 0, __pyx_v_self->view.itemsize - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bytesitem = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":492
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "View.MemoryView":493
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)             # <<<<<<<<<<<<<<
 *         except struct.error:
 *             raise ValueError("Unable to convert item to object")
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_unpack); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 493, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 493, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_6, __pyx_v_bytesitem};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 493, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_6, __pyx_v_bytesitem};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 493, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 493, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_6);
        __Pyx_INCREF(__pyx_v_bytesitem);
        __Pyx_GIVEREF(__pyx_v_bytesitem);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_v_bytesitem);
        __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 493, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "View.MemoryView":492
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    }

    /* "View.MemoryView":497
 *             raise ValueError("Unable to convert item to object")
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
    /*else:*/ {
      __pyx_t_10 = strlen(__pyx_v_self->view.format); 
      __pyx_t_11 = ((__pyx_t_10 == 1) != 0);
      if (__pyx_t_11) {

        /* "View.MemoryView":498
 *         else:
 *             if len(self.view.format) == 1:
 *                 return result[0]             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_result, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 498, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L6_except_return;

        /* "View.MemoryView":497
 *             raise ValueError("Unable to convert item to object")
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
      }

      /* "View.MemoryView":499
 *             if len(self.view.format) == 1:
 *                 return result[0]
 *             return result             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_result);
      __pyx_r = __pyx_v_result;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "View.MemoryView":494
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:             # <<<<<<<<<<<<<<
 *             raise ValueError("Unable to convert item to object")
 *         else:
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_5, &__pyx_t_9);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_error); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 494, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_5, __pyx_t_9);
    __pyx_t_1 = 0; __pyx_t_5 = 0; __pyx_t_9 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(2, 494, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_1);

      /* "View.MemoryView":495
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 *             raise ValueError("Unable to convert item to object")             # <<<<<<<<<<<<<<
 *         else:
 *             if len(self.view.format) == 1:
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__74, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 495, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 495, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "View.MemoryView":492
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "View.MemoryView":485
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesitem);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":501
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_struct = NULL;
  char __pyx_v_c;
  PyObject *__pyx_v_bytesvalue = 0;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  char *__pyx_t_11;
  char *__pyx_t_12;
  char *__pyx_t_13;
  char *__pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 0);

  /* "View.MemoryView":504
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef char c
 *         cdef bytes bytesvalue
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_struct, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":509
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_value); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "View.MemoryView":510
 * 
 *         if isinstance(value, tuple):
 *             bytesvalue = struct.pack(self.view.format, *value)             # <<<<<<<<<<<<<<
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_v_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(2, 510, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "View.MemoryView":509
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":512
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)             # <<<<<<<<<<<<<<
 * 
 *         for i, c in enumerate(bytesvalue):
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_1, __pyx_v_value};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 512, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_1, __pyx_v_value};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 512, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_1);
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_value);
      __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_4)->tp_name), 0))) __PYX_ERR(2, 512, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":514
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
  __pyx_t_9 = 0;
  if (unlikely(__pyx_v_bytesvalue == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(2, 514, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_bytesvalue);
  __pyx_t_10 = __pyx_v_bytesvalue;
  __pyx_t_12 = PyBytes_AS_STRING(__pyx_t_10);
  __pyx_t_13 = (__pyx_t_12 + PyBytes_GET_SIZE(__pyx_t_10));
  for (__pyx_t_14 = __pyx_t_12; __pyx_t_14 < __pyx_t_13; __pyx_t_14++) {
    __pyx_t_11 = __pyx_t_14;
    __pyx_v_c = (__pyx_t_11[0]);

    /* "View.MemoryView":515
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_v_i = __pyx_t_9;

    /* "View.MemoryView":514
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
    __pyx_t_9 = (__pyx_t_9 + 1);

    /* "View.MemoryView":515
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    (__pyx_v_itemp[__pyx_v_i]) = __pyx_v_c;
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "View.MemoryView":501
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("View.MemoryView.memoryview.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":518
 * 
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):             # <<<<<<<<<<<<<<
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t *__pyx_t_4;
  char *__pyx_t_5;
  void *__pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (__pyx_v_info == NULL) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":519
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")
 * 
 */
  __pyx_t_2 = ((__pyx_v_flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->view.readonly != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":520
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_ND:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__75, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 520, __pyx_L1_error)

    /* "View.MemoryView":519
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")
 * 
 */
  }

  /* "View.MemoryView":522
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_ND) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":523
 * 
 *         if flags & PyBUF_ND:
 *             info.shape = self.view.shape             # <<<<<<<<<<<<<<
 *         else:
 *             info.shape = NULL
 */
    __pyx_t_4 = __pyx_v_self->view.shape;
    __pyx_v_info->shape = __pyx_t_4;

    /* "View.MemoryView":522
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":525
 *             info.shape = self.view.shape
 *         else:
 *             info.shape = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  /*else*/ {
    __pyx_v_info->shape = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":527
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":528
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.strides = self.view.strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.strides = NULL
 */
    __pyx_t_4 = __pyx_v_self->view.strides;
    __pyx_v_info->strides = __pyx_t_4;

    /* "View.MemoryView":527
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
    goto __pyx_L7;
  }

  /* "View.MemoryView":530
 *             info.strides = self.view.strides
 *         else:
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_INDIRECT:
 */
  /*else*/ {
    __pyx_v_info->strides = NULL;
  }
  __pyx_L7:;

  /* "View.MemoryView":532
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_INDIRECT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":533
 * 
 *         if flags & PyBUF_INDIRECT:
 *             info.suboffsets = self.view.suboffsets             # <<<<<<<<<<<<<<
 *         else:
 *             info.suboffsets = NULL
 */
    __pyx_t_4 = __pyx_v_self->view.suboffsets;
    __pyx_v_info->suboffsets = __pyx_t_4;

    /* "View.MemoryView":532
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
    goto __pyx_L8;
  }

  /* "View.MemoryView":535
 *             info.suboffsets = self.view.suboffsets
 *         else:
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
  /*else*/ {
    __pyx_v_info->suboffsets = NULL;
  }
  __pyx_L8:;

  /* "View.MemoryView":537
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":538
 * 
 *         if flags & PyBUF_FORMAT:
 *             info.format = self.view.format             # <<<<<<<<<<<<<<
 *         else:
 *             info.format = NULL
 */
    __pyx_t_5 = __pyx_v_self->view.format;
    __pyx_v_info->format = __pyx_t_5;

    /* "View.MemoryView":537
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":540
 *             info.format = self.view.format
 *         else:
 *             info.format = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.buf = self.view.buf
 */
  /*else*/ {
    __pyx_v_info->format = NULL;
  }
  __pyx_L9:;

  /* "View.MemoryView":542
 *             info.format = NULL
 * 
 *         info.buf = self.view.buf             # <<<<<<<<<<<<<<
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 */
  __pyx_t_6 = __pyx_v_self->view.buf;
  __pyx_v_info->buf = __pyx_t_6;

  /* "View.MemoryView":543
 * 
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim             # <<<<<<<<<<<<<<
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 */
  __pyx_t_7 = __pyx_v_self->view.ndim;
  __pyx_v_info->ndim = __pyx_t_7;

  /* "View.MemoryView":544
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize             # <<<<<<<<<<<<<<
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 */
  __pyx_t_8 = __pyx_v_self->view.itemsize;
  __pyx_v_info->itemsize = __pyx_t_8;

  /* "View.MemoryView":545
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len             # <<<<<<<<<<<<<<
 *         info.readonly = self.view.readonly
 *         info.obj = self
 */
  __pyx_t_8 = __pyx_v_self->view.len;
  __pyx_v_info->len = __pyx_t_8;

  /* "View.MemoryView":546
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_v_info->readonly = __pyx_t_1;

  /* "View.MemoryView":547
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 *     __pyx_getbuffer = capsule(<void *> &__pyx_memoryview_getbuffer, "getbuffer(obj, view, flags)")
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":518
 * 
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):             # <<<<<<<<<<<<<<
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":553
 * 
 *     @property
 *     def T(self):             # <<<<<<<<<<<<<<
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":554
 *     @property
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&result.from_slice)
 *         return result
 */
  __pyx_t_1 = __pyx_memoryview_copy_object(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_memoryviewslice_type))))) __PYX_ERR(2, 554, __pyx_L1_error)
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":555
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_2 = __pyx_memslice_transpose((&__pyx_v_result->from_slice)); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(2, 555, __pyx_L1_error)

  /* "View.MemoryView":556
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":553
 * 
 *     @property
 *     def T(self):             # <<<<<<<<<<<<<<
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.T.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":559
 * 
 *     @property
 *     def base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":560
 *     @property
 *     def base(self):
 *         return self.obj             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->obj);
  __pyx_r = __pyx_v_self->obj;
  goto __pyx_L0;

  /* "View.MemoryView":559
 * 
 *     @property
 *     def base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":563
 * 
 *     @property
 *     def shape(self):             # <<<<<<<<<<<<<<
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":564
 *     @property
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
  for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_2 = __pyx_t_4;
    __pyx_v_length = (__pyx_t_2[0]);
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(2, 564, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyList_AsTuple(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":563
 * 
 *     @property
 *     def shape(self):             # <<<<<<<<<<<<<<
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.shape.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":567
 * 
 *     @property
 *     def strides(self):             # <<<<<<<<<<<<<<
 *         if self.view.strides == NULL:
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_v_stride;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":568
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError("Buffer view does not expose strides")
 */
  __pyx_t_1 = ((__pyx_v_self->view.strides == NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":570
 *         if self.view.strides == NULL:
 * 
 *             raise ValueError("Buffer view does not expose strides")             # <<<<<<<<<<<<<<
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__76, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 570, __pyx_L1_error)

    /* "View.MemoryView":568
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError("Buffer view does not expose strides")
 */
  }

  /* "View.MemoryView":572
 *             raise ValueError("Buffer view does not expose strides")
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__pyx_v_self->view.strides + __pyx_v_self->view.ndim);
  for (__pyx_t_5 = __pyx_v_self->view.strides; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
    __pyx_t_3 = __pyx_t_5;
    __pyx_v_stride = (__pyx_t_3[0]);
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_stride); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(2, 572, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":567
 * 
 *     @property
 *     def strides(self):             # <<<<<<<<<<<<<<
 *         if self.view.strides == NULL:
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.strides.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":575
 * 
 *     @property
 *     def suboffsets(self):             # <<<<<<<<<<<<<<
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_v_suboffset;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  Py_ssize_t *__pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":576
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->view.suboffsets == NULL) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":577
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Multiply(__pyx_tuple__77, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":576
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  }

  /* "View.MemoryView":579
 *             return (-1,) * self.view.ndim
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = (__pyx_v_self->view.suboffsets + __pyx_v_self->view.ndim);
  for (__pyx_t_6 = __pyx_v_self->view.suboffsets; __pyx_t_6 < __pyx_t_5; __pyx_t_6++) {
    __pyx_t_4 = __pyx_t_6;
    __pyx_v_suboffset = (__pyx_t_4[0]);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_suboffset); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_2))) __PYX_ERR(2, 579, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":575
 * 
 *     @property
 *     def suboffsets(self):             # <<<<<<<<<<<<<<
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.suboffsets.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":582
 * 
 *     @property
 *     def ndim(self):             # <<<<<<<<<<<<<<
 *         return self.view.ndim
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":583
 *     @property
 *     def ndim(self):
 *         return self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":582
 * 
 *     @property
 *     def ndim(self):             # <<<<<<<<<<<<<<
 *         return self.view.ndim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.ndim.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":586
 * 
 *     @property
 *     def itemsize(self):             # <<<<<<<<<<<<<<
 *         return self.view.itemsize
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":587
 *     @property
 *     def itemsize(self):
 *         return self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":586
 * 
 *     @property
 *     def itemsize(self):             # <<<<<<<<<<<<<<
 *         return self.view.itemsize
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.itemsize.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":590
 * 
 *     @property
 *     def nbytes(self):             # <<<<<<<<<<<<<<
 *         return self.size * self.view.itemsize
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":591
 *     @property
 *     def nbytes(self):
 *         return self.size * self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":590
 * 
 *     @property
 *     def nbytes(self):             # <<<<<<<<<<<<<<
 *         return self.size * self.view.itemsize
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.nbytes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":594
 * 
 *     @property
 *     def size(self):             # <<<<<<<<<<<<<<
 *         if self._size is None:
 *             result = 1
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":595
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_size == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":596
 *     def size(self):
 *         if self._size is None:
 *             result = 1             # <<<<<<<<<<<<<<
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 */
    __Pyx_INCREF(__pyx_int_1);
    __pyx_v_result = __pyx_int_1;

    /* "View.MemoryView":598
 *             result = 1
 * 
 *             for length in self.view.shape[:self.view.ndim]:             # <<<<<<<<<<<<<<
 *                 result *= length
 * 
 */
    __pyx_t_4 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.shape; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_t_6 = PyInt_FromSsize_t((__pyx_t_3[0])); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "View.MemoryView":599
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 *                 result *= length             # <<<<<<<<<<<<<<
 * 
 *             self._size = result
 */
      __pyx_t_6 = PyNumber_InPlaceMultiply(__pyx_v_result, __pyx_v_length); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_6);
      __pyx_t_6 = 0;
    }

    /* "View.MemoryView":601
 *                 result *= length
 * 
 *             self._size = result             # <<<<<<<<<<<<<<
 * 
 *         return self._size
 */
    __Pyx_INCREF(__pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __Pyx_GOTREF(__pyx_v_self->_size);
    __Pyx_DECREF(__pyx_v_self->_size);
    __pyx_v_self->_size = __pyx_v_result;

    /* "View.MemoryView":595
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  }

  /* "View.MemoryView":603
 *             self._size = result
 * 
 *         return self._size             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_size);
  __pyx_r = __pyx_v_self->_size;
  goto __pyx_L0;

  /* "View.MemoryView":594
 * 
 *     @property
 *     def size(self):             # <<<<<<<<<<<<<<
 *         if self._size is None:
 *             result = 1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":605
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

/* Python wrapper */
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "View.MemoryView":606
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->view.ndim >= 1) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":607
 *     def __len__(self):
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = (__pyx_v_self->view.shape[0]);
    goto __pyx_L0;

    /* "View.MemoryView":606
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  }

  /* "View.MemoryView":609
 *             return self.view.shape[0]
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":605
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":611
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "View.MemoryView":612
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":613
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "View.MemoryView":612
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":611
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":615
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "View.MemoryView":616
 * 
 *     def __str__(self):
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_object, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":615
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":619
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_c_contig (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_c_contig", 0);

  /* "View.MemoryView":622
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(2, 622, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":623
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def is_f_contig(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'C', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":619
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_c_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":625
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_f_contig (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_f_contig", 0);

  /* "View.MemoryView":628
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(2, 628, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":629
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'F', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":625
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_f_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":631
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_mslice;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "View.MemoryView":633
 *     def copy(self):
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &mslice)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_F_CONTIGUOUS));

  /* "View.MemoryView":635
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 * 
 *         slice_copy(self, &mslice)             # <<<<<<<<<<<<<<
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,
 *                                    self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_mslice));

  /* "View.MemoryView":636
 * 
 *         slice_copy(self, &mslice)
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                    self.view.itemsize,
 *                                    flags|PyBUF_C_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_mslice), ((char *)"c"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_C_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 636, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":641
 *                                    self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &mslice)             # <<<<<<<<<<<<<<
 * 
 *     def copy_fortran(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_mslice)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":631
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":643
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy_fortran (wrapper)", 0);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_fortran", 0);

  /* "View.MemoryView":645
 *     def copy_fortran(self):
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &src)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_C_CONTIGUOUS));

  /* "View.MemoryView":647
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 * 
 *         slice_copy(self, &src)             # <<<<<<<<<<<<<<
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,
 *                                 self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_src));

  /* "View.MemoryView":648
 * 
 *         slice_copy(self, &src)
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                 self.view.itemsize,
 *                                 flags|PyBUF_F_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_src), ((char *)"fortran"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_F_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 648, __pyx_L1_error)
  __pyx_v_dst = __pyx_t_1;

  /* "View.MemoryView":653
 *                                 self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &dst)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_dst)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":643
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy_fortran", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_memoryview___reduce_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_memoryview_2__setstate_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__79, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":657
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

static PyObject *__pyx_memoryview_new(PyObject *__pyx_v_o, int __pyx_v_flags, int __pyx_v_dtype_is_object, __Pyx_TypeInfo *__pyx_v_typeinfo) {
  struct __pyx_memoryview_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_cwrapper", 0);

  /* "View.MemoryView":658
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)             # <<<<<<<<<<<<<<
 *     result.typeinfo = typeinfo
 *     return result
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryview_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":659
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
  __pyx_v_result->typeinfo = __pyx_v_typeinfo;

  /* "View.MemoryView":660
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_check')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":657
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":663
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o):             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

static CYTHON_INLINE int __pyx_memoryview_check(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("memoryview_check", 0);

  /* "View.MemoryView":664
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o):
 *     return isinstance(o, memoryview)             # <<<<<<<<<<<<<<
 * 
 * cdef tuple _unellipsify(object index, int ndim):
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_o, __pyx_memoryview_type); 
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":663
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o):             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":666
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

static PyObject *_unellipsify(PyObject *__pyx_v_index, int __pyx_v_ndim) {
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_v_result = NULL;
  int __pyx_v_have_slices;
  int __pyx_v_seen_ellipsis;
  CYTHON_UNUSED PyObject *__pyx_v_idx = NULL;
  PyObject *__pyx_v_item = NULL;
  Py_ssize_t __pyx_v_nslices;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unellipsify", 0);

  /* "View.MemoryView":671
 *     full slices.
 *     """
 *     if not isinstance(index, tuple):             # <<<<<<<<<<<<<<
 *         tup = (index,)
 *     else:
 */
  __pyx_t_1 = PyTuple_Check(__pyx_v_index); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":672
 *     """
 *     if not isinstance(index, tuple):
 *         tup = (index,)             # <<<<<<<<<<<<<<
 *     else:
 *         tup = index
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_index);
    __Pyx_GIVEREF(__pyx_v_index);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_index);
    __pyx_v_tup = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "View.MemoryView":671
 *     full slices.
 *     """
 *     if not isinstance(index, tuple):             # <<<<<<<<<<<<<<
 *         tup = (index,)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":674
 *         tup = (index,)
 *     else:
 *         tup = index             # <<<<<<<<<<<<<<
 * 
 *     result = []
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_index);
    __pyx_v_tup = __pyx_v_index;
  }
  __pyx_L3:;

  /* "View.MemoryView":676
 *         tup = index
 * 
 *     result = []             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_result = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "View.MemoryView":677
 * 
 *     result = []
 *     have_slices = False             # <<<<<<<<<<<<<<
 *     seen_ellipsis = False
 *     for idx, item in enumerate(tup):
 */
  __pyx_v_have_slices = 0;

  /* "View.MemoryView":678
 *     result = []
 *     have_slices = False
 *     seen_ellipsis = False             # <<<<<<<<<<<<<<
 *     for idx, item in enumerate(tup):
 *         if item is Ellipsis:
 */
  __pyx_v_seen_ellipsis = 0;

  /* "View.MemoryView":679
 *     have_slices = False
 *     seen_ellipsis = False
 *     for idx, item in enumerate(tup):             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_3 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_tup)) || PyTuple_CheckExact(__pyx_v_tup)) {
    __pyx_t_4 = __pyx_v_tup; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_tup); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 679, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(2, 679, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(2, 679, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_6(__pyx_t_4);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(2, 679, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_idx, __pyx_t_3);
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "View.MemoryView":680
 *     seen_ellipsis = False
 *     for idx, item in enumerate(tup):
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 result.extend([slice(None)] * (ndim - len(tup) + 1))
 */
    __pyx_t_2 = (__pyx_v_item == __pyx_builtin_Ellipsis);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":681
 *     for idx, item in enumerate(tup):
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 result.extend([slice(None)] * (ndim - len(tup) + 1))
 *                 seen_ellipsis = True
 */
      __pyx_t_1 = ((!(__pyx_v_seen_ellipsis != 0)) != 0);
      if (__pyx_t_1) {

        /* "View.MemoryView":682
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 *                 result.extend([slice(None)] * (ndim - len(tup) + 1))             # <<<<<<<<<<<<<<
 *                 seen_ellipsis = True
 *             else:
 */
        __pyx_t_8 = PyObject_Length(__pyx_v_tup); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(2, 682, __pyx_L1_error)
        __pyx_t_7 = PyList_New(1 * ((((__pyx_v_ndim - __pyx_t_8) + 1)<0) ? 0:((__pyx_v_ndim - __pyx_t_8) + 1))); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        { Py_ssize_t __pyx_temp;
          for (__pyx_temp=0; __pyx_temp < ((__pyx_v_ndim - __pyx_t_8) + 1); __pyx_temp++) {
            __Pyx_INCREF(__pyx_slice__3);
            __Pyx_GIVEREF(__pyx_slice__3);
            PyList_SET_ITEM(__pyx_t_7, __pyx_temp, __pyx_slice__3);
          }
        }
        __pyx_t_9 = __Pyx_PyList_Extend(__pyx_v_result, __pyx_t_7); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(2, 682, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "View.MemoryView":683
 *             if not seen_ellipsis:
 *                 result.extend([slice(None)] * (ndim - len(tup) + 1))
 *                 seen_ellipsis = True             # <<<<<<<<<<<<<<
 *             else:
 *                 result.append(slice(None))
 */
        __pyx_v_seen_ellipsis = 1;

        /* "View.MemoryView":681
 *     for idx, item in enumerate(tup):
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 result.extend([slice(None)] * (ndim - len(tup) + 1))
 *                 seen_ellipsis = True
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":685
 *                 seen_ellipsis = True
 *             else:
 *                 result.append(slice(None))             # <<<<<<<<<<<<<<
 *             have_slices = True
 *         else:
 */
      /*else*/ {
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_result, __pyx_slice__3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(2, 685, __pyx_L1_error)
      }
      __pyx_L7:;

      /* "View.MemoryView":686
 *             else:
 *                 result.append(slice(None))
 *             have_slices = True             # <<<<<<<<<<<<<<
 *         else:
 *             if not isinstance(item, slice) and not PyIndex_Check(item):
 */
      __pyx_v_have_slices = 1;

      /* "View.MemoryView":680
 *     seen_ellipsis = False
 *     for idx, item in enumerate(tup):
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 result.extend([slice(None)] * (ndim - len(tup) + 1))
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":688
 *             have_slices = True
 *         else:
 *             if not isinstance(item, slice) and not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError("Cannot index with type '%s'" % type(item))
 * 
 */
    /*else*/ {
      __pyx_t_2 = PySlice_Check(__pyx_v_item); 
      __pyx_t_10 = ((!(__pyx_t_2 != 0)) != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_1 = __pyx_t_10;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_10 = ((!(PyIndex_Check(__pyx_v_item) != 0)) != 0);
      __pyx_t_1 = __pyx_t_10;
      __pyx_L9_bool_binop_done:;
      if (unlikely(__pyx_t_1)) {

        /* "View.MemoryView":689
 *         else:
 *             if not isinstance(item, slice) and not PyIndex_Check(item):
 *                 raise TypeError("Cannot index with type '%s'" % type(item))             # <<<<<<<<<<<<<<
 * 
 *             have_slices = have_slices or isinstance(item, slice)
 */
        __pyx_t_7 = __Pyx_PyString_FormatSafe(__pyx_kp_s_Cannot_index_with_type_s, ((PyObject *)Py_TYPE(__pyx_v_item))); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_7); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_Raise(__pyx_t_11, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __PYX_ERR(2, 689, __pyx_L1_error)

        /* "View.MemoryView":688
 *             have_slices = True
 *         else:
 *             if not isinstance(item, slice) and not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError("Cannot index with type '%s'" % type(item))
 * 
 */
      }

      /* "View.MemoryView":691
 *                 raise TypeError("Cannot index with type '%s'" % type(item))
 * 
 *             have_slices = have_slices or isinstance(item, slice)             # <<<<<<<<<<<<<<
 *             result.append(item)
 * 
 */
      __pyx_t_10 = (__pyx_v_have_slices != 0);
      if (!__pyx_t_10) {
      } else {
        __pyx_t_1 = __pyx_t_10;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_10 = PySlice_Check(__pyx_v_item); 
      __pyx_t_2 = (__pyx_t_10 != 0);
      __pyx_t_1 = __pyx_t_2;
      __pyx_L11_bool_binop_done:;
      __pyx_v_have_slices = __pyx_t_1;

      /* "View.MemoryView":692
 * 
 *             have_slices = have_slices or isinstance(item, slice)
 *             result.append(item)             # <<<<<<<<<<<<<<
 * 
 *     nslices = ndim - len(result)
 */
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_result, __pyx_v_item); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(2, 692, __pyx_L1_error)
    }
    __pyx_L6:;

    /* "View.MemoryView":679
 *     have_slices = False
 *     seen_ellipsis = False
 *     for idx, item in enumerate(tup):             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "View.MemoryView":694
 *             result.append(item)
 * 
 *     nslices = ndim - len(result)             # <<<<<<<<<<<<<<
 *     if nslices:
 *         result.extend([slice(None)] * nslices)
 */
  __pyx_t_5 = PyList_GET_SIZE(__pyx_v_result); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(2, 694, __pyx_L1_error)
  __pyx_v_nslices = (__pyx_v_ndim - __pyx_t_5);

  /* "View.MemoryView":695
 * 
 *     nslices = ndim - len(result)
 *     if nslices:             # <<<<<<<<<<<<<<
 *         result.extend([slice(None)] * nslices)
 * 
 */
  __pyx_t_1 = (__pyx_v_nslices != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":696
 *     nslices = ndim - len(result)
 *     if nslices:
 *         result.extend([slice(None)] * nslices)             # <<<<<<<<<<<<<<
 * 
 *     return have_slices or nslices, tuple(result)
 */
    __pyx_t_3 = PyList_New(1 * ((__pyx_v_nslices<0) ? 0:__pyx_v_nslices)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    { Py_ssize_t __pyx_temp;
      for (__pyx_temp=0; __pyx_temp < __pyx_v_nslices; __pyx_temp++) {
        __Pyx_INCREF(__pyx_slice__3);
        __Pyx_GIVEREF(__pyx_slice__3);
        PyList_SET_ITEM(__pyx_t_3, __pyx_temp, __pyx_slice__3);
      }
    }
    __pyx_t_9 = __Pyx_PyList_Extend(__pyx_v_result, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(2, 696, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "View.MemoryView":695
 * 
 *     nslices = ndim - len(result)
 *     if nslices:             # <<<<<<<<<<<<<<
 *         result.extend([slice(None)] * nslices)
 * 
 */
  }

  /* "View.MemoryView":698
 *         result.extend([slice(None)] * nslices)
 * 
 *     return have_slices or nslices, tuple(result)             # <<<<<<<<<<<<<<
 * 
 * cdef assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!__pyx_v_have_slices) {
  } else {
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_have_slices); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_nslices); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_L14_bool_binop_done:;
  __pyx_t_4 = PyList_AsTuple(__pyx_v_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_4);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_r = ((PyObject*)__pyx_t_11);
  __pyx_t_11 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":666
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("View.MemoryView._unellipsify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim):             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

static PyObject *assert_direct_dimensions(Py_ssize_t *__pyx_v_suboffsets, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_suboffset;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t *__pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assert_direct_dimensions", 0);

  /* "View.MemoryView":701
 * 
 * cdef assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim):
 *     for suboffset in suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             raise ValueError("Indirect dimensions not supported")
 */
  __pyx_t_2 = (__pyx_v_suboffsets + __pyx_v_ndim);
  for (__pyx_t_3 = __pyx_v_suboffsets; __pyx_t_3 < __pyx_t_2; __pyx_t_3++) {
    __pyx_t_1 = __pyx_t_3;
    __pyx_v_suboffset = (__pyx_t_1[0]);

    /* "View.MemoryView":702
 * cdef assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim):
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Indirect dimensions not supported")
 * 
 */
    __pyx_t_4 = ((__pyx_v_suboffset >= 0) != 0);
    if (unlikely(__pyx_t_4)) {

      /* "View.MemoryView":703
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             raise ValueError("Indirect dimensions not supported")             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__80, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 703, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(2, 703, __pyx_L1_error)

      /* "View.MemoryView":702
 * cdef assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim):
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Indirect dimensions not supported")
 * 
 */
    }
  }

  /* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim):             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.assert_direct_dimensions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":710
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *__pyx_v_memview, PyObject *__pyx_v_indices) {
  int __pyx_v_new_ndim;
  int __pyx_v_suboffset_dim;
  int __pyx_v_dim;
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  __Pyx_memviewslice *__pyx_v_p_src;
  struct __pyx_memoryviewslice_obj *__pyx_v_memviewsliceobj = 0;
  __Pyx_memviewslice *__pyx_v_p_dst;
  int *__pyx_v_p_suboffset_dim;
  Py_ssize_t __pyx_v_start;
  Py_ssize_t __pyx_v_stop;
  Py_ssize_t __pyx_v_step;
  int __pyx_v_have_start;
  int __pyx_v_have_stop;
  int __pyx_v_have_step;
  PyObject *__pyx_v_index = NULL;
  struct __pyx_memoryview_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  struct __pyx_memoryview_obj *__pyx_t_4;
  char *__pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memview_slice", 0);

  /* "View.MemoryView":711
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim             # <<<<<<<<<<<<<<
 *     cdef bint negative_step
 *     cdef __Pyx_memviewslice src, dst
 */
  __pyx_v_new_ndim = 0;
  __pyx_v_suboffset_dim = -1;

  /* "View.MemoryView":718
 * 
 * 
 *     memset(&dst, 0, sizeof(dst))             # <<<<<<<<<<<<<<
 * 
 *     cdef _memoryviewslice memviewsliceobj
 */
  (void)(memset((&__pyx_v_dst), 0, (sizeof(__pyx_v_dst))));

  /* "View.MemoryView":722
 *     cdef _memoryviewslice memviewsliceobj
 * 
 *     assert memview.view.ndim > 0             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!((__pyx_v_memview->view.ndim > 0) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(2, 722, __pyx_L1_error)
    }
  }
  #endif

  /* "View.MemoryView":724
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":725
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview             # <<<<<<<<<<<<<<
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(2, 725, __pyx_L1_error)
    __pyx_t_3 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_memviewsliceobj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":726
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, &src)
 */
    __pyx_v_p_src = (&__pyx_v_memviewsliceobj->from_slice);

    /* "View.MemoryView":724
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":728
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 *         slice_copy(memview, &src)             # <<<<<<<<<<<<<<
 *         p_src = &src
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_src));

    /* "View.MemoryView":729
 *     else:
 *         slice_copy(memview, &src)
 *         p_src = &src             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_p_src = (&__pyx_v_src);
  }
  __pyx_L3:;

  /* "View.MemoryView":735
 * 
 * 
 *     dst.memview = p_src.memview             # <<<<<<<<<<<<<<
 *     dst.data = p_src.data
 * 
 */
  __pyx_t_4 = __pyx_v_p_src->memview;
  __pyx_v_dst.memview = __pyx_t_4;

  /* "View.MemoryView":736
 * 
 *     dst.memview = p_src.memview
 *     dst.data = p_src.data             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __pyx_v_p_src->data;
  __pyx_v_dst.data = __pyx_t_5;

  /* "View.MemoryView":741
 * 
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst             # <<<<<<<<<<<<<<
 *     cdef int *p_suboffset_dim = &suboffset_dim
 *     cdef Py_ssize_t start, stop, step
 */
  __pyx_v_p_dst = (&__pyx_v_dst);

  /* "View.MemoryView":742
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst
 *     cdef int *p_suboffset_dim = &suboffset_dim             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t start, stop, step
 *     cdef bint have_start, have_stop, have_step
 */
  __pyx_v_p_suboffset_dim = (&__pyx_v_suboffset_dim);

  /* "View.MemoryView":746
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             slice_memviewslice(
 */
  __pyx_t_6 = 0;
  if (likely(PyList_CheckExact(__pyx_v_indices)) || PyTuple_CheckExact(__pyx_v_indices)) {
    __pyx_t_3 = __pyx_v_indices; __Pyx_INCREF(__pyx_t_3); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_indices); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 746, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_9 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_9); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(2, 746, __pyx_L1_error)
        #else
        __pyx_t_9 = PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 746, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        #endif
      } else {
        if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_9 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_9); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(2, 746, __pyx_L1_error)
        #else
        __pyx_t_9 = PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 746, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        #endif
      }
    } else {
      __pyx_t_9 = __pyx_t_8(__pyx_t_3);
      if (unlikely(!__pyx_t_9)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(2, 746, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_9);
    }
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_9);
    __pyx_t_9 = 0;
    __pyx_v_dim = __pyx_t_6;
    __pyx_t_6 = (__pyx_t_6 + 1);

    /* "View.MemoryView":747
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             slice_memviewslice(
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 */
    __pyx_t_2 = (PyIndex_Check(__pyx_v_index) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":751
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 *                 index, 0, 0, # start, stop, step             # <<<<<<<<<<<<<<
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 */
      __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 751, __pyx_L1_error)

      /* "View.MemoryView":748
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_11 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_t_10, 0, 0, 0, 0, 0, 0); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 748, __pyx_L1_error)

      /* "View.MemoryView":747
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             slice_memviewslice(
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":754
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
    __pyx_t_2 = (__pyx_v_index == Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":755
 *                 False)
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1             # <<<<<<<<<<<<<<
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 */
      (__pyx_v_p_dst->shape[__pyx_v_new_ndim]) = 1;

      /* "View.MemoryView":756
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0             # <<<<<<<<<<<<<<
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1
 */
      (__pyx_v_p_dst->strides[__pyx_v_new_ndim]) = 0;

      /* "View.MemoryView":757
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1             # <<<<<<<<<<<<<<
 *             new_ndim += 1
 *         else:
 */
      (__pyx_v_p_dst->suboffsets[__pyx_v_new_ndim]) = -1L;

      /* "View.MemoryView":758
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 *         else:
 *             start = index.start or 0
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);

      /* "View.MemoryView":754
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":760
 *             new_ndim += 1
 *         else:
 *             start = index.start or 0             # <<<<<<<<<<<<<<
 *             stop = index.stop or 0
 *             step = index.step or 0
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 760, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_t_9); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 760, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_12;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_10 = 0;
      __pyx_L7_bool_binop_done:;
      __pyx_v_start = __pyx_t_10;

      /* "View.MemoryView":761
 *         else:
 *             start = index.start or 0
 *             stop = index.stop or 0             # <<<<<<<<<<<<<<
 *             step = index.step or 0
 * 
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 761, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_t_9); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 761, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_12;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_10 = 0;
      __pyx_L9_bool_binop_done:;
      __pyx_v_stop = __pyx_t_10;

      /* "View.MemoryView":762
 *             start = index.start or 0
 *             stop = index.stop or 0
 *             step = index.step or 0             # <<<<<<<<<<<<<<
 * 
 *             have_start = index.start is not None
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 762, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_t_9); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 762, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_12;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_10 = 0;
      __pyx_L11_bool_binop_done:;
      __pyx_v_step = __pyx_t_10;

      /* "View.MemoryView":764
 *             step = index.step or 0
 * 
 *             have_start = index.start is not None             # <<<<<<<<<<<<<<
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = (__pyx_t_9 != Py_None);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_have_start = __pyx_t_1;

      /* "View.MemoryView":765
 * 
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None             # <<<<<<<<<<<<<<
 *             have_step = index.step is not None
 * 
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = (__pyx_t_9 != Py_None);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_have_stop = __pyx_t_1;

      /* "View.MemoryView":766
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None             # <<<<<<<<<<<<<<
 * 
 *             slice_memviewslice(
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = (__pyx_t_9 != Py_None);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_have_step = __pyx_t_1;

      /* "View.MemoryView":768
 *             have_step = index.step is not None
 * 
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_11 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_start, __pyx_v_stop, __pyx_v_step, __pyx_v_have_start, __pyx_v_have_stop, __pyx_v_have_step, 1); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 768, __pyx_L1_error)

      /* "View.MemoryView":774
 *                 have_start, have_stop, have_step,
 *                 True)
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);
    }
    __pyx_L6:;

    /* "View.MemoryView":746
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             slice_memviewslice(
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "View.MemoryView":776
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":777
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __Pyx_XDECREF(((PyObject *)__pyx_r));

    /* "View.MemoryView":778
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_dtype_func,
 *                                     memview.dtype_is_object)
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(2, 778, __pyx_L1_error) }

    /* "View.MemoryView":779
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 *     else:
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(2, 779, __pyx_L1_error) }

    /* "View.MemoryView":777
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, __pyx_v_memviewsliceobj->to_object_func, __pyx_v_memviewsliceobj->to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_memoryview_type))))) __PYX_ERR(2, 777, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":776
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  }

  /* "View.MemoryView":782
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(((PyObject *)__pyx_r));

    /* "View.MemoryView":783
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,
 *                                     memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, NULL, NULL, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "View.MemoryView":782
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_memoryview_type))))) __PYX_ERR(2, 782, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":710
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("View.MemoryView.memview_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_memviewsliceobj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":807
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *__pyx_v_dst, Py_ssize_t __pyx_v_shape, Py_ssize_t __pyx_v_stride, Py_ssize_t __pyx_v_suboffset, int __pyx_v_dim, int __pyx_v_new_ndim, int *__pyx_v_suboffset_dim, Py_ssize_t __pyx_v_start, Py_ssize_t __pyx_v_stop, Py_ssize_t __pyx_v_step, int __pyx_v_have_start, int __pyx_v_have_stop, int __pyx_v_have_step, int __pyx_v_is_slice) {
  Py_ssize_t __pyx_v_new_shape;
  int __pyx_v_negative_step;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":827
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
  __pyx_t_1 = ((!(__pyx_v_is_slice != 0)) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":829
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    __pyx_t_1 = ((__pyx_v_start < 0) != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":830
 * 
 *         if start < 0:
 *             start += shape             # <<<<<<<<<<<<<<
 *         if not 0 <= start < shape:
 *             _err_dim(IndexError, "Index out of bounds (axis %d)", dim)
 */
      __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

      /* "View.MemoryView":829
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    }

    /* "View.MemoryView":831
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    __pyx_t_1 = (0 <= __pyx_v_start);
    if (__pyx_t_1) {
      __pyx_t_1 = (__pyx_v_start < __pyx_v_shape);
    }
    __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":832
 *             start += shape
 *         if not 0 <= start < shape:
 *             _err_dim(IndexError, "Index out of bounds (axis %d)", dim)             # <<<<<<<<<<<<<<
 *     else:
 * 
 */
      __pyx_t_3 = __pyx_memoryview_err_dim(__pyx_builtin_IndexError, ((char *)"Index out of bounds (axis %d)"), __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 832, __pyx_L1_error)

      /* "View.MemoryView":831
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    }

    /* "View.MemoryView":827
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":835
 *     else:
 * 
 *         negative_step = have_step != 0 and step < 0             # <<<<<<<<<<<<<<
 * 
 *         if have_step and step == 0:
 */
  /*else*/ {
    __pyx_t_1 = ((__pyx_v_have_step != 0) != 0);
    if (__pyx_t_1) {
    } else {
      __pyx_t_2 = __pyx_t_1;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = ((__pyx_v_step < 0) != 0);
    __pyx_t_2 = __pyx_t_1;
    __pyx_L6_bool_binop_done:;
    __pyx_v_negative_step = __pyx_t_2;

    /* "View.MemoryView":837
 *         negative_step = have_step != 0 and step < 0
 * 
 *         if have_step and step == 0:             # <<<<<<<<<<<<<<
 *             _err_dim(ValueError, "Step may not be zero (axis %d)", dim)
 * 
 */
    __pyx_t_1 = (__pyx_v_have_step != 0);
    if (__pyx_t_1) {
    } else {
      __pyx_t_2 = __pyx_t_1;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_1 = ((__pyx_v_step == 0) != 0);
    __pyx_t_2 = __pyx_t_1;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_2) {

      /* "View.MemoryView":838
 * 
 *         if have_step and step == 0:
 *             _err_dim(ValueError, "Step may not be zero (axis %d)", dim)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_3 = __pyx_memoryview_err_dim(__pyx_builtin_ValueError, ((char *)"Step may not be zero (axis %d)"), __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 838, __pyx_L1_error)

      /* "View.MemoryView":837
 *         negative_step = have_step != 0 and step < 0
 * 
 *         if have_step and step == 0:             # <<<<<<<<<<<<<<
 *             _err_dim(ValueError, "Step may not be zero (axis %d)", dim)
 * 
 */
    }

    /* "View.MemoryView":841
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
    __pyx_t_2 = (__pyx_v_have_start != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":842
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
      __pyx_t_2 = ((__pyx_v_start < 0) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":843
 *         if have_start:
 *             if start < 0:
 *                 start += shape             # <<<<<<<<<<<<<<
 *                 if start < 0:
 *                     start = 0
 */
        __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

        /* "View.MemoryView":844
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        __pyx_t_2 = ((__pyx_v_start < 0) != 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":845
 *                 start += shape
 *                 if start < 0:
 *                     start = 0             # <<<<<<<<<<<<<<
 *             elif start >= shape:
 *                 if negative_step:
 */
          __pyx_v_start = 0;

          /* "View.MemoryView":844
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        }

        /* "View.MemoryView":842
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
        goto __pyx_L12;
      }

      /* "View.MemoryView":846
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      __pyx_t_2 = ((__pyx_v_start >= __pyx_v_shape) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":847
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
        __pyx_t_2 = (__pyx_v_negative_step != 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":848
 *             elif start >= shape:
 *                 if negative_step:
 *                     start = shape - 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     start = shape
 */
          __pyx_v_start = (__pyx_v_shape - 1);

          /* "View.MemoryView":847
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
          goto __pyx_L14;
        }

        /* "View.MemoryView":850
 *                     start = shape - 1
 *                 else:
 *                     start = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        /*else*/ {
          __pyx_v_start = __pyx_v_shape;
        }
        __pyx_L14:;

        /* "View.MemoryView":846
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      }
      __pyx_L12:;

      /* "View.MemoryView":841
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
      goto __pyx_L11;
    }

    /* "View.MemoryView":852
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
    /*else*/ {
      __pyx_t_2 = (__pyx_v_negative_step != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":853
 *         else:
 *             if negative_step:
 *                 start = shape - 1             # <<<<<<<<<<<<<<
 *             else:
 *                 start = 0
 */
        __pyx_v_start = (__pyx_v_shape - 1);

        /* "View.MemoryView":852
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
        goto __pyx_L15;
      }

      /* "View.MemoryView":855
 *                 start = shape - 1
 *             else:
 *                 start = 0             # <<<<<<<<<<<<<<
 * 
 *         if have_stop:
 */
      /*else*/ {
        __pyx_v_start = 0;
      }
      __pyx_L15:;
    }
    __pyx_L11:;

    /* "View.MemoryView":857
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
    __pyx_t_2 = (__pyx_v_have_stop != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":858
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
      __pyx_t_2 = ((__pyx_v_stop < 0) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":859
 *         if have_stop:
 *             if stop < 0:
 *                 stop += shape             # <<<<<<<<<<<<<<
 *                 if stop < 0:
 *                     stop = 0
 */
        __pyx_v_stop = (__pyx_v_stop + __pyx_v_shape);

        /* "View.MemoryView":860
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        __pyx_t_2 = ((__pyx_v_stop < 0) != 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":861
 *                 stop += shape
 *                 if stop < 0:
 *                     stop = 0             # <<<<<<<<<<<<<<
 *             elif stop > shape:
 *                 stop = shape
 */
          __pyx_v_stop = 0;

          /* "View.MemoryView":860
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        }

        /* "View.MemoryView":858
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
        goto __pyx_L17;
      }

      /* "View.MemoryView":862
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      __pyx_t_2 = ((__pyx_v_stop > __pyx_v_shape) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":863
 *                     stop = 0
 *             elif stop > shape:
 *                 stop = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        __pyx_v_stop = __pyx_v_shape;

        /* "View.MemoryView":862
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      }
      __pyx_L17:;

      /* "View.MemoryView":857
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
      goto __pyx_L16;
    }

    /* "View.MemoryView":865
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
    /*else*/ {
      __pyx_t_2 = (__pyx_v_negative_step != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":866
 *         else:
 *             if negative_step:
 *                 stop = -1             # <<<<<<<<<<<<<<
 *             else:
 *                 stop = shape
 */
        __pyx_v_stop = -1L;

        /* "View.MemoryView":865
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
        goto __pyx_L19;
      }

      /* "View.MemoryView":868
 *                 stop = -1
 *             else:
 *                 stop = shape             # <<<<<<<<<<<<<<
 * 
 *         if not have_step:
 */
      /*else*/ {
        __pyx_v_stop = __pyx_v_shape;
      }
      __pyx_L19:;
    }
    __pyx_L16:;

    /* "View.MemoryView":870
 *                 stop = shape
 * 
 *         if not have_step:             # <<<<<<<<<<<<<<
 *             step = 1
 * 
 */
    __pyx_t_2 = ((!(__pyx_v_have_step != 0)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":871
 * 
 *         if not have_step:
 *             step = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_step = 1;

      /* "View.MemoryView":870
 *                 stop = shape
 * 
 *         if not have_step:             # <<<<<<<<<<<<<<
 *             step = 1
 * 
 */
    }

    /* "View.MemoryView":875
 * 
 *         with cython.cdivision(True):
 *             new_shape = (stop - start) // step             # <<<<<<<<<<<<<<
 * 
 *             if (stop - start) - step * new_shape:
 */
    __pyx_v_new_shape = ((__pyx_v_stop - __pyx_v_start) / __pyx_v_step);

    /* "View.MemoryView":877
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    __pyx_t_2 = (((__pyx_v_stop - __pyx_v_start) - (__pyx_v_step * __pyx_v_new_shape)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":878
 * 
 *             if (stop - start) - step * new_shape:
 *                 new_shape += 1             # <<<<<<<<<<<<<<
 * 
 *         if new_shape < 0:
 */
      __pyx_v_new_shape = (__pyx_v_new_shape + 1);

      /* "View.MemoryView":877
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    }

    /* "View.MemoryView":880
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    __pyx_t_2 = ((__pyx_v_new_shape < 0) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":881
 * 
 *         if new_shape < 0:
 *             new_shape = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_new_shape = 0;

      /* "View.MemoryView":880
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    }

    /* "View.MemoryView":884
 * 
 * 
 *         dst.strides[new_ndim] = stride * step             # <<<<<<<<<<<<<<
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset
 */
    (__pyx_v_dst->strides[__pyx_v_new_ndim]) = (__pyx_v_stride * __pyx_v_step);

    /* "View.MemoryView":885
 * 
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape             # <<<<<<<<<<<<<<
 *         dst.suboffsets[new_ndim] = suboffset
 * 
 */
    (__pyx_v_dst->shape[__pyx_v_new_ndim]) = __pyx_v_new_shape;

    /* "View.MemoryView":886
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_dst->suboffsets[__pyx_v_new_ndim]) = __pyx_v_suboffset;
  }
  __pyx_L3:;

  /* "View.MemoryView":889
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
  __pyx_t_2 = (((__pyx_v_suboffset_dim[0]) < 0) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":890
 * 
 *     if suboffset_dim[0] < 0:
 *         dst.data += start * stride             # <<<<<<<<<<<<<<
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 */
    __pyx_v_dst->data = (__pyx_v_dst->data + (__pyx_v_start * __pyx_v_stride));

    /* "View.MemoryView":889
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
    goto __pyx_L23;
  }

  /* "View.MemoryView":892
 *         dst.data += start * stride
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride             # <<<<<<<<<<<<<<
 * 
 *     if suboffset >= 0:
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_suboffset_dim[0]);
    (__pyx_v_dst->suboffsets[__pyx_t_3]) = ((__pyx_v_dst->suboffsets[__pyx_t_3]) + (__pyx_v_start * __pyx_v_stride));
  }
  __pyx_L23:;

  /* "View.MemoryView":894
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  __pyx_t_2 = ((__pyx_v_suboffset >= 0) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":895
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
    __pyx_t_2 = ((!(__pyx_v_is_slice != 0)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":896
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
      __pyx_t_2 = ((__pyx_v_new_ndim == 0) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":897
 *         if not is_slice:
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_dim(IndexError, "All dimensions preceding dimension %d "
 */
        __pyx_v_dst->data = ((((char **)__pyx_v_dst->data)[0]) + __pyx_v_suboffset);

        /* "View.MemoryView":896
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
        goto __pyx_L26;
      }

      /* "View.MemoryView":899
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 *                 _err_dim(IndexError, "All dimensions preceding dimension %d "             # <<<<<<<<<<<<<<
 *                                      "must be indexed and not sliced", dim)
 *         else:
 */
      /*else*/ {

        /* "View.MemoryView":900
 *             else:
 *                 _err_dim(IndexError, "All dimensions preceding dimension %d "
 *                                      "must be indexed and not sliced", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             suboffset_dim[0] = new_ndim
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(__pyx_builtin_IndexError, ((char *)"All dimensions preceding dimension %d must be indexed and not sliced"), __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 899, __pyx_L1_error)
      }
      __pyx_L26:;

      /* "View.MemoryView":895
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
      goto __pyx_L25;
    }

    /* "View.MemoryView":902
 *                                      "must be indexed and not sliced", dim)
 *         else:
 *             suboffset_dim[0] = new_ndim             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
    /*else*/ {
      (__pyx_v_suboffset_dim[0]) = __pyx_v_new_ndim;
    }
    __pyx_L25:;

    /* "View.MemoryView":894
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  }

  /* "View.MemoryView":904
 *             suboffset_dim[0] = new_ndim
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":807
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

  /* function exit code */
  __pyx_L1_error:;
  {
    #ifdef WITH_THREAD
    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
    #endif
    __Pyx_AddTraceback("View.MemoryView.slice_memviewslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
    #ifdef WITH_THREAD
    __Pyx_PyGILState_Release(__pyx_gilstate_save);
    #endif
  }
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":910
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

static char *__pyx_pybuffer_index(Py_buffer *__pyx_v_view, char *__pyx_v_bufp, Py_ssize_t __pyx_v_index, Py_ssize_t __pyx_v_dim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_suboffset;
  Py_ssize_t __pyx_v_itemsize;
  char *__pyx_v_resultp;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pybuffer_index", 0);

  /* "View.MemoryView":912
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t itemsize = view.itemsize
 *     cdef char *resultp
 */
  __pyx_v_suboffset = -1L;

  /* "View.MemoryView":913
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 *     cdef Py_ssize_t itemsize = view.itemsize             # <<<<<<<<<<<<<<
 *     cdef char *resultp
 * 
 */
  __pyx_t_1 = __pyx_v_view->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":916
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len / itemsize
 *         stride = itemsize
 */
  __pyx_t_2 = ((__pyx_v_view->ndim == 0) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":917
 * 
 *     if view.ndim == 0:
 *         shape = view.len / itemsize             # <<<<<<<<<<<<<<
 *         stride = itemsize
 *     else:
 */
    if (unlikely(__pyx_v_itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(2, 917, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_itemsize == (Py_ssize_t)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW(__pyx_v_view->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(2, 917, __pyx_L1_error)
    }
    __pyx_v_shape = __Pyx_div_Py_ssize_t(__pyx_v_view->len, __pyx_v_itemsize);

    /* "View.MemoryView":918
 *     if view.ndim == 0:
 *         shape = view.len / itemsize
 *         stride = itemsize             # <<<<<<<<<<<<<<
 *     else:
 *         shape = view.shape[dim]
 */
    __pyx_v_stride = __pyx_v_itemsize;

    /* "View.MemoryView":916
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len / itemsize
 *         stride = itemsize
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":920
 *         stride = itemsize
 *     else:
 *         shape = view.shape[dim]             # <<<<<<<<<<<<<<
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 */
  /*else*/ {
    __pyx_v_shape = (__pyx_v_view->shape[__pyx_v_dim]);

    /* "View.MemoryView":921
 *     else:
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]             # <<<<<<<<<<<<<<
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]
 */
    __pyx_v_stride = (__pyx_v_view->strides[__pyx_v_dim]);

    /* "View.MemoryView":922
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    __pyx_t_2 = ((__pyx_v_view->suboffsets != NULL) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":923
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]             # <<<<<<<<<<<<<<
 * 
 *     if index < 0:
 */
      __pyx_v_suboffset = (__pyx_v_view->suboffsets[__pyx_v_dim]);

      /* "View.MemoryView":922
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":925
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  __pyx_t_2 = ((__pyx_v_index < 0) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":926
 * 
 *     if index < 0:
 *         index += view.shape[dim]             # <<<<<<<<<<<<<<
 *         if index < 0:
 *             raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 */
    __pyx_v_index = (__pyx_v_index + (__pyx_v_view->shape[__pyx_v_dim]));

    /* "View.MemoryView":927
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 */
    __pyx_t_2 = ((__pyx_v_index < 0) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":928
 *         index += view.shape[dim]
 *         if index < 0:
 *             raise IndexError("Out of bounds on buffer access (axis %d)" % dim)             # <<<<<<<<<<<<<<
 * 
 *     if index >= shape:
 */
      __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_dim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 928, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Out_of_bounds_on_buffer_access_a, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 928, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_IndexError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 928, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 928, __pyx_L1_error)

      /* "View.MemoryView":927
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 */
    }

    /* "View.MemoryView":925
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  }

  /* "View.MemoryView":930
 *             raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 */
  __pyx_t_2 = ((__pyx_v_index >= __pyx_v_shape) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":931
 * 
 *     if index >= shape:
 *         raise IndexError("Out of bounds on buffer access (axis %d)" % dim)             # <<<<<<<<<<<<<<
 * 
 *     resultp = bufp + index * stride
 */
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_dim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Out_of_bounds_on_buffer_access_a, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_IndexError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 931, __pyx_L1_error)

    /* "View.MemoryView":930
 *             raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 */
  }

  /* "View.MemoryView":933
 *         raise IndexError("Out of bounds on buffer access (axis %d)" % dim)
 * 
 *     resultp = bufp + index * stride             # <<<<<<<<<<<<<<
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset
 */
  __pyx_v_resultp = (__pyx_v_bufp + (__pyx_v_index * __pyx_v_stride));

  /* "View.MemoryView":934
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  __pyx_t_2 = ((__pyx_v_suboffset >= 0) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":935
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset             # <<<<<<<<<<<<<<
 * 
 *     return resultp
 */
    __pyx_v_resultp = ((((char **)__pyx_v_resultp)[0]) + __pyx_v_suboffset);

    /* "View.MemoryView":934
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  }

  /* "View.MemoryView":937
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 *     return resultp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_resultp;
  goto __pyx_L0;

  /* "View.MemoryView":910
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.pybuffer_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":943
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) nogil except 0:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

static int __pyx_memslice_transpose(__Pyx_memviewslice *__pyx_v_memslice) {
  int __pyx_v_ndim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_r;
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":944
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) nogil except 0:
 *     cdef int ndim = memslice.memview.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 */
  __pyx_t_1 = __pyx_v_memslice->memview->view.ndim;
  __pyx_v_ndim = __pyx_t_1;

  /* "View.MemoryView":946
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 *     cdef Py_ssize_t *shape = memslice.shape             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t *strides = memslice.strides
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->shape;
  __pyx_v_shape = __pyx_t_2;

  /* "View.MemoryView":947
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 *     cdef Py_ssize_t *strides = memslice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->strides;
  __pyx_v_strides = __pyx_t_2;

  /* "View.MemoryView":951
 * 
 *     cdef int i, j
 *     for i in range(ndim / 2):             # <<<<<<<<<<<<<<
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 */
  __pyx_t_3 = __Pyx_div_long(__pyx_v_ndim, 2);
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_4; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":952
 *     cdef int i, j
 *     for i in range(ndim / 2):
 *         j = ndim - 1 - i             # <<<<<<<<<<<<<<
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]
 */
    __pyx_v_j = ((__pyx_v_ndim - 1) - __pyx_v_i);

    /* "View.MemoryView":953
 *     for i in range(ndim / 2):
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]             # <<<<<<<<<<<<<<
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 */
    __pyx_t_5 = (__pyx_v_strides[__pyx_v_j]);
    __pyx_t_6 = (__pyx_v_strides[__pyx_v_i]);
    (__pyx_v_strides[__pyx_v_i]) = __pyx_t_5;
    (__pyx_v_strides[__pyx_v_j]) = __pyx_t_6;

    /* "View.MemoryView":954
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]             # <<<<<<<<<<<<<<
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 */
    __pyx_t_6 = (__pyx_v_shape[__pyx_v_j]);
    __pyx_t_5 = (__pyx_v_shape[__pyx_v_i]);
    (__pyx_v_shape[__pyx_v_i]) = __pyx_t_6;
    (__pyx_v_shape[__pyx_v_j]) = __pyx_t_5;

    /* "View.MemoryView":956
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    __pyx_t_8 = (((__pyx_v_memslice->suboffsets[__pyx_v_i]) >= 0) != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_8 = (((__pyx_v_memslice->suboffsets[__pyx_v_j]) >= 0) != 0);
    __pyx_t_7 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_7) {

      /* "View.MemoryView":957
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 *             _err(ValueError, "Cannot transpose memoryview with indirect dimensions")             # <<<<<<<<<<<<<<
 * 
 *     return 1
 */
      __pyx_t_9 = __pyx_memoryview_err(__pyx_builtin_ValueError, ((char *)"Cannot transpose memoryview with indirect dimensions")); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(2, 957, __pyx_L1_error)

      /* "View.MemoryView":956
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    }
  }

  /* "View.MemoryView":959
 *             _err(ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "View.MemoryView":943
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) nogil except 0:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  {
    #ifdef WITH_THREAD
    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
    #endif
    __Pyx_AddTraceback("View.MemoryView.transpose_memslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
    #ifdef WITH_THREAD
    __Pyx_PyGILState_Release(__pyx_gilstate_save);
    #endif
  }
  __pyx_r = 0;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":976
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XDEC_MEMVIEW(&self.from_slice, 1)
 * 
 */

/* Python wrapper */
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "View.MemoryView":977
 * 
 *     def __dealloc__(self):
 *         __PYX_XDEC_MEMVIEW(&self.from_slice, 1)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __PYX_XDEC_MEMVIEW((&__pyx_v_self->from_slice), 1);

  /* "View.MemoryView":976
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XDEC_MEMVIEW(&self.from_slice, 1)
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":979
 *         __PYX_XDEC_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 0);

  /* "View.MemoryView":980
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_self->to_object_func != NULL) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":981
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)             # <<<<<<<<<<<<<<
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_self->to_object_func(__pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":980
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  }

  /* "View.MemoryView":983
 *             return self.to_object_func(itemp)
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_memoryview_convert_item_to_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":979
 *         __PYX_XDEC_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":985
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 0);

  /* "View.MemoryView":986
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_self->to_dtype_func != NULL) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":987
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)             # <<<<<<<<<<<<<<
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)
 */
    __pyx_t_2 = __pyx_v_self->to_dtype_func(__pyx_v_itemp, __pyx_v_value); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(2, 987, __pyx_L1_error)

    /* "View.MemoryView":986
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":989
 *             self.to_dtype_func(itemp, value)
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  /*else*/ {
    __pyx_t_3 = __pyx_memoryview_assign_item_from_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":985
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":992
 * 
 *     @property
 *     def base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_16_memoryviewslice_4base_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_16_memoryviewslice_4base_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_16_memoryviewslice_4base___get__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_16_memoryviewslice_4base___get__(struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "View.MemoryView":993
 *     @property
 *     def base(self):
 *         return self.from_object             # <<<<<<<<<<<<<<
 * 
 *     __pyx_getbuffer = capsule(<void *> &__pyx_memoryview_getbuffer, "getbuffer(obj, view, flags)")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->from_object);
  __pyx_r = __pyx_v_self->from_object;
  goto __pyx_L0;

  /* "View.MemoryView":992
 * 
 *     @property
 *     def base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_memoryviewslice___reduce_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__81, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf___pyx_memoryviewslice_2__setstate_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__82, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice __pyx_v_memviewslice, int __pyx_v_ndim, PyObject *(*__pyx_v_to_object_func)(char *), int (*__pyx_v_to_dtype_func)(char *, PyObject *), int __pyx_v_dtype_is_object) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  Py_ssize_t __pyx_v_suboffset;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_TypeInfo *__pyx_t_4;
  Py_buffer __pyx_t_5;
  Py_ssize_t *__pyx_t_6;
  Py_ssize_t *__pyx_t_7;
  Py_ssize_t *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_fromslice", 0);

  /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_1 = ((((PyObject *)__pyx_v_memviewslice.memview) == Py_None) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1008
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  }

  /* "View.MemoryView":1013
 * 
 * 
 *     result = _memoryviewslice(None, 0, dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     result.from_slice = memviewslice
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_3, 0, Py_None);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryviewslice_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":1015
 *     result = _memoryviewslice(None, 0, dtype_is_object)
 * 
 *     result.from_slice = memviewslice             # <<<<<<<<<<<<<<
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 */
  __pyx_v_result->from_slice = __pyx_v_memviewslice;

  /* "View.MemoryView":1016
 * 
 *     result.from_slice = memviewslice
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)             # <<<<<<<<<<<<<<
 * 
 *     result.from_object = (<memoryview> memviewslice.memview).base
 */
  __PYX_INC_MEMVIEW((&__pyx_v_memviewslice), 1);

  /* "View.MemoryView":1018
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 *     result.from_object = (<memoryview> memviewslice.memview).base             # <<<<<<<<<<<<<<
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_memviewslice.memview), __pyx_n_s_base); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->from_object);
  __Pyx_DECREF(__pyx_v_result->from_object);
  __pyx_v_result->from_object = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "View.MemoryView":1019
 * 
 *     result.from_object = (<memoryview> memviewslice.memview).base
 *     result.typeinfo = memviewslice.memview.typeinfo             # <<<<<<<<<<<<<<
 * 
 *     result.view = memviewslice.memview.view
 */
  __pyx_t_4 = __pyx_v_memviewslice.memview->typeinfo;
  __pyx_v_result->__pyx_base.typeinfo = __pyx_t_4;

  /* "View.MemoryView":1021
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 *     result.view = memviewslice.memview.view             # <<<<<<<<<<<<<<
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 */
  __pyx_t_5 = __pyx_v_memviewslice.memview->view;
  __pyx_v_result->__pyx_base.view = __pyx_t_5;

  /* "View.MemoryView":1022
 * 
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data             # <<<<<<<<<<<<<<
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 */
  __pyx_v_result->__pyx_base.view.buf = ((void *)__pyx_v_memviewslice.data);

  /* "View.MemoryView":1023
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim             # <<<<<<<<<<<<<<
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)
 */
  __pyx_v_result->__pyx_base.view.ndim = __pyx_v_ndim;

  /* "View.MemoryView":1024
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None             # <<<<<<<<<<<<<<
 *     Py_INCREF(Py_None)
 * 
 */
  ((Py_buffer *)(&__pyx_v_result->__pyx_base.view))->obj = Py_None;

  /* "View.MemoryView":1025
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 */
  Py_INCREF(Py_None);

  /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
  __pyx_t_1 = ((((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1028
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 *         result.flags = PyBUF_RECORDS             # <<<<<<<<<<<<<<
 *     else:
 *         result.flags = PyBUF_RECORDS_RO
 */
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS;

    /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":1030
 *         result.flags = PyBUF_RECORDS
 *     else:
 *         result.flags = PyBUF_RECORDS_RO             # <<<<<<<<<<<<<<
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 */
  /*else*/ {
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS_RO;
  }
  __pyx_L4:;

  /* "View.MemoryView":1032
 *         result.flags = PyBUF_RECORDS_RO
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape             # <<<<<<<<<<<<<<
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides
 * 
 */
  __pyx_v_result->__pyx_base.view.shape = ((Py_ssize_t *)__pyx_v_result->from_slice.shape);

  /* "View.MemoryView":1033
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_result->__pyx_base.view.strides = ((Py_ssize_t *)__pyx_v_result->from_slice.strides);

  /* "View.MemoryView":1036
 * 
 * 
 *     result.view.suboffsets = NULL             # <<<<<<<<<<<<<<
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 */
  __pyx_v_result->__pyx_base.view.suboffsets = NULL;

  /* "View.MemoryView":1037
 * 
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 */
  __pyx_t_7 = (__pyx_v_result->from_slice.suboffsets + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->from_slice.suboffsets; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_v_suboffset = (__pyx_t_6[0]);

    /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    __pyx_t_1 = ((__pyx_v_suboffset >= 0) != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":1039
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_result->__pyx_base.view.suboffsets = ((Py_ssize_t *)__pyx_v_result->from_slice.suboffsets);

      /* "View.MemoryView":1040
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break             # <<<<<<<<<<<<<<
 * 
 *     result.view.len = result.view.itemsize
 */
      goto __pyx_L6_break;

      /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    }
  }
  __pyx_L6_break:;

  /* "View.MemoryView":1042
 *             break
 * 
 *     result.view.len = result.view.itemsize             # <<<<<<<<<<<<<<
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length
 */
  __pyx_t_9 = __pyx_v_result->__pyx_base.view.itemsize;
  __pyx_v_result->__pyx_base.view.len = __pyx_t_9;

  /* "View.MemoryView":1043
 * 
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         result.view.len *= length
 * 
 */
  __pyx_t_7 = (__pyx_v_result->__pyx_base.view.shape + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->__pyx_base.view.shape; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_t_2 = PyInt_FromSsize_t((__pyx_t_6[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1044
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length             # <<<<<<<<<<<<<<
 * 
 *     result.to_object_func = to_object_func
 */
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_result->__pyx_base.view.len); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_InPlaceMultiply(__pyx_t_2, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_result->__pyx_base.view.len = __pyx_t_9;
  }

  /* "View.MemoryView":1046
 *         result.view.len *= length
 * 
 *     result.to_object_func = to_object_func             # <<<<<<<<<<<<<<
 *     result.to_dtype_func = to_dtype_func
 * 
 */
  __pyx_v_result->to_object_func = __pyx_v_to_object_func;

  /* "View.MemoryView":1047
 * 
 *     result.to_object_func = to_object_func
 *     result.to_dtype_func = to_dtype_func             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  __pyx_v_result->to_dtype_func = __pyx_v_to_dtype_func;

  /* "View.MemoryView":1049
 *     result.to_dtype_func = to_dtype_func
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_result));
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_fromslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_mslice) {
  struct __pyx_memoryviewslice_obj *__pyx_v_obj = 0;
  __Pyx_memviewslice *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_slice_from_memview", 0);

  /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1056
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview             # <<<<<<<<<<<<<<
 *         return &obj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(2, 1056, __pyx_L1_error)
    __pyx_t_3 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_obj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":1057
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview
 *         return &obj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, mslice)
 */
    __pyx_r = (&__pyx_v_obj->from_slice);
    goto __pyx_L0;

    /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  }

  /* "View.MemoryView":1059
 *         return &obj.from_slice
 *     else:
 *         slice_copy(memview, mslice)             # <<<<<<<<<<<<<<
 *         return mslice
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, __pyx_v_mslice);

    /* "View.MemoryView":1060
 *     else:
 *         slice_copy(memview, mslice)
 *         return mslice             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_slice_copy')
 */
    __pyx_r = __pyx_v_mslice;
    goto __pyx_L0;
  }

  /* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.get_slice_from_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_obj);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst):             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_dst) {
  int __pyx_v_dim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  Py_ssize_t *__pyx_v_suboffsets;
  __Pyx_RefNannyDeclarations
  Py_ssize_t *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  __Pyx_RefNannySetupContext("slice_copy", 0);

  /* "View.MemoryView":1067
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 * 
 *     shape = memview.view.shape             # <<<<<<<<<<<<<<
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets
 */
  __pyx_t_1 = __pyx_v_memview->view.shape;
  __pyx_v_shape = __pyx_t_1;

  /* "View.MemoryView":1068
 * 
 *     shape = memview.view.shape
 *     strides = memview.view.strides             # <<<<<<<<<<<<<<
 *     suboffsets = memview.view.suboffsets
 * 
 */
  __pyx_t_1 = __pyx_v_memview->view.strides;
  __pyx_v_strides = __pyx_t_1;

  /* "View.MemoryView":1069
 *     shape = memview.view.shape
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets             # <<<<<<<<<<<<<<
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 */
  __pyx_t_1 = __pyx_v_memview->view.suboffsets;
  __pyx_v_suboffsets = __pyx_t_1;

  /* "View.MemoryView":1071
 *     suboffsets = memview.view.suboffsets
 * 
 *     dst.memview = <__pyx_memoryview *> memview             # <<<<<<<<<<<<<<
 *     dst.data = <char *> memview.view.buf
 * 
 */
  __pyx_v_dst->memview = ((struct __pyx_memoryview_obj *)__pyx_v_memview);

  /* "View.MemoryView":1072
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 *     dst.data = <char *> memview.view.buf             # <<<<<<<<<<<<<<
 * 
 *     for dim in range(memview.view.ndim):
 */
  __pyx_v_dst->data = ((char *)__pyx_v_memview->view.buf);

  /* "View.MemoryView":1074
 *     dst.data = <char *> memview.view.buf
 * 
 *     for dim in range(memview.view.ndim):             # <<<<<<<<<<<<<<
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 */
  __pyx_t_2 = __pyx_v_memview->view.ndim;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_dim = __pyx_t_4;

    /* "View.MemoryView":1075
 * 
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]             # <<<<<<<<<<<<<<
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 */
    (__pyx_v_dst->shape[__pyx_v_dim]) = (__pyx_v_shape[__pyx_v_dim]);

    /* "View.MemoryView":1076
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]             # <<<<<<<<<<<<<<
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 * 
 */
    (__pyx_v_dst->strides[__pyx_v_dim]) = (__pyx_v_strides[__pyx_v_dim]);

    /* "View.MemoryView":1077
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object')
 */
    if ((__pyx_v_suboffsets != 0)) {
      __pyx_t_5 = (__pyx_v_suboffsets[__pyx_v_dim]);
    } else {
      __pyx_t_5 = -1L;
    }
    (__pyx_v_dst->suboffsets[__pyx_v_dim]) = __pyx_t_5;
  }

  /* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst):             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *__pyx_v_memview) {
  __Pyx_memviewslice __pyx_v_memviewslice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy", 0);

  /* "View.MemoryView":1083
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)             # <<<<<<<<<<<<<<
 *     return memoryview_copy_from_slice(memview, &memviewslice)
 * 
 */
  __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_memviewslice));

  /* "View.MemoryView":1084
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)
 *     return memoryview_copy_from_slice(memview, &memviewslice)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_copy_object_from_slice(__pyx_v_memview, (&__pyx_v_memviewslice)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_memviewslice) {
  PyObject *(*__pyx_v_to_object_func)(char *);
  int (*__pyx_v_to_dtype_func)(char *, PyObject *);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *(*__pyx_t_3)(char *);
  int (*__pyx_t_4)(char *, PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy_from_slice", 0);

  /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1095
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func             # <<<<<<<<<<<<<<
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 */
    __pyx_t_3 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_object_func;
    __pyx_v_to_object_func = __pyx_t_3;

    /* "View.MemoryView":1096
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func             # <<<<<<<<<<<<<<
 *     else:
 *         to_object_func = NULL
 */
    __pyx_t_4 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_dtype_func;
    __pyx_v_to_dtype_func = __pyx_t_4;

    /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1098
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 *         to_object_func = NULL             # <<<<<<<<<<<<<<
 *         to_dtype_func = NULL
 * 
 */
  /*else*/ {
    __pyx_v_to_object_func = NULL;

    /* "View.MemoryView":1099
 *     else:
 *         to_object_func = NULL
 *         to_dtype_func = NULL             # <<<<<<<<<<<<<<
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 */
    __pyx_v_to_dtype_func = NULL;
  }
  __pyx_L3:;

  /* "View.MemoryView":1101
 *         to_dtype_func = NULL
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,             # <<<<<<<<<<<<<<
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)
 */
  __Pyx_XDECREF(__pyx_r);

  /* "View.MemoryView":1103
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __pyx_memoryview_fromslice((__pyx_v_memviewslice[0]), __pyx_v_memview->view.ndim, __pyx_v_to_object_func, __pyx_v_to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_from_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) nogil:             # <<<<<<<<<<<<<<
 *     if arg < 0:
 *         return -arg
 */

static Py_ssize_t abs_py_ssize_t(Py_ssize_t __pyx_v_arg) {
  Py_ssize_t __pyx_r;
  int __pyx_t_1;

  /* "View.MemoryView":1110
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) nogil:
 *     if arg < 0:             # <<<<<<<<<<<<<<
 *         return -arg
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_arg < 0) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1111
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) nogil:
 *     if arg < 0:
 *         return -arg             # <<<<<<<<<<<<<<
 *     else:
 *         return arg
 */
    __pyx_r = (-__pyx_v_arg);
    goto __pyx_L0;

    /* "View.MemoryView":1110
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) nogil:
 *     if arg < 0:             # <<<<<<<<<<<<<<
 *         return -arg
 *     else:
 */
  }

  /* "View.MemoryView":1113
 *         return -arg
 *     else:
 *         return arg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_get_best_slice_order')
 */
  /*else*/ {
    __pyx_r = __pyx_v_arg;
    goto __pyx_L0;
  }

  /* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) nogil:             # <<<<<<<<<<<<<<
 *     if arg < 0:
 *         return -arg
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1116
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

static char __pyx_get_best_slice_order(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim) {
  int __pyx_v_i;
  Py_ssize_t __pyx_v_c_stride;
  Py_ssize_t __pyx_v_f_stride;
  char __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1121
 *     """
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t f_stride = 0
 * 
 */
  __pyx_v_c_stride = 0;

  /* "View.MemoryView":1122
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0
 *     cdef Py_ssize_t f_stride = 0             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_f_stride = 0;

  /* "View.MemoryView":1124
 *     cdef Py_ssize_t f_stride = 0
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1125
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = (((__pyx_v_mslice->shape[__pyx_v_i]) > 1) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1126
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_c_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1127
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
      goto __pyx_L4_break;

      /* "View.MemoryView":1125
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L4_break:;

  /* "View.MemoryView":1129
 *             break
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 */
  __pyx_t_1 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1130
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = (((__pyx_v_mslice->shape[__pyx_v_i]) > 1) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1131
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_f_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1132
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 */
      goto __pyx_L7_break;

      /* "View.MemoryView":1130
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L7_break:;

  /* "View.MemoryView":1134
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  __pyx_t_2 = ((abs_py_ssize_t(__pyx_v_c_stride) <= abs_py_ssize_t(__pyx_v_f_stride)) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1135
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 *         return 'C'             # <<<<<<<<<<<<<<
 *     else:
 *         return 'F'
 */
    __pyx_r = 'C';
    goto __pyx_L0;

    /* "View.MemoryView":1134
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  }

  /* "View.MemoryView":1137
 *         return 'C'
 *     else:
 *         return 'F'             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
  /*else*/ {
    __pyx_r = 'F';
    goto __pyx_L0;
  }

  /* "View.MemoryView":1116
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1140
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

static void _copy_strided_to_strided(char *__pyx_v_src_data, Py_ssize_t *__pyx_v_src_strides, char *__pyx_v_dst_data, Py_ssize_t *__pyx_v_dst_strides, Py_ssize_t *__pyx_v_src_shape, Py_ssize_t *__pyx_v_dst_shape, int __pyx_v_ndim, size_t __pyx_v_itemsize) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  CYTHON_UNUSED Py_ssize_t __pyx_v_src_extent;
  Py_ssize_t __pyx_v_dst_extent;
  Py_ssize_t __pyx_v_src_stride;
  Py_ssize_t __pyx_v_dst_stride;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;

  /* "View.MemoryView":1147
 * 
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 */
  __pyx_v_src_extent = (__pyx_v_src_shape[0]);

  /* "View.MemoryView":1148
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 */
  __pyx_v_dst_extent = (__pyx_v_dst_shape[0]);

  /* "View.MemoryView":1149
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 */
  __pyx_v_src_stride = (__pyx_v_src_strides[0]);

  /* "View.MemoryView":1150
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_dst_stride = (__pyx_v_dst_strides[0]);

  /* "View.MemoryView":1152
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *        if (src_stride > 0 and dst_stride > 0 and
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
  __pyx_t_1 = ((__pyx_v_ndim == 1) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1153
 * 
 *     if ndim == 1:
 *        if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):
 *            memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    __pyx_t_2 = ((__pyx_v_src_stride > 0) != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = ((__pyx_v_dst_stride > 0) != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }

    /* "View.MemoryView":1154
 *     if ndim == 1:
 *        if (src_stride > 0 and dst_stride > 0 and
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):             # <<<<<<<<<<<<<<
 *            memcpy(dst_data, src_data, itemsize * dst_extent)
 *        else:
 */
    __pyx_t_2 = (((size_t)__pyx_v_src_stride) == __pyx_v_itemsize);
    if (__pyx_t_2) {
      __pyx_t_2 = (__pyx_v_itemsize == ((size_t)__pyx_v_dst_stride));
    }
    __pyx_t_3 = (__pyx_t_2 != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L5_bool_binop_done:;

    /* "View.MemoryView":1153
 * 
 *     if ndim == 1:
 *        if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):
 *            memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    if (__pyx_t_1) {

      /* "View.MemoryView":1155
 *        if (src_stride > 0 and dst_stride > 0 and
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):
 *            memcpy(dst_data, src_data, itemsize * dst_extent)             # <<<<<<<<<<<<<<
 *        else:
 *            for i in range(dst_extent):
 */
      (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, (__pyx_v_itemsize * __pyx_v_dst_extent)));

      /* "View.MemoryView":1153
 * 
 *     if ndim == 1:
 *        if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):
 *            memcpy(dst_data, src_data, itemsize * dst_extent)
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":1157
 *            memcpy(dst_data, src_data, itemsize * dst_extent)
 *        else:
 *            for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *                memcpy(dst_data, src_data, itemsize)
 *                src_data += src_stride
 */
    /*else*/ {
      __pyx_t_4 = __pyx_v_dst_extent;
      __pyx_t_5 = __pyx_t_4;
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
        __pyx_v_i = __pyx_t_6;

        /* "View.MemoryView":1158
 *        else:
 *            for i in range(dst_extent):
 *                memcpy(dst_data, src_data, itemsize)             # <<<<<<<<<<<<<<
 *                src_data += src_stride
 *                dst_data += dst_stride
 */
        (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, __pyx_v_itemsize));

        /* "View.MemoryView":1159
 *            for i in range(dst_extent):
 *                memcpy(dst_data, src_data, itemsize)
 *                src_data += src_stride             # <<<<<<<<<<<<<<
 *                dst_data += dst_stride
 *     else:
 */
        __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

        /* "View.MemoryView":1160
 *                memcpy(dst_data, src_data, itemsize)
 *                src_data += src_stride
 *                dst_data += dst_stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(dst_extent):
 */
        __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
      }
    }
    __pyx_L4:;

    /* "View.MemoryView":1152
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *        if (src_stride > 0 and dst_stride > 0 and
 *            <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1162
 *                dst_data += dst_stride
 *     else:
 *         for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *             _copy_strided_to_strided(src_data, src_strides + 1,
 *                                      dst_data, dst_strides + 1,
 */
  /*else*/ {
    __pyx_t_4 = __pyx_v_dst_extent;
    __pyx_t_5 = __pyx_t_4;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "View.MemoryView":1163
 *     else:
 *         for i in range(dst_extent):
 *             _copy_strided_to_strided(src_data, src_strides + 1,             # <<<<<<<<<<<<<<
 *                                      dst_data, dst_strides + 1,
 *                                      src_shape + 1, dst_shape + 1,
 */
      _copy_strided_to_strided(__pyx_v_src_data, (__pyx_v_src_strides + 1), __pyx_v_dst_data, (__pyx_v_dst_strides + 1), (__pyx_v_src_shape + 1), (__pyx_v_dst_shape + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize);

      /* "View.MemoryView":1167
 *                                      src_shape + 1, dst_shape + 1,
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride             # <<<<<<<<<<<<<<
 *             dst_data += dst_stride
 * 
 */
      __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

      /* "View.MemoryView":1168
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride
 *             dst_data += dst_stride             # <<<<<<<<<<<<<<
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,
 */
      __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1140
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

  /* function exit code */
}

/* "View.MemoryView":1170
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) nogil:
 */

static void copy_strided_to_strided(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize) {

  /* "View.MemoryView":1173
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) nogil:
 *     _copy_strided_to_strided(src.data, src.strides, dst.data, dst.strides,             # <<<<<<<<<<<<<<
 *                              src.shape, dst.shape, ndim, itemsize)
 * 
 */
  _copy_strided_to_strided(__pyx_v_src->data, __pyx_v_src->strides, __pyx_v_dst->data, __pyx_v_dst->strides, __pyx_v_src->shape, __pyx_v_dst->shape, __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1170
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1177
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *__pyx_v_src, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_size;
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;

  /* "View.MemoryView":1179
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) nogil:
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     for shape in src.shape[:ndim]:
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_size = __pyx_t_1;

  /* "View.MemoryView":1181
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 * 
 *     for shape in src.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         size *= shape
 * 
 */
  __pyx_t_3 = (__pyx_v_src->shape + __pyx_v_ndim);
  for (__pyx_t_4 = __pyx_v_src->shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_2 = __pyx_t_4;
    __pyx_v_shape = (__pyx_t_2[0]);

    /* "View.MemoryView":1182
 * 
 *     for shape in src.shape[:ndim]:
 *         size *= shape             # <<<<<<<<<<<<<<
 * 
 *     return size
 */
    __pyx_v_size = (__pyx_v_size * __pyx_v_shape);
  }

  /* "View.MemoryView":1184
 *         size *= shape
 * 
 *     return size             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_fill_contig_strides_array')
 */
  __pyx_r = __pyx_v_size;
  goto __pyx_L0;

  /* "View.MemoryView":1177
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1187
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) nogil:
 */

static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, Py_ssize_t __pyx_v_stride, int __pyx_v_ndim, char __pyx_v_order) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1196
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
  __pyx_t_1 = ((__pyx_v_order == 'F') != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1197
 * 
 *     if order == 'F':
 *         for idx in range(ndim):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
    __pyx_t_2 = __pyx_v_ndim;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_idx = __pyx_t_4;

      /* "View.MemoryView":1198
 *     if order == 'F':
 *         for idx in range(ndim):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 *     else:
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1199
 *         for idx in range(ndim):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }

    /* "View.MemoryView":1196
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1201
 *             stride *= shape[idx]
 *     else:
 *         for idx in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
  /*else*/ {
    for (__pyx_t_2 = (__pyx_v_ndim - 1); __pyx_t_2 > -1; __pyx_t_2-=1) {
      __pyx_v_idx = __pyx_t_2;

      /* "View.MemoryView":1202
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 * 
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1203
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 * 
 *     return stride
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1205
 *             stride *= shape[idx]
 * 
 *     return stride             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 */
  __pyx_r = __pyx_v_stride;
  goto __pyx_L0;

  /* "View.MemoryView":1187
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1208
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_tmpslice, char __pyx_v_order, int __pyx_v_ndim) {
  int __pyx_v_i;
  void *__pyx_v_result;
  size_t __pyx_v_itemsize;
  size_t __pyx_v_size;
  void *__pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_memoryview_obj *__pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":1219
 *     cdef void *result
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1220
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef size_t size = slice_get_size(src, ndim)             # <<<<<<<<<<<<<<
 * 
 *     result = malloc(size)
 */
  __pyx_v_size = __pyx_memoryview_slice_get_size(__pyx_v_src, __pyx_v_ndim);

  /* "View.MemoryView":1222
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 *     result = malloc(size)             # <<<<<<<<<<<<<<
 *     if not result:
 *         _err(MemoryError, NULL)
 */
  __pyx_v_result = malloc(__pyx_v_size);

  /* "View.MemoryView":1223
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err(MemoryError, NULL)
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_result != 0)) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1224
 *     result = malloc(size)
 *     if not result:
 *         _err(MemoryError, NULL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __pyx_memoryview_err(__pyx_builtin_MemoryError, NULL); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 1224, __pyx_L1_error)

    /* "View.MemoryView":1223
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err(MemoryError, NULL)
 * 
 */
  }

  /* "View.MemoryView":1227
 * 
 * 
 *     tmpslice.data = <char *> result             # <<<<<<<<<<<<<<
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 */
  __pyx_v_tmpslice->data = ((char *)__pyx_v_result);

  /* "View.MemoryView":1228
 * 
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview             # <<<<<<<<<<<<<<
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 */
  __pyx_t_4 = __pyx_v_src->memview;
  __pyx_v_tmpslice->memview = __pyx_t_4;

  /* "View.MemoryView":1229
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1230
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]             # <<<<<<<<<<<<<<
 *         tmpslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_tmpslice->shape[__pyx_v_i]) = (__pyx_v_src->shape[__pyx_v_i]);

    /* "View.MemoryView":1231
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize,
 */
    (__pyx_v_tmpslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1233
 *         tmpslice.suboffsets[i] = -1
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize,             # <<<<<<<<<<<<<<
 *                               ndim, order)
 * 
 */
  (void)(__pyx_fill_contig_strides_array((&(__pyx_v_tmpslice->shape[0])), (&(__pyx_v_tmpslice->strides[0])), __pyx_v_itemsize, __pyx_v_ndim, __pyx_v_order));

  /* "View.MemoryView":1237
 * 
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1238
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    __pyx_t_2 = (((__pyx_v_tmpslice->shape[__pyx_v_i]) == 1) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1239
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     if slice_is_contig(src[0], order, ndim):
 */
      (__pyx_v_tmpslice->strides[__pyx_v_i]) = 0;

      /* "View.MemoryView":1238
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    }
  }

  /* "View.MemoryView":1241
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
  __pyx_t_2 = (__pyx_memviewslice_is_contig((__pyx_v_src[0]), __pyx_v_order, __pyx_v_ndim) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1242
 * 
 *     if slice_is_contig(src[0], order, ndim):
 *         memcpy(result, src.data, size)             # <<<<<<<<<<<<<<
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 */
    (void)(memcpy(__pyx_v_result, __pyx_v_src->data, __pyx_v_size));

    /* "View.MemoryView":1241
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":1244
 *         memcpy(result, src.data, size)
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  /*else*/ {
    copy_strided_to_strided(__pyx_v_src, __pyx_v_tmpslice, __pyx_v_ndim, __pyx_v_itemsize);
  }
  __pyx_L9:;

  /* "View.MemoryView":1246
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":1208
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

  /* function exit code */
  __pyx_L1_error:;
  {
    #ifdef WITH_THREAD
    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
    #endif
    __Pyx_AddTraceback("View.MemoryView.copy_data_to_temp", __pyx_clineno, __pyx_lineno, __pyx_filename);
    #ifdef WITH_THREAD
    __Pyx_PyGILState_Release(__pyx_gilstate_save);
    #endif
  }
  __pyx_r = NULL;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1251
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError("got differing extents in dimension %d (got %d and %d)" %
 */

static int __pyx_memoryview_err_extents(int __pyx_v_i, Py_ssize_t __pyx_v_extent1, Py_ssize_t __pyx_v_extent2) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_extents", 0);

  /* "View.MemoryView":1254
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError("got differing extents in dimension %d (got %d and %d)" %
 *                                                         (i, extent1, extent2))             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_dim')
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_extent1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_extent2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;

  /* "View.MemoryView":1253
 * cdef int _err_extents(int i, Py_ssize_t extent1,
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError("got differing extents in dimension %d (got %d and %d)" %             # <<<<<<<<<<<<<<
 *                                                         (i, extent1, extent2))
 * 
 */
  __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_got_differing_extents_in_dimensi, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_Raise(__pyx_t_4, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(2, 1253, __pyx_L1_error)

  /* "View.MemoryView":1251
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError("got differing extents in dimension %d (got %d and %d)" %
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView._err_extents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1257
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(object error, char *msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise error(msg.decode('ascii') % dim)
 * 
 */

static int __pyx_memoryview_err_dim(PyObject *__pyx_v_error, char *__pyx_v_msg, int __pyx_v_dim) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_dim", 0);
  __Pyx_INCREF(__pyx_v_error);

  /* "View.MemoryView":1258
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(object error, char *msg, int dim) except -1 with gil:
 *     raise error(msg.decode('ascii') % dim)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err')
 */
  __pyx_t_2 = __Pyx_decode_c_string(__pyx_v_msg, 0, strlen(__pyx_v_msg), NULL, NULL, PyUnicode_DecodeASCII); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_dim); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyUnicode_Format(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_v_error);
  __pyx_t_3 = __pyx_v_error; __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(2, 1258, __pyx_L1_error)

  /* "View.MemoryView":1257
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(object error, char *msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise error(msg.decode('ascii') % dim)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView._err_dim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1261
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(object error, char *msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     if msg != NULL:
 *         raise error(msg.decode('ascii'))
 */

static int __pyx_memoryview_err(PyObject *__pyx_v_error, char *__pyx_v_msg) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err", 0);
  __Pyx_INCREF(__pyx_v_error);

  /* "View.MemoryView":1262
 * @cname('__pyx_memoryview_err')
 * cdef int _err(object error, char *msg) except -1 with gil:
 *     if msg != NULL:             # <<<<<<<<<<<<<<
 *         raise error(msg.decode('ascii'))
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_msg != NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":1263
 * cdef int _err(object error, char *msg) except -1 with gil:
 *     if msg != NULL:
 *         raise error(msg.decode('ascii'))             # <<<<<<<<<<<<<<
 *     else:
 *         raise error
 */
    __pyx_t_3 = __Pyx_decode_c_string(__pyx_v_msg, 0, strlen(__pyx_v_msg), NULL, NULL, PyUnicode_DecodeASCII); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_error);
    __pyx_t_4 = __pyx_v_error; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1263, __pyx_L1_error)

    /* "View.MemoryView":1262
 * @cname('__pyx_memoryview_err')
 * cdef int _err(object error, char *msg) except -1 with gil:
 *     if msg != NULL:             # <<<<<<<<<<<<<<
 *         raise error(msg.decode('ascii'))
 *     else:
 */
  }

  /* "View.MemoryView":1265
 *         raise error(msg.decode('ascii'))
 *     else:
 *         raise error             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_contents')
 */
  /*else*/ {
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(2, 1265, __pyx_L1_error)
  }

  /* "View.MemoryView":1261
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(object error, char *msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     if msg != NULL:
 *         raise error(msg.decode('ascii'))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView._err", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1268
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

static int __pyx_memoryview_copy_contents(__Pyx_memviewslice __pyx_v_src, __Pyx_memviewslice __pyx_v_dst, int __pyx_v_src_ndim, int __pyx_v_dst_ndim, int __pyx_v_dtype_is_object) {
  void *__pyx_v_tmpdata;
  size_t __pyx_v_itemsize;
  int __pyx_v_i;
  char __pyx_v_order;
  int __pyx_v_broadcasting;
  int __pyx_v_direct_copy;
  __Pyx_memviewslice __pyx_v_tmp;
  int __pyx_v_ndim;
  int __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  void *__pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":1276
 *     Check for overlapping memory and verify the shapes.
 *     """
 *     cdef void *tmpdata = NULL             # <<<<<<<<<<<<<<
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 */
  __pyx_v_tmpdata = NULL;

  /* "View.MemoryView":1277
 *     """
 *     cdef void *tmpdata = NULL
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 */
  __pyx_t_1 = __pyx_v_src.memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1279
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)             # <<<<<<<<<<<<<<
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False
 */
  __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_src), __pyx_v_src_ndim);

  /* "View.MemoryView":1280
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False             # <<<<<<<<<<<<<<
 *     cdef bint direct_copy = False
 *     cdef __Pyx_memviewslice tmp
 */
  __pyx_v_broadcasting = 0;

  /* "View.MemoryView":1281
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False             # <<<<<<<<<<<<<<
 *     cdef __Pyx_memviewslice tmp
 * 
 */
  __pyx_v_direct_copy = 0;

  /* "View.MemoryView":1284
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
  __pyx_t_2 = ((__pyx_v_src_ndim < __pyx_v_dst_ndim) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1285
 * 
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_src), __pyx_v_src_ndim, __pyx_v_dst_ndim);

    /* "View.MemoryView":1284
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1286
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  __pyx_t_2 = ((__pyx_v_dst_ndim < __pyx_v_src_ndim) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1287
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)             # <<<<<<<<<<<<<<
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_dst), __pyx_v_dst_ndim, __pyx_v_src_ndim);

    /* "View.MemoryView":1286
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":1289
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
  __pyx_t_3 = __pyx_v_dst_ndim;
  __pyx_t_4 = __pyx_v_src_ndim;
  if (((__pyx_t_3 > __pyx_t_4) != 0)) {
    __pyx_t_5 = __pyx_t_3;
  } else {
    __pyx_t_5 = __pyx_t_4;
  }
  __pyx_v_ndim = __pyx_t_5;

  /* "View.MemoryView":1291
 *     cdef int ndim = max(src_ndim, dst_ndim)
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 */
  __pyx_t_5 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_5;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1292
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    __pyx_t_2 = (((__pyx_v_src.shape[__pyx_v_i]) != (__pyx_v_dst.shape[__pyx_v_i])) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1293
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
      __pyx_t_2 = (((__pyx_v_src.shape[__pyx_v_i]) == 1) != 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":1294
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 *                 broadcasting = True             # <<<<<<<<<<<<<<
 *                 src.strides[i] = 0
 *             else:
 */
        __pyx_v_broadcasting = 1;

        /* "View.MemoryView":1295
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 *                 src.strides[i] = 0             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 */
        (__pyx_v_src.strides[__pyx_v_i]) = 0;

        /* "View.MemoryView":1293
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":1297
 *                 src.strides[i] = 0
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])             # <<<<<<<<<<<<<<
 * 
 *         if src.suboffsets[i] >= 0:
 */
      /*else*/ {
        __pyx_t_6 = __pyx_memoryview_err_extents(__pyx_v_i, (__pyx_v_dst.shape[__pyx_v_i]), (__pyx_v_src.shape[__pyx_v_i])); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(2, 1297, __pyx_L1_error)
      }
      __pyx_L7:;

      /* "View.MemoryView":1292
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    }

    /* "View.MemoryView":1299
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(ValueError, "Dimension %d is not direct", i)
 * 
 */
    __pyx_t_2 = (((__pyx_v_src.suboffsets[__pyx_v_i]) >= 0) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1300
 * 
 *         if src.suboffsets[i] >= 0:
 *             _err_dim(ValueError, "Dimension %d is not direct", i)             # <<<<<<<<<<<<<<
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 */
      __pyx_t_6 = __pyx_memoryview_err_dim(__pyx_builtin_ValueError, ((char *)"Dimension %d is not direct"), __pyx_v_i); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(2, 1300, __pyx_L1_error)

      /* "View.MemoryView":1299
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(ValueError, "Dimension %d is not direct", i)
 * 
 */
    }
  }

  /* "View.MemoryView":1302
 *             _err_dim(ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  __pyx_t_2 = (__pyx_slices_overlap((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1304
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    __pyx_t_2 = ((!(__pyx_memviewslice_is_contig(__pyx_v_src, __pyx_v_order, __pyx_v_ndim) != 0)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1305
 * 
 *         if not slice_is_contig(src, order, ndim):
 *             order = get_best_order(&dst, ndim)             # <<<<<<<<<<<<<<
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 */
      __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim);

      /* "View.MemoryView":1304
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    }

    /* "View.MemoryView":1307
 *             order = get_best_order(&dst, ndim)
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)             # <<<<<<<<<<<<<<
 *         src = tmp
 * 
 */
    __pyx_t_7 = __pyx_memoryview_copy_data_to_temp((&__pyx_v_src), (&__pyx_v_tmp), __pyx_v_order, __pyx_v_ndim); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(2, 1307, __pyx_L1_error)
    __pyx_v_tmpdata = __pyx_t_7;

    /* "View.MemoryView":1308
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 *         src = tmp             # <<<<<<<<<<<<<<
 * 
 *     if not broadcasting:
 */
    __pyx_v_src = __pyx_v_tmp;

    /* "View.MemoryView":1302
 *             _err_dim(ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  }

  /* "View.MemoryView":1310
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_broadcasting != 0)) != 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":1313
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
    __pyx_t_2 = (__pyx_memviewslice_is_contig(__pyx_v_src, 'C', __pyx_v_ndim) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1314
 * 
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)             # <<<<<<<<<<<<<<
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'C', __pyx_v_ndim);

      /* "View.MemoryView":1313
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
      goto __pyx_L12;
    }

    /* "View.MemoryView":1315
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    __pyx_t_2 = (__pyx_memviewslice_is_contig(__pyx_v_src, 'F', __pyx_v_ndim) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1316
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)             # <<<<<<<<<<<<<<
 * 
 *         if direct_copy:
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'F', __pyx_v_ndim);

      /* "View.MemoryView":1315
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    }
    __pyx_L12:;

    /* "View.MemoryView":1318
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, False)
 */
    __pyx_t_2 = (__pyx_v_direct_copy != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1320
 *         if direct_copy:
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, False)             # <<<<<<<<<<<<<<
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, True)
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

      /* "View.MemoryView":1321
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))             # <<<<<<<<<<<<<<
 *             refcount_copying(&dst, dtype_is_object, ndim, True)
 *             free(tmpdata)
 */
      (void)(memcpy(__pyx_v_dst.data, __pyx_v_src.data, __pyx_memoryview_slice_get_size((&__pyx_v_src), __pyx_v_ndim)));

      /* "View.MemoryView":1322
 *             refcount_copying(&dst, dtype_is_object, ndim, False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, True)             # <<<<<<<<<<<<<<
 *             free(tmpdata)
 *             return 0
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

      /* "View.MemoryView":1323
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, True)
 *             free(tmpdata)             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
      free(__pyx_v_tmpdata);

      /* "View.MemoryView":1324
 *             refcount_copying(&dst, dtype_is_object, ndim, True)
 *             free(tmpdata)
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "View.MemoryView":1318
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, False)
 */
    }

    /* "View.MemoryView":1310
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1326
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (__pyx_v_order == 'F');
  if (__pyx_t_2) {
    __pyx_t_2 = ('F' == __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim));
  }
  __pyx_t_8 = (__pyx_t_2 != 0);
  if (__pyx_t_8) {

    /* "View.MemoryView":1329
 * 
 * 
 *         transpose_memslice(&src)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&dst)
 * 
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_src)); if (unlikely(__pyx_t_5 == ((int)0))) __PYX_ERR(2, 1329, __pyx_L1_error)

    /* "View.MemoryView":1330
 * 
 *         transpose_memslice(&src)
 *         transpose_memslice(&dst)             # <<<<<<<<<<<<<<
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, False)
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_dst)); if (unlikely(__pyx_t_5 == ((int)0))) __PYX_ERR(2, 1330, __pyx_L1_error)

    /* "View.MemoryView":1326
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1332
 *         transpose_memslice(&dst)
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, False)             # <<<<<<<<<<<<<<
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, True)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1333
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)             # <<<<<<<<<<<<<<
 *     refcount_copying(&dst, dtype_is_object, ndim, True)
 * 
 */
  copy_strided_to_strided((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1334
 *     refcount_copying(&dst, dtype_is_object, ndim, False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, True)             # <<<<<<<<<<<<<<
 * 
 *     free(tmpdata)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1336
 *     refcount_copying(&dst, dtype_is_object, ndim, True)
 * 
 *     free(tmpdata)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
  free(__pyx_v_tmpdata);

  /* "View.MemoryView":1337
 * 
 *     free(tmpdata)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1268
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

  /* function exit code */
  __pyx_L1_error:;
  {
    #ifdef WITH_THREAD
    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
    #endif
    __Pyx_AddTraceback("View.MemoryView.memoryview_copy_contents", __pyx_clineno, __pyx_lineno, __pyx_filename);
    #ifdef WITH_THREAD
    __Pyx_PyGILState_Release(__pyx_gilstate_save);
    #endif
  }
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1340
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) nogil:
 */

static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim, int __pyx_v_ndim_other) {
  int __pyx_v_i;
  int __pyx_v_offset;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "View.MemoryView":1344
 *                             int ndim_other) nogil:
 *     cdef int i
 *     cdef int offset = ndim_other - ndim             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_offset = (__pyx_v_ndim_other - __pyx_v_ndim);

  /* "View.MemoryView":1346
 *     cdef int offset = ndim_other - ndim
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1347
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]             # <<<<<<<<<<<<<<
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 */
    (__pyx_v_mslice->shape[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->shape[__pyx_v_i]);

    /* "View.MemoryView":1348
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 */
    (__pyx_v_mslice->strides[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->strides[__pyx_v_i]);

    /* "View.MemoryView":1349
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(offset):
 */
    (__pyx_v_mslice->suboffsets[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->suboffsets[__pyx_v_i]);
  }

  /* "View.MemoryView":1351
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 *     for i in range(offset):             # <<<<<<<<<<<<<<
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 */
  __pyx_t_1 = __pyx_v_offset;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1352
 * 
 *     for i in range(offset):
 *         mslice.shape[i] = 1             # <<<<<<<<<<<<<<
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1
 */
    (__pyx_v_mslice->shape[__pyx_v_i]) = 1;

    /* "View.MemoryView":1353
 *     for i in range(offset):
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_mslice->strides[__pyx_v_i]) = (__pyx_v_mslice->strides[0]);

    /* "View.MemoryView":1354
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_mslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1340
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1362
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object,             # <<<<<<<<<<<<<<
 *                            int ndim, bint inc) nogil:
 * 
 */

static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_dtype_is_object, int __pyx_v_ndim, int __pyx_v_inc) {
  int __pyx_t_1;

  /* "View.MemoryView":1366
 * 
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape,
 *                                            dst.strides, ndim, inc)
 */
  __pyx_t_1 = (__pyx_v_dtype_is_object != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1367
 * 
 *     if dtype_is_object:
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape,             # <<<<<<<<<<<<<<
 *                                            dst.strides, ndim, inc)
 * 
 */
    __pyx_memoryview_refcount_objects_in_slice_with_gil(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_inc);

    /* "View.MemoryView":1366
 * 
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape,
 *                                            dst.strides, ndim, inc)
 */
  }

  /* "View.MemoryView":1362
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object,             # <<<<<<<<<<<<<<
 *                            int ndim, bint inc) nogil:
 * 
 */

  /* function exit code */
}

/* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) with gil:
 */

static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  __Pyx_RefNannyDeclarations
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("refcount_objects_in_slice_with_gil", 0);

  /* "View.MemoryView":1374
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) with gil:
 *     refcount_objects_in_slice(data, shape, strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 */
  __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, __pyx_v_shape, __pyx_v_strides, __pyx_v_ndim, __pyx_v_inc);

  /* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) with gil:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "View.MemoryView":1377
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc):
 *     cdef Py_ssize_t i
 */

static void __pyx_memoryview_refcount_objects_in_slice(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("refcount_objects_in_slice", 0);

  /* "View.MemoryView":1381
 *     cdef Py_ssize_t i
 * 
 *     for i in range(shape[0]):             # <<<<<<<<<<<<<<
 *         if ndim == 1:
 *             if inc:
 */
  __pyx_t_1 = (__pyx_v_shape[0]);
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1382
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
    __pyx_t_4 = ((__pyx_v_ndim == 1) != 0);
    if (__pyx_t_4) {

      /* "View.MemoryView":1383
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
      __pyx_t_4 = (__pyx_v_inc != 0);
      if (__pyx_t_4) {

        /* "View.MemoryView":1384
 *         if ndim == 1:
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])
 */
        Py_INCREF((((PyObject **)__pyx_v_data)[0]));

        /* "View.MemoryView":1383
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
        goto __pyx_L6;
      }

      /* "View.MemoryView":1386
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1,
 */
      /*else*/ {
        Py_DECREF((((PyObject **)__pyx_v_data)[0]));
      }
      __pyx_L6:;

      /* "View.MemoryView":1382
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":1388
 *                 Py_DECREF((<PyObject **> data)[0])
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1,             # <<<<<<<<<<<<<<
 *                                       ndim - 1, inc)
 * 
 */
    /*else*/ {

      /* "View.MemoryView":1389
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1,
 *                                       ndim - 1, inc)             # <<<<<<<<<<<<<<
 * 
 *         data += strides[0]
 */
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_inc);
    }
    __pyx_L5:;

    /* "View.MemoryView":1391
 *                                       ndim - 1, inc)
 * 
 *         data += strides[0]             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_data = (__pyx_v_data + (__pyx_v_strides[0]));
  }

  /* "View.MemoryView":1377
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc):
 *     cdef Py_ssize_t i
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "View.MemoryView":1397
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) nogil:
 */

static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item, int __pyx_v_dtype_is_object) {

  /* "View.MemoryView":1400
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, False)             # <<<<<<<<<<<<<<
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim,
 *                          itemsize, item)
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1401
 *                               bint dtype_is_object) nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim,             # <<<<<<<<<<<<<<
 *                          itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, True)
 */
  __pyx_memoryview__slice_assign_scalar(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_itemsize, __pyx_v_item);

  /* "View.MemoryView":1403
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim,
 *                          itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, True)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1397
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1407
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) nogil:
 */

static void __pyx_memoryview__slice_assign_scalar(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_extent;
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;

  /* "View.MemoryView":1411
 *                               size_t itemsize, void *item) nogil:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t extent = shape[0]
 * 
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1412
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]
 *     cdef Py_ssize_t extent = shape[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_extent = (__pyx_v_shape[0]);

  /* "View.MemoryView":1414
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
  __pyx_t_1 = ((__pyx_v_ndim == 1) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1415
 * 
 *     if ndim == 1:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             memcpy(data, item, itemsize)
 *             data += stride
 */
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1416
 *     if ndim == 1:
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)             # <<<<<<<<<<<<<<
 *             data += stride
 *     else:
 */
      (void)(memcpy(__pyx_v_data, __pyx_v_item, __pyx_v_itemsize));

      /* "View.MemoryView":1417
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 *             data += stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(extent):
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }

    /* "View.MemoryView":1414
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1419
 *             data += stride
 *     else:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             _slice_assign_scalar(data, shape + 1, strides + 1,
 *                                 ndim - 1, itemsize, item)
 */
  /*else*/ {
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1420
 *     else:
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1,             # <<<<<<<<<<<<<<
 *                                 ndim - 1, itemsize, item)
 *             data += stride
 */
      __pyx_memoryview__slice_assign_scalar(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize, __pyx_v_item);

      /* "View.MemoryView":1422
 *             _slice_assign_scalar(data, shape + 1, strides + 1,
 *                                 ndim - 1, itemsize, item)
 *             data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1407
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) nogil:
 */

  /* function exit code */
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum = {"__pyx_unpickle_Enum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 1); __PYX_ERR(2, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 2); __PYX_ERR(2, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_Enum") < 0)) __PYX_ERR(2, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xb068931:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xb068931) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xb068931:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)
 *     __pyx_result = Enum.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xb068931:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xb0, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xb068931:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)
 *     __pyx_result = Enum.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_MemviewEnum_type), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(2, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_unpickle_Enum__set_state(((struct __pyx_MemviewEnum_obj *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb068931 = (name))" % __pyx_checksum)
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->name);
  __Pyx_DECREF(__pyx_v___pyx_result->name);
  __pyx_v___pyx_result->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(2, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(2, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 1) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_gmt);
  Py_CLEAR(p->__pyx_v_plotsubdf);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *)o;
  if (p->__pyx_v_gmt) {
    e = (*v)(p->__pyx_v_gmt, a); if (e) return e;
  }
  if (p->__pyx_v_plotsubdf) {
    e = (*v)(p->__pyx_v_plotsubdf, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster *)o;
  tmp = ((PyObject*)p->__pyx_v_gmt);
  p->__pyx_v_gmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_plotsubdf);
  p->__pyx_v_plotsubdf = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct__plotCluster", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster, /*tp_traverse*/
  __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_elem);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_elem) {
    e = (*v)(p->__pyx_v_elem, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_gmt);
  Py_CLEAR(p->__pyx_v_plotcomb);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *)o;
  if (p->__pyx_v_gmt) {
    e = (*v)(p->__pyx_v_gmt, a); if (e) return e;
  }
  if (p->__pyx_v_plotcomb) {
    e = (*v)(p->__pyx_v_plotcomb, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig *)o;
  tmp = ((PyObject*)p->__pyx_v_gmt);
  p->__pyx_v_gmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_plotcomb);
  p->__pyx_v_plotcomb = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_2_savetopfig", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig, /*tp_traverse*/
  __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_elem);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_elem) {
    e = (*v)(p->__pyx_v_elem, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_3_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_gmt);
  Py_CLEAR(p->__pyx_v_seedids);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *)o;
  if (p->__pyx_v_gmt) {
    e = (*v)(p->__pyx_v_gmt, a); if (e) return e;
  }
  if (p->__pyx_v_seedids) {
    e = (*v)(p->__pyx_v_seedids, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval *)o;
  tmp = ((PyObject*)p->__pyx_v_gmt);
  p->__pyx_v_gmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_seedids);
  p->__pyx_v_seedids = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_4_saveresfigWithPval", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval, /*tp_traverse*/
  __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_elem);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_elem) {
    e = (*v)(p->__pyx_v_elem, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_5_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_gmt);
  Py_CLEAR(p->__pyx_v_seedids);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *)o;
  if (p->__pyx_v_gmt) {
    e = (*v)(p->__pyx_v_gmt, a); if (e) return e;
  }
  if (p->__pyx_v_seedids) {
    e = (*v)(p->__pyx_v_seedids, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig *)o;
  tmp = ((PyObject*)p->__pyx_v_gmt);
  p->__pyx_v_gmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_seedids);
  p->__pyx_v_seedids = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_6_saveresfig", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig, /*tp_traverse*/
  __pyx_tp_clear_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr[8];
static int __pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr = 0;

static PyObject *__pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr)))) {
    o = (PyObject*)__pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr[--__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr(PyObject *o) {
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_elem);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr)))) {
    __pyx_freelist_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr[__pyx_freecount_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr++] = ((struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *p = (struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_elem) {
    e = (*v)(p->__pyx_v_elem, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.__pyx_scope_struct_7_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_array __pyx_vtable_array;

static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_array_obj *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_array_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_array;
  p->mode = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_format = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_array___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_array(PyObject *o) {
  struct __pyx_array_obj *p = (struct __pyx_array_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_array___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->mode);
  Py_CLEAR(p->_format);
  (*Py_TYPE(o)->tp_free)(o);
}
static PyObject *__pyx_sq_item_array(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_array(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_array___setitem__(o, i, v);
  }
  else {
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by %.200s", Py_TYPE(o)->tp_name);
    return -1;
  }
}

static PyObject *__pyx_tp_getattro_array(PyObject *o, PyObject *n) {
  PyObject *v = __Pyx_PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_array___getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_getprop___pyx_array_memview(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(o);
}

static PyMethodDef __pyx_methods_array[] = {
  {"__getattr__", (PyCFunction)__pyx_array___getattr__, METH_O|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw___pyx_array_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw___pyx_array_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_array[] = {
  {(char *)"memview", __pyx_getprop___pyx_array_memview, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_array = {
  __pyx_array___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_array, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_array = {
  __pyx_array___len__, /*mp_length*/
  __pyx_array___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_array, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_array = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.array", /*tp_name*/
  sizeof(struct __pyx_array_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_array, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_array, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_array, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_array, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_array, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_array, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_array, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_array, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_MemviewEnum_obj *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_MemviewEnum_obj *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_Enum(PyObject *o) {
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_Enum(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_Enum(PyObject *o) {
  PyObject* tmp;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_Enum[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw___pyx_MemviewEnum_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw___pyx_MemviewEnum_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type___pyx_MemviewEnum = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.Enum", /*tp_name*/
  sizeof(struct __pyx_MemviewEnum_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_Enum, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_MemviewEnum___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_Enum, /*tp_traverse*/
  __pyx_tp_clear_Enum, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_Enum, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_MemviewEnum___init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_Enum, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct_memoryview __pyx_vtable_memoryview;

static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryview_obj *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_memoryview_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_memoryview;
  p->obj = Py_None; Py_INCREF(Py_None);
  p->_size = Py_None; Py_INCREF(Py_None);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  p->view.obj = NULL;
  if (unlikely(__pyx_memoryview___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_memoryview(PyObject *o) {
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryview___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->obj);
  Py_CLEAR(p->_size);
  Py_CLEAR(p->_array_interface);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_memoryview(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  if (p->obj) {
    e = (*v)(p->obj, a); if (e) return e;
  }
  if (p->_size) {
    e = (*v)(p->_size, a); if (e) return e;
  }
  if (p->_array_interface) {
    e = (*v)(p->_array_interface, a); if (e) return e;
  }
  if (p->view.obj) {
    e = (*v)(p->view.obj, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_memoryview(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  tmp = ((PyObject*)p->obj);
  p->obj = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_size);
  p->_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_array_interface);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  Py_CLEAR(p->view.obj);
  return 0;
}
static PyObject *__pyx_sq_item_memoryview(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_memoryview(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_memoryview___setitem__(o, i, v);
  }
  else {
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by %.200s", Py_TYPE(o)->tp_name);
    return -1;
  }
}

static PyObject *__pyx_getprop___pyx_memoryview_T(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_base(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_shape(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_strides(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_suboffsets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_ndim(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_itemsize(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_nbytes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(o);
}

static PyMethodDef __pyx_methods_memoryview[] = {
  {"is_c_contig", (PyCFunction)__pyx_memoryview_is_c_contig, METH_NOARGS, 0},
  {"is_f_contig", (PyCFunction)__pyx_memoryview_is_f_contig, METH_NOARGS, 0},
  {"copy", (PyCFunction)__pyx_memoryview_copy, METH_NOARGS, 0},
  {"copy_fortran", (PyCFunction)__pyx_memoryview_copy_fortran, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw___pyx_memoryview_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw___pyx_memoryview_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_memoryview[] = {
  {(char *)"T", __pyx_getprop___pyx_memoryview_T, 0, (char *)0, 0},
  {(char *)"base", __pyx_getprop___pyx_memoryview_base, 0, (char *)0, 0},
  {(char *)"shape", __pyx_getprop___pyx_memoryview_shape, 0, (char *)0, 0},
  {(char *)"strides", __pyx_getprop___pyx_memoryview_strides, 0, (char *)0, 0},
  {(char *)"suboffsets", __pyx_getprop___pyx_memoryview_suboffsets, 0, (char *)0, 0},
  {(char *)"ndim", __pyx_getprop___pyx_memoryview_ndim, 0, (char *)0, 0},
  {(char *)"itemsize", __pyx_getprop___pyx_memoryview_itemsize, 0, (char *)0, 0},
  {(char *)"nbytes", __pyx_getprop___pyx_memoryview_nbytes, 0, (char *)0, 0},
  {(char *)"size", __pyx_getprop___pyx_memoryview_size, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_memoryview = {
  __pyx_memoryview___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_memoryview, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_memoryview = {
  __pyx_memoryview___len__, /*mp_length*/
  __pyx_memoryview___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_memoryview, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_memoryview = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark.memoryview", /*tp_name*/
  sizeof(struct __pyx_memoryview_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_memoryview, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_memoryview___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_memoryview, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_memoryview, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_memoryview___str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_memoryview, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_memoryview, /*tp_traverse*/
  __pyx_tp_clear_memoryview, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_memoryview, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_memoryview, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_memoryview, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};
static struct __pyx_vtabstruct__memoryviewslice __pyx_vtable__memoryviewslice;

static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryviewslice_obj *p;
  PyObject *o = __pyx_tp_new_memoryview(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_memoryviewslice_obj *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_memoryview*)__pyx_vtabptr__memoryviewslice;
  p->from_object = Py_None; Py_INCREF(Py_None);
  p->from_slice.memview = NULL;
  return o;
}

static void __pyx_tp_dealloc__memoryviewslice(PyObject *o) {
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryviewslice___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->from_object);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_memoryview(o);
}

static int __pyx_tp_traverse__memoryviewslice(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  e = __pyx_tp_traverse_memoryview(o, v, a); if (e) return e;
  if (p->from_object) {
    e = (*v)(p->from_object, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear__memoryviewslice(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  __pyx_tp_clear_memoryview(o);
  tmp = ((PyObject*)p->from_object);
  p->from_object = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  __PYX_XDEC_MEMVIEW(&p->from_slice, 1);
  return 0;
}

static PyObject *__pyx_getprop___pyx_memoryviewslice_base(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_16_memoryviewslice_4base_1__get__(o);
}

static PyMethodDef __pyx_methods__memoryviewslice[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw___pyx_memoryviewslice_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw___pyx_memoryviewslice_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets__memoryviewslice[] = {
  {(char *)"base", __pyx_getprop___pyx_memoryviewslice_base, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type___pyx_memoryviewslice = {
  PyVarObject_HEAD_INIT(0, 0)
  "revealer.REVEALER_runbenchmark._memoryviewslice", /*tp_name*/
  sizeof(struct __pyx_memoryviewslice_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc__memoryviewslice, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_memoryview___repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_memoryview___str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Internal class for passing memoryview slices to Python", /*tp_doc*/
  __pyx_tp_traverse__memoryviewslice, /*tp_traverse*/
  __pyx_tp_clear__memoryviewslice, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods__memoryviewslice, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets__memoryviewslice, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new__memoryviewslice, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {"calc_bandwidth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_1calc_bandwidth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_calc_bandwidth},
  {"binaryInformationCoefficient_cython", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_3binaryInformationCoefficient_cython, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_2binaryInformationCoefficient_cython},
  {"ConditionalInformationCoefficient_cython", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_5ConditionalInformationCoefficient_cython, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_4ConditionalInformationCoefficient_cython},
  {"findBestCIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_7findBestCIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_6findBestCIC},
  {"rankCIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_9rankCIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_8rankCIC},
  {"findBestIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_11findBestIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_10findBestIC},
  {"rankIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_13rankIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_12rankIC},
  {"topmatch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_23topmatch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_22topmatch},
  {"runBenchmark", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_25runBenchmark, METH_VARARGS|METH_KEYWORDS, 0},
  {"REVEALERInner", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_27REVEALERInner, METH_VARARGS|METH_KEYWORDS, 0},
  {"updatePval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_29updatePval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_28updatePval},
  {"prepPvalICInd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_33prepPvalICInd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_32prepPvalICInd},
  {"calcPvalCIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_35calcPvalCIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_34calcPvalCIC},
  {"prepPvalCIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_37prepPvalCIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_36prepPvalCIC},
  {"calcPvalIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_39calcPvalIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_38calcPvalIC},
  {"prepPvalIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_41prepPvalIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_40prepPvalIC},
  {"runIndividualPvalIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_45runIndividualPvalIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_44runIndividualPvalIC},
  {"runBootstrap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_49runBootstrap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_48runBootstrap},
  {"runBootstrapIC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8revealer_21REVEALER_runbenchmark_53runBootstrapIC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_8revealer_21REVEALER_runbenchmark_52runBootstrapIC},
  {0, 0, 0, 0}
};

static int __pyx_import_star_set(PyObject *o, PyObject* py_name, char *name) {
  static const char* internal_type_names[] = {
    "Enum",
    "FILE",
    "PyObject",
    "PyThread_type_lock",
    "Py_intptr_t",
    "__Pyx_TypeInfo",
    "__Pyx_memviewslice",
    "__pyx_atomic_int",
    "__pyx_buffer",
    "__pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc",
    "__pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc_struct",
    "__pyx_ctuple_841ef__int__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc",
    "__pyx_ctuple_841ef__int__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc_struct",
    "__pyx_ctuple_Py_ssize_t",
    "__pyx_ctuple_Py_ssize_t__and_long",
    "__pyx_ctuple_Py_ssize_t__and_long_struct",
    "__pyx_ctuple_Py_ssize_t_struct",
    "__pyx_ctuple___dunderpyx_t_5numpy_double_t",
    "__pyx_ctuple___dunderpyx_t_5numpy_double_t_struct",
    "__pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t",
    "__pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t_struct",
    "__pyx_ctuple_char__ptr",
    "__pyx_ctuple_char__ptr_struct",
    "__pyx_ctuple_double",
    "__pyx_ctuple_double__and_double__and_double",
    "__pyx_ctuple_double__and_double__and_double_struct",
    "__pyx_ctuple_double_struct",
    "__pyx_ctuple_int",
    "__pyx_ctuple_int__and_Py_ssize_t",
    "__pyx_ctuple_int__and_Py_ssize_t__and_Py_ssize_t",
    "__pyx_ctuple_int__and_Py_ssize_t__and_Py_ssize_t_struct",
    "__pyx_ctuple_int__and_Py_ssize_t_struct",
    "__pyx_ctuple_int__and___dunderpyx_t_5numpy_double_t",
    "__pyx_ctuple_int__and___dunderpyx_t_5numpy_double_t_struct",
    "__pyx_ctuple_int_struct",
    "__pyx_ctuple_long",
    "__pyx_ctuple_long__and_Py_ssize_t",
    "__pyx_ctuple_long__and_Py_ssize_t_struct",
    "__pyx_ctuple_long__and_int",
    "__pyx_ctuple_long__and_int_struct",
    "__pyx_ctuple_long__and_long",
    "__pyx_ctuple_long__and_long__and_double",
    "__pyx_ctuple_long__and_long__and_double_struct",
    "__pyx_ctuple_long__and_long__and_long",
    "__pyx_ctuple_long__and_long__and_long_struct",
    "__pyx_ctuple_long__and_long_struct",
    "__pyx_ctuple_long_struct",
    "__pyx_memoryview",
    "__pyx_opt_args_8revealer_21REVEALER_runbenchmark_ConditionalInformationCoefficient_cython",
    "__pyx_opt_args_8revealer_21REVEALER_runbenchmark_binaryInformationCoefficient_cython",
    "__pyx_opt_args_8revealer_21REVEALER_runbenchmark_calc_bandwidth",
    "__pyx_opt_args_8revealer_21REVEALER_runbenchmark_py_bcv",
    "__pyx_opt_args_8revealer_21REVEALER_runbenchmark_runBenchmark",
    "__pyx_scope_struct_1_genexpr",
    "__pyx_scope_struct_2_savetopfig",
    "__pyx_scope_struct_3_genexpr",
    "__pyx_scope_struct_4_saveresfigWithPval",
    "__pyx_scope_struct_5_genexpr",
    "__pyx_scope_struct_6_saveresfig",
    "__pyx_scope_struct_7_genexpr",
    "__pyx_scope_struct__plotCluster",
    "_memoryviewslice",
    "array",
    "density",
    "memoryview",
    0
  };
  const char** type_name = internal_type_names;
  while (*type_name) {
    if (__Pyx_StrEq(name, *type_name)) {
      PyErr_Format(PyExc_TypeError, "Cannot overwrite C type %s", name);
      goto bad;
    }
    type_name++;
  }
  if (0);
  else if (__Pyx_StrEq(name, "DELMAX")) {
    __pyx_v_8revealer_21REVEALER_runbenchmark_DELMAX = __pyx_PyFloat_AsDouble(o); if (unlikely((__pyx_v_8revealer_21REVEALER_runbenchmark_DELMAX == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 34, __pyx_L2_error)
  }
  else if (__Pyx_StrEq(name, "EPS")) {
    __pyx_v_8revealer_21REVEALER_runbenchmark_EPS = __pyx_PyFloat_AsDouble(o); if (unlikely((__pyx_v_8revealer_21REVEALER_runbenchmark_EPS == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 12, __pyx_L2_error)
  }
  else if (__Pyx_StrEq(name, "Py_None")) {
    PyErr_Format(PyExc_TypeError, "Cannot convert Python object Py_None to PyObject *");
    __PYX_ERR(2, 57, __pyx_L2_error)
  }
  else if (__Pyx_StrEq(name, "RANDOM_SEED")) {
    __pyx_v_8revealer_21REVEALER_runbenchmark_RANDOM_SEED = __Pyx_PyInt_As_int(o); if (unlikely((__pyx_v_8revealer_21REVEALER_runbenchmark_RANDOM_SEED == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 28, __pyx_L2_error)
  }
  else if (__Pyx_StrEq(name, "__pyx_memoryview_thread_locks")) {
    PyErr_Format(PyExc_TypeError, "Cannot convert Python object __pyx_memoryview_thread_locks to PyThread_type_lock [8]");
    __PYX_ERR(2, 317, __pyx_L2_error)
  }
  else if (__Pyx_StrEq(name, "__pyx_memoryview_thread_locks_used")) {
    __pyx_memoryview_thread_locks_used = __Pyx_PyInt_As_int(o); if (unlikely((__pyx_memoryview_thread_locks_used == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 316, __pyx_L2_error)
  }
  else if (__Pyx_StrEq(name, "contiguous")) {
    Py_INCREF(o);
    Py_DECREF(contiguous);
    contiguous = o;
  }
  else if (__Pyx_StrEq(name, "generic")) {
    Py_INCREF(o);
    Py_DECREF(generic);
    generic = o;
  }
  else if (__Pyx_StrEq(name, "indirect")) {
    Py_INCREF(o);
    Py_DECREF(indirect);
    indirect = o;
  }
  else if (__Pyx_StrEq(name, "indirect_contiguous")) {
    Py_INCREF(o);
    Py_DECREF(indirect_contiguous);
    indirect_contiguous = o;
  }
  else if (__Pyx_StrEq(name, "strided")) {
    Py_INCREF(o);
    Py_DECREF(strided);
    strided = o;
  }
  else {
    if (PyObject_SetAttr(__pyx_m, py_name, o) < 0) goto bad;
  }
  return 0;
  __pyx_L2_error:;
  __Pyx_AddTraceback("revealer.REVEALER_runbenchmark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  bad:
  return -1;
}

static int
__Pyx_import_all_from(PyObject *locals, PyObject *v)
{
    PyObject *all = PyObject_GetAttrString(v, "__all__");
    PyObject *dict, *name, *value;
    int skip_leading_underscores = 0;
    int pos, err;
    if (all == NULL) {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError))
            return -1;
        PyErr_Clear();
        dict = PyObject_GetAttrString(v, "__dict__");
        if (dict == NULL) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError))
                return -1;
            PyErr_SetString(PyExc_ImportError,
            "from-import-* object has no __dict__ and no __all__");
            return -1;
        }
#if PY_MAJOR_VERSION < 3
        all = PyObject_CallMethod(dict, (char *)"keys", NULL);
#else
        all = PyMapping_Keys(dict);
#endif
        Py_DECREF(dict);
        if (all == NULL)
            return -1;
        skip_leading_underscores = 1;
    }
    for (pos = 0, err = 0; ; pos++) {
        name = PySequence_GetItem(all, pos);
        if (name == NULL) {
            if (!PyErr_ExceptionMatches(PyExc_IndexError))
                err = -1;
            else
                PyErr_Clear();
            break;
        }
        if (skip_leading_underscores &&
#if PY_MAJOR_VERSION < 3
            likely(PyString_Check(name)) &&
            PyString_AS_STRING(name)[0] == '_')
#else
            likely(PyUnicode_Check(name)) &&
            likely(__Pyx_PyUnicode_GET_LENGTH(name)) &&
            __Pyx_PyUnicode_READ_CHAR(name, 0) == '_')
#endif
        {
            Py_DECREF(name);
            continue;
        }
        value = PyObject_GetAttr(v, name);
        if (value == NULL)
            err = -1;
        else if (PyDict_CheckExact(locals))
            err = PyDict_SetItem(locals, name, value);
        else
            err = PyObject_SetItem(locals, name, value);
        Py_DECREF(name);
        Py_XDECREF(value);
        if (err != 0)
            break;
    }
    Py_DECREF(all);
    return err;
}
static int __pyx_import_star(PyObject* m) {
    int i;
    int ret = -1;
    char* s;
    PyObject *locals = 0;
    PyObject *list = 0;
#if PY_MAJOR_VERSION >= 3
    PyObject *utf8_name = 0;
#endif
    PyObject *name;
    PyObject *item;
    locals = PyDict_New();              if (!locals) goto bad;
    if (__Pyx_import_all_from(locals, m) < 0) goto bad;
    list = PyDict_Items(locals);        if (!list) goto bad;
    for(i=0; i<PyList_GET_SIZE(list); i++) {
        name = PyTuple_GET_ITEM(PyList_GET_ITEM(list, i), 0);
        item = PyTuple_GET_ITEM(PyList_GET_ITEM(list, i), 1);
#if PY_MAJOR_VERSION >= 3
        utf8_name = PyUnicode_AsUTF8String(name);
        if (!utf8_name) goto bad;
        s = PyBytes_AS_STRING(utf8_name);
        if (__pyx_import_star_set(item, name, s) < 0) goto bad;
        Py_DECREF(utf8_name); utf8_name = 0;
#else
        s = PyString_AsString(name);
        if (!s) goto bad;
        if (__pyx_import_star_set(item, name, s) < 0) goto bad;
#endif
    }
    ret = 0;
bad:
    Py_XDECREF(locals);
    Py_XDECREF(list);
#if PY_MAJOR_VERSION >= 3
    Py_XDECREF(utf8_name);
#endif
    return ret;
}



#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_REVEALER_runbenchmark(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_REVEALER_runbenchmark},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "REVEALER_runbenchmark",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_1f, __pyx_k_1f, sizeof(__pyx_k_1f), 0, 1, 0, 0},
  {&__pyx_kp_u_3f, __pyx_k_3f, sizeof(__pyx_k_3f), 0, 1, 0, 0},
  {&__pyx_kp_u_3f_2, __pyx_k_3f_2, sizeof(__pyx_k_3f_2), 0, 1, 0, 0},
  {&__pyx_n_s_ASCII, __pyx_k_ASCII, sizeof(__pyx_k_ASCII), 0, 0, 1, 1},
  {&__pyx_kp_u_All_core, __pyx_k_All_core, sizeof(__pyx_k_All_core), 0, 1, 0, 0},
  {&__pyx_kp_u_Best_feature_choosen_in_this_rou, __pyx_k_Best_feature_choosen_in_this_rou, sizeof(__pyx_k_Best_feature_choosen_in_this_rou), 0, 1, 0, 0},
  {&__pyx_kp_s_Buffer_view_does_not_expose_stri, __pyx_k_Buffer_view_does_not_expose_stri, sizeof(__pyx_k_Buffer_view_does_not_expose_stri), 0, 0, 1, 0},
  {&__pyx_kp_u_CIC, __pyx_k_CIC, sizeof(__pyx_k_CIC), 0, 1, 0, 0},
  {&__pyx_n_u_CIC_2, __pyx_k_CIC_2, sizeof(__pyx_k_CIC_2), 0, 1, 0, 1},
  {&__pyx_kp_u_CIC_GeneNames, __pyx_k_CIC_GeneNames, sizeof(__pyx_k_CIC_GeneNames), 0, 1, 0, 0},
  {&__pyx_kp_u_CIC_calculated_in_this_round_is, __pyx_k_CIC_calculated_in_this_round_is, sizeof(__pyx_k_CIC_calculated_in_this_round_is), 0, 1, 0, 0},
  {&__pyx_n_s_CICs, __pyx_k_CICs, sizeof(__pyx_k_CICs), 0, 0, 1, 1},
  {&__pyx_n_u_CICs, __pyx_k_CICs, sizeof(__pyx_k_CICs), 0, 1, 0, 1},
  {&__pyx_kp_s_Can_only_create_a_buffer_that_is, __pyx_k_Can_only_create_a_buffer_that_is, sizeof(__pyx_k_Can_only_create_a_buffer_that_is), 0, 0, 1, 0},
  {&__pyx_kp_s_Cannot_assign_to_read_only_memor, __pyx_k_Cannot_assign_to_read_only_memor, sizeof(__pyx_k_Cannot_assign_to_read_only_memor), 0, 0, 1, 0},
  {&__pyx_kp_s_Cannot_create_writable_memory_vi, __pyx_k_Cannot_create_writable_memory_vi, sizeof(__pyx_k_Cannot_create_writable_memory_vi), 0, 0, 1, 0},
  {&__pyx_kp_s_Cannot_index_with_type_s, __pyx_k_Cannot_index_with_type_s, sizeof(__pyx_k_Cannot_index_with_type_s), 0, 0, 1, 0},
  {&__pyx_n_s_DataFrame, __pyx_k_DataFrame, sizeof(__pyx_k_DataFrame), 0, 0, 1, 1},
  {&__pyx_kp_u_Done_reading_input_files, __pyx_k_Done_reading_input_files, sizeof(__pyx_k_Done_reading_input_files), 0, 1, 0, 0},
  {&__pyx_n_s_Ellipsis, __pyx_k_Ellipsis, sizeof(__pyx_k_Ellipsis), 0, 0, 1, 1},
  {&__pyx_kp_s_Empty_shape_tuple_for_cython_arr, __pyx_k_Empty_shape_tuple_for_cython_arr, sizeof(__pyx_k_Empty_shape_tuple_for_cython_arr), 0, 0, 1, 0},
  {&__pyx_kp_u_Grid_size_is, __pyx_k_Grid_size_is, sizeof(__pyx_k_Grid_size_is), 0, 1, 0, 0},
  {&__pyx_n_u_Group, __pyx_k_Group, sizeof(__pyx_k_Group), 0, 1, 0, 1},
  {&__pyx_n_s_IC, __pyx_k_IC, sizeof(__pyx_k_IC), 0, 0, 1, 1},
  {&__pyx_n_u_IC, __pyx_k_IC, sizeof(__pyx_k_IC), 0, 1, 0, 1},
  {&__pyx_kp_u_IC_2, __pyx_k_IC_2, sizeof(__pyx_k_IC_2), 0, 1, 0, 0},
  {&__pyx_kp_u_IC_of_new_seed_is, __pyx_k_IC_of_new_seed_is, sizeof(__pyx_k_IC_of_new_seed_is), 0, 1, 0, 0},
  {&__pyx_n_s_ICs, __pyx_k_ICs, sizeof(__pyx_k_ICs), 0, 0, 1, 1},
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xb0, __pyx_k_Incompatible_checksums_s_vs_0xb0, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xb0), 0, 0, 1, 0},
  {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
  {&__pyx_kp_u_Indicated_Core_Number_exceed_max, __pyx_k_Indicated_Core_Number_exceed_max, sizeof(__pyx_k_Indicated_Core_Number_exceed_max), 0, 1, 0, 0},
  {&__pyx_kp_s_Indirect_dimensions_not_supporte, __pyx_k_Indirect_dimensions_not_supporte, sizeof(__pyx_k_Indirect_dimensions_not_supporte), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_mode_expected_c_or_fortr, __pyx_k_Invalid_mode_expected_c_or_fortr, sizeof(__pyx_k_Invalid_mode_expected_c_or_fortr), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_shape_in_axis_d_d, __pyx_k_Invalid_shape_in_axis_d_d, sizeof(__pyx_k_Invalid_shape_in_axis_d_d), 0, 0, 1, 0},
  {&__pyx_n_u_Iteration, __pyx_k_Iteration, sizeof(__pyx_k_Iteration), 0, 1, 0, 1},
  {&__pyx_n_s_LinearSegmentedColormap, __pyx_k_LinearSegmentedColormap, sizeof(__pyx_k_LinearSegmentedColormap), 0, 0, 1, 1},
  {&__pyx_n_u_Location, __pyx_k_Location, sizeof(__pyx_k_Location), 0, 1, 0, 1},
  {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {&__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_k_MemoryView_of_r_at_0x_x, sizeof(__pyx_k_MemoryView_of_r_at_0x_x), 0, 0, 1, 0},
  {&__pyx_kp_s_MemoryView_of_r_object, __pyx_k_MemoryView_of_r_object, sizeof(__pyx_k_MemoryView_of_r_object), 0, 0, 1, 0},
  {&__pyx_n_s_N, __pyx_k_N, sizeof(__pyx_k_N), 0, 0, 1, 1},
  {&__pyx_kp_u_NMF, __pyx_k_NMF, sizeof(__pyx_k_NMF), 0, 1, 0, 0},
  {&__pyx_n_u_Name, __pyx_k_Name, sizeof(__pyx_k_Name), 0, 1, 0, 1},
  {&__pyx_kp_u_Names_in_gmt_file_is_not_matchin, __pyx_k_Names_in_gmt_file_is_not_matchin, sizeof(__pyx_k_Names_in_gmt_file_is_not_matchin), 0, 1, 0, 0},
  {&__pyx_kp_u_New_Seed, __pyx_k_New_Seed, sizeof(__pyx_k_New_Seed), 0, 1, 0, 0},
  {&__pyx_n_u_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 1, 0, 1},
  {&__pyx_kp_u_Null_Seed, __pyx_k_Null_Seed, sizeof(__pyx_k_Null_Seed), 0, 1, 0, 0},
  {&__pyx_kp_u_Number_of_features_passing_thres, __pyx_k_Number_of_features_passing_thres, sizeof(__pyx_k_Number_of_features_passing_thres), 0, 1, 0, 0},
  {&__pyx_kp_u_Number_of_features_that_pass_the, __pyx_k_Number_of_features_that_pass_the, sizeof(__pyx_k_Number_of_features_that_pass_the), 0, 1, 0, 0},
  {&__pyx_kp_u_Number_of_thread_used, __pyx_k_Number_of_thread_used, sizeof(__pyx_k_Number_of_thread_used), 0, 1, 0, 0},
  {&__pyx_n_b_O, __pyx_k_O, sizeof(__pyx_k_O), 0, 0, 0, 1},
  {&__pyx_kp_s_Out_of_bounds_on_buffer_access_a, __pyx_k_Out_of_bounds_on_buffer_access_a, sizeof(__pyx_k_Out_of_bounds_on_buffer_access_a), 0, 0, 1, 0},
  {&__pyx_kp_u_PhenotypeDistribution, __pyx_k_PhenotypeDistribution, sizeof(__pyx_k_PhenotypeDistribution), 0, 1, 0, 0},
  {&__pyx_kp_u_Picked_seed_is, __pyx_k_Picked_seed_is, sizeof(__pyx_k_Picked_seed_is), 0, 1, 0, 0},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_kp_u_Please_put_input, __pyx_k_Please_put_input, sizeof(__pyx_k_Please_put_input), 0, 1, 0, 0},
  {&__pyx_kp_u_Result, __pyx_k_Result, sizeof(__pyx_k_Result), 0, 1, 0, 0},
  {&__pyx_kp_u_ResultClustered, __pyx_k_ResultClustered, sizeof(__pyx_k_ResultClustered), 0, 1, 0, 0},
  {&__pyx_kp_u_ResultClustered_txt, __pyx_k_ResultClustered_txt, sizeof(__pyx_k_ResultClustered_txt), 0, 1, 0, 0},
  {&__pyx_kp_u_Result_gmt, __pyx_k_Result_gmt, sizeof(__pyx_k_Result_gmt), 0, 1, 0, 0},
  {&__pyx_kp_u_Result_txt, __pyx_k_Result_txt, sizeof(__pyx_k_Result_txt), 0, 1, 0, 0},
  {&__pyx_kp_u_Round, __pyx_k_Round, sizeof(__pyx_k_Round), 0, 1, 0, 0},
  {&__pyx_kp_u_Run_name, __pyx_k_Run_name, sizeof(__pyx_k_Run_name), 0, 1, 0, 0},
  {&__pyx_kp_u_Seed, __pyx_k_Seed, sizeof(__pyx_k_Seed), 0, 1, 0, 0},
  {&__pyx_n_u_Seed_2, __pyx_k_Seed_2, sizeof(__pyx_k_Seed_2), 0, 1, 0, 1},
  {&__pyx_kp_u_Start_reading_input_files, __pyx_k_Start_reading_input_files, sizeof(__pyx_k_Start_reading_input_files), 0, 1, 0, 0},
  {&__pyx_n_s_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 0, 1, 1},
  {&__pyx_kp_u_Target, __pyx_k_Target, sizeof(__pyx_k_Target), 0, 1, 0, 0},
  {&__pyx_n_u_Target_2, __pyx_k_Target_2, sizeof(__pyx_k_Target_2), 0, 1, 0, 1},
  {&__pyx_kp_u_Time_used_to_read_input_s_second, __pyx_k_Time_used_to_read_input_s_second, sizeof(__pyx_k_Time_used_to_read_input_s_second), 0, 1, 0, 0},
  {&__pyx_kp_u_Time_used_to_run_loops_s_second, __pyx_k_Time_used_to_run_loops_s_second, sizeof(__pyx_k_Time_used_to_run_loops_s_second), 0, 1, 0, 0},
  {&__pyx_kp_u_Time_used_to_run_one_loop_s_seco, __pyx_k_Time_used_to_run_one_loop_s_seco, sizeof(__pyx_k_Time_used_to_run_one_loop_s_seco), 0, 1, 0, 0},
  {&__pyx_n_u_Top, __pyx_k_Top, sizeof(__pyx_k_Top), 0, 1, 0, 1},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_s_Unable_to_convert_item_to_object, __pyx_k_Unable_to_convert_item_to_object, sizeof(__pyx_k_Unable_to_convert_item_to_object), 0, 0, 1, 0},
  {&__pyx_kp_u_Universal_bandwidth_is, __pyx_k_Universal_bandwidth_is, sizeof(__pyx_k_Universal_bandwidth_is), 0, 1, 0, 0},
  {&__pyx_kp_u_Used, __pyx_k_Used, sizeof(__pyx_k_Used), 0, 1, 0, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_View_MemoryView, __pyx_k_View_MemoryView, sizeof(__pyx_k_View_MemoryView), 0, 0, 1, 1},
  {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
  {&__pyx_kp_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 0},
  {&__pyx_kp_u__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 1, 0, 0},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_u__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 1, 0, 0},
  {&__pyx_kp_u__27, __pyx_k__27, sizeof(__pyx_k__27), 0, 1, 0, 0},
  {&__pyx_kp_u__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 1, 0, 0},
  {&__pyx_kp_u__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 1, 0, 0},
  {&__pyx_kp_u__40, __pyx_k__40, sizeof(__pyx_k__40), 0, 1, 0, 0},
  {&__pyx_kp_u__44, __pyx_k__44, sizeof(__pyx_k__44), 0, 1, 0, 0},
  {&__pyx_kp_u__45, __pyx_k__45, sizeof(__pyx_k__45), 0, 1, 0, 0},
  {&__pyx_kp_u__46, __pyx_k__46, sizeof(__pyx_k__46), 0, 1, 0, 0},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_n_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 1},
  {&__pyx_n_s__84, __pyx_k__84, sizeof(__pyx_k__84), 0, 0, 1, 1},
  {&__pyx_kp_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 0},
  {&__pyx_n_u_agg, __pyx_k_agg, sizeof(__pyx_k_agg), 0, 1, 0, 1},
  {&__pyx_n_s_algorithm, __pyx_k_algorithm, sizeof(__pyx_k_algorithm), 0, 0, 1, 1},
  {&__pyx_n_u_all, __pyx_k_all, sizeof(__pyx_k_all), 0, 1, 0, 1},
  {&__pyx_n_s_allocate_buffer, __pyx_k_allocate_buffer, sizeof(__pyx_k_allocate_buffer), 0, 0, 1, 1},
  {&__pyx_n_s_alpha, __pyx_k_alpha, sizeof(__pyx_k_alpha), 0, 0, 1, 1},
  {&__pyx_n_s_annot, __pyx_k_annot, sizeof(__pyx_k_annot), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
  {&__pyx_n_s_asarray, __pyx_k_asarray, sizeof(__pyx_k_asarray), 0, 0, 1, 1},
  {&__pyx_n_s_ascending, __pyx_k_ascending, sizeof(__pyx_k_ascending), 0, 0, 1, 1},
  {&__pyx_n_s_ascontiguousarray, __pyx_k_ascontiguousarray, sizeof(__pyx_k_ascontiguousarray), 0, 0, 1, 1},
  {&__pyx_n_s_astype, __pyx_k_astype, sizeof(__pyx_k_astype), 0, 0, 1, 1},
  {&__pyx_n_s_ax, __pyx_k_ax, sizeof(__pyx_k_ax), 0, 0, 1, 1},
  {&__pyx_n_s_axis, __pyx_k_axis, sizeof(__pyx_k_axis), 0, 0, 1, 1},
  {&__pyx_n_s_bandwidth, __pyx_k_bandwidth, sizeof(__pyx_k_bandwidth), 0, 0, 1, 1},
  {&__pyx_kp_u_bandwidth_2, __pyx_k_bandwidth_2, sizeof(__pyx_k_bandwidth_2), 0, 1, 0, 0},
  {&__pyx_n_s_bandwidth_adj, __pyx_k_bandwidth_adj, sizeof(__pyx_k_bandwidth_adj), 0, 0, 1, 1},
  {&__pyx_n_s_bandwidth_mult, __pyx_k_bandwidth_mult, sizeof(__pyx_k_bandwidth_mult), 0, 0, 1, 1},
  {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
  {&__pyx_n_u_blue, __pyx_k_blue, sizeof(__pyx_k_blue), 0, 1, 0, 1},
  {&__pyx_n_u_bootstrap, __pyx_k_bootstrap, sizeof(__pyx_k_bootstrap), 0, 1, 0, 1},
  {&__pyx_n_s_bootstraps, __pyx_k_bootstraps, sizeof(__pyx_k_bootstraps), 0, 0, 1, 1},
  {&__pyx_n_u_bootstraps, __pyx_k_bootstraps, sizeof(__pyx_k_bootstraps), 0, 1, 0, 1},
  {&__pyx_n_u_bwr, __pyx_k_bwr, sizeof(__pyx_k_bwr), 0, 1, 0, 1},
  {&__pyx_n_s_by, __pyx_k_by, sizeof(__pyx_k_by), 0, 0, 1, 1},
  {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
  {&__pyx_n_u_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 1, 0, 1},
  {&__pyx_n_s_calcBootstrap, __pyx_k_calcBootstrap, sizeof(__pyx_k_calcBootstrap), 0, 0, 1, 1},
  {&__pyx_n_s_calcBootstrapIC, __pyx_k_calcBootstrapIC, sizeof(__pyx_k_calcBootstrapIC), 0, 0, 1, 1},
  {&__pyx_n_s_calcIndivisualPvalIC, __pyx_k_calcIndivisualPvalIC, sizeof(__pyx_k_calcIndivisualPvalIC), 0, 0, 1, 1},
  {&__pyx_n_s_cbar, __pyx_k_cbar, sizeof(__pyx_k_cbar), 0, 0, 1, 1},
  {&__pyx_n_s_ccal, __pyx_k_ccal, sizeof(__pyx_k_ccal), 0, 0, 1, 1},
  {&__pyx_n_s_center, __pyx_k_center, sizeof(__pyx_k_center), 0, 0, 1, 1},
  {&__pyx_n_u_center, __pyx_k_center, sizeof(__pyx_k_center), 0, 1, 0, 1},
  {&__pyx_n_s_check_inset, __pyx_k_check_inset, sizeof(__pyx_k_check_inset), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_clr, __pyx_k_clr, sizeof(__pyx_k_clr), 0, 0, 1, 1},
  {&__pyx_n_s_cmap, __pyx_k_cmap, sizeof(__pyx_k_cmap), 0, 0, 1, 1},
  {&__pyx_n_s_collapse, __pyx_k_collapse, sizeof(__pyx_k_collapse), 0, 0, 1, 1},
  {&__pyx_n_s_color, __pyx_k_color, sizeof(__pyx_k_color), 0, 0, 1, 1},
  {&__pyx_n_s_colspan, __pyx_k_colspan, sizeof(__pyx_k_colspan), 0, 0, 1, 1},
  {&__pyx_n_s_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 0, 1, 1},
  {&__pyx_n_u_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 1, 0, 1},
  {&__pyx_n_s_comb, __pyx_k_comb, sizeof(__pyx_k_comb), 0, 0, 1, 1},
  {&__pyx_n_s_comball, __pyx_k_comball, sizeof(__pyx_k_comball), 0, 0, 1, 1},
  {&__pyx_n_s_commoncol, __pyx_k_commoncol, sizeof(__pyx_k_commoncol), 0, 0, 1, 1},
  {&__pyx_n_s_concat, __pyx_k_concat, sizeof(__pyx_k_concat), 0, 0, 1, 1},
  {&__pyx_kp_s_contiguous_and_direct, __pyx_k_contiguous_and_direct, sizeof(__pyx_k_contiguous_and_direct), 0, 0, 1, 0},
  {&__pyx_kp_s_contiguous_and_indirect, __pyx_k_contiguous_and_indirect, sizeof(__pyx_k_contiguous_and_indirect), 0, 0, 1, 0},
  {&__pyx_n_s_cophenetic_correlation_coefficie, __pyx_k_cophenetic_correlation_coefficie, sizeof(__pyx_k_cophenetic_correlation_coefficie), 0, 0, 1, 1},
  {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
  {&__pyx_n_u_corr, __pyx_k_corr, sizeof(__pyx_k_corr), 0, 1, 0, 1},
  {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
  {&__pyx_n_s_countless, __pyx_k_countless, sizeof(__pyx_k_countless), 0, 0, 1, 1},
  {&__pyx_n_s_cpu_count, __pyx_k_cpu_count, sizeof(__pyx_k_cpu_count), 0, 0, 1, 1},
  {&__pyx_n_s_currentseed, __pyx_k_currentseed, sizeof(__pyx_k_currentseed), 0, 0, 1, 1},
  {&__pyx_kp_u_custom_greys, __pyx_k_custom_greys, sizeof(__pyx_k_custom_greys), 0, 1, 0, 0},
  {&__pyx_n_s_cython, __pyx_k_cython, sizeof(__pyx_k_cython), 0, 0, 1, 1},
  {&__pyx_n_s_cythonseed, __pyx_k_cythonseed, sizeof(__pyx_k_cythonseed), 0, 0, 1, 1},
  {&__pyx_n_s_deltay, __pyx_k_deltay, sizeof(__pyx_k_deltay), 0, 0, 1, 1},
  {&__pyx_n_s_df, __pyx_k_df, sizeof(__pyx_k_df), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_diff, __pyx_k_diff, sizeof(__pyx_k_diff), 0, 0, 1, 1},
  {&__pyx_n_s_diffindex, __pyx_k_diffindex, sizeof(__pyx_k_diffindex), 0, 0, 1, 1},
  {&__pyx_n_s_direction, __pyx_k_direction, sizeof(__pyx_k_direction), 0, 0, 1, 1},
  {&__pyx_n_s_directory_path, __pyx_k_directory_path, sizeof(__pyx_k_directory_path), 0, 0, 1, 1},
  {&__pyx_n_s_drawFeature, __pyx_k_drawFeature, sizeof(__pyx_k_drawFeature), 0, 0, 1, 1},
  {&__pyx_n_s_drawSeed, __pyx_k_drawSeed, sizeof(__pyx_k_drawSeed), 0, 0, 1, 1},
  {&__pyx_n_s_drawTarget, __pyx_k_drawTarget, sizeof(__pyx_k_drawTarget), 0, 0, 1, 1},
  {&__pyx_n_s_drop, __pyx_k_drop, sizeof(__pyx_k_drop), 0, 0, 1, 1},
  {&__pyx_n_s_dropna, __pyx_k_dropna, sizeof(__pyx_k_dropna), 0, 0, 1, 1},
  {&__pyx_n_s_dtype_is_object, __pyx_k_dtype_is_object, sizeof(__pyx_k_dtype_is_object), 0, 0, 1, 1},
  {&__pyx_kp_u_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 1, 0, 0},
  {&__pyx_n_u_e_2, __pyx_k_e_2, sizeof(__pyx_k_e_2), 0, 1, 0, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
  {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
  {&__pyx_n_s_eps, __pyx_k_eps, sizeof(__pyx_k_eps), 0, 0, 1, 1},
  {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
  {&__pyx_n_s_exists, __pyx_k_exists, sizeof(__pyx_k_exists), 0, 0, 1, 1},
  {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
  {&__pyx_n_s_exit_2, __pyx_k_exit_2, sizeof(__pyx_k_exit_2), 0, 0, 1, 1},
  {&__pyx_n_s_explore_components, __pyx_k_explore_components, sizeof(__pyx_k_explore_components), 0, 0, 1, 1},
  {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
  {&__pyx_n_s_feature, __pyx_k_feature, sizeof(__pyx_k_feature), 0, 0, 1, 1},
  {&__pyx_n_s_feature_df, __pyx_k_feature_df, sizeof(__pyx_k_feature_df), 0, 0, 1, 1},
  {&__pyx_n_s_feature_file, __pyx_k_feature_file, sizeof(__pyx_k_feature_file), 0, 0, 1, 1},
  {&__pyx_n_s_feature_name, __pyx_k_feature_name, sizeof(__pyx_k_feature_name), 0, 0, 1, 1},
  {&__pyx_n_s_featurecmap, __pyx_k_featurecmap, sizeof(__pyx_k_featurecmap), 0, 0, 1, 1},
  {&__pyx_n_s_features, __pyx_k_features, sizeof(__pyx_k_features), 0, 0, 1, 1},
  {&__pyx_n_s_fig, __pyx_k_fig, sizeof(__pyx_k_fig), 0, 0, 1, 1},
  {&__pyx_n_s_figsize, __pyx_k_figsize, sizeof(__pyx_k_figsize), 0, 0, 1, 1},
  {&__pyx_n_s_figure, __pyx_k_figure, sizeof(__pyx_k_figure), 0, 0, 1, 1},
  {&__pyx_n_s_figure_format, __pyx_k_figure_format, sizeof(__pyx_k_figure_format), 0, 0, 1, 1},
  {&__pyx_n_s_filterwarnings, __pyx_k_filterwarnings, sizeof(__pyx_k_filterwarnings), 0, 0, 1, 1},
  {&__pyx_n_s_finfo, __pyx_k_finfo, sizeof(__pyx_k_finfo), 0, 0, 1, 1},
  {&__pyx_n_u_firstseed, __pyx_k_firstseed, sizeof(__pyx_k_firstseed), 0, 1, 0, 1},
  {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
  {&__pyx_n_s_floor, __pyx_k_floor, sizeof(__pyx_k_floor), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 0, 1, 1},
  {&__pyx_n_u_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 1, 0, 1},
  {&__pyx_n_s_from_list, __pyx_k_from_list, sizeof(__pyx_k_from_list), 0, 0, 1, 1},
  {&__pyx_n_s_g, __pyx_k_g, sizeof(__pyx_k_g), 0, 0, 1, 1},
  {&__pyx_n_s_gene, __pyx_k_gene, sizeof(__pyx_k_gene), 0, 0, 1, 1},
  {&__pyx_n_s_gene_locus, __pyx_k_gene_locus, sizeof(__pyx_k_gene_locus), 0, 0, 1, 1},
  {&__pyx_n_s_gene_separator, __pyx_k_gene_separator, sizeof(__pyx_k_gene_separator), 0, 0, 1, 1},
  {&__pyx_n_s_gene_set, __pyx_k_gene_set, sizeof(__pyx_k_gene_set), 0, 0, 1, 1},
  {&__pyx_n_s_genename, __pyx_k_genename, sizeof(__pyx_k_genename), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_gmt, __pyx_k_gmt, sizeof(__pyx_k_gmt), 0, 0, 1, 1},
  {&__pyx_kp_u_gmt_2, __pyx_k_gmt_2, sizeof(__pyx_k_gmt_2), 0, 1, 0, 0},
  {&__pyx_n_s_gmt_file, __pyx_k_gmt_file, sizeof(__pyx_k_gmt_file), 0, 0, 1, 1},
  {&__pyx_kp_s_got_differing_extents_in_dimensi, __pyx_k_got_differing_extents_in_dimensi, sizeof(__pyx_k_got_differing_extents_in_dimensi), 0, 0, 1, 0},
  {&__pyx_n_s_grid, __pyx_k_grid, sizeof(__pyx_k_grid), 0, 0, 1, 1},
  {&__pyx_kp_u_grid_size, __pyx_k_grid_size, sizeof(__pyx_k_grid_size), 0, 1, 0, 0},
  {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
  {&__pyx_n_u_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 1, 0, 1},
  {&__pyx_n_s_groupindex, __pyx_k_groupindex, sizeof(__pyx_k_groupindex), 0, 0, 1, 1},
  {&__pyx_n_s_gsubdf, __pyx_k_gsubdf, sizeof(__pyx_k_gsubdf), 0, 0, 1, 1},
  {&__pyx_n_s_gzip, __pyx_k_gzip, sizeof(__pyx_k_gzip), 0, 0, 1, 1},
  {&__pyx_n_s_ha, __pyx_k_ha, sizeof(__pyx_k_ha), 0, 0, 1, 1},
  {&__pyx_n_s_header, __pyx_k_header, sizeof(__pyx_k_header), 0, 0, 1, 1},
  {&__pyx_n_s_heatmap, __pyx_k_heatmap, sizeof(__pyx_k_heatmap), 0, 0, 1, 1},
  {&__pyx_n_s_high_threshold, __pyx_k_high_threshold, sizeof(__pyx_k_high_threshold), 0, 0, 1, 1},
  {&__pyx_n_s_how, __pyx_k_how, sizeof(__pyx_k_how), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_ifSeed, __pyx_k_ifSeed, sizeof(__pyx_k_ifSeed), 0, 0, 1, 1},
  {&__pyx_n_s_if_bootstrap, __pyx_k_if_bootstrap, sizeof(__pyx_k_if_bootstrap), 0, 0, 1, 1},
  {&__pyx_n_s_if_cluster, __pyx_k_if_cluster, sizeof(__pyx_k_if_cluster), 0, 0, 1, 1},
  {&__pyx_n_s_if_intermediate, __pyx_k_if_intermediate, sizeof(__pyx_k_if_intermediate), 0, 0, 1, 1},
  {&__pyx_n_s_if_pval, __pyx_k_if_pval, sizeof(__pyx_k_if_pval), 0, 0, 1, 1},
  {&__pyx_n_u_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 1, 0, 1},
  {&__pyx_n_s_iloc, __pyx_k_iloc, sizeof(__pyx_k_iloc), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_index_col, __pyx_k_index_col, sizeof(__pyx_k_index_col), 0, 0, 1, 1},
  {&__pyx_n_u_inner, __pyx_k_inner, sizeof(__pyx_k_inner), 0, 1, 0, 1},
  {&__pyx_n_s_inplace, __pyx_k_inplace, sizeof(__pyx_k_inplace), 0, 0, 1, 1},
  {&__pyx_n_s_inset_list, __pyx_k_inset_list, sizeof(__pyx_k_inset_list), 0, 0, 1, 1},
  {&__pyx_n_s_itemsize, __pyx_k_itemsize, sizeof(__pyx_k_itemsize), 0, 0, 1, 1},
  {&__pyx_kp_s_itemsize_0_for_cython_array, __pyx_k_itemsize_0_for_cython_array, sizeof(__pyx_k_itemsize_0_for_cython_array), 0, 0, 1, 0},
  {&__pyx_n_u_itr, __pyx_k_itr, sizeof(__pyx_k_itr), 0, 1, 0, 1},
  {&__pyx_n_u_itr_2, __pyx_k_itr_2, sizeof(__pyx_k_itr_2), 0, 1, 0, 1},
  {&__pyx_n_s_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 0, 1, 1},
  {&__pyx_n_s_jitter, __pyx_k_jitter, sizeof(__pyx_k_jitter), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
  {&__pyx_n_s_ks, __pyx_k_ks, sizeof(__pyx_k_ks), 0, 0, 1, 1},
  {&__pyx_n_s_loc, __pyx_k_loc, sizeof(__pyx_k_loc), 0, 0, 1, 1},
  {&__pyx_n_s_locus, __pyx_k_locus, sizeof(__pyx_k_locus), 0, 0, 1, 1},
  {&__pyx_n_s_locusdic, __pyx_k_locusdic, sizeof(__pyx_k_locusdic), 0, 0, 1, 1},
  {&__pyx_n_s_low_threshold, __pyx_k_low_threshold, sizeof(__pyx_k_low_threshold), 0, 0, 1, 1},
  {&__pyx_n_u_ls, __pyx_k_ls, sizeof(__pyx_k_ls), 0, 1, 0, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_makedirs, __pyx_k_makedirs, sizeof(__pyx_k_makedirs), 0, 0, 1, 1},
  {&__pyx_n_s_math, __pyx_k_math, sizeof(__pyx_k_math), 0, 0, 1, 1},
  {&__pyx_n_s_matplotlib_colors, __pyx_k_matplotlib_colors, sizeof(__pyx_k_matplotlib_colors), 0, 0, 1, 1},
  {&__pyx_n_s_matplotlib_pyplot, __pyx_k_matplotlib_pyplot, sizeof(__pyx_k_matplotlib_pyplot), 0, 0, 1, 1},
  {&__pyx_n_s_max_iteration, __pyx_k_max_iteration, sizeof(__pyx_k_max_iteration), 0, 0, 1, 1},
  {&__pyx_n_s_mean, __pyx_k_mean, sizeof(__pyx_k_mean), 0, 0, 1, 1},
  {&__pyx_n_s_memview, __pyx_k_memview, sizeof(__pyx_k_memview), 0, 0, 1, 1},
  {&__pyx_n_s_miny, __pyx_k_miny, sizeof(__pyx_k_miny), 0, 0, 1, 1},
  {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
  {&__pyx_n_s_mp, __pyx_k_mp, sizeof(__pyx_k_mp), 0, 0, 1, 1},
  {&__pyx_n_u_multi, __pyx_k_multi, sizeof(__pyx_k_multi), 0, 1, 0, 1},
  {&__pyx_n_s_multiprocessing, __pyx_k_multiprocessing, sizeof(__pyx_k_multiprocessing), 0, 0, 1, 1},
  {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
  {&__pyx_n_s_n_clustering, __pyx_k_n_clustering, sizeof(__pyx_k_n_clustering), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_nb, __pyx_k_nb, sizeof(__pyx_k_nb), 0, 0, 1, 1},
  {&__pyx_n_s_ndim, __pyx_k_ndim, sizeof(__pyx_k_ndim), 0, 0, 1, 1},
  {&__pyx_n_u_neg, __pyx_k_neg, sizeof(__pyx_k_neg), 0, 1, 0, 1},
  {&__pyx_n_s_neighborhood, __pyx_k_neighborhood, sizeof(__pyx_k_neighborhood), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_new_2, __pyx_k_new_2, sizeof(__pyx_k_new_2), 0, 0, 1, 1},
  {&__pyx_n_s_newseed, __pyx_k_newseed, sizeof(__pyx_k_newseed), 0, 0, 1, 1},
  {&__pyx_n_s_newseed_names, __pyx_k_newseed_names, sizeof(__pyx_k_newseed_names), 0, 0, 1, 1},
  {&__pyx_n_s_ninety, __pyx_k_ninety, sizeof(__pyx_k_ninety), 0, 0, 1, 1},
  {&__pyx_n_s_nitr, __pyx_k_nitr, sizeof(__pyx_k_nitr), 0, 0, 1, 1},
  {&__pyx_n_s_nmf_results, __pyx_k_nmf_results, sizeof(__pyx_k_nmf_results), 0, 0, 1, 1},
  {&__pyx_n_u_no, __pyx_k_no, sizeof(__pyx_k_no), 0, 1, 0, 1},
  {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
  {&__pyx_n_s_norm, __pyx_k_norm, sizeof(__pyx_k_norm), 0, 0, 1, 1},
  {&__pyx_n_s_normalize, __pyx_k_normalize, sizeof(__pyx_k_normalize), 0, 0, 1, 1},
  {&__pyx_n_s_notna, __pyx_k_notna, sizeof(__pyx_k_notna), 0, 0, 1, 1},
  {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
  {&__pyx_n_s_num_top, __pyx_k_num_top, sizeof(__pyx_k_num_top), 0, 0, 1, 1},
  {&__pyx_n_s_numgroup, __pyx_k_numgroup, sizeof(__pyx_k_numgroup), 0, 0, 1, 1},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
  {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
  {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
  {&__pyx_n_s_old, __pyx_k_old, sizeof(__pyx_k_old), 0, 0, 1, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_s_origfeature, __pyx_k_origfeature, sizeof(__pyx_k_origfeature), 0, 0, 1, 1},
  {&__pyx_n_s_origtarget, __pyx_k_origtarget, sizeof(__pyx_k_origtarget), 0, 0, 1, 1},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_out_folder, __pyx_k_out_folder, sizeof(__pyx_k_out_folder), 0, 0, 1, 1},
  {&__pyx_n_s_pVals, __pyx_k_pVals, sizeof(__pyx_k_pVals), 0, 0, 1, 1},
  {&__pyx_n_u_pVals, __pyx_k_pVals, sizeof(__pyx_k_pVals), 0, 1, 0, 1},
  {&__pyx_kp_u_p_value, __pyx_k_p_value, sizeof(__pyx_k_p_value), 0, 1, 0, 0},
  {&__pyx_n_s_pack, __pyx_k_pack, sizeof(__pyx_k_pack), 0, 0, 1, 1},
  {&__pyx_n_s_pandas, __pyx_k_pandas, sizeof(__pyx_k_pandas), 0, 0, 1, 1},
  {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
  {&__pyx_n_s_patient, __pyx_k_patient, sizeof(__pyx_k_patient), 0, 0, 1, 1},
  {&__pyx_n_s_patientfig, __pyx_k_patientfig, sizeof(__pyx_k_patientfig), 0, 0, 1, 1},
  {&__pyx_n_s_pd, __pyx_k_pd, sizeof(__pyx_k_pd), 0, 0, 1, 1},
  {&__pyx_n_u_pdf, __pyx_k_pdf, sizeof(__pyx_k_pdf), 0, 1, 0, 1},
  {&__pyx_n_s_pearsonr, __pyx_k_pearsonr, sizeof(__pyx_k_pearsonr), 0, 0, 1, 1},
  {&__pyx_n_s_percentile, __pyx_k_percentile, sizeof(__pyx_k_percentile), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pile, __pyx_k_pile, sizeof(__pyx_k_pile), 0, 0, 1, 1},
  {&__pyx_n_s_pileRank, __pyx_k_pileRank, sizeof(__pyx_k_pileRank), 0, 0, 1, 1},
  {&__pyx_n_s_piled, __pyx_k_piled, sizeof(__pyx_k_piled), 0, 0, 1, 1},
  {&__pyx_n_s_pileres, __pyx_k_pileres, sizeof(__pyx_k_pileres), 0, 0, 1, 1},
  {&__pyx_n_s_pilesize, __pyx_k_pilesize, sizeof(__pyx_k_pilesize), 0, 0, 1, 1},
  {&__pyx_n_s_plot, __pyx_k_plot, sizeof(__pyx_k_plot), 0, 0, 1, 1},
  {&__pyx_n_s_plotCluster, __pyx_k_plotCluster, sizeof(__pyx_k_plotCluster), 0, 0, 1, 1},
  {&__pyx_n_s_plotCluster_locals_genexpr, __pyx_k_plotCluster_locals_genexpr, sizeof(__pyx_k_plotCluster_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_plotcomb, __pyx_k_plotcomb, sizeof(__pyx_k_plotcomb), 0, 0, 1, 1},
  {&__pyx_n_s_plotcomb2, __pyx_k_plotcomb2, sizeof(__pyx_k_plotcomb2), 0, 0, 1, 1},
  {&__pyx_n_s_plotpval, __pyx_k_plotpval, sizeof(__pyx_k_plotpval), 0, 0, 1, 1},
  {&__pyx_n_s_plotsubdf, __pyx_k_plotsubdf, sizeof(__pyx_k_plotsubdf), 0, 0, 1, 1},
  {&__pyx_n_s_plt, __pyx_k_plt, sizeof(__pyx_k_plt), 0, 0, 1, 1},
  {&__pyx_n_s_pos, __pyx_k_pos, sizeof(__pyx_k_pos), 0, 0, 1, 1},
  {&__pyx_n_u_pos, __pyx_k_pos, sizeof(__pyx_k_pos), 0, 1, 0, 1},
  {&__pyx_n_s_prefix, __pyx_k_prefix, sizeof(__pyx_k_prefix), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_pval, __pyx_k_pval, sizeof(__pyx_k_pval), 0, 0, 1, 1},
  {&__pyx_n_s_pvallist, __pyx_k_pvallist, sizeof(__pyx_k_pvallist), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_getbuffer, __pyx_k_pyx_getbuffer, sizeof(__pyx_k_pyx_getbuffer), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_Enum, __pyx_k_pyx_unpickle_Enum, sizeof(__pyx_k_pyx_unpickle_Enum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
  {&__pyx_n_s_random, __pyx_k_random, sizeof(__pyx_k_random), 0, 0, 1, 1},
  {&__pyx_n_s_random_seed, __pyx_k_random_seed, sizeof(__pyx_k_random_seed), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_rank, __pyx_k_rank, sizeof(__pyx_k_rank), 0, 0, 1, 1},
  {&__pyx_n_s_readInput, __pyx_k_readInput, sizeof(__pyx_k_readInput), 0, 0, 1, 1},
  {&__pyx_n_s_read_csv, __pyx_k_read_csv, sizeof(__pyx_k_read_csv), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_rename, __pyx_k_rename, sizeof(__pyx_k_rename), 0, 0, 1, 1},
  {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
  {&__pyx_n_s_report, __pyx_k_report, sizeof(__pyx_k_report), 0, 0, 1, 1},
  {&__pyx_kp_u_report_txt, __pyx_k_report_txt, sizeof(__pyx_k_report_txt), 0, 1, 0, 0},
  {&__pyx_n_s_reportdf, __pyx_k_reportdf, sizeof(__pyx_k_reportdf), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_n_s_results, __pyx_k_results, sizeof(__pyx_k_results), 0, 0, 1, 1},
  {&__pyx_n_s_revealer_REVEALER_runbenchmark, __pyx_k_revealer_REVEALER_runbenchmark, sizeof(__pyx_k_revealer_REVEALER_runbenchmark), 0, 0, 1, 1},
  {&__pyx_n_s_revealer_ccal, __pyx_k_revealer_ccal, sizeof(__pyx_k_revealer_ccal), 0, 0, 1, 1},
  {&__pyx_n_u_right, __pyx_k_right, sizeof(__pyx_k_right), 0, 1, 0, 1},
  {&__pyx_n_s_rmrow, __pyx_k_rmrow, sizeof(__pyx_k_rmrow), 0, 0, 1, 1},
  {&__pyx_n_s_rowspan, __pyx_k_rowspan, sizeof(__pyx_k_rowspan), 0, 0, 1, 1},
  {&__pyx_n_s_sample, __pyx_k_sample, sizeof(__pyx_k_sample), 0, 0, 1, 1},
  {&__pyx_n_s_savefig, __pyx_k_savefig, sizeof(__pyx_k_savefig), 0, 0, 1, 1},
  {&__pyx_n_s_saveresfig, __pyx_k_saveresfig, sizeof(__pyx_k_saveresfig), 0, 0, 1, 1},
  {&__pyx_n_s_saveresfigWithPval, __pyx_k_saveresfigWithPval, sizeof(__pyx_k_saveresfigWithPval), 0, 0, 1, 1},
  {&__pyx_n_s_saveresfigWithPval_locals_genexp, __pyx_k_saveresfigWithPval_locals_genexp, sizeof(__pyx_k_saveresfigWithPval_locals_genexp), 0, 0, 1, 1},
  {&__pyx_n_s_saveresfig_locals_genexpr, __pyx_k_saveresfig_locals_genexpr, sizeof(__pyx_k_saveresfig_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_savetopfig, __pyx_k_savetopfig, sizeof(__pyx_k_savetopfig), 0, 0, 1, 1},
  {&__pyx_n_s_savetopfig_locals_genexpr, __pyx_k_savetopfig_locals_genexpr, sizeof(__pyx_k_savetopfig_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_scipy, __pyx_k_scipy, sizeof(__pyx_k_scipy), 0, 0, 1, 1},
  {&__pyx_n_s_scipy_stats, __pyx_k_scipy_stats, sizeof(__pyx_k_scipy_stats), 0, 0, 1, 1},
  {&__pyx_n_s_seaborn, __pyx_k_seaborn, sizeof(__pyx_k_seaborn), 0, 0, 1, 1},
  {&__pyx_n_s_seed, __pyx_k_seed, sizeof(__pyx_k_seed), 0, 0, 1, 1},
  {&__pyx_n_s_seedCombine, __pyx_k_seedCombine, sizeof(__pyx_k_seedCombine), 0, 0, 1, 1},
  {&__pyx_n_s_seedID, __pyx_k_seedID, sizeof(__pyx_k_seedID), 0, 0, 1, 1},
  {&__pyx_n_s_seedIndex, __pyx_k_seedIndex, sizeof(__pyx_k_seedIndex), 0, 0, 1, 1},
  {&__pyx_kp_u_seed_Search, __pyx_k_seed_Search, sizeof(__pyx_k_seed_Search), 0, 1, 0, 0},
  {&__pyx_n_s_seed_df, __pyx_k_seed_df, sizeof(__pyx_k_seed_df), 0, 0, 1, 1},
  {&__pyx_n_s_seed_file, __pyx_k_seed_file, sizeof(__pyx_k_seed_file), 0, 0, 1, 1},
  {&__pyx_kp_u_seed_file_is, __pyx_k_seed_file_is, sizeof(__pyx_k_seed_file_is), 0, 1, 0, 0},
  {&__pyx_n_s_seed_name, __pyx_k_seed_name, sizeof(__pyx_k_seed_name), 0, 0, 1, 1},
  {&__pyx_n_s_seedcmap, __pyx_k_seedcmap, sizeof(__pyx_k_seedcmap), 0, 0, 1, 1},
  {&__pyx_n_s_seedcomb, __pyx_k_seedcomb, sizeof(__pyx_k_seedcomb), 0, 0, 1, 1},
  {&__pyx_n_s_seedcomball, __pyx_k_seedcomball, sizeof(__pyx_k_seedcomball), 0, 0, 1, 1},
  {&__pyx_n_s_seedids, __pyx_k_seedids, sizeof(__pyx_k_seedids), 0, 0, 1, 1},
  {&__pyx_n_s_seedlists, __pyx_k_seedlists, sizeof(__pyx_k_seedlists), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_sep, __pyx_k_sep, sizeof(__pyx_k_sep), 0, 0, 1, 1},
  {&__pyx_n_s_set_axis_off, __pyx_k_set_axis_off, sizeof(__pyx_k_set_axis_off), 0, 0, 1, 1},
  {&__pyx_n_s_set_figheight, __pyx_k_set_figheight, sizeof(__pyx_k_set_figheight), 0, 0, 1, 1},
  {&__pyx_n_s_set_figwidth, __pyx_k_set_figwidth, sizeof(__pyx_k_set_figwidth), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
  {&__pyx_n_s_sign, __pyx_k_sign, sizeof(__pyx_k_sign), 0, 0, 1, 1},
  {&__pyx_n_u_single, __pyx_k_single, sizeof(__pyx_k_single), 0, 1, 0, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_n_s_skiprows, __pyx_k_skiprows, sizeof(__pyx_k_skiprows), 0, 0, 1, 1},
  {&__pyx_n_s_sns, __pyx_k_sns, sizeof(__pyx_k_sns), 0, 0, 1, 1},
  {&__pyx_n_s_sort_values, __pyx_k_sort_values, sizeof(__pyx_k_sort_values), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_k_src_revealer_REVEALER_runbenchma, sizeof(__pyx_k_src_revealer_REVEALER_runbenchma), 0, 0, 1, 0},
  {&__pyx_kp_u_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 1, 0, 0},
  {&__pyx_n_s_start_2, __pyx_k_start_2, sizeof(__pyx_k_start_2), 0, 0, 1, 1},
  {&__pyx_n_s_stats, __pyx_k_stats, sizeof(__pyx_k_stats), 0, 0, 1, 1},
  {&__pyx_n_s_std, __pyx_k_std, sizeof(__pyx_k_std), 0, 0, 1, 1},
  {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
  {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_strided_and_direct, __pyx_k_strided_and_direct, sizeof(__pyx_k_strided_and_direct), 0, 0, 1, 0},
  {&__pyx_kp_s_strided_and_direct_or_indirect, __pyx_k_strided_and_direct_or_indirect, sizeof(__pyx_k_strided_and_direct_or_indirect), 0, 0, 1, 0},
  {&__pyx_kp_s_strided_and_indirect, __pyx_k_strided_and_indirect, sizeof(__pyx_k_strided_and_indirect), 0, 0, 1, 0},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_struct, __pyx_k_struct, sizeof(__pyx_k_struct), 0, 0, 1, 1},
  {&__pyx_n_s_sub, __pyx_k_sub, sizeof(__pyx_k_sub), 0, 0, 1, 1},
  {&__pyx_n_s_subcomb, __pyx_k_subcomb, sizeof(__pyx_k_subcomb), 0, 0, 1, 1},
  {&__pyx_n_s_subplot2grid, __pyx_k_subplot2grid, sizeof(__pyx_k_subplot2grid), 0, 0, 1, 1},
  {&__pyx_n_s_subplots, __pyx_k_subplots, sizeof(__pyx_k_subplots), 0, 0, 1, 1},
  {&__pyx_n_s_subseed, __pyx_k_subseed, sizeof(__pyx_k_subseed), 0, 0, 1, 1},
  {&__pyx_n_s_subset, __pyx_k_subset, sizeof(__pyx_k_subset), 0, 0, 1, 1},
  {&__pyx_kp_u_subset_not_exist_Please_check_yo, __pyx_k_subset_not_exist_Please_check_yo, sizeof(__pyx_k_subset_not_exist_Please_check_yo), 0, 1, 0, 0},
  {&__pyx_n_s_subsubcomb, __pyx_k_subsubcomb, sizeof(__pyx_k_subsubcomb), 0, 0, 1, 1},
  {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
  {&__pyx_n_s_switch_backend, __pyx_k_switch_backend, sizeof(__pyx_k_switch_backend), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_tarfile, __pyx_k_tarfile, sizeof(__pyx_k_tarfile), 0, 0, 1, 1},
  {&__pyx_n_s_target, __pyx_k_target, sizeof(__pyx_k_target), 0, 0, 1, 1},
  {&__pyx_n_s_target_df, __pyx_k_target_df, sizeof(__pyx_k_target_df), 0, 0, 1, 1},
  {&__pyx_n_s_target_file, __pyx_k_target_file, sizeof(__pyx_k_target_file), 0, 0, 1, 1},
  {&__pyx_n_s_target_name, __pyx_k_target_name, sizeof(__pyx_k_target_name), 0, 0, 1, 1},
  {&__pyx_n_s_targets, __pyx_k_targets, sizeof(__pyx_k_targets), 0, 0, 1, 1},
  {&__pyx_n_u_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 1, 0, 1},
  {&__pyx_n_s_test_2, __pyx_k_test_2, sizeof(__pyx_k_test_2), 0, 0, 1, 1},
  {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
  {&__pyx_n_s_thread_number, __pyx_k_thread_number, sizeof(__pyx_k_thread_number), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
  {&__pyx_kp_u_tissueType, __pyx_k_tissueType, sizeof(__pyx_k_tissueType), 0, 1, 0, 0},
  {&__pyx_n_s_tissue_file, __pyx_k_tissue_file, sizeof(__pyx_k_tissue_file), 0, 0, 1, 1},
  {&__pyx_n_s_to_csv, __pyx_k_to_csv, sizeof(__pyx_k_to_csv), 0, 0, 1, 1},
  {&__pyx_n_s_to_numpy, __pyx_k_to_numpy, sizeof(__pyx_k_to_numpy), 0, 0, 1, 1},
  {&__pyx_n_s_tolist, __pyx_k_tolist, sizeof(__pyx_k_tolist), 0, 0, 1, 1},
  {&__pyx_n_u_top, __pyx_k_top, sizeof(__pyx_k_top), 0, 1, 0, 1},
  {&__pyx_n_s_topMatches, __pyx_k_topMatches, sizeof(__pyx_k_topMatches), 0, 0, 1, 1},
  {&__pyx_n_s_total, __pyx_k_total, sizeof(__pyx_k_total), 0, 0, 1, 1},
  {&__pyx_n_s_tqdm, __pyx_k_tqdm, sizeof(__pyx_k_tqdm), 0, 0, 1, 1},
  {&__pyx_n_s_tqdm_notebook, __pyx_k_tqdm_notebook, sizeof(__pyx_k_tqdm_notebook), 0, 0, 1, 1},
  {&__pyx_kp_u_txt, __pyx_k_txt, sizeof(__pyx_k_txt), 0, 1, 0, 0},
  {&__pyx_kp_s_unable_to_allocate_array_data, __pyx_k_unable_to_allocate_array_data, sizeof(__pyx_k_unable_to_allocate_array_data), 0, 0, 1, 0},
  {&__pyx_kp_s_unable_to_allocate_shape_and_str, __pyx_k_unable_to_allocate_shape_and_str, sizeof(__pyx_k_unable_to_allocate_shape_and_str), 0, 0, 1, 0},
  {&__pyx_n_s_unique, __pyx_k_unique, sizeof(__pyx_k_unique), 0, 0, 1, 1},
  {&__pyx_n_s_unpack, __pyx_k_unpack, sizeof(__pyx_k_unpack), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_va, __pyx_k_va, sizeof(__pyx_k_va), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_n_s_verbose, __pyx_k_verbose, sizeof(__pyx_k_verbose), 0, 0, 1, 1},
  {&__pyx_n_u_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 1, 0, 1},
  {&__pyx_n_s_warnings, __pyx_k_warnings, sizeof(__pyx_k_warnings), 0, 0, 1, 1},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_kp_u_x_10, __pyx_k_x_10, sizeof(__pyx_k_x_10), 0, 1, 0, 0},
  {&__pyx_n_s_x_in, __pyx_k_x_in, sizeof(__pyx_k_x_in), 0, 0, 1, 1},
  {&__pyx_n_s_x_view, __pyx_k_x_view, sizeof(__pyx_k_x_view), 0, 0, 1, 1},
  {&__pyx_n_s_xs_in, __pyx_k_xs_in, sizeof(__pyx_k_xs_in), 0, 0, 1, 1},
  {&__pyx_n_s_xticklabels, __pyx_k_xticklabels, sizeof(__pyx_k_xticklabels), 0, 0, 1, 1},
  {&__pyx_n_s_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 0, 1, 1},
  {&__pyx_n_s_y_in, __pyx_k_y_in, sizeof(__pyx_k_y_in), 0, 0, 1, 1},
  {&__pyx_n_s_ys_in, __pyx_k_ys_in, sizeof(__pyx_k_ys_in), 0, 0, 1, 1},
  {&__pyx_n_s_yticklabels, __pyx_k_yticklabels, sizeof(__pyx_k_yticklabels), 0, 0, 1, 1},
  {&__pyx_n_s_z, __pyx_k_z, sizeof(__pyx_k_z), 0, 0, 1, 1},
  {&__pyx_n_s_z_in, __pyx_k_z_in, sizeof(__pyx_k_z_in), 0, 0, 1, 1},
  {&__pyx_n_u_zerobase, __pyx_k_zerobase, sizeof(__pyx_k_zerobase), 0, 1, 0, 1},
  {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 70, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 1272, __pyx_L1_error)
  __pyx_builtin_sum = __Pyx_GetBuiltinName(__pyx_n_s_sum); if (!__pyx_builtin_sum) __PYX_ERR(0, 1314, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(0, 1703, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(1, 945, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(2, 133, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(2, 148, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(2, 151, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(2, 2, __pyx_L1_error)
  __pyx_builtin_Ellipsis = __Pyx_GetBuiltinName(__pyx_n_s_Ellipsis); if (!__pyx_builtin_Ellipsis) __PYX_ERR(2, 404, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(2, 613, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(2, 832, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "revealer/REVEALER_runbenchmark.pyx":997
 *     '''
 * 
 *     f, ax = plt.subplots(figsize=(10, 1))             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(comb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=comb.iloc[0].mean())
 */
  __pyx_tuple_ = PyTuple_Pack(2, __pyx_int_10, __pyx_int_1); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "revealer/REVEALER_runbenchmark.pyx":1155
 *         CICs = CICs + list(ICs)
 *     else:
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[rank[:,0][:num_top]]])             # <<<<<<<<<<<<<<
 *         CICs = CICs + list(rank[:,1][:num_top])
 * 
 */
  __pyx_slice__3 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__3)) __PYX_ERR(0, 1155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__3);
  __Pyx_GIVEREF(__pyx_slice__3);
  __pyx_tuple__4 = PyTuple_Pack(2, __pyx_slice__3, __pyx_int_0); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 1155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "revealer/REVEALER_runbenchmark.pyx":1156
 *     else:
 *         rankfeature = pd.concat([comb.iloc[[0]],comb.loc[rank[:,0][:num_top]]])
 *         CICs = CICs + list(rank[:,1][:num_top])             # <<<<<<<<<<<<<<
 * 
 *     if ifSeed == True:
 */
  __pyx_tuple__5 = PyTuple_Pack(2, __pyx_slice__3, __pyx_int_1); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "revealer/REVEALER_runbenchmark.pyx":1286
 *     if (isinstance(target_df,str) or isinstance(feature_df,str)) and \
 *        (target_file == 'no' or feature_file == 'no') :
 *         raise Exception("Please put input!")             # <<<<<<<<<<<<<<
 *     if mp.cpu_count() <thread_number:
 *         if verbose != 0:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Please_put_input); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 1286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "revealer/REVEALER_runbenchmark.pyx":1289
 *     if mp.cpu_count() <thread_number:
 *         if verbose != 0:
 *             print('Indicated Core Number exceed maximum available core. All core is used')             # <<<<<<<<<<<<<<
 *         thread_number = mp.cpu_count()
 *     if thread_number == -1:
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Indicated_Core_Number_exceed_max); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 1289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "revealer/REVEALER_runbenchmark.pyx":1313
 *             comb = pd.concat([target_df,seed_df,feature_df], join='inner')
 *         rmrow=[]
 *         for i in comb.index.tolist()[2:]:             # <<<<<<<<<<<<<<
 *             if sum(comb.loc[i].tolist()) <= low_threshold or \
 *                sum(comb.loc[i].tolist()) >= high_threshold:
 */
  __pyx_slice__13 = PySlice_New(__pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_slice__13)) __PYX_ERR(0, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__13);
  __Pyx_GIVEREF(__pyx_slice__13);

  /* "revealer/REVEALER_runbenchmark.pyx":1328
 *         gmt = pd.read_csv(gmt_file,sep='\t',header=None,index_col=0)
 *         gmt = gmt.drop(columns=gmt.columns[0])
 *         gmt.index = gmt.index.str.replace("-", "_")             # <<<<<<<<<<<<<<
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')
 */
  __pyx_tuple__16 = PyTuple_Pack(2, __pyx_kp_u__15, __pyx_n_u__8); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 1328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "revealer/REVEALER_runbenchmark.pyx":1330
 *         gmt.index = gmt.index.str.replace("-", "_")
 *         if (len(list(set(comb.index.tolist())&set(gmt.index.tolist()))) == 0) and verbose != 0:
 *             print('Names in gmt file is not matching with input file. Setting gmt to None.')             # <<<<<<<<<<<<<<
 *             gmt = None
 *     else:
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Names_in_gmt_file_is_not_matchin); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 1330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "revealer/REVEALER_runbenchmark.pyx":1423
 *     ):
 * 
 *     seedcmap = clr.LinearSegmentedColormap.from_list('custom greys', [(.9,.9,.9),(0.5,0.5,0.5)],             # <<<<<<<<<<<<<<
 *                                                      N=256)
 *     featurecmap = clr.LinearSegmentedColormap.from_list('custom greys',
 */
  __pyx_tuple__18 = PyTuple_Pack(3, __pyx_float__9, __pyx_float__9, __pyx_float__9); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);
  __pyx_tuple__19 = PyTuple_Pack(3, __pyx_float_0_5, __pyx_float_0_5, __pyx_float_0_5); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "revealer/REVEALER_runbenchmark.pyx":1448
 *         combpatient = pd.concat([comb.iloc[[0]],patient])
 *         corr = []
 *         for i in combpatient.index.tolist()[1:]:             # <<<<<<<<<<<<<<
 *             if combpatient.loc[i].sum() == 0:
 *                 corr.append(-100)
 */
  __pyx_slice__20 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__20)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__20);
  __Pyx_GIVEREF(__pyx_slice__20);

  /* "revealer/REVEALER_runbenchmark.pyx":1454
 *                 corr.append(stats.pearsonr(combpatient.iloc[0],combpatient.loc[i])[0])
 *         combpatient['corr'] = [1]+corr
 *         combpatient = combpatient.sort_values('corr',ascending=False).drop(columns= ['corr'])             # <<<<<<<<<<<<<<
 * 
 *         patientfig(df = combpatient, seedcmap = seedcmap, featurecmap = featurecmap,
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_n_u_corr); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "revealer/REVEALER_runbenchmark.pyx":1509
 *         CICs.append('')
 *         if verbose != 0:
 *             print('seed Search...')             # <<<<<<<<<<<<<<
 *         seedid,IC = findBestIC(y, np.array(comb.iloc[1:].values.astype(int).tolist()),
 *                              k, int(len(comb.index)-1), size, bandwidth,
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_u_seed_Search); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 1509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "revealer/REVEALER_runbenchmark.pyx":1703
 *     report = report + 'Time used to run loops: %s second(s)'%(int(time.time() - start)) + '\n'
 * 
 *     with open(out_folder + prefix + 'report.txt','w') as f:             # <<<<<<<<<<<<<<
 *         f.write(report)
 * 
 */
  __pyx_tuple__24 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "revealer/REVEALER_runbenchmark.pyx":1811
 * 
 *     #Target name at left of target heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.9,0.5, 'Target:'+str(target_name), ha='right', va='center')
 */
  __pyx_tuple__25 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_0); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "revealer/REVEALER_runbenchmark.pyx":1816
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(df.index)+1),110), loc=(0, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(df.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=df.iloc[0].mean())
 */
  __pyx_tuple__26 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_20); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "revealer/REVEALER_runbenchmark.pyx":2295
 *     #Replace new line otherwise there's error
 *     plotcomb2 = plotcomb.copy()
 *     plotcomb2.index = plotcomb2.index.str.replace("\n", ",")             # <<<<<<<<<<<<<<
 * 
 *     #Run NMF with different k
 */
  __pyx_tuple__30 = PyTuple_Pack(2, __pyx_kp_u__9, __pyx_kp_u__29); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "revealer/REVEALER_runbenchmark.pyx":2299
 *     #Run NMF with different k
 *     res, nmf_results, cophenetic_correlation_coefficients = ccal.explore_components(
 *                     df = plotcomb2.iloc[1:,].T,             # <<<<<<<<<<<<<<
 *                     ks = range(2,12),
 *                     n_clustering = 10,
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_slice__20); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 2299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "revealer/REVEALER_runbenchmark.pyx":2300
 *     res, nmf_results, cophenetic_correlation_coefficients = ccal.explore_components(
 *                     df = plotcomb2.iloc[1:,].T,
 *                     ks = range(2,12),             # <<<<<<<<<<<<<<
 *                     n_clustering = 10,
 *                     random_seed = 19981218,
 */
  __pyx_tuple__32 = PyTuple_Pack(2, __pyx_int_2, __pyx_int_12); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "revealer/REVEALER_runbenchmark.pyx":2310
 *     diff = -1
 *     diffindex = 0
 *     for i in range(len(cophenetic_correlation_coefficients.index.tolist()[:-1])):             # <<<<<<<<<<<<<<
 *         if cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1] > diff:
 *             diff = cophenetic_correlation_coefficients.iloc[i] - cophenetic_correlation_coefficients.iloc[i+1]
 */
  __pyx_slice__33 = PySlice_New(Py_None, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__33)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__33);
  __Pyx_GIVEREF(__pyx_slice__33);

  /* "revealer/REVEALER_runbenchmark.pyx":2336
 * 
 *     #Label for IC or CIC and p-values on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __pyx_tuple__34 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_110); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 2336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "revealer/REVEALER_runbenchmark.pyx":2339
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')
 */
  __pyx_tuple__35 = PyTuple_Pack(3, __pyx_float_0_5, __pyx_float_0_5, __pyx_kp_u_CIC); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 2339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "revealer/REVEALER_runbenchmark.pyx":2341
 *         ax.text(0.5,0.5,'CIC()',ha='center', va='center', color = 'blue')
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  __pyx_tuple__36 = PyTuple_Pack(3, __pyx_float_0_5, __pyx_float_0_5, __pyx_n_u_CIC_2); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 2341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "revealer/REVEALER_runbenchmark.pyx":2342
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center', color = 'blue')
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(0, 122), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if plotpval == True:
 */
  __pyx_tuple__37 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_122); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 2342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "revealer/REVEALER_runbenchmark.pyx":2345
 *     ax.set_axis_off()
 *     if plotpval == True:
 *         ax.text(0.5,0.5,'p-value',ha='center', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Label seed name at left of seed heatmap
 */
  __pyx_tuple__38 = PyTuple_Pack(3, __pyx_float_0_5, __pyx_float_0_5, __pyx_kp_u_p_value); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 2345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "revealer/REVEALER_runbenchmark.pyx":2348
 * 
 *     #Label seed name at left of seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 0), colspan=20,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if seed_name != None:
 */
  __pyx_tuple__39 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_0); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 2348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "revealer/REVEALER_runbenchmark.pyx":2356
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 *     else:
 *         ax.text(0.9,0.5, 'Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot seed heatmap
 */
  __pyx_tuple__41 = PyTuple_Pack(3, __pyx_float_0_9, __pyx_float_0_5, __pyx_n_u_Seed_2); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 2356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "revealer/REVEALER_runbenchmark.pyx":2359
 * 
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 20), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)
 */
  __pyx_tuple__42 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_20); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "revealer/REVEALER_runbenchmark.pyx":2364
 * 
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2+numgroup),132), loc=(5, 110), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __pyx_tuple__43 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_110); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 2364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "revealer/REVEALER_runbenchmark.pyx":2503
 *         for gene in pile:
 *             if '\n' in gene[0]:
 *                 pileres = pileres + gene[0].replace('\n','(')+')' + '\t'             # <<<<<<<<<<<<<<
 *             else:
 *                 pileres = pileres + gene[0] + '\t'
 */
  __pyx_tuple__47 = PyTuple_Pack(2, __pyx_kp_u__9, __pyx_kp_u__27); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 2503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "revealer/REVEALER_runbenchmark.pyx":2560
 * 
 *     #Plot heatmap for target
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 30), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(plotcomb.iloc[[0]].to_numpy(), cmap='bwr', annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False, center=plotcomb.iloc[0].mean())
 */
  __pyx_tuple__48 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_30); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "revealer/REVEALER_runbenchmark.pyx":2565
 * 
 *     #Label for IC or CIC and p-values on right of target heatmap.
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 120), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 */
  __pyx_tuple__49 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_120); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "revealer/REVEALER_runbenchmark.pyx":2571
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color='blue')
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(0, 132), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if plotpval == True:
 */
  __pyx_tuple__50 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_132); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "revealer/REVEALER_runbenchmark.pyx":2588
 * 
 *     #Plot seed heatmap
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 30), colspan=90,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax = sns.heatmap(np.array([cythonseed]), cmap=seedcmap, annot=False, yticklabels=False,
 *                      xticklabels=False, cbar=False)
 */
  __pyx_tuple__51 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_30); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "revealer/REVEALER_runbenchmark.pyx":2593
 * 
 *     #Blanks
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 120), colspan=12,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 132), colspan=10,rowspan=5)
 */
  __pyx_tuple__52 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_120); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "revealer/REVEALER_runbenchmark.pyx":2595
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 120), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(CICs)+2),142), loc=(5, 132), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __pyx_tuple__53 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_132); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "revealer/REVEALER_runbenchmark.pyx":2739
 *     ax.set_axis_off()
 *     if if_bootstrap == True:
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')
 */
  __pyx_tuple__54 = PyTuple_Pack(3, __pyx_float_0_5, __pyx_float_0_5, __pyx_kp_u_IC_2); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 2739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "revealer/REVEALER_runbenchmark.pyx":2741
 *         ax.text(0.5,0.5,'IC()',ha='center', va='center')
 *     else:
 *         ax.text(0.5,0.5,'IC',ha='center', va='center')             # <<<<<<<<<<<<<<
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 122), colspan=10,rowspan=5)
 *     ax.set_axis_off()
 */
  __pyx_tuple__55 = PyTuple_Pack(3, __pyx_float_0_5, __pyx_float_0_5, __pyx_n_u_IC); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 2741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "revealer/REVEALER_runbenchmark.pyx":2751
 *     else:
 *         ax.text(0.5,0.5,'CIC',ha='center', va='center',color = 'blue')
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(0, 144), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     ax.text(0.5,0.5,'p-value',ha='center', va='center',color = 'blue')
 */
  __pyx_tuple__56 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_144); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "revealer/REVEALER_runbenchmark.pyx":2767
 *             ax.text(0.9,0.5, 'Seed:'+str(seed_name[0]), ha='right', va='center')
 *     else:
 *         ax.text(0.9,0.5, 'Null Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *     #Plot seed heatmap
 */
  __pyx_tuple__57 = PyTuple_Pack(3, __pyx_float_0_9, __pyx_float_0_5, __pyx_kp_u_Null_Seed); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "revealer/REVEALER_runbenchmark.pyx":2783
 * 
 *     #p-value for this seed if seed exists
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 122), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 *     if isinstance(pVals[0],float) == True:
 */
  __pyx_tuple__58 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_122); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "revealer/REVEALER_runbenchmark.pyx":2794
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 132), colspan=12,rowspan=5)
 *     ax.set_axis_off()
 *     ax = plt.subplot2grid(shape=(5*(len(seedids)+1)*2,154), loc=(5, 144), colspan=10,rowspan=5)             # <<<<<<<<<<<<<<
 *     ax.set_axis_off()
 * 
 */
  __pyx_tuple__59 = PyTuple_Pack(2, __pyx_int_5, __pyx_int_144); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "revealer/REVEALER_runbenchmark.pyx":2861
 *                               colspan=20,rowspan=5)
 *         ax.set_axis_off()
 *         ax.text(0.9,0.5,'New Seed', ha='right', va='center')             # <<<<<<<<<<<<<<
 * 
 *         #Put new seed to report
 */
  __pyx_tuple__60 = PyTuple_Pack(3, __pyx_float_0_9, __pyx_float_0_5, __pyx_kp_u_New_Seed); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "revealer/REVEALER_runbenchmark.pyx":3181
 *     '''
 * 
 *     print('Start reading input files...')             # <<<<<<<<<<<<<<
 * 
 *     #Read target file with given target name or index, replace - with _ in column name
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_kp_u_Start_reading_input_files); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "revealer/REVEALER_runbenchmark.pyx":3239
 *     if subset != 'no':
 *         if(len(list(set(comb.columns.tolist())&set(subset)))) == 0:
 *             print('subset not exist! Please check your subset list.')             # <<<<<<<<<<<<<<
 *             sys.exit(1)
 *         comb = comb[list(set(comb.columns.tolist())&set(subset))]
 */
  __pyx_tuple__62 = PyTuple_Pack(1, __pyx_kp_u_subset_not_exist_Please_check_yo); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "revealer/REVEALER_runbenchmark.pyx":3309
 * 
 * 
 *     print('Done reading input files')             # <<<<<<<<<<<<<<
 * 
 *     return comb,locusdic
 */
  __pyx_tuple__63 = PyTuple_Pack(1, __pyx_kp_u_Done_reading_input_files); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":945
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__64 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(1, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "../conda/envs/revealer/lib/python3.9/site-packages/numpy/__init__.pxd":951
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(1, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "View.MemoryView":133
 * 
 *         if not self.ndim:
 *             raise ValueError("Empty shape tuple for cython.array")             # <<<<<<<<<<<<<<
 * 
 *         if itemsize <= 0:
 */
  __pyx_tuple__66 = PyTuple_Pack(1, __pyx_kp_s_Empty_shape_tuple_for_cython_arr); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(2, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "View.MemoryView":136
 * 
 *         if itemsize <= 0:
 *             raise ValueError("itemsize <= 0 for cython.array")             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(format, bytes):
 */
  __pyx_tuple__67 = PyTuple_Pack(1, __pyx_kp_s_itemsize_0_for_cython_array); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(2, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "View.MemoryView":148
 * 
 *         if not self._shape:
 *             raise MemoryError("unable to allocate shape and strides.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__68 = PyTuple_Pack(1, __pyx_kp_s_unable_to_allocate_shape_and_str); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(2, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "View.MemoryView":176
 *             self.data = <char *>malloc(self.len)
 *             if not self.data:
 *                 raise MemoryError("unable to allocate array data.")             # <<<<<<<<<<<<<<
 * 
 *             if self.dtype_is_object:
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_kp_s_unable_to_allocate_array_data); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(2, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "View.MemoryView":192
 *             bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *         if not (flags & bufmode):
 *             raise ValueError("Can only create a buffer that is contiguous in memory.")             # <<<<<<<<<<<<<<
 *         info.buf = self.data
 *         info.len = self.len
 */
  __pyx_tuple__70 = PyTuple_Pack(1, __pyx_kp_s_Can_only_create_a_buffer_that_is); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(2, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__71 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(2, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__72 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "View.MemoryView":418
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:
 *             raise TypeError("Cannot assign to read-only memoryview")             # <<<<<<<<<<<<<<
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 */
  __pyx_tuple__73 = PyTuple_Pack(1, __pyx_kp_s_Cannot_assign_to_read_only_memor); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(2, 418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "View.MemoryView":495
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 *             raise ValueError("Unable to convert item to object")             # <<<<<<<<<<<<<<
 *         else:
 *             if len(self.view.format) == 1:
 */
  __pyx_tuple__74 = PyTuple_Pack(1, __pyx_kp_s_Unable_to_convert_item_to_object); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(2, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "View.MemoryView":520
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError("Cannot create writable memory view from read-only memoryview")             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_ND:
 */
  __pyx_tuple__75 = PyTuple_Pack(1, __pyx_kp_s_Cannot_create_writable_memory_vi); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(2, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "View.MemoryView":570
 *         if self.view.strides == NULL:
 * 
 *             raise ValueError("Buffer view does not expose strides")             # <<<<<<<<<<<<<<
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 */
  __pyx_tuple__76 = PyTuple_Pack(1, __pyx_kp_s_Buffer_view_does_not_expose_stri); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(2, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "View.MemoryView":577
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
  __pyx_tuple__77 = PyTuple_New(1); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(2, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_INCREF(__pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_int_neg_1);
  PyTuple_SET_ITEM(__pyx_tuple__77, 0, __pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__78 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(2, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__79 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "View.MemoryView":703
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             raise ValueError("Indirect dimensions not supported")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__80 = PyTuple_Pack(1, __pyx_kp_s_Indirect_dimensions_not_supporte); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(2, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__81 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(2, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__82 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "revealer/REVEALER_runbenchmark.pyx":6
 * cython: profile=True
 * import warnings
 * warnings.filterwarnings("ignore")             # <<<<<<<<<<<<<<
 * 
 * from revealer.ccal import *
 */
  __pyx_tuple__83 = PyTuple_Pack(1, __pyx_n_u_ignore); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "revealer/REVEALER_runbenchmark.pyx":49
 * import tarfile
 * 
 * plt.switch_backend('agg')             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __pyx_tuple__85 = PyTuple_Pack(1, __pyx_n_u_agg); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "revealer/REVEALER_runbenchmark.pyx":989
 *     return res
 * 
 * def drawTarget(             # <<<<<<<<<<<<<<
 *     comb    #Combined dataframe
 *     ):
 */
  __pyx_tuple__86 = PyTuple_Pack(3, __pyx_n_s_comb, __pyx_n_s_f, __pyx_n_s_ax); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__86, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_drawTarget, 989, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(0, 989, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1002
 *     return f
 * 
 * def drawFeature(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     featurecmap,    #Cmap to plot feature
 */
  __pyx_tuple__88 = PyTuple_Pack(6, __pyx_n_s_comb, __pyx_n_s_featurecmap, __pyx_n_s_seed_name, __pyx_n_s_seedID, __pyx_n_s_f, __pyx_n_s_ax); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 1002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(4, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_drawFeature, 1002, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(0, 1002, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1024
 *         return f
 * 
 * def drawSeed(             # <<<<<<<<<<<<<<
 *     seed,       #Seed list
 *     seedcmap    #Cmap to draw seed
 */
  __pyx_tuple__90 = PyTuple_Pack(4, __pyx_n_s_seed, __pyx_n_s_seedcmap, __pyx_n_s_f, __pyx_n_s_ax); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);
  __pyx_codeobj__91 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__90, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_drawSeed, 1024, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__91)) __PYX_ERR(0, 1024, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1038
 *     return f
 * 
 * def seedCombine(             # <<<<<<<<<<<<<<
 *     currentseed,    #Current seed
 *     newseed         #New seed to be added
 */
  __pyx_tuple__92 = PyTuple_Pack(4, __pyx_n_s_currentseed, __pyx_n_s_newseed, __pyx_n_s_seed, __pyx_n_s_i); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);
  __pyx_codeobj__93 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__92, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_seedCombine, 1038, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__93)) __PYX_ERR(0, 1038, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":1792
 *     return pVals
 * 
 * def patientfig(             # <<<<<<<<<<<<<<
 *     df,       #Dataframe used to plot
 *     seedcmap,       #Cmap for seed heatmap
 */
  __pyx_tuple__94 = PyTuple_Pack(10, __pyx_n_s_df, __pyx_n_s_seedcmap, __pyx_n_s_featurecmap, __pyx_n_s_prefix, __pyx_n_s_figure_format, __pyx_n_s_out_folder, __pyx_n_s_target_name, __pyx_n_s_fig, __pyx_n_s_ax, __pyx_n_s_i); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(0, 1792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);
  __pyx_codeobj__95 = (PyObject*)__Pyx_PyCode_New(7, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__94, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_patientfig, 1792, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__95)) __PYX_ERR(0, 1792, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2011
 * 
 * 
 * def calcIndivisualPvalIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K value for kernel
 */
  __pyx_tuple__96 = PyTuple_Pack(16, __pyx_n_s_subcomb, __pyx_n_s_k, __pyx_n_s_size, __pyx_n_s_bandwidth, __pyx_n_s_bandwidth_mult, __pyx_n_s_bandwidth_adj, __pyx_n_s_grid, __pyx_n_s_thread_number, __pyx_n_s_IC, __pyx_n_s_neighborhood, __pyx_n_s_origtarget, __pyx_n_s_targets, __pyx_n_s_i, __pyx_n_s_res, __pyx_n_s_countless, __pyx_n_s_r); if (unlikely(!__pyx_tuple__96)) __PYX_ERR(0, 2011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__96);
  __Pyx_GIVEREF(__pyx_tuple__96);
  __pyx_codeobj__97 = (PyObject*)__Pyx_PyCode_New(10, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__96, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_calcIndivisualPvalIC, 2011, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__97)) __PYX_ERR(0, 2011, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2087
 * 
 * 
 * def calcBootstrap(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     cythonseed,     #Seed to calculate
 */
  __pyx_tuple__98 = PyTuple_Pack(20, __pyx_n_s_subcomb, __pyx_n_s_cythonseed, __pyx_n_s_k, __pyx_n_s_size, __pyx_n_s_bandwidth, __pyx_n_s_bandwidth_mult, __pyx_n_s_bandwidth_adj, __pyx_n_s_grid, __pyx_n_s_thread_number, __pyx_n_s_IC, __pyx_n_s_neighborhood, __pyx_n_s_origfeature, __pyx_n_s_origtarget, __pyx_n_s_features, __pyx_n_s_targets, __pyx_n_s_i, __pyx_n_s_subsubcomb, __pyx_n_s_res, __pyx_n_s_ninety, __pyx_n_s_diff); if (unlikely(!__pyx_tuple__98)) __PYX_ERR(0, 2087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);
  __pyx_codeobj__99 = (PyObject*)__Pyx_PyCode_New(11, 0, 20, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__98, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_calcBootstrap, 2087, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__99)) __PYX_ERR(0, 2087, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2168
 *     return res
 * 
 * def calcBootstrapIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K for kernel
 */
  __pyx_tuple__100 = PyTuple_Pack(19, __pyx_n_s_subcomb, __pyx_n_s_k, __pyx_n_s_size, __pyx_n_s_bandwidth, __pyx_n_s_bandwidth_mult, __pyx_n_s_bandwidth_adj, __pyx_n_s_grid, __pyx_n_s_thread_number, __pyx_n_s_IC, __pyx_n_s_neighborhood, __pyx_n_s_origfeature, __pyx_n_s_origtarget, __pyx_n_s_features, __pyx_n_s_targets, __pyx_n_s_i, __pyx_n_s_subsubcomb, __pyx_n_s_res, __pyx_n_s_ninety, __pyx_n_s_diff); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 2168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);
  __pyx_codeobj__101 = (PyObject*)__Pyx_PyCode_New(10, 0, 19, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__100, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_calcBootstrapIC, 2168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__101)) __PYX_ERR(0, 2168, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2255
 * 
 * 
 * def plotCluster(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */
  __pyx_tuple__102 = PyTuple_Pack(41, __pyx_n_s_plotcomb, __pyx_n_s_CICs, __pyx_n_s_size, __pyx_n_s_cythonseed, __pyx_n_s_seedcmap, __pyx_n_s_featurecmap, __pyx_n_s_prefix, __pyx_n_s_figure_format, __pyx_n_s_pVals, __pyx_n_s_num_top, __pyx_n_s_bootstraps, __pyx_n_s_nitr, __pyx_n_s_out_folder, __pyx_n_s_target_name, __pyx_n_s_seed_name, __pyx_n_s_locusdic, __pyx_n_s_gmt, __pyx_n_s_plotpval, __pyx_n_s_if_bootstrap, __pyx_n_s_comball, __pyx_n_s_plotcomb2, __pyx_n_s_res, __pyx_n_s_nmf_results, __pyx_n_s_cophenetic_correlation_coefficie, __pyx_n_s_diff, __pyx_n_s_diffindex, __pyx_n_s_i, __pyx_n_s_group, __pyx_n_s_numgroup, __pyx_n_s_fig, __pyx_n_s_ax, __pyx_n_s_plotsubdf, __pyx_n_s_pos, __pyx_n_s_groupindex, __pyx_n_s_g, __pyx_n_s_gsubdf, __pyx_n_s_j, __pyx_n_s_pval, __pyx_n_s_pvallist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);
  __pyx_codeobj__103 = (PyObject*)__Pyx_PyCode_New(17, 0, 41, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__102, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_plotCluster, 2255, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__103)) __PYX_ERR(0, 2255, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2463
 * 
 * 
 * def pileRank(             # <<<<<<<<<<<<<<
 *     rank,       #Rank for features
 *     num_top,    #Number of top feature
 */
  __pyx_tuple__104 = PyTuple_Pack(16, __pyx_n_s_rank, __pyx_n_s_num_top, __pyx_n_s_prefix, __pyx_n_s_out_folder, __pyx_n_s_nitr, __pyx_n_s_sub, __pyx_n_s_ICs, __pyx_n_s_old, __pyx_n_s_n, __pyx_n_s_total, __pyx_n_s_i, __pyx_n_s_new_2, __pyx_n_s_pileres, __pyx_n_s_pile, __pyx_n_s_gene, __pyx_n_s_f); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(0, 2463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);
  __pyx_codeobj__105 = (PyObject*)__Pyx_PyCode_New(5, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__104, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_pileRank, 2463, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__105)) __PYX_ERR(0, 2463, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2514
 * 
 * 
 * def savetopfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */
  __pyx_tuple__106 = PyTuple_Pack(27, __pyx_n_s_plotcomb, __pyx_n_s_CICs, __pyx_n_s_cythonseed, __pyx_n_s_seedcmap, __pyx_n_s_featurecmap, __pyx_n_s_prefix, __pyx_n_s_figure_format, __pyx_n_s_pVals, __pyx_n_s_num_top, __pyx_n_s_bootstraps, __pyx_n_s_pilesize, __pyx_n_s_nitr, __pyx_n_s_out_folder, __pyx_n_s_target_name, __pyx_n_s_seed_name, __pyx_n_s_gmt, __pyx_n_s_locusdic, __pyx_n_s_plotpval, __pyx_n_s_piled, __pyx_n_s_if_bootstrap, __pyx_n_s_fig, __pyx_n_s_ax, __pyx_n_s_i, __pyx_n_s_pval, __pyx_n_s_pvallist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);
  __pyx_codeobj__107 = (PyObject*)__Pyx_PyCode_New(17, 0, 27, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__106, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_savetopfig, 2514, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__107)) __PYX_ERR(0, 2514, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2687
 * 
 * 
 * def saveresfigWithPval(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */
  __pyx_tuple__108 = PyTuple_Pack(24, __pyx_n_s_plotcomb, __pyx_n_s_seedids, __pyx_n_s_CICs, __pyx_n_s_seedlists, __pyx_n_s_seedcmap, __pyx_n_s_featurecmap, __pyx_n_s_prefix, __pyx_n_s_figure_format, __pyx_n_s_pVals, __pyx_n_s_bootstraps, __pyx_n_s_out_folder, __pyx_n_s_target_name, __pyx_n_s_seed_name, __pyx_n_s_locusdic, __pyx_n_s_gmt, __pyx_n_s_if_bootstrap, __pyx_n_s_reportdf, __pyx_n_s_fig, __pyx_n_s_ax, __pyx_n_s_pval, __pyx_n_s_pvallist, __pyx_n_s_i, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(0, 2687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);
  __pyx_codeobj__109 = (PyObject*)__Pyx_PyCode_New(15, 0, 24, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__108, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_saveresfigWithPval, 2687, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__109)) __PYX_ERR(0, 2687, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":2921
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def saveresfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */
  __pyx_tuple__110 = PyTuple_Pack(21, __pyx_n_s_plotcomb, __pyx_n_s_seedids, __pyx_n_s_CICs, __pyx_n_s_seedlists, __pyx_n_s_seedcmap, __pyx_n_s_featurecmap, __pyx_n_s_prefix, __pyx_n_s_figure_format, __pyx_n_s_bootstraps, __pyx_n_s_out_folder, __pyx_n_s_target_name, __pyx_n_s_seed_name, __pyx_n_s_locusdic, __pyx_n_s_gmt, __pyx_n_s_if_bootstrap, __pyx_n_s_reportdf, __pyx_n_s_fig, __pyx_n_s_ax, __pyx_n_s_i, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(0, 2921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);
  __pyx_codeobj__111 = (PyObject*)__Pyx_PyCode_New(14, 0, 21, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__110, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_saveresfig, 2921, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__111)) __PYX_ERR(0, 2921, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":3106
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def topMatches(             # <<<<<<<<<<<<<<
 *     comb,           #Dataframe contain target and features
 *     y,              #Target
 */
  __pyx_tuple__112 = PyTuple_Pack(14, __pyx_n_s_comb, __pyx_n_s_y, __pyx_n_s_grid, __pyx_n_s_k, __pyx_n_s_size, __pyx_n_s_bandwidth, __pyx_n_s_bandwidth_mult, __pyx_n_s_bandwidth_adj, __pyx_n_s_thread_number, __pyx_n_s_neighborhood, __pyx_n_s_seed, __pyx_n_s_rank, __pyx_n_s_results, __pyx_n_s_i); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);
  __pyx_codeobj__113 = (PyObject*)__Pyx_PyCode_New(11, 0, 14, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__112, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_topMatches, 3106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__113)) __PYX_ERR(0, 3106, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":3142
 *         return rank
 * 
 * def seedcomball(             # <<<<<<<<<<<<<<
 *     comb,       #Dataframe
 *     seed_name   #List of seed name
 */
  __pyx_tuple__114 = PyTuple_Pack(4, __pyx_n_s_comb, __pyx_n_s_seed_name, __pyx_n_s_currentseed, __pyx_n_s_subseed); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 3142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);
  __pyx_codeobj__115 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__114, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_seedcomball, 3142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__115)) __PYX_ERR(0, 3142, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":3158
 *     return currentseed
 * 
 * def readInput(             # <<<<<<<<<<<<<<
 *     target_file,    #Name of target file
 *     feature_file,   #Name of feature file
 */
  __pyx_tuple__116 = PyTuple_Pack(31, __pyx_n_s_target_file, __pyx_n_s_feature_file, __pyx_n_s_seed_file, __pyx_n_s_seed_name, __pyx_n_s_target_name, __pyx_n_s_direction, __pyx_n_s_gene_locus, __pyx_n_s_low_threshold, __pyx_n_s_high_threshold, __pyx_n_s_subset, __pyx_n_s_gene_set, __pyx_n_s_gene_separator, __pyx_n_s_thread_number, __pyx_n_s_tissue_file, __pyx_n_s_target, __pyx_n_s_feature, __pyx_n_s_patient, __pyx_n_s_commoncol, __pyx_n_s_comb, __pyx_n_s_seed_df, __pyx_n_s_rmrow, __pyx_n_s_i, __pyx_n_s_seedIndex, __pyx_n_s_locus, __pyx_n_s_locusdic, __pyx_n_s_name, __pyx_n_s_genename, __pyx_n_s_newseed_names, __pyx_n_s_currentseed, __pyx_n_s_inset_list, __pyx_n_s_feature_name); if (unlikely(!__pyx_tuple__116)) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);
  __pyx_codeobj__117 = (PyObject*)__Pyx_PyCode_New(14, 0, 31, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__116, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_readInput, 3158, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__117)) __PYX_ERR(0, 3158, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":3313
 *     return comb,locusdic
 * 
 * def check_inset(gene_set,feature_name,gene_separator):             # <<<<<<<<<<<<<<
 *     if feature_name.split(gene_separator)[0] in gene_set:
 *         return True
 */
  __pyx_tuple__118 = PyTuple_Pack(3, __pyx_n_s_gene_set, __pyx_n_s_feature_name, __pyx_n_s_gene_separator); if (unlikely(!__pyx_tuple__118)) __PYX_ERR(0, 3313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);
  __pyx_codeobj__119 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__118, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_revealer_REVEALER_runbenchma, __pyx_n_s_check_inset, 3313, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__119)) __PYX_ERR(0, 3313, __pyx_L1_error)

  /* "View.MemoryView":286
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_tuple__120 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct_or_indirect); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(2, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "View.MemoryView":287
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_tuple__121 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);

  /* "View.MemoryView":288
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__122 = PyTuple_Pack(1, __pyx_kp_s_strided_and_indirect); if (unlikely(!__pyx_tuple__122)) __PYX_ERR(2, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "View.MemoryView":291
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_tuple__123 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_direct); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(2, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);

  /* "View.MemoryView":292
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__124 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_indirect); if (unlikely(!__pyx_tuple__124)) __PYX_ERR(2, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__124);
  __Pyx_GIVEREF(__pyx_tuple__124);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__125 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__125, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Enum, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  /* InitThreads.init */
  #ifdef WITH_THREAD
PyEval_InitThreads();
#endif

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  __pyx_umethod_PyList_Type_copy.type = (PyObject*)&PyList_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_float__9 = PyFloat_FromDouble(.9); if (unlikely(!__pyx_float__9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_5 = PyFloat_FromDouble(0.5); if (unlikely(!__pyx_float_0_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_9 = PyFloat_FromDouble(0.9); if (unlikely(!__pyx_float_0_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_0 = PyFloat_FromDouble(2.0); if (unlikely(!__pyx_float_2_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_65 = PyFloat_FromDouble(0.65); if (unlikely(!__pyx_float_0_65)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_13_4 = PyFloat_FromDouble(13.4); if (unlikely(!__pyx_float_13_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_14_2 = PyFloat_FromDouble(14.2); if (unlikely(!__pyx_float_14_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_15_4 = PyFloat_FromDouble(15.4); if (unlikely(!__pyx_float_15_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_11 = PyInt_FromLong(11); if (unlikely(!__pyx_int_11)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_20 = PyInt_FromLong(20); if (unlikely(!__pyx_int_20)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_30 = PyInt_FromLong(30); if (unlikely(!__pyx_int_30)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_34 = PyInt_FromLong(34); if (unlikely(!__pyx_int_34)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_90 = PyInt_FromLong(90); if (unlikely(!__pyx_int_90)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_110 = PyInt_FromLong(110); if (unlikely(!__pyx_int_110)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_120 = PyInt_FromLong(120); if (unlikely(!__pyx_int_120)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_122 = PyInt_FromLong(122); if (unlikely(!__pyx_int_122)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_132 = PyInt_FromLong(132); if (unlikely(!__pyx_int_132)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_134 = PyInt_FromLong(134); if (unlikely(!__pyx_int_134)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_142 = PyInt_FromLong(142); if (unlikely(!__pyx_int_142)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_144 = PyInt_FromLong(144); if (unlikely(!__pyx_int_144)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_154 = PyInt_FromLong(154); if (unlikely(!__pyx_int_154)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_256 = PyInt_FromLong(256); if (unlikely(!__pyx_int_256)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000 = PyInt_FromLong(1000); if (unlikely(!__pyx_int_1000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10000 = PyInt_FromLong(10000L); if (unlikely(!__pyx_int_10000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_19981218 = PyInt_FromLong(19981218L); if (unlikely(!__pyx_int_19981218)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_184977713 = PyInt_FromLong(184977713L); if (unlikely(!__pyx_int_184977713)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_100 = PyInt_FromLong(-100); if (unlikely(!__pyx_int_neg_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  generic = Py_None; Py_INCREF(Py_None);
  strided = Py_None; Py_INCREF(Py_None);
  indirect = Py_None; Py_INCREF(Py_None);
  contiguous = Py_None; Py_INCREF(Py_None);
  indirect_contiguous = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster) < 0) __PYX_ERR(0, 2255, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct__plotCluster;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 2455, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_1_genexpr;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig) < 0) __PYX_ERR(0, 2514, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_2_savetopfig;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr) < 0) __PYX_ERR(0, 2680, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_3_genexpr;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval) < 0) __PYX_ERR(0, 2687, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_4_saveresfigWithPval;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr) < 0) __PYX_ERR(0, 2915, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_5_genexpr;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig) < 0) __PYX_ERR(0, 2921, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_6_saveresfig;
  if (PyType_Ready(&__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr) < 0) __PYX_ERR(0, 3100, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr.tp_dictoffset && __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr = &__pyx_type_8revealer_21REVEALER_runbenchmark___pyx_scope_struct_7_genexpr;
  __pyx_vtabptr_array = &__pyx_vtable_array;
  __pyx_vtable_array.get_memview = (PyObject *(*)(struct __pyx_array_obj *))__pyx_array_get_memview;
  if (PyType_Ready(&__pyx_type___pyx_array) < 0) __PYX_ERR(2, 105, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type___pyx_array.tp_print = 0;
  #endif
  if (__Pyx_SetVtable(__pyx_type___pyx_array.tp_dict, __pyx_vtabptr_array) < 0) __PYX_ERR(2, 105, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type___pyx_array) < 0) __PYX_ERR(2, 105, __pyx_L1_error)
  __pyx_array_type = &__pyx_type___pyx_array;
  if (PyType_Ready(&__pyx_type___pyx_MemviewEnum) < 0) __PYX_ERR(2, 279, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type___pyx_MemviewEnum.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type___pyx_MemviewEnum.tp_dictoffset && __pyx_type___pyx_MemviewEnum.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type___pyx_MemviewEnum.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type___pyx_MemviewEnum) < 0) __PYX_ERR(2, 279, __pyx_L1_error)
  __pyx_MemviewEnum_type = &__pyx_type___pyx_MemviewEnum;
  __pyx_vtabptr_memoryview = &__pyx_vtable_memoryview;
  __pyx_vtable_memoryview.get_item_pointer = (char *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_get_item_pointer;
  __pyx_vtable_memoryview.is_slice = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_is_slice;
  __pyx_vtable_memoryview.setitem_slice_assignment = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_slice_assignment;
  __pyx_vtable_memoryview.setitem_slice_assign_scalar = (PyObject *(*)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_setitem_slice_assign_scalar;
  __pyx_vtable_memoryview.setitem_indexed = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_indexed;
  __pyx_vtable_memoryview.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryview_convert_item_to_object;
  __pyx_vtable_memoryview.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryview_assign_item_from_object;
  if (PyType_Ready(&__pyx_type___pyx_memoryview) < 0) __PYX_ERR(2, 330, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type___pyx_memoryview.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type___pyx_memoryview.tp_dictoffset && __pyx_type___pyx_memoryview.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type___pyx_memoryview.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type___pyx_memoryview.tp_dict, __pyx_vtabptr_memoryview) < 0) __PYX_ERR(2, 330, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type___pyx_memoryview) < 0) __PYX_ERR(2, 330, __pyx_L1_error)
  __pyx_memoryview_type = &__pyx_type___pyx_memoryview;
  __pyx_vtabptr__memoryviewslice = &__pyx_vtable__memoryviewslice;
  __pyx_vtable__memoryviewslice.__pyx_base = *__pyx_vtabptr_memoryview;
  __pyx_vtable__memoryviewslice.__pyx_base.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryviewslice_convert_item_to_object;
  __pyx_vtable__memoryviewslice.__pyx_base.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryviewslice_assign_item_from_object;
  __pyx_type___pyx_memoryviewslice.tp_base = __pyx_memoryview_type;
  if (PyType_Ready(&__pyx_type___pyx_memoryviewslice) < 0) __PYX_ERR(2, 965, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type___pyx_memoryviewslice.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type___pyx_memoryviewslice.tp_dictoffset && __pyx_type___pyx_memoryviewslice.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type___pyx_memoryviewslice.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type___pyx_memoryviewslice.tp_dict, __pyx_vtabptr__memoryviewslice) < 0) __PYX_ERR(2, 965, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type___pyx_memoryviewslice) < 0) __PYX_ERR(2, 965, __pyx_L1_error)
  __pyx_memoryviewslice_type = &__pyx_type___pyx_memoryviewslice;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(1, 200, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(1, 223, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(1, 227, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(1, 239, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_generic) __PYX_ERR(1, 771, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType(__pyx_t_1, "numpy", "number", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_number) __PYX_ERR(1, 773, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_integer) __PYX_ERR(1, 775, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(1, 777, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(1, 779, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(1, 781, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_floating) __PYX_ERR(1, 783, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(1, 785, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(1, 787, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType(__pyx_t_1, "numpy", "character", sizeof(PyObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_character) __PYX_ERR(1, 789, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(1, 827, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initREVEALER_runbenchmark(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initREVEALER_runbenchmark(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_REVEALER_runbenchmark(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_REVEALER_runbenchmark(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_REVEALER_runbenchmark(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __pyx_t_5numpy_double_t __pyx_t_3;
  static PyThread_type_lock __pyx_t_4[8];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'REVEALER_runbenchmark' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_REVEALER_runbenchmark(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("REVEALER_runbenchmark", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_revealer__REVEALER_runbenchmark) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "revealer.REVEALER_runbenchmark")) {
      if (unlikely(PyDict_SetItemString(modules, "revealer.REVEALER_runbenchmark", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "revealer/REVEALER_runbenchmark.pyx":3
 * #-f -a --compile-args=-DCYTHON_TRACE_NOGIL=1
 * cimport cython
 * cython: infer_types=True             # <<<<<<<<<<<<<<
 * cython: profile=True
 * import warnings
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cython, Py_True) < 0) __PYX_ERR(0, 3, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":4
 * cimport cython
 * cython: infer_types=True
 * cython: profile=True             # <<<<<<<<<<<<<<
 * import warnings
 * warnings.filterwarnings("ignore")
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cython, Py_True) < 0) __PYX_ERR(0, 4, __pyx_L1_error)

  /* "revealer/REVEALER_runbenchmark.pyx":5
 * cython: infer_types=True
 * cython: profile=True
 * import warnings             # <<<<<<<<<<<<<<
 * warnings.filterwarnings("ignore")
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_warnings, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_1) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":6
 * cython: profile=True
 * import warnings
 * warnings.filterwarnings("ignore")             # <<<<<<<<<<<<<<
 * 
 * from revealer.ccal import *
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_filterwarnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":8
 * warnings.filterwarnings("ignore")
 * 
 * from revealer.ccal import *             # <<<<<<<<<<<<<<
 * import numpy as np
 * cimport numpy as np
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s__84);
  __Pyx_GIVEREF(__pyx_n_s__84);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s__84);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_revealer_ccal, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_import_star(__pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":9
 * 
 * from revealer.ccal import *
 * import numpy as np             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * import math
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_numpy, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_2) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":11
 * import numpy as np
 * cimport numpy as np
 * import math             # <<<<<<<<<<<<<<
 * cdef np.double_t EPS = np.finfo(float).eps
 * import sys
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_math, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_math, __pyx_t_2) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":12
 * cimport numpy as np
 * import math
 * cdef np.double_t EPS = np.finfo(float).eps             # <<<<<<<<<<<<<<
 * import sys
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_finfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)(&PyFloat_Type))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eps); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_3 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_8revealer_21REVEALER_runbenchmark_EPS = __pyx_t_3;

  /* "revealer/REVEALER_runbenchmark.pyx":13
 * import math
 * cdef np.double_t EPS = np.finfo(float).eps
 * import sys             # <<<<<<<<<<<<<<
 * 
 * import pandas as pd
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":15
 * import sys
 * 
 * import pandas as pd             # <<<<<<<<<<<<<<
 * 
 * from libc.float cimport DBL_EPSILON
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_pandas, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pd, __pyx_t_1) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":23
 * from libc.stdio cimport printf
 * from cython.parallel import prange
 * from scipy import stats             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_stats);
  __Pyx_GIVEREF(__pyx_n_s_stats);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_stats);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_scipy, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_stats); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stats, __pyx_t_1) < 0) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":28
 * cdef extern from "limits.h":
 *     int RAND_MAX
 * cdef int RANDOM_SEED = 20121020             # <<<<<<<<<<<<<<
 * 
 * cdef struct density:
 */
  __pyx_v_8revealer_21REVEALER_runbenchmark_RANDOM_SEED = 0x13305BC;

  /* "revealer/REVEALER_runbenchmark.pyx":34
 *     np.uint32_t* cnt
 * 
 * cdef np.double_t DELMAX=1000             # <<<<<<<<<<<<<<
 * 
 * import matplotlib.pyplot as plt
 */
  __pyx_v_8revealer_21REVEALER_runbenchmark_DELMAX = 1000.0;

  /* "revealer/REVEALER_runbenchmark.pyx":36
 * cdef np.double_t DELMAX=1000
 * 
 * import matplotlib.pyplot as plt             # <<<<<<<<<<<<<<
 * from scipy.stats import norm
 * import seaborn as sns
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s__84);
  __Pyx_GIVEREF(__pyx_n_s__84);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s__84);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_matplotlib_pyplot, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_plt, __pyx_t_1) < 0) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":37
 * 
 * import matplotlib.pyplot as plt
 * from scipy.stats import norm             # <<<<<<<<<<<<<<
 * import seaborn as sns
 * from tqdm.notebook import tqdm
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_norm);
  __Pyx_GIVEREF(__pyx_n_s_norm);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_norm);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_scipy_stats, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_norm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_norm, __pyx_t_1) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":38
 * import matplotlib.pyplot as plt
 * from scipy.stats import norm
 * import seaborn as sns             # <<<<<<<<<<<<<<
 * from tqdm.notebook import tqdm
 * import time
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_seaborn, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sns, __pyx_t_2) < 0) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":39
 * from scipy.stats import norm
 * import seaborn as sns
 * from tqdm.notebook import tqdm             # <<<<<<<<<<<<<<
 * import time
 * import matplotlib.colors as clr
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_tqdm);
  __Pyx_GIVEREF(__pyx_n_s_tqdm);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_tqdm);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_tqdm_notebook, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tqdm, __pyx_t_2) < 0) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":40
 * import seaborn as sns
 * from tqdm.notebook import tqdm
 * import time             # <<<<<<<<<<<<<<
 * import matplotlib.colors as clr
 * import multiprocessing as mp
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_time, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_1) < 0) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":41
 * from tqdm.notebook import tqdm
 * import time
 * import matplotlib.colors as clr             # <<<<<<<<<<<<<<
 * import multiprocessing as mp
 * import warnings
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s__84);
  __Pyx_GIVEREF(__pyx_n_s__84);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s__84);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_matplotlib_colors, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_clr, __pyx_t_2) < 0) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":42
 * import time
 * import matplotlib.colors as clr
 * import multiprocessing as mp             # <<<<<<<<<<<<<<
 * import warnings
 * import pickle
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_multiprocessing, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mp, __pyx_t_2) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":43
 * import matplotlib.colors as clr
 * import multiprocessing as mp
 * import warnings             # <<<<<<<<<<<<<<
 * import pickle
 * import random
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_warnings, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_2) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":44
 * import multiprocessing as mp
 * import warnings
 * import pickle             # <<<<<<<<<<<<<<
 * import random
 * import os
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pickle, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pickle, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":45
 * import warnings
 * import pickle
 * import random             # <<<<<<<<<<<<<<
 * import os
 * import tarfile
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_random, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_random, __pyx_t_2) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":46
 * import pickle
 * import random
 * import os             # <<<<<<<<<<<<<<
 * import tarfile
 * 
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_os, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_2) < 0) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":47
 * import random
 * import os
 * import tarfile             # <<<<<<<<<<<<<<
 * 
 * plt.switch_backend('agg')
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_tarfile, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tarfile, __pyx_t_2) < 0) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":49
 * import tarfile
 * 
 * plt.switch_backend('agg')             # <<<<<<<<<<<<<<
 * 
 * @cython.boundscheck(False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_plt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_switch_backend); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__85, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":989
 *     return res
 * 
 * def drawTarget(             # <<<<<<<<<<<<<<
 *     comb    #Combined dataframe
 *     ):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_15drawTarget, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_drawTarget, __pyx_t_2) < 0) __PYX_ERR(0, 989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1002
 *     return f
 * 
 * def drawFeature(             # <<<<<<<<<<<<<<
 *     comb,           #Combined dataframe
 *     featurecmap,    #Cmap to plot feature
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_17drawFeature, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_drawFeature, __pyx_t_2) < 0) __PYX_ERR(0, 1002, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1024
 *         return f
 * 
 * def drawSeed(             # <<<<<<<<<<<<<<
 *     seed,       #Seed list
 *     seedcmap    #Cmap to draw seed
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_19drawSeed, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_drawSeed, __pyx_t_2) < 0) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1038
 *     return f
 * 
 * def seedCombine(             # <<<<<<<<<<<<<<
 *     currentseed,    #Current seed
 *     newseed         #New seed to be added
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_21seedCombine, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_seedCombine, __pyx_t_2) < 0) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1241
 *                   k=5, # size of kernel for k standard deviation away
 *                   bandwidth_mult=0.65, # multiplication for bandwidth
 *                   bandwidth_adj=-0.95, # adjustion value for bandwidth             # <<<<<<<<<<<<<<
 *                   direction='pos', # direction that feature should match with target
 *                   mode='single', # indicate if multiple parameter set is passes. if True, then prefix, k, grid, bandwidth_mult, and bandwidth_adj has to be a list
 */
  __pyx_t_2 = PyFloat_FromDouble((-0.95)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_k__6 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1229
 * @cython.boundscheck(False)
 * @cython.cdivision(True)
 * cpdef runBenchmark(target_file='no', # gct file for target(continuous or binary             # <<<<<<<<<<<<<<
 *                   feature_file='no', # gct file for features(binary)
 *                   seed_file='no', # file for seed, if not provided, feature file is used directly
 */
  __pyx_t_2 = PyFloat_FromDouble((-0.95)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_k__6 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1792
 *     return pVals
 * 
 * def patientfig(             # <<<<<<<<<<<<<<
 *     df,       #Dataframe used to plot
 *     seedcmap,       #Cmap for seed heatmap
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_31patientfig, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_patientfig, __pyx_t_2) < 0) __PYX_ERR(0, 1792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2011
 * 
 * 
 * def calcIndivisualPvalIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K value for kernel
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_43calcIndivisualPvalIC, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_calcIndivisualPvalIC, __pyx_t_2) < 0) __PYX_ERR(0, 2011, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2087
 * 
 * 
 * def calcBootstrap(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     cythonseed,     #Seed to calculate
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_47calcBootstrap, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_calcBootstrap, __pyx_t_2) < 0) __PYX_ERR(0, 2087, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2168
 *     return res
 * 
 * def calcBootstrapIC(             # <<<<<<<<<<<<<<
 *     subcomb,        #Combined dataframe
 *     k,              #K for kernel
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_51calcBootstrapIC, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_calcBootstrapIC, __pyx_t_2) < 0) __PYX_ERR(0, 2168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2255
 * 
 * 
 * def plotCluster(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_55plotCluster, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_plotCluster, __pyx_t_2) < 0) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2463
 * 
 * 
 * def pileRank(             # <<<<<<<<<<<<<<
 *     rank,       #Rank for features
 *     num_top,    #Number of top feature
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_57pileRank, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pileRank, __pyx_t_2) < 0) __PYX_ERR(0, 2463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2514
 * 
 * 
 * def savetopfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     CICs,           #List of CIC values
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_59savetopfig, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_savetopfig, __pyx_t_2) < 0) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2687
 * 
 * 
 * def saveresfigWithPval(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_61saveresfigWithPval, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_saveresfigWithPval, __pyx_t_2) < 0) __PYX_ERR(0, 2687, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":2921
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def saveresfig(             # <<<<<<<<<<<<<<
 *     plotcomb,       #Dataframe used to plot
 *     seedids,        #List of name of feature picked
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_63saveresfig, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_saveresfig, __pyx_t_2) < 0) __PYX_ERR(0, 2921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3106
 *     reportdf.to_csv(out_folder + prefix+'_Result.txt',sep='\t')
 * 
 * def topMatches(             # <<<<<<<<<<<<<<
 *     comb,           #Dataframe contain target and features
 *     y,              #Target
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_65topMatches, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_topMatches, __pyx_t_2) < 0) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3142
 *         return rank
 * 
 * def seedcomball(             # <<<<<<<<<<<<<<
 *     comb,       #Dataframe
 *     seed_name   #List of seed name
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_67seedcomball, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_seedcomball, __pyx_t_2) < 0) __PYX_ERR(0, 3142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3158
 *     return currentseed
 * 
 * def readInput(             # <<<<<<<<<<<<<<
 *     target_file,    #Name of target file
 *     feature_file,   #Name of feature file
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_69readInput, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_readInput, __pyx_t_2) < 0) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":3313
 *     return comb,locusdic
 * 
 * def check_inset(gene_set,feature_name,gene_separator):             # <<<<<<<<<<<<<<
 *     if feature_name.split(gene_separator)[0] in gene_set:
 *         return True
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_8revealer_21REVEALER_runbenchmark_71check_inset, NULL, __pyx_n_s_revealer_REVEALER_runbenchmark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_check_inset, __pyx_t_2) < 0) __PYX_ERR(0, 3313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "revealer/REVEALER_runbenchmark.pyx":1
 * #-f -a --compile-args=-DCYTHON_TRACE_NOGIL=1             # <<<<<<<<<<<<<<
 * cimport cython
 * cython: infer_types=True
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_2, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":209
 *         info.obj = self
 * 
 *     __pyx_getbuffer = capsule(<void *> &__pyx_array_getbuffer, "getbuffer(obj, view, flags)")             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(array self):
 */
  __pyx_t_2 = __pyx_capsule_create(((void *)(&__pyx_array_getbuffer)), ((char *)"getbuffer(obj, view, flags)")); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem((PyObject *)__pyx_array_type->tp_dict, __pyx_n_s_pyx_getbuffer, __pyx_t_2) < 0) __PYX_ERR(2, 209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_array_type);

  /* "View.MemoryView":286
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(generic);
  __Pyx_DECREF_SET(generic, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":287
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(strided);
  __Pyx_DECREF_SET(strided, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":288
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(indirect);
  __Pyx_DECREF_SET(indirect, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":291
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__123, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(contiguous);
  __Pyx_DECREF_SET(contiguous, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":292
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__124, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(indirect_contiguous);
  __Pyx_DECREF_SET(indirect_contiguous, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":316
 * 
 * DEF THREAD_LOCKS_PREALLOCATED = 8
 * cdef int __pyx_memoryview_thread_locks_used = 0             # <<<<<<<<<<<<<<
 * cdef PyThread_type_lock[THREAD_LOCKS_PREALLOCATED] __pyx_memoryview_thread_locks = [
 *     PyThread_allocate_lock(),
 */
  __pyx_memoryview_thread_locks_used = 0;

  /* "View.MemoryView":317
 * DEF THREAD_LOCKS_PREALLOCATED = 8
 * cdef int __pyx_memoryview_thread_locks_used = 0
 * cdef PyThread_type_lock[THREAD_LOCKS_PREALLOCATED] __pyx_memoryview_thread_locks = [             # <<<<<<<<<<<<<<
 *     PyThread_allocate_lock(),
 *     PyThread_allocate_lock(),
 */
  __pyx_t_4[0] = PyThread_allocate_lock();
  __pyx_t_4[1] = PyThread_allocate_lock();
  __pyx_t_4[2] = PyThread_allocate_lock();
  __pyx_t_4[3] = PyThread_allocate_lock();
  __pyx_t_4[4] = PyThread_allocate_lock();
  __pyx_t_4[5] = PyThread_allocate_lock();
  __pyx_t_4[6] = PyThread_allocate_lock();
  __pyx_t_4[7] = PyThread_allocate_lock();
  memcpy(&(__pyx_memoryview_thread_locks[0]), __pyx_t_4, sizeof(__pyx_memoryview_thread_locks[0]) * (8));

  /* "View.MemoryView":549
 *         info.obj = self
 * 
 *     __pyx_getbuffer = capsule(<void *> &__pyx_memoryview_getbuffer, "getbuffer(obj, view, flags)")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_capsule_create(((void *)(&__pyx_memoryview_getbuffer)), ((char *)"getbuffer(obj, view, flags)")); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem((PyObject *)__pyx_memoryview_type->tp_dict, __pyx_n_s_pyx_getbuffer, __pyx_t_2) < 0) __PYX_ERR(2, 549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_memoryview_type);

  /* "View.MemoryView":995
 *         return self.from_object
 * 
 *     __pyx_getbuffer = capsule(<void *> &__pyx_memoryview_getbuffer, "getbuffer(obj, view, flags)")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_capsule_create(((void *)(&__pyx_memoryview_getbuffer)), ((char *)"getbuffer(obj, view, flags)")); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem((PyObject *)__pyx_memoryviewslice_type->tp_dict, __pyx_n_s_pyx_getbuffer, __pyx_t_2) < 0) __PYX_ERR(2, 995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_memoryviewslice_type);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum, NULL, __pyx_n_s_View_MemoryView); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Enum, __pyx_t_2) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init revealer.REVEALER_runbenchmark", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init revealer.REVEALER_runbenchmark");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* MemviewSliceInit */
static int
__Pyx_init_memviewslice(struct __pyx_memoryview_obj *memview,
                        int ndim,
                        __Pyx_memviewslice *memviewslice,
                        int memview_is_new_reference)
{
    __Pyx_RefNannyDeclarations
    int i, retval=-1;
    Py_buffer *buf = &memview->view;
    __Pyx_RefNannySetupContext("init_memviewslice", 0);
    if (unlikely(memviewslice->memview || memviewslice->data)) {
        PyErr_SetString(PyExc_ValueError,
            "memviewslice is already initialized!");
        goto fail;
    }
    if (buf->strides) {
        for (i = 0; i < ndim; i++) {
            memviewslice->strides[i] = buf->strides[i];
        }
    } else {
        Py_ssize_t stride = buf->itemsize;
        for (i = ndim - 1; i >= 0; i--) {
            memviewslice->strides[i] = stride;
            stride *= buf->shape[i];
        }
    }
    for (i = 0; i < ndim; i++) {
        memviewslice->shape[i]   = buf->shape[i];
        if (buf->suboffsets) {
            memviewslice->suboffsets[i] = buf->suboffsets[i];
        } else {
            memviewslice->suboffsets[i] = -1;
        }
    }
    memviewslice->memview = memview;
    memviewslice->data = (char *)buf->buf;
    if (__pyx_add_acquisition_count(memview) == 0 && !memview_is_new_reference) {
        Py_INCREF(memview);
    }
    retval = 0;
    goto no_fail;
fail:
    memviewslice->memview = 0;
    memviewslice->data = 0;
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}
#ifndef Py_NO_RETURN
#define Py_NO_RETURN
#endif
static void __pyx_fatalerror(const char *fmt, ...) Py_NO_RETURN {
    va_list vargs;
    char msg[200];
#ifdef HAVE_STDARG_PROTOTYPES
    va_start(vargs, fmt);
#else
    va_start(vargs);
#endif
    vsnprintf(msg, 200, fmt, vargs);
    va_end(vargs);
    Py_FatalError(msg);
}
static CYTHON_INLINE int
__pyx_add_acquisition_count_locked(__pyx_atomic_int *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)++;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE int
__pyx_sub_acquisition_count_locked(__pyx_atomic_int *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)--;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE void
__Pyx_INC_MEMVIEW(__Pyx_memviewslice *memslice, int have_gil, int lineno)
{
    int first_time;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None))
        return;
    if (unlikely(__pyx_get_slice_count(memview) < 0))
        __pyx_fatalerror("Acquisition count is %d (line %d)",
                         __pyx_get_slice_count(memview), lineno);
    first_time = __pyx_add_acquisition_count(memview) == 0;
    if (unlikely(first_time)) {
        if (have_gil) {
            Py_INCREF((PyObject *) memview);
        } else {
            PyGILState_STATE _gilstate = PyGILState_Ensure();
            Py_INCREF((PyObject *) memview);
            PyGILState_Release(_gilstate);
        }
    }
}
static CYTHON_INLINE void __Pyx_XDEC_MEMVIEW(__Pyx_memviewslice *memslice,
                                             int have_gil, int lineno) {
    int last_time;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        memslice->memview = NULL;
        return;
    }
    if (unlikely(__pyx_get_slice_count(memview) <= 0))
        __pyx_fatalerror("Acquisition count is %d (line %d)",
                         __pyx_get_slice_count(memview), lineno);
    last_time = __pyx_sub_acquisition_count(memview) == 1;
    memslice->data = NULL;
    if (unlikely(last_time)) {
        if (have_gil) {
            Py_CLEAR(memslice->memview);
        } else {
            PyGILState_STATE _gilstate = PyGILState_Ensure();
            Py_CLEAR(memslice->memview);
            PyGILState_Release(_gilstate);
        }
    } else {
        memslice->memview = NULL;
    }
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* None */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_FALSE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a != b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_TRUE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_TRUE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a != (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* py_abs */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *n) {
    if (likely(Py_SIZE(n) == -1)) {
        return PyLong_FromLong(((PyLongObject*)n)->ob_digit[0]);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    {
        PyObject *copy = _PyLong_Copy((PyLongObject*)n);
        if (likely(copy)) {
            __Pyx_SET_SIZE(copy, -Py_SIZE(copy));
        }
        return copy;
    }
#else
    return PyNumber_Negative(n);
#endif
}
#endif

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject** CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyList_New(0);
    dest = PyList_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyListObject*)src)->ob_item + start,
        ((PyListObject*)dest)->ob_item,
        length);
    return dest;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyTuple_New(0);
    dest = PyTuple_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyTupleObject*)src)->ob_item + start,
        ((PyTupleObject*)dest)->ob_item,
        length);
    return dest;
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntFromDouble */
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE PyObject* __Pyx_PyInt_FromDouble(double value) {
    if (value >= (double)LONG_MIN && value <= (double)LONG_MAX) {
        return PyInt_FromLong((long)value);
    }
    return PyLong_FromDouble(value);
}
#endif

/* pyobject_as_double */
static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if !CYTHON_USE_TYPE_SLOTS
    float_value = PyNumber_Float(obj);  if ((0)) goto bad;
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
#if PY_MAJOR_VERSION < 3 || CYTHON_USE_PYLONG_INTERNALS
#define __Pyx_PyInt_TrueDivideObjC_ZeroDivisionError(operand)\
    if (unlikely(zerodivision_check && ((operand) == 0))) {\
        PyErr_SetString(PyExc_ZeroDivisionError, "integer division by zero");\
        return NULL;\
    }
#endif
static PyObject* __Pyx_PyInt_TrueDivideObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
            __Pyx_PyInt_TrueDivideObjC_ZeroDivisionError(b)
            if (8 * sizeof(long) <= 53 || likely(labs(a) <= ((PY_LONG_LONG)1 << 53))) {
                return PyFloat_FromDouble((double)a / (double)b);
            }
            return PyInt_Type.tp_as_number->nb_true_divide(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT && 1 * PyLong_SHIFT < 53) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT && 1 * PyLong_SHIFT < 53) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT && 2 * PyLong_SHIFT < 53) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT && 2 * PyLong_SHIFT < 53) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT && 3 * PyLong_SHIFT < 53) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT && 3 * PyLong_SHIFT < 53) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_true_divide(op1, op2);
            }
        }
                __Pyx_PyInt_TrueDivideObjC_ZeroDivisionError(b)
                if ((8 * sizeof(long) <= 53 || likely(labs(a) <= ((PY_LONG_LONG)1 << 53)))
                        || __Pyx_sst_abs(size) <= 52 / PyLong_SHIFT) {
                    return PyFloat_FromDouble((double)a / (double)b);
                }
                return PyLong_Type.tp_as_number->nb_true_divide(op1, op2);
            return PyLong_FromLong(x);
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            if (unlikely(zerodivision_check && b == 0)) {
                PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero");
                return NULL;
            }
            PyFPE_START_PROTECT("divide", return NULL)
            result = ((double)a) / (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
}
#endif

/* None */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double b = floatval;
    double a, result;
    (void)inplace;
    (void)zerodivision_check;
    if (likely(PyFloat_CheckExact(op1))) {
        a = PyFloat_AS_DOUBLE(op1);
        
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        a = (double) PyInt_AS_LONG(op1);
        
    } else
    #endif
    if (likely(PyLong_CheckExact(op1))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        switch (size) {
            case  0: a = 0.0; break;
            case -1: a = -(double) digits[0]; break;
            case  1: a = (double) digits[0]; break;
            case -2:
            case 2:
                if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                    a = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                        if (size == -2)
                            a = -a;
                        break;
                    }
                }
                CYTHON_FALLTHROUGH;
            case -3:
            case 3:
                if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                    a = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                        if (size == -3)
                            a = -a;
                        break;
                    }
                }
                CYTHON_FALLTHROUGH;
            case -4:
            case 4:
                if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                    a = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                        if (size == -4)
                            a = -a;
                        break;
                    }
                }
                CYTHON_FALLTHROUGH;
            default:
        #else
        {
        #endif
            a = PyLong_AsDouble(op1);
            if (unlikely(a == -1.0 && PyErr_Occurred())) return NULL;
            
        }
    } else {
        return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
    }
        
        PyFPE_START_PROTECT("divide", return NULL)
        result = a / b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* PyObjectFormat */
  #if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* obj, PyObject* format_spec) {
    int ret;
    _PyUnicodeWriter writer;
    if (likely(PyFloat_CheckExact(obj))) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x03040000
        _PyUnicodeWriter_Init(&writer, 0);
#else
        _PyUnicodeWriter_Init(&writer);
#endif
        ret = _PyFloat_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else if (likely(PyLong_CheckExact(obj))) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x03040000
        _PyUnicodeWriter_Init(&writer, 0);
#else
        _PyUnicodeWriter_Init(&writer);
#endif
        ret = _PyLong_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else {
        return PyObject_Format(obj, format_spec);
    }
    if (unlikely(ret == -1)) {
        _PyUnicodeWriter_Dealloc(&writer);
        return NULL;
    }
    return _PyUnicodeWriter_Finish(&writer);
}
#endif

/* PyObjectFormatAndDecref */
  static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyString_CheckExact(s))) {
        PyObject *result = PyUnicode_FromEncodedObject(s, NULL, "strict");
        Py_DECREF(s);
        return result;
    }
    #endif
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
  static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* PyErrExceptionMatches */
  #if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* ArgTypeTest */
  static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* None */
  static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t a, Py_ssize_t b) {
    Py_ssize_t q = a / b;
    Py_ssize_t r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* GetAttr */
  static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* decode_c_string */
  static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (unlikely(stop <= start))
        return __Pyx_NewRef(__pyx_empty_unicode);
    length = stop - start;
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* GetAttr3 */
  static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* RaiseNoneIterError */
  static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* ExtTypeTest */
  static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* SwapException */
  #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* Import */
  static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* FastTypeChecks */
  #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* None */
  static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* ImportFrom */
  static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
  static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObject_GenericGetAttrNoDict */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
  static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
  static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
  static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
  #ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* CLineInTraceback */
  #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
  static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
  #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_array_type)) return __pyx_array_getbuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_memoryview_type)) return __pyx_memoryview_getbuffer(obj, view, flags);
    PyErr_Format(PyExc_TypeError, "'%.200s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
    if ((0)) {}
    view->obj = NULL;
    Py_DECREF(obj);
}
#endif


  /* MemviewSliceIsContig */
  static int
__pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim)
{
    int i, index, step, start;
    Py_ssize_t itemsize = mvs.memview->view.itemsize;
    if (order == 'F') {
        step = 1;
        start = 0;
    } else {
        step = -1;
        start = ndim - 1;
    }
    for (i = 0; i < ndim; i++) {
        index = start + step * i;
        if (mvs.suboffsets[index] >= 0 || mvs.strides[index] != itemsize)
            return 0;
        itemsize *= mvs.shape[index];
    }
    return 1;
}

/* OverlappingSlices */
  static void
__pyx_get_array_memory_extents(__Pyx_memviewslice *slice,
                               void **out_start, void **out_end,
                               int ndim, size_t itemsize)
{
    char *start, *end;
    int i;
    start = end = slice->data;
    for (i = 0; i < ndim; i++) {
        Py_ssize_t stride = slice->strides[i];
        Py_ssize_t extent = slice->shape[i];
        if (extent == 0) {
            *out_start = *out_end = start;
            return;
        } else {
            if (stride > 0)
                end += stride * (extent - 1);
            else
                start += stride * (extent - 1);
        }
    }
    *out_start = start;
    *out_end = end + itemsize;
}
static int
__pyx_slices_overlap(__Pyx_memviewslice *slice1,
                     __Pyx_memviewslice *slice2,
                     int ndim, size_t itemsize)
{
    void *start1, *end1, *start2, *end2;
    __pyx_get_array_memory_extents(slice1, &start1, &end1, ndim, itemsize);
    __pyx_get_array_memory_extents(slice2, &start2, &end2, ndim, itemsize);
    return (start1 < end2) && (start2 < end1);
}

/* Capsule */
  static CYTHON_INLINE PyObject *
__pyx_capsule_create(void *p, CYTHON_UNUSED const char *sig)
{
    PyObject *cobj;
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(p, sig, NULL);
#else
    cobj = PyCObject_FromVoidPtr(p, NULL);
#endif
    return cobj;
}

/* IsLittleEndian */
  static CYTHON_INLINE int __Pyx_Is_Little_Endian(void)
{
  union {
    uint32_t u32;
    uint8_t u8[4];
  } S;
  S.u32 = 0x01020304;
  return S.u8[0] == 4;
}

/* BufferFormatCheck */
  static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t <= '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case '?': return "'bool'";
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case '?': case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number, ndim;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    ndim = ctx->head->field->type->ndim;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
        CYTHON_FALLTHROUGH;
      case '?': case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if ((ctx->enc_type == *ts) && (got_Z == ctx->is_complex) &&
            (ctx->enc_packmode == ctx->new_packmode) && (!ctx->is_valid_array)) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
        CYTHON_FALLTHROUGH;
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}

/* TypeInfoCompare */
    static int
__pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b)
{
    int i;
    if (!a || !b)
        return 0;
    if (a == b)
        return 1;
    if (a->size != b->size || a->typegroup != b->typegroup ||
            a->is_unsigned != b->is_unsigned || a->ndim != b->ndim) {
        if (a->typegroup == 'H' || b->typegroup == 'H') {
            return a->size == b->size;
        } else {
            return 0;
        }
    }
    if (a->ndim) {
        for (i = 0; i < a->ndim; i++)
            if (a->arraysize[i] != b->arraysize[i])
                return 0;
    }
    if (a->typegroup == 'S') {
        if (a->flags != b->flags)
            return 0;
        if (a->fields || b->fields) {
            if (!(a->fields && b->fields))
                return 0;
            for (i = 0; a->fields[i].type && b->fields[i].type; i++) {
                __Pyx_StructField *field_a = a->fields + i;
                __Pyx_StructField *field_b = b->fields + i;
                if (field_a->offset != field_b->offset ||
                    !__pyx_typeinfo_cmp(field_a->type, field_b->type))
                    return 0;
            }
            return !a->fields[i].type && !b->fields[i].type;
        }
    }
    return 1;
}

/* MemviewSliceValidateAndInit */
    static int
__pyx_check_strides(Py_buffer *buf, int dim, int ndim, int spec)
{
    if (buf->shape[dim] <= 1)
        return 1;
    if (buf->strides) {
        if (spec & __Pyx_MEMVIEW_CONTIG) {
            if (spec & (__Pyx_MEMVIEW_PTR|__Pyx_MEMVIEW_FULL)) {
                if (unlikely(buf->strides[dim] != sizeof(void *))) {
                    PyErr_Format(PyExc_ValueError,
                                 "Buffer is not indirectly contiguous "
                                 "in dimension %d.", dim);
                    goto fail;
                }
            } else if (unlikely(buf->strides[dim] != buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
        if (spec & __Pyx_MEMVIEW_FOLLOW) {
            Py_ssize_t stride = buf->strides[dim];
            if (stride < 0)
                stride = -stride;
            if (unlikely(stride < buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
    } else {
        if (unlikely(spec & __Pyx_MEMVIEW_CONTIG && dim != ndim - 1)) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not contiguous in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(spec & (__Pyx_MEMVIEW_PTR))) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not indirect in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(buf->suboffsets)) {
            PyErr_SetString(PyExc_ValueError,
                            "Buffer exposes suboffsets but no strides");
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_check_suboffsets(Py_buffer *buf, int dim, CYTHON_UNUSED int ndim, int spec)
{
    if (spec & __Pyx_MEMVIEW_DIRECT) {
        if (unlikely(buf->suboffsets && buf->suboffsets[dim] >= 0)) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer not compatible with direct access "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    if (spec & __Pyx_MEMVIEW_PTR) {
        if (unlikely(!buf->suboffsets || (buf->suboffsets[dim] < 0))) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer is not indirectly accessible "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_verify_contig(Py_buffer *buf, int ndim, int c_or_f_flag)
{
    int i;
    if (c_or_f_flag & __Pyx_IS_F_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = 0; i < ndim; i++) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not fortran contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    } else if (c_or_f_flag & __Pyx_IS_C_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = ndim - 1; i >- 1; i--) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not C contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    }
    return 1;
fail:
    return 0;
}
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj)
{
    struct __pyx_memoryview_obj *memview, *new_memview;
    __Pyx_RefNannyDeclarations
    Py_buffer *buf;
    int i, spec = 0, retval = -1;
    __Pyx_BufFmt_Context ctx;
    int from_memoryview = __pyx_memoryview_check(original_obj);
    __Pyx_RefNannySetupContext("ValidateAndInit_memviewslice", 0);
    if (from_memoryview && __pyx_typeinfo_cmp(dtype, ((struct __pyx_memoryview_obj *)
                                                            original_obj)->typeinfo)) {
        memview = (struct __pyx_memoryview_obj *) original_obj;
        new_memview = NULL;
    } else {
        memview = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                            original_obj, buf_flags, 0, dtype);
        new_memview = memview;
        if (unlikely(!memview))
            goto fail;
    }
    buf = &memview->view;
    if (unlikely(buf->ndim != ndim)) {
        PyErr_Format(PyExc_ValueError,
                "Buffer has wrong number of dimensions (expected %d, got %d)",
                ndim, buf->ndim);
        goto fail;
    }
    if (new_memview) {
        __Pyx_BufFmt_Init(&ctx, stack, dtype);
        if (unlikely(!__Pyx_BufFmt_CheckString(&ctx, buf->format))) goto fail;
    }
    if (unlikely((unsigned) buf->itemsize != dtype->size)) {
        PyErr_Format(PyExc_ValueError,
                     "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "u byte%s) "
                     "does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "u byte%s)",
                     buf->itemsize,
                     (buf->itemsize > 1) ? "s" : "",
                     dtype->name,
                     dtype->size,
                     (dtype->size > 1) ? "s" : "");
        goto fail;
    }
    if (buf->len > 0) {
        for (i = 0; i < ndim; i++) {
            spec = axes_specs[i];
            if (unlikely(!__pyx_check_strides(buf, i, ndim, spec)))
                goto fail;
            if (unlikely(!__pyx_check_suboffsets(buf, i, ndim, spec)))
                goto fail;
        }
        if (unlikely(buf->strides && !__pyx_verify_contig(buf, ndim, c_or_f_flag)))
            goto fail;
    }
    if (unlikely(__Pyx_init_memviewslice(memview, ndim, memviewslice,
                                         new_memview != NULL) == -1)) {
        goto fail;
    }
    retval = 0;
    goto no_fail;
fail:
    Py_XDECREF(new_memview);
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}

/* ObjectToMemviewSlice */
    static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_double_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_double_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* CIntFromPyVerify */
    #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* ObjectToMemviewSlice */
    static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
    static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_int_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED), (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 2,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
    static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dsds_nn___pyx_t_5numpy_double_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED), (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 2,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_double_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* CIntToPy */
    static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
    static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* MemviewDtypeToObject */
    static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_double_t(const char *itemp) {
    return (PyObject *) PyFloat_FromDouble(*(__pyx_t_5numpy_double_t *) itemp);
}
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_double_t(const char *itemp, PyObject *obj) {
    __pyx_t_5numpy_double_t value = __pyx_PyFloat_AsDouble(obj);
    if ((value == ((npy_double)-1)) && PyErr_Occurred())
        return 0;
    *(__pyx_t_5numpy_double_t *) itemp = value;
    return 1;
}

/* CIntToPy */
    static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_long(npy_long value) {
    const npy_long neg_one = (npy_long) ((npy_long) 0 - (npy_long) 1), const_zero = (npy_long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_long),
                                     little, !is_unsigned);
    }
}

/* MemviewDtypeToObject */
    static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int_t(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_long(*(__pyx_t_5numpy_int_t *) itemp);
}
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_int_t(const char *itemp, PyObject *obj) {
    __pyx_t_5numpy_int_t value = __Pyx_PyInt_As_npy_long(obj);
    if ((value == ((npy_long)-1)) && PyErr_Occurred())
        return 0;
    *(__pyx_t_5numpy_int_t *) itemp = value;
    return 1;
}

/* ToPyCTupleUtility */
    static PyObject* __pyx_convert__to_py___pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc(__pyx_ctuple_3b47e____dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t__and___dunderpyx_t_5numpy_double_t__etc value) {
    PyObject* item = NULL;
    PyObject* result = PyTuple_New(3);
    if (!result) goto bad;
        item = __Pyx_PyInt_From_npy_long(value.f0);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 0, item);
        item = PyFloat_FromDouble(value.f1);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 1, item);
        item = PyFloat_FromDouble(value.f2);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 2, item);
    return result;
bad:
    Py_XDECREF(item);
    Py_XDECREF(result);
    return NULL;
}

/* ToPyCTupleUtility */
    static PyObject* __pyx_convert__to_py___pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t(__pyx_ctuple___dunderpyx_t_5numpy_int_t__and___dunderpyx_t_5numpy_double_t value) {
    PyObject* item = NULL;
    PyObject* result = PyTuple_New(2);
    if (!result) goto bad;
        item = __Pyx_PyInt_From_npy_long(value.f0);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 0, item);
        item = PyFloat_FromDouble(value.f1);
        if (!item) goto bad;
        PyTuple_SET_ITEM(result, 1, item);
    return result;
bad:
    Py_XDECREF(item);
    Py_XDECREF(result);
    return NULL;
}

/* Declarations */
    #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
    #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
    #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
    #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* MemviewSliceCopyTemplate */
    static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object)
{
    __Pyx_RefNannyDeclarations
    int i;
    __Pyx_memviewslice new_mvs = { 0, 0, { 0 }, { 0 }, { 0 } };
    struct __pyx_memoryview_obj *from_memview = from_mvs->memview;
    Py_buffer *buf = &from_memview->view;
    PyObject *shape_tuple = NULL;
    PyObject *temp_int = NULL;
    struct __pyx_array_obj *array_obj = NULL;
    struct __pyx_memoryview_obj *memview_obj = NULL;
    __Pyx_RefNannySetupContext("__pyx_memoryview_copy_new_contig", 0);
    for (i = 0; i < ndim; i++) {
        if (unlikely(from_mvs->suboffsets[i] >= 0)) {
            PyErr_Format(PyExc_ValueError, "Cannot copy memoryview slice with "
                                           "indirect dimensions (axis %d)", i);
            goto fail;
        }
    }
    shape_tuple = PyTuple_New(ndim);
    if (unlikely(!shape_tuple)) {
        goto fail;
    }
    __Pyx_GOTREF(shape_tuple);
    for(i = 0; i < ndim; i++) {
        temp_int = PyInt_FromSsize_t(from_mvs->shape[i]);
        if(unlikely(!temp_int)) {
            goto fail;
        } else {
            PyTuple_SET_ITEM(shape_tuple, i, temp_int);
            temp_int = NULL;
        }
    }
    array_obj = __pyx_array_new(shape_tuple, sizeof_dtype, buf->format, (char *) mode, NULL);
    if (unlikely(!array_obj)) {
        goto fail;
    }
    __Pyx_GOTREF(array_obj);
    memview_obj = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                    (PyObject *) array_obj, contig_flag,
                                    dtype_is_object,
                                    from_mvs->memview->typeinfo);
    if (unlikely(!memview_obj))
        goto fail;
    if (unlikely(__Pyx_init_memviewslice(memview_obj, ndim, &new_mvs, 1) < 0))
        goto fail;
    if (unlikely(__pyx_memoryview_copy_contents(*from_mvs, new_mvs, ndim, ndim,
                                                dtype_is_object) < 0))
        goto fail;
    goto no_fail;
fail:
    __Pyx_XDECREF(new_mvs.memview);
    new_mvs.memview = NULL;
    new_mvs.data = NULL;
no_fail:
    __Pyx_XDECREF(shape_tuple);
    __Pyx_XDECREF(temp_int);
    __Pyx_XDECREF(array_obj);
    __Pyx_RefNannyFinishContext();
    return new_mvs;
}

/* CIntFromPy */
    static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
    static CYTHON_INLINE npy_long __Pyx_PyInt_As_npy_long(PyObject *x) {
    const npy_long neg_one = (npy_long) ((npy_long) 0 - (npy_long) 1), const_zero = (npy_long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(npy_long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(npy_long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(npy_long, digit, digits[0])
                case 2:
                    if (8 * sizeof(npy_long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) >= 2 * PyLong_SHIFT) {
                            return (npy_long) (((((npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) >= 3 * PyLong_SHIFT) {
                            return (npy_long) (((((((npy_long)digits[2]) << PyLong_SHIFT) | (npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) >= 4 * PyLong_SHIFT) {
                            return (npy_long) (((((((((npy_long)digits[3]) << PyLong_SHIFT) | (npy_long)digits[2]) << PyLong_SHIFT) | (npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(npy_long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(npy_long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(npy_long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(npy_long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_long) (((npy_long)-1)*(((((npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(npy_long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_long) ((((((npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(npy_long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_long) (((npy_long)-1)*(((((((npy_long)digits[2]) << PyLong_SHIFT) | (npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_long) ((((((((npy_long)digits[2]) << PyLong_SHIFT) | (npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(npy_long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_long) (((npy_long)-1)*(((((((((npy_long)digits[3]) << PyLong_SHIFT) | (npy_long)digits[2]) << PyLong_SHIFT) | (npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_long) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_long) ((((((((((npy_long)digits[3]) << PyLong_SHIFT) | (npy_long)digits[2]) << PyLong_SHIFT) | (npy_long)digits[1]) << PyLong_SHIFT) | (npy_long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(npy_long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            npy_long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (npy_long) -1;
        }
    } else {
        npy_long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_long) -1;
        val = __Pyx_PyInt_As_npy_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_long");
    return (npy_long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_long");
    return (npy_long) -1;
}

/* CIntFromPy */
    static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
    static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *x) {
    const char neg_one = (char) ((char) 0 - (char) 1), const_zero = (char) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(char) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(char, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (char) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (char) 0;
                case  1: __PYX_VERIFY_RETURN_INT(char, digit, digits[0])
                case 2:
                    if (8 * sizeof(char) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) >= 2 * PyLong_SHIFT) {
                            return (char) (((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(char) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) >= 3 * PyLong_SHIFT) {
                            return (char) (((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(char) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) >= 4 * PyLong_SHIFT) {
                            return (char) (((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (char) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(char) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(char) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (char) 0;
                case -1: __PYX_VERIFY_RETURN_INT(char, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(char,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(char) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 2 * PyLong_SHIFT) {
                            return (char) (((char)-1)*(((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(char) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 2 * PyLong_SHIFT) {
                            return (char) ((((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(char) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 3 * PyLong_SHIFT) {
                            return (char) (((char)-1)*(((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(char) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 3 * PyLong_SHIFT) {
                            return (char) ((((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(char) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 4 * PyLong_SHIFT) {
                            return (char) (((char)-1)*(((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(char) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(char) - 1 > 4 * PyLong_SHIFT) {
                            return (char) ((((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(char) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(char) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(char, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            char val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (char) -1;
        }
    } else {
        char val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (char) -1;
        val = __Pyx_PyInt_As_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to char");
    return (char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to char");
    return (char) -1;
}

/* FetchCommonType */
    static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* PyObjectGetMethod */
    static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
    static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* CoroutineBase */
    #include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
    static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
    #ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
    static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CStringEquals */
    static CYTHON_INLINE int __Pyx_StrEq(const char *s1, const char *s2) {
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    return *s1 == *s2;
}

/* CheckBinaryVersion */
    static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
    static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
